=== modified file '.pc/10-fix-gcc4.3.patch/src/connectionsocks5proxy.cpp'
--- .pc/10-fix-gcc4.3.patch/src/connectionsocks5proxy.cpp	2014-01-16 01:11:18 +0000
+++ .pc/10-fix-gcc4.3.patch/src/connectionsocks5proxy.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file '.pc/10-fix-gcc4.3.patch/src/tests/tag/tag_perf.cpp'
--- .pc/10-fix-gcc4.3.patch/src/tests/tag/tag_perf.cpp	2014-01-16 01:11:18 +0000
+++ .pc/10-fix-gcc4.3.patch/src/tests/tag/tag_perf.cpp	2014-01-16 10:42:06 +0000
@@ -55,7 +55,7 @@
 
 static void randomize( const int size )
 {
-  srand( time(NULL) );
+  srand( time( 0 ) );
   for (int i = 0; i < size-1; ++i)
   {
     values[i] = rand() % 96 + 32;

=== modified file '.pc/10-fix-gcc4.3.patch/src/tlsgnutlsbase.cpp'
--- .pc/10-fix-gcc4.3.patch/src/tlsgnutlsbase.cpp	2014-01-16 01:11:18 +0000
+++ .pc/10-fix-gcc4.3.patch/src/tlsgnutlsbase.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -19,6 +19,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
+#include <cstdio>
 
 namespace gloox
 {
@@ -97,12 +98,13 @@
     gnutls_bye( *m_session, GNUTLS_SHUT_RDWR );
     gnutls_db_remove_session( *m_session );
     gnutls_credentials_clear( *m_session );
-    if( m_secure )
+    if( m_session )
       gnutls_deinit( *m_session );
 
+    delete m_session;
+
     m_secure = false;
     m_valid = false;
-    delete m_session;
     m_session = 0;
     m_session = new gnutls_session_t;
     m_handler = handler;
@@ -139,6 +141,28 @@
     return true;
   }
 
+  bool GnuTLSBase::hasChannelBinding() const
+  {
+#ifdef HAVE_GNUTLS_SESSION_CHANNEL_BINDING
+    return true;
+#else
+    return false;
+#endif
+  }
+
+  const std::string GnuTLSBase::channelBinding() const
+  {
+#ifdef HAVE_GNUTLS_SESSION_CHANNEL_BINDING
+    gnutls_datum_t cb;
+    int rc;
+    rc = gnutls_session_channel_binding( *m_session, GNUTLS_CB_TLS_UNIQUE, &cb );
+    if( !rc )
+      return std::string( (char*)cb.data, cb.size );
+    else
+#endif
+      return EmptyString;
+  }
+
   ssize_t GnuTLSBase::pullFunc( void* data, size_t len )
   {
     ssize_t cpy = ( len > m_recvBuffer.length() ) ? ( m_recvBuffer.length() ) : ( len );

=== modified file 'ChangeLog'
--- ChangeLog	2010-01-17 13:05:04 +0000
+++ ChangeLog	2014-01-16 10:42:06 +0000
@@ -1,5 +1,124 @@
+v1.0.9 -- 15 Oct 2013
+---------------------
+- changed colon to dash in uid generation to possibly fix #191
+- added Channel Binding (needed for SASL SCRAM-SHA-1-PLUS) to SChannel on win32 (untested)
+- fixed SCRAM-SHA-1-PLUS
+
+
+
+v1.0.8 -- 15 Oct 2013
+---------------------
+- ConnectionTLS: make stacked TLS/SSL connections work again with HTTP proxies
+- added SASL SCRAM-SHA-1/SCRAM-SHA-1-PLUS authentication mechanisms (GnuTLS & OpenSSL only) (#201)
+- properly seed the RNG
+- SHA::hex(): finalize() only once
+
+
+
+v1.0.7.1 -- 11 Oct 2013
+---------------------
+- fixed/updated the win32 project files
+
+
+
+v1.0.7 -- 11 Oct 2013
+---------------------
+- added Jingle (XEP-0166)
+- added Jingle ICE-UDP Transport (XEP-0176)
+- added Jingle File Transfer (XEP-0234)
+- fixed compilation in iOS7 SDK (thanks to Kurt Vermeersch)
+- fixed bug in stanza handling/counting related to Stream Management (patch by Norbert Riedlin)
+- added protected ClientBase::stanzasSent() to return sent stanzas (if Stream Management enabled)
+
+
+
+v1.0.6 -- 04 Sep 2013
+---------------------
+- ClientBase: removed check for empty message body --> messages of type chat with empty bodies will be passed on to listeners - required for Message Carbons
+- MessageSession: removed check for empty message body --> messages of type chat with empty bodies will be passed on to listeners - required for Message Carbons
+- don't send presence after stream resumption
+- added ClientBase::sendQueue()
+- documentation updates and fixes
+
+
+
+v1.0.5 -- 02 Sep 2013
+---------------------
+- added support for Stanza Forwarding (XEP-0297)
+- added support for Message Carbons (XEP-0280)
+
+
+
+v1.0.4 -- 30 Aug 2013
+---------------------
+- added support for Stream Management (XEP-0198)
+- Fix some iterator usage for portability related to erase (patch by Daniel Bowen)
+- Ensure setting a connection does not leave a deleted value in the member variable for a time (patch by Daniel Bowen)
+- Add operator< and relatives to JID so that it can be in a map (patch by Daniel Bowen)
+- Sandboxing on Apple doesn't like getprotobyname (patch by Daniel Bowen)
+- MessageSession::send(): removed default argument of 2nd parameter to remove ambiguity of MS::send( string ) (#206) (source incompatible!)
+- VCard: renamed setPhoto( string ) to setPhotoUri( string ) (#166) (source and binary incompatible)
+
+
+
+v1.0.3 -- 22 Jul 2013
+---------------------
+- Changed license to GPLv3
+- removed space from VS project name (--> gloox-1.0)
+- VCardUpdate: fixed handling of empty hash (#203)
+- VCardUpdate: added hasPhoto() to inidicate whether there was a photo tag (#203)
+- compilation fixed when using getaddrinfo (patch by Roy van Dam)
+- Receipt: recognize id attribute (patch by Dídac Pérez) (#208)
+- MessageSession: added MS::send( string& ) to properly provide a base for MUCMS::send( string& ) (#206)
+- really fixed memory leak in prep::idna()
+- gloox.vcproj: removed not-yet-present tlsgnutlsserver.cpp/.h
+
+
+
+v1.0.2 -- 05 Jul 2013
+---------------------
+- SOCKS5Bytestream: Don't wait for incoming data, notify about open stream immediately upon
+connection (patch by Erik Horemans)
+- fixed/updated Code::Blocks and VS project files (fixes #197, #198)
+- fixed memory leak in ClientBase (fixes #204)
+- fixed memory leak in prep::idna()
+
+
+
+v1.0.1 -- 29 Jun 2013
+---------------------
+- Added support for Serverless Messaging (XEP-0174)
+- TLSOpenSSLServer: compilation fix
+- don't bail on DNS TCP queries
+- fixed µs timeout value (now defaults to 1.000.000)
+- omit port in initial greeting (usually -1 anyway)
+- fixed SHA1 hashes of 55 byte strings (#164)
+- fixed CFLAGS and LIBS in pkg-config file (#163)
+- fixed SOCKS5Bytestream double close notification
+- tell gcrypt that we're using pthreads (if available)
+- ClientBase: send IQ error response for unsupported features
+- ClientBase: fixed potential infinite loop on IQ error
+- ClientBase: fixed NTLM auth
+- ClientBase, SEF: mutex-protected SE handling
+- PubSub: added 'subscribe & configure'
+- PubSub: added optional subid
+- SOCKS5BytestreamServer: expose local socket
+- RosterManager: don't use string-comparison on JIDs; use JID class
+- NonSASLAuth: fixed resource usage by deprecating ClientBase::m_selectedResource
+- InBandBytestream: don't call handler in dtor
+- util: fixed long2string()
+- fixed a few leaks in GnutTLS client code (#181)
+- VCard: made getters const (#186) (binary-incompatible change!)
+- PubsubManager: fixed using wrong Tag (#190)
+- Search: fixed search() (#193)
+- DNS: fix socket leak if no network connection is available (#192)
+- PubsubManager: unconditionally call handleItemPublication() (#194)
+- configure: Added -lgcrypt (dependency of GNUTLS)
+
+
+
 v1.0 -- 31 Oct 2009
--------------------
+---------------------
 
 general changes and additions:
 - XEP-0020 (Feature Negotiation) wrapper

=== modified file 'Doxyfile'
--- Doxyfile	2010-01-17 13:05:04 +0000
+++ Doxyfile	2014-01-16 10:42:06 +0000
@@ -4,7 +4,7 @@
 # Project related configuration options
 #---------------------------------------------------------------------------
 PROJECT_NAME           = gloox
-PROJECT_NUMBER         = 1.0
+PROJECT_NUMBER         = 1.0.9
 OUTPUT_DIRECTORY       = ./api/
 CREATE_SUBDIRS         = NO
 OUTPUT_LANGUAGE        = English
@@ -24,7 +24,7 @@
 INHERIT_DOCS           = YES
 SEPARATE_MEMBER_PAGES  = NO
 TAB_SIZE               = 8
-ALIASES                =
+ALIASES                = xep{1}="<a href=\"http://xmpp.org/extensions/xep-\1.html\">XEP-\1</a>"
 OPTIMIZE_OUTPUT_FOR_C  = NO
 OPTIMIZE_OUTPUT_JAVA   = NO
 BUILTIN_STL_SUPPORT    = YES
@@ -190,7 +190,8 @@
                          HAVE_OPENSSL \
                          HAVE_ZLIB \
                          HAVE_WINTLS \
-                         HAVE_WINDNS
+                         HAVE_WINDNS \
+                         HAVE_MDNS
 EXPAND_AS_DEFINED      =
 SKIP_FUNCTION_MACROS   = YES
 #---------------------------------------------------------------------------

=== modified file 'LICENSE'
--- LICENSE	2005-12-12 00:24:17 +0000
+++ LICENSE	2014-01-16 10:42:06 +0000
@@ -1,289 +1,630 @@
-An exception to the GPL to allow linking gloox against the OpenSSL library
+An exception to the GPLv3 below to allow linking gloox against the OpenSSL library
 can be found at the bottom of this file.
 
-
-		    GNU GENERAL PUBLIC LICENSE
-		       Version 2, June 1991
-
- Copyright (C) 1989, 1991 Free Software Foundation, Inc.
-                 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+  
+  GNU GENERAL PUBLIC LICENSE
+                       Version 3, 29 June 2007
+
+ Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>
  Everyone is permitted to copy and distribute verbatim copies
  of this license document, but changing it is not allowed.
 
-			    Preamble
-
-  The licenses for most software are designed to take away your
-freedom to share and change it.  By contrast, the GNU General Public
-License is intended to guarantee your freedom to share and change free
-software--to make sure the software is free for all its users.  This
-General Public License applies to most of the Free Software
-Foundation's software and to any other program whose authors commit to
-using it.  (Some other Free Software Foundation software is covered by
-the GNU Library General Public License instead.)  You can apply it to
+                            Preamble
+
+  The GNU General Public License is a free, copyleft license for
+software and other kinds of works.
+
+  The licenses for most software and other practical works are designed
+to take away your freedom to share and change the works.  By contrast,
+the GNU General Public License is intended to guarantee your freedom to
+share and change all versions of a program--to make sure it remains free
+software for all its users.  We, the Free Software Foundation, use the
+GNU General Public License for most of our software; it applies also to
+any other work released this way by its authors.  You can apply it to
 your programs, too.
 
   When we speak of free software, we are referring to freedom, not
 price.  Our General Public Licenses are designed to make sure that you
 have the freedom to distribute copies of free software (and charge for
-this service if you wish), that you receive source code or can get it
-if you want it, that you can change the software or use pieces of it
-in new free programs; and that you know you can do these things.
+them if you wish), that you receive source code or can get it if you
+want it, that you can change the software or use pieces of it in new
+free programs, and that you know you can do these things.
 
-  To protect your rights, we need to make restrictions that forbid
-anyone to deny you these rights or to ask you to surrender the rights.
-These restrictions translate to certain responsibilities for you if you
-distribute copies of the software, or if you modify it.
+  To protect your rights, we need to prevent others from denying you
+these rights or asking you to surrender the rights.  Therefore, you have
+certain responsibilities if you distribute copies of the software, or if
+you modify it: responsibilities to respect the freedom of others.
 
   For example, if you distribute copies of such a program, whether
-gratis or for a fee, you must give the recipients all the rights that
-you have.  You must make sure that they, too, receive or can get the
-source code.  And you must show them these terms so they know their
-rights.
-
-  We protect your rights with two steps: (1) copyright the software, and
-(2) offer you this license which gives you legal permission to copy,
-distribute and/or modify the software.
-
-  Also, for each author's protection and ours, we want to make certain
-that everyone understands that there is no warranty for this free
-software.  If the software is modified by someone else and passed on, we
-want its recipients to know that what they have is not the original, so
-that any problems introduced by others will not reflect on the original
-authors' reputations.
-
-  Finally, any free program is threatened constantly by software
-patents.  We wish to avoid the danger that redistributors of a free
-program will individually obtain patent licenses, in effect making the
-program proprietary.  To prevent this, we have made it clear that any
-patent must be licensed for everyone's free use or not licensed at all.
+gratis or for a fee, you must pass on to the recipients the same
+freedoms that you received.  You must make sure that they, too, receive
+or can get the source code.  And you must show them these terms so they
+know their rights.
+
+  Developers that use the GNU GPL protect your rights with two steps:
+(1) assert copyright on the software, and (2) offer you this License
+giving you legal permission to copy, distribute and/or modify it.
+
+  For the developers' and authors' protection, the GPL clearly explains
+that there is no warranty for this free software.  For both users' and
+authors' sake, the GPL requires that modified versions be marked as
+changed, so that their problems will not be attributed erroneously to
+authors of previous versions.
+
+  Some devices are designed to deny users access to install or run
+modified versions of the software inside them, although the manufacturer
+can do so.  This is fundamentally incompatible with the aim of
+protecting users' freedom to change the software.  The systematic
+pattern of such abuse occurs in the area of products for individuals to
+use, which is precisely where it is most unacceptable.  Therefore, we
+have designed this version of the GPL to prohibit the practice for those
+products.  If such problems arise substantially in other domains, we
+stand ready to extend this provision to those domains in future versions
+of the GPL, as needed to protect the freedom of users.
+
+  Finally, every program is threatened constantly by software patents.
+States should not allow patents to restrict development and use of
+software on general-purpose computers, but in those that do, we wish to
+avoid the special danger that patents applied to a free program could
+make it effectively proprietary.  To prevent this, the GPL assures that
+patents cannot be used to render the program non-free.
 
   The precise terms and conditions for copying, distribution and
 modification follow.
-
-		    GNU GENERAL PUBLIC LICENSE
-   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
-
-  0. This License applies to any program or other work which contains
-a notice placed by the copyright holder saying it may be distributed
-under the terms of this General Public License.  The "Program", below,
-refers to any such program or work, and a "work based on the Program"
-means either the Program or any derivative work under copyright law:
-that is to say, a work containing the Program or a portion of it,
-either verbatim or with modifications and/or translated into another
-language.  (Hereinafter, translation is included without limitation in
-the term "modification".)  Each licensee is addressed as "you".
-
-Activities other than copying, distribution and modification are not
-covered by this License; they are outside its scope.  The act of
-running the Program is not restricted, and the output from the Program
-is covered only if its contents constitute a work based on the
-Program (independent of having been made by running the Program).
-Whether that is true depends on what the Program does.
-
-  1. You may copy and distribute verbatim copies of the Program's
-source code as you receive it, in any medium, provided that you
-conspicuously and appropriately publish on each copy an appropriate
-copyright notice and disclaimer of warranty; keep intact all the
-notices that refer to this License and to the absence of any warranty;
-and give any other recipients of the Program a copy of this License
-along with the Program.
-
-You may charge a fee for the physical act of transferring a copy, and
-you may at your option offer warranty protection in exchange for a fee.
-
-  2. You may modify your copy or copies of the Program or any portion
-of it, thus forming a work based on the Program, and copy and
-distribute such modifications or work under the terms of Section 1
-above, provided that you also meet all of these conditions:
-
-    a) You must cause the modified files to carry prominent notices
-    stating that you changed the files and the date of any change.
-
-    b) You must cause any work that you distribute or publish, that in
-    whole or in part contains or is derived from the Program or any
-    part thereof, to be licensed as a whole at no charge to all third
-    parties under the terms of this License.
-
-    c) If the modified program normally reads commands interactively
-    when run, you must cause it, when started running for such
-    interactive use in the most ordinary way, to print or display an
-    announcement including an appropriate copyright notice and a
-    notice that there is no warranty (or else, saying that you provide
-    a warranty) and that users may redistribute the program under
-    these conditions, and telling the user how to view a copy of this
-    License.  (Exception: if the Program itself is interactive but
-    does not normally print such an announcement, your work based on
-    the Program is not required to print an announcement.)
-
-These requirements apply to the modified work as a whole.  If
-identifiable sections of that work are not derived from the Program,
-and can be reasonably considered independent and separate works in
-themselves, then this License, and its terms, do not apply to those
-sections when you distribute them as separate works.  But when you
-distribute the same sections as part of a whole which is a work based
-on the Program, the distribution of the whole must be on the terms of
-this License, whose permissions for other licensees extend to the
-entire whole, and thus to each and every part regardless of who wrote it.
-
-Thus, it is not the intent of this section to claim rights or contest
-your rights to work written entirely by you; rather, the intent is to
-exercise the right to control the distribution of derivative or
-collective works based on the Program.
-
-In addition, mere aggregation of another work not based on the Program
-with the Program (or with a work based on the Program) on a volume of
-a storage or distribution medium does not bring the other work under
-the scope of this License.
-
-  3. You may copy and distribute the Program (or a work based on it,
-under Section 2) in object code or executable form under the terms of
-Sections 1 and 2 above provided that you also do one of the following:
-
-    a) Accompany it with the complete corresponding machine-readable
-    source code, which must be distributed under the terms of Sections
-    1 and 2 above on a medium customarily used for software interchange; or,
-
-    b) Accompany it with a written offer, valid for at least three
-    years, to give any third party, for a charge no more than your
-    cost of physically performing source distribution, a complete
-    machine-readable copy of the corresponding source code, to be
-    distributed under the terms of Sections 1 and 2 above on a medium
-    customarily used for software interchange; or,
-
-    c) Accompany it with the information you received as to the offer
-    to distribute corresponding source code.  (This alternative is
-    allowed only for noncommercial distribution and only if you
-    received the program in object code or executable form with such
-    an offer, in accord with Subsection b above.)
-
-The source code for a work means the preferred form of the work for
-making modifications to it.  For an executable work, complete source
-code means all the source code for all modules it contains, plus any
-associated interface definition files, plus the scripts used to
-control compilation and installation of the executable.  However, as a
-special exception, the source code distributed need not include
-anything that is normally distributed (in either source or binary
-form) with the major components (compiler, kernel, and so on) of the
-operating system on which the executable runs, unless that component
-itself accompanies the executable.
-
-If distribution of executable or object code is made by offering
-access to copy from a designated place, then offering equivalent
-access to copy the source code from the same place counts as
-distribution of the source code, even though third parties are not
-compelled to copy the source along with the object code.
-
-  4. You may not copy, modify, sublicense, or distribute the Program
-except as expressly provided under this License.  Any attempt
-otherwise to copy, modify, sublicense or distribute the Program is
-void, and will automatically terminate your rights under this License.
-However, parties who have received copies, or rights, from you under
-this License will not have their licenses terminated so long as such
-parties remain in full compliance.
-
-  5. You are not required to accept this License, since you have not
-signed it.  However, nothing else grants you permission to modify or
-distribute the Program or its derivative works.  These actions are
-prohibited by law if you do not accept this License.  Therefore, by
-modifying or distributing the Program (or any work based on the
-Program), you indicate your acceptance of this License to do so, and
-all its terms and conditions for copying, distributing or modifying
-the Program or works based on it.
-
-  6. Each time you redistribute the Program (or any work based on the
-Program), the recipient automatically receives a license from the
-original licensor to copy, distribute or modify the Program subject to
-these terms and conditions.  You may not impose any further
-restrictions on the recipients' exercise of the rights granted herein.
-You are not responsible for enforcing compliance by third parties to
+
+                       TERMS AND CONDITIONS
+
+  0. Definitions.
+
+  "This License" refers to version 3 of the GNU General Public License.
+
+  "Copyright" also means copyright-like laws that apply to other kinds of
+works, such as semiconductor masks.
+
+  "The Program" refers to any copyrightable work licensed under this
+License.  Each licensee is addressed as "you".  "Licensees" and
+"recipients" may be individuals or organizations.
+
+  To "modify" a work means to copy from or adapt all or part of the work
+in a fashion requiring copyright permission, other than the making of an
+exact copy.  The resulting work is called a "modified version" of the
+earlier work or a work "based on" the earlier work.
+
+  A "covered work" means either the unmodified Program or a work based
+on the Program.
+
+  To "propagate" a work means to do anything with it that, without
+permission, would make you directly or secondarily liable for
+infringement under applicable copyright law, except executing it on a
+computer or modifying a private copy.  Propagation includes copying,
+distribution (with or without modification), making available to the
+public, and in some countries other activities as well.
+
+  To "convey" a work means any kind of propagation that enables other
+parties to make or receive copies.  Mere interaction with a user through
+a computer network, with no transfer of a copy, is not conveying.
+
+  An interactive user interface displays "Appropriate Legal Notices"
+to the extent that it includes a convenient and prominently visible
+feature that (1) displays an appropriate copyright notice, and (2)
+tells the user that there is no warranty for the work (except to the
+extent that warranties are provided), that licensees may convey the
+work under this License, and how to view a copy of this License.  If
+the interface presents a list of user commands or options, such as a
+menu, a prominent item in the list meets this criterion.
+
+  1. Source Code.
+
+  The "source code" for a work means the preferred form of the work
+for making modifications to it.  "Object code" means any non-source
+form of a work.
+
+  A "Standard Interface" means an interface that either is an official
+standard defined by a recognized standards body, or, in the case of
+interfaces specified for a particular programming language, one that
+is widely used among developers working in that language.
+
+  The "System Libraries" of an executable work include anything, other
+than the work as a whole, that (a) is included in the normal form of
+packaging a Major Component, but which is not part of that Major
+Component, and (b) serves only to enable use of the work with that
+Major Component, or to implement a Standard Interface for which an
+implementation is available to the public in source code form.  A
+"Major Component", in this context, means a major essential component
+(kernel, window system, and so on) of the specific operating system
+(if any) on which the executable work runs, or a compiler used to
+produce the work, or an object code interpreter used to run it.
+
+  The "Corresponding Source" for a work in object code form means all
+the source code needed to generate, install, and (for an executable
+work) run the object code and to modify the work, including scripts to
+control those activities.  However, it does not include the work's
+System Libraries, or general-purpose tools or generally available free
+programs which are used unmodified in performing those activities but
+which are not part of the work.  For example, Corresponding Source
+includes interface definition files associated with source files for
+the work, and the source code for shared libraries and dynamically
+linked subprograms that the work is specifically designed to require,
+such as by intimate data communication or control flow between those
+subprograms and other parts of the work.
+
+  The Corresponding Source need not include anything that users
+can regenerate automatically from other parts of the Corresponding
+Source.
+
+  The Corresponding Source for a work in source code form is that
+same work.
+
+  2. Basic Permissions.
+
+  All rights granted under this License are granted for the term of
+copyright on the Program, and are irrevocable provided the stated
+conditions are met.  This License explicitly affirms your unlimited
+permission to run the unmodified Program.  The output from running a
+covered work is covered by this License only if the output, given its
+content, constitutes a covered work.  This License acknowledges your
+rights of fair use or other equivalent, as provided by copyright law.
+
+  You may make, run and propagate covered works that you do not
+convey, without conditions so long as your license otherwise remains
+in force.  You may convey covered works to others for the sole purpose
+of having them make modifications exclusively for you, or provide you
+with facilities for running those works, provided that you comply with
+the terms of this License in conveying all material for which you do
+not control copyright.  Those thus making or running the covered works
+for you must do so exclusively on your behalf, under your direction
+and control, on terms that prohibit them from making any copies of
+your copyrighted material outside their relationship with you.
+
+  Conveying under any other circumstances is permitted solely under
+the conditions stated below.  Sublicensing is not allowed; section 10
+makes it unnecessary.
+
+  3. Protecting Users' Legal Rights From Anti-Circumvention Law.
+
+  No covered work shall be deemed part of an effective technological
+measure under any applicable law fulfilling obligations under article
+11 of the WIPO copyright treaty adopted on 20 December 1996, or
+similar laws prohibiting or restricting circumvention of such
+measures.
+
+  When you convey a covered work, you waive any legal power to forbid
+circumvention of technological measures to the extent such circumvention
+is effected by exercising rights under this License with respect to
+the covered work, and you disclaim any intention to limit operation or
+modification of the work as a means of enforcing, against the work's
+users, your or third parties' legal rights to forbid circumvention of
+technological measures.
+
+  4. Conveying Verbatim Copies.
+
+  You may convey verbatim copies of the Program's source code as you
+receive it, in any medium, provided that you conspicuously and
+appropriately publish on each copy an appropriate copyright notice;
+keep intact all notices stating that this License and any
+non-permissive terms added in accord with section 7 apply to the code;
+keep intact all notices of the absence of any warranty; and give all
+recipients a copy of this License along with the Program.
+
+  You may charge any price or no price for each copy that you convey,
+and you may offer support or warranty protection for a fee.
+
+  5. Conveying Modified Source Versions.
+
+  You may convey a work based on the Program, or the modifications to
+produce it from the Program, in the form of source code under the
+terms of section 4, provided that you also meet all of these conditions:
+
+    a) The work must carry prominent notices stating that you modified
+    it, and giving a relevant date.
+
+    b) The work must carry prominent notices stating that it is
+    released under this License and any conditions added under section
+    7.  This requirement modifies the requirement in section 4 to
+    "keep intact all notices".
+
+    c) You must license the entire work, as a whole, under this
+    License to anyone who comes into possession of a copy.  This
+    License will therefore apply, along with any applicable section 7
+    additional terms, to the whole of the work, and all its parts,
+    regardless of how they are packaged.  This License gives no
+    permission to license the work in any other way, but it does not
+    invalidate such permission if you have separately received it.
+
+    d) If the work has interactive user interfaces, each must display
+    Appropriate Legal Notices; however, if the Program has interactive
+    interfaces that do not display Appropriate Legal Notices, your
+    work need not make them do so.
+
+  A compilation of a covered work with other separate and independent
+works, which are not by their nature extensions of the covered work,
+and which are not combined with it such as to form a larger program,
+in or on a volume of a storage or distribution medium, is called an
+"aggregate" if the compilation and its resulting copyright are not
+used to limit the access or legal rights of the compilation's users
+beyond what the individual works permit.  Inclusion of a covered work
+in an aggregate does not cause this License to apply to the other
+parts of the aggregate.
+
+  6. Conveying Non-Source Forms.
+
+  You may convey a covered work in object code form under the terms
+of sections 4 and 5, provided that you also convey the
+machine-readable Corresponding Source under the terms of this License,
+in one of these ways:
+
+    a) Convey the object code in, or embodied in, a physical product
+    (including a physical distribution medium), accompanied by the
+    Corresponding Source fixed on a durable physical medium
+    customarily used for software interchange.
+
+    b) Convey the object code in, or embodied in, a physical product
+    (including a physical distribution medium), accompanied by a
+    written offer, valid for at least three years and valid for as
+    long as you offer spare parts or customer support for that product
+    model, to give anyone who possesses the object code either (1) a
+    copy of the Corresponding Source for all the software in the
+    product that is covered by this License, on a durable physical
+    medium customarily used for software interchange, for a price no
+    more than your reasonable cost of physically performing this
+    conveying of source, or (2) access to copy the
+    Corresponding Source from a network server at no charge.
+
+    c) Convey individual copies of the object code with a copy of the
+    written offer to provide the Corresponding Source.  This
+    alternative is allowed only occasionally and noncommercially, and
+    only if you received the object code with such an offer, in accord
+    with subsection 6b.
+
+    d) Convey the object code by offering access from a designated
+    place (gratis or for a charge), and offer equivalent access to the
+    Corresponding Source in the same way through the same place at no
+    further charge.  You need not require recipients to copy the
+    Corresponding Source along with the object code.  If the place to
+    copy the object code is a network server, the Corresponding Source
+    may be on a different server (operated by you or a third party)
+    that supports equivalent copying facilities, provided you maintain
+    clear directions next to the object code saying where to find the
+    Corresponding Source.  Regardless of what server hosts the
+    Corresponding Source, you remain obligated to ensure that it is
+    available for as long as needed to satisfy these requirements.
+
+    e) Convey the object code using peer-to-peer transmission, provided
+    you inform other peers where the object code and Corresponding
+    Source of the work are being offered to the general public at no
+    charge under subsection 6d.
+
+  A separable portion of the object code, whose source code is excluded
+from the Corresponding Source as a System Library, need not be
+included in conveying the object code work.
+
+  A "User Product" is either (1) a "consumer product", which means any
+tangible personal property which is normally used for personal, family,
+or household purposes, or (2) anything designed or sold for incorporation
+into a dwelling.  In determining whether a product is a consumer product,
+doubtful cases shall be resolved in favor of coverage.  For a particular
+product received by a particular user, "normally used" refers to a
+typical or common use of that class of product, regardless of the status
+of the particular user or of the way in which the particular user
+actually uses, or expects or is expected to use, the product.  A product
+is a consumer product regardless of whether the product has substantial
+commercial, industrial or non-consumer uses, unless such uses represent
+the only significant mode of use of the product.
+
+  "Installation Information" for a User Product means any methods,
+procedures, authorization keys, or other information required to install
+and execute modified versions of a covered work in that User Product from
+a modified version of its Corresponding Source.  The information must
+suffice to ensure that the continued functioning of the modified object
+code is in no case prevented or interfered with solely because
+modification has been made.
+
+  If you convey an object code work under this section in, or with, or
+specifically for use in, a User Product, and the conveying occurs as
+part of a transaction in which the right of possession and use of the
+User Product is transferred to the recipient in perpetuity or for a
+fixed term (regardless of how the transaction is characterized), the
+Corresponding Source conveyed under this section must be accompanied
+by the Installation Information.  But this requirement does not apply
+if neither you nor any third party retains the ability to install
+modified object code on the User Product (for example, the work has
+been installed in ROM).
+
+  The requirement to provide Installation Information does not include a
+requirement to continue to provide support service, warranty, or updates
+for a work that has been modified or installed by the recipient, or for
+the User Product in which it has been modified or installed.  Access to a
+network may be denied when the modification itself materially and
+adversely affects the operation of the network or violates the rules and
+protocols for communication across the network.
+
+  Corresponding Source conveyed, and Installation Information provided,
+in accord with this section must be in a format that is publicly
+documented (and with an implementation available to the public in
+source code form), and must require no special password or key for
+unpacking, reading or copying.
+
+  7. Additional Terms.
+
+  "Additional permissions" are terms that supplement the terms of this
+License by making exceptions from one or more of its conditions.
+Additional permissions that are applicable to the entire Program shall
+be treated as though they were included in this License, to the extent
+that they are valid under applicable law.  If additional permissions
+apply only to part of the Program, that part may be used separately
+under those permissions, but the entire Program remains governed by
+this License without regard to the additional permissions.
+
+  When you convey a copy of a covered work, you may at your option
+remove any additional permissions from that copy, or from any part of
+it.  (Additional permissions may be written to require their own
+removal in certain cases when you modify the work.)  You may place
+additional permissions on material, added by you to a covered work,
+for which you have or can give appropriate copyright permission.
+
+  Notwithstanding any other provision of this License, for material you
+add to a covered work, you may (if authorized by the copyright holders of
+that material) supplement the terms of this License with terms:
+
+    a) Disclaiming warranty or limiting liability differently from the
+    terms of sections 15 and 16 of this License; or
+
+    b) Requiring preservation of specified reasonable legal notices or
+    author attributions in that material or in the Appropriate Legal
+    Notices displayed by works containing it; or
+
+    c) Prohibiting misrepresentation of the origin of that material, or
+    requiring that modified versions of such material be marked in
+    reasonable ways as different from the original version; or
+
+    d) Limiting the use for publicity purposes of names of licensors or
+    authors of the material; or
+
+    e) Declining to grant rights under trademark law for use of some
+    trade names, trademarks, or service marks; or
+
+    f) Requiring indemnification of licensors and authors of that
+    material by anyone who conveys the material (or modified versions of
+    it) with contractual assumptions of liability to the recipient, for
+    any liability that these contractual assumptions directly impose on
+    those licensors and authors.
+
+  All other non-permissive additional terms are considered "further
+restrictions" within the meaning of section 10.  If the Program as you
+received it, or any part of it, contains a notice stating that it is
+governed by this License along with a term that is a further
+restriction, you may remove that term.  If a license document contains
+a further restriction but permits relicensing or conveying under this
+License, you may add to a covered work material governed by the terms
+of that license document, provided that the further restriction does
+not survive such relicensing or conveying.
+
+  If you add terms to a covered work in accord with this section, you
+must place, in the relevant source files, a statement of the
+additional terms that apply to those files, or a notice indicating
+where to find the applicable terms.
+
+  Additional terms, permissive or non-permissive, may be stated in the
+form of a separately written license, or stated as exceptions;
+the above requirements apply either way.
+
+  8. Termination.
+
+  You may not propagate or modify a covered work except as expressly
+provided under this License.  Any attempt otherwise to propagate or
+modify it is void, and will automatically terminate your rights under
+this License (including any patent licenses granted under the third
+paragraph of section 11).
+
+  However, if you cease all violation of this License, then your
+license from a particular copyright holder is reinstated (a)
+provisionally, unless and until the copyright holder explicitly and
+finally terminates your license, and (b) permanently, if the copyright
+holder fails to notify you of the violation by some reasonable means
+prior to 60 days after the cessation.
+
+  Moreover, your license from a particular copyright holder is
+reinstated permanently if the copyright holder notifies you of the
+violation by some reasonable means, this is the first time you have
+received notice of violation of this License (for any work) from that
+copyright holder, and you cure the violation prior to 30 days after
+your receipt of the notice.
+
+  Termination of your rights under this section does not terminate the
+licenses of parties who have received copies or rights from you under
+this License.  If your rights have been terminated and not permanently
+reinstated, you do not qualify to receive new licenses for the same
+material under section 10.
+
+  9. Acceptance Not Required for Having Copies.
+
+  You are not required to accept this License in order to receive or
+run a copy of the Program.  Ancillary propagation of a covered work
+occurring solely as a consequence of using peer-to-peer transmission
+to receive a copy likewise does not require acceptance.  However,
+nothing other than this License grants you permission to propagate or
+modify any covered work.  These actions infringe copyright if you do
+not accept this License.  Therefore, by modifying or propagating a
+covered work, you indicate your acceptance of this License to do so.
+
+  10. Automatic Licensing of Downstream Recipients.
+
+  Each time you convey a covered work, the recipient automatically
+receives a license from the original licensors, to run, modify and
+propagate that work, subject to this License.  You are not responsible
+for enforcing compliance by third parties with this License.
+
+  An "entity transaction" is a transaction transferring control of an
+organization, or substantially all assets of one, or subdividing an
+organization, or merging organizations.  If propagation of a covered
+work results from an entity transaction, each party to that
+transaction who receives a copy of the work also receives whatever
+licenses to the work the party's predecessor in interest had or could
+give under the previous paragraph, plus a right to possession of the
+Corresponding Source of the work from the predecessor in interest, if
+the predecessor has it or can get it with reasonable efforts.
+
+  You may not impose any further restrictions on the exercise of the
+rights granted or affirmed under this License.  For example, you may
+not impose a license fee, royalty, or other charge for exercise of
+rights granted under this License, and you may not initiate litigation
+(including a cross-claim or counterclaim in a lawsuit) alleging that
+any patent claim is infringed by making, using, selling, offering for
+sale, or importing the Program or any portion of it.
+
+  11. Patents.
+
+  A "contributor" is a copyright holder who authorizes use under this
+License of the Program or a work on which the Program is based.  The
+work thus licensed is called the contributor's "contributor version".
+
+  A contributor's "essential patent claims" are all patent claims
+owned or controlled by the contributor, whether already acquired or
+hereafter acquired, that would be infringed by some manner, permitted
+by this License, of making, using, or selling its contributor version,
+but do not include claims that would be infringed only as a
+consequence of further modification of the contributor version.  For
+purposes of this definition, "control" includes the right to grant
+patent sublicenses in a manner consistent with the requirements of
 this License.
 
-  7. If, as a consequence of a court judgment or allegation of patent
-infringement or for any other reason (not limited to patent issues),
-conditions are imposed on you (whether by court order, agreement or
+  Each contributor grants you a non-exclusive, worldwide, royalty-free
+patent license under the contributor's essential patent claims, to
+make, use, sell, offer for sale, import and otherwise run, modify and
+propagate the contents of its contributor version.
+
+  In the following three paragraphs, a "patent license" is any express
+agreement or commitment, however denominated, not to enforce a patent
+(such as an express permission to practice a patent or covenant not to
+sue for patent infringement).  To "grant" such a patent license to a
+party means to make such an agreement or commitment not to enforce a
+patent against the party.
+
+  If you convey a covered work, knowingly relying on a patent license,
+and the Corresponding Source of the work is not available for anyone
+to copy, free of charge and under the terms of this License, through a
+publicly available network server or other readily accessible means,
+then you must either (1) cause the Corresponding Source to be so
+available, or (2) arrange to deprive yourself of the benefit of the
+patent license for this particular work, or (3) arrange, in a manner
+consistent with the requirements of this License, to extend the patent
+license to downstream recipients.  "Knowingly relying" means you have
+actual knowledge that, but for the patent license, your conveying the
+covered work in a country, or your recipient's use of the covered work
+in a country, would infringe one or more identifiable patents in that
+country that you have reason to believe are valid.
+
+  If, pursuant to or in connection with a single transaction or
+arrangement, you convey, or propagate by procuring conveyance of, a
+covered work, and grant a patent license to some of the parties
+receiving the covered work authorizing them to use, propagate, modify
+or convey a specific copy of the covered work, then the patent license
+you grant is automatically extended to all recipients of the covered
+work and works based on it.
+
+  A patent license is "discriminatory" if it does not include within
+the scope of its coverage, prohibits the exercise of, or is
+conditioned on the non-exercise of one or more of the rights that are
+specifically granted under this License.  You may not convey a covered
+work if you are a party to an arrangement with a third party that is
+in the business of distributing software, under which you make payment
+to the third party based on the extent of your activity of conveying
+the work, and under which the third party grants, to any of the
+parties who would receive the covered work from you, a discriminatory
+patent license (a) in connection with copies of the covered work
+conveyed by you (or copies made from those copies), or (b) primarily
+for and in connection with specific products or compilations that
+contain the covered work, unless you entered into that arrangement,
+or that patent license was granted, prior to 28 March 2007.
+
+  Nothing in this License shall be construed as excluding or limiting
+any implied license or other defenses to infringement that may
+otherwise be available to you under applicable patent law.
+
+  12. No Surrender of Others' Freedom.
+
+  If conditions are imposed on you (whether by court order, agreement or
 otherwise) that contradict the conditions of this License, they do not
-excuse you from the conditions of this License.  If you cannot
-distribute so as to satisfy simultaneously your obligations under this
-License and any other pertinent obligations, then as a consequence you
-may not distribute the Program at all.  For example, if a patent
-license would not permit royalty-free redistribution of the Program by
-all those who receive copies directly or indirectly through you, then
-the only way you could satisfy both it and this License would be to
-refrain entirely from distribution of the Program.
-
-If any portion of this section is held invalid or unenforceable under
-any particular circumstance, the balance of the section is intended to
-apply and the section as a whole is intended to apply in other
-circumstances.
-
-It is not the purpose of this section to induce you to infringe any
-patents or other property right claims or to contest validity of any
-such claims; this section has the sole purpose of protecting the
-integrity of the free software distribution system, which is
-implemented by public license practices.  Many people have made
-generous contributions to the wide range of software distributed
-through that system in reliance on consistent application of that
-system; it is up to the author/donor to decide if he or she is willing
-to distribute software through any other system and a licensee cannot
-impose that choice.
-
-This section is intended to make thoroughly clear what is believed to
-be a consequence of the rest of this License.
-
-  8. If the distribution and/or use of the Program is restricted in
-certain countries either by patents or by copyrighted interfaces, the
-original copyright holder who places the Program under this License
-may add an explicit geographical distribution limitation excluding
-those countries, so that distribution is permitted only in or among
-countries not thus excluded.  In such case, this License incorporates
-the limitation as if written in the body of this License.
-
-  9. The Free Software Foundation may publish revised and/or new versions
-of the General Public License from time to time.  Such new versions will
+excuse you from the conditions of this License.  If you cannot convey a
+covered work so as to satisfy simultaneously your obligations under this
+License and any other pertinent obligations, then as a consequence you may
+not convey it at all.  For example, if you agree to terms that obligate you
+to collect a royalty for further conveying from those to whom you convey
+the Program, the only way you could satisfy both those terms and this
+License would be to refrain entirely from conveying the Program.
+
+  13. Use with the GNU Affero General Public License.
+
+  Notwithstanding any other provision of this License, you have
+permission to link or combine any covered work with a work licensed
+under version 3 of the GNU Affero General Public License into a single
+combined work, and to convey the resulting work.  The terms of this
+License will continue to apply to the part which is the covered work,
+but the special requirements of the GNU Affero General Public License,
+section 13, concerning interaction through a network will apply to the
+combination as such.
+
+  14. Revised Versions of this License.
+
+  The Free Software Foundation may publish revised and/or new versions of
+the GNU General Public License from time to time.  Such new versions will
 be similar in spirit to the present version, but may differ in detail to
 address new problems or concerns.
 
-Each version is given a distinguishing version number.  If the Program
-specifies a version number of this License which applies to it and "any
-later version", you have the option of following the terms and conditions
-either of that version or of any later version published by the Free
-Software Foundation.  If the Program does not specify a version number of
-this License, you may choose any version ever published by the Free Software
-Foundation.
-
-  10. If you wish to incorporate parts of the Program into other free
-programs whose distribution conditions are different, write to the author
-to ask for permission.  For software which is copyrighted by the Free
-Software Foundation, write to the Free Software Foundation; we sometimes
-make exceptions for this.  Our decision will be guided by the two goals
-of preserving the free status of all derivatives of our free software and
-of promoting the sharing and reuse of software generally.
-
-			    NO WARRANTY
-
-  11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED
-OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS
-TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE
-PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
-REPAIR OR CORRECTION.
-
-  12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,
-INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING
-OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED
-TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY
-YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
-PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
-POSSIBILITY OF SUCH DAMAGES.
-
-		     END OF TERMS AND CONDITIONS
-
-	    How to Apply These Terms to Your New Programs
+  Each version is given a distinguishing version number.  If the
+Program specifies that a certain numbered version of the GNU General
+Public License "or any later version" applies to it, you have the
+option of following the terms and conditions either of that numbered
+version or of any later version published by the Free Software
+Foundation.  If the Program does not specify a version number of the
+GNU General Public License, you may choose any version ever published
+by the Free Software Foundation.
+
+  If the Program specifies that a proxy can decide which future
+versions of the GNU General Public License can be used, that proxy's
+public statement of acceptance of a version permanently authorizes you
+to choose that version for the Program.
+
+  Later license versions may give you additional or different
+permissions.  However, no additional obligations are imposed on any
+author or copyright holder as a result of your choosing to follow a
+later version.
+
+  15. Disclaimer of Warranty.
+
+  THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY
+APPLICABLE LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
+HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY
+OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
+THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM
+IS WITH YOU.  SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF
+ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
+
+  16. Limitation of Liability.
+
+  IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS
+THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY
+GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
+USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
+DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD
+PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS),
+EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
+
+  17. Interpretation of Sections 15 and 16.
+
+  If the disclaimer of warranty and limitation of liability provided
+above cannot be given local legal effect according to their terms,
+reviewing courts shall apply local law that most closely approximates
+an absolute waiver of all civil liability in connection with the
+Program, unless a warranty or assumption of liability accompanies a
+copy of the Program in return for a fee.
+
+                     END OF TERMS AND CONDITIONS
+
+            How to Apply These Terms to Your New Programs
 
   If you develop a new program, and you want it to be of the greatest
 possible use to the public, the best way to achieve this is to make it
@@ -291,15 +632,15 @@
 
   To do so, attach the following notices to the program.  It is safest
 to attach them to the start of each source file to most effectively
-convey the exclusion of warranty; and each file should have at least
+state the exclusion of warranty; and each file should have at least
 the "copyright" line and a pointer to where the full notice is found.
 
     <one line to give the program's name and a brief idea of what it does.>
     Copyright (C) <year>  <name of author>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -308,41 +649,38 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
-
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 Also add information on how to contact you by electronic and paper mail.
 
-If the program is interactive, make it output a short notice like this
-when it starts in an interactive mode:
+  If the program does terminal interaction, make it output a short
+notice like this when it starts in an interactive mode:
 
-    Gnomovision version 69, Copyright (C) year name of author
-    Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
+    <program>  Copyright (C) <year>  <name of author>
+    This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
     This is free software, and you are welcome to redistribute it
     under certain conditions; type `show c' for details.
 
 The hypothetical commands `show w' and `show c' should show the appropriate
-parts of the General Public License.  Of course, the commands you use may
-be called something other than `show w' and `show c'; they could even be
-mouse-clicks or menu items--whatever suits your program.
-
-You should also get your employer (if you work as a programmer) or your
-school, if any, to sign a "copyright disclaimer" for the program, if
-necessary.  Here is a sample; alter the names:
-
-  Yoyodyne, Inc., hereby disclaims all copyright interest in the program
-  `Gnomovision' (which makes passes at compilers) written by James Hacker.
-
-  <signature of Ty Coon>, 1 April 1989
-  Ty Coon, President of Vice
-
-This General Public License does not permit incorporating your program into
-proprietary programs.  If your program is a subroutine library, you may
-consider it more useful to permit linking proprietary applications with the
-library.  If this is what you want to do, use the GNU Library General
-Public License instead of this License.
-
+parts of the General Public License.  Of course, your program's commands
+might be different; for a GUI interface, you would use an "about box".
+
+  You should also get your employer (if you work as a programmer) or school,
+if any, to sign a "copyright disclaimer" for the program, if necessary.
+For more information on this, and how to apply and follow the GNU GPL, see
+<http://www.gnu.org/licenses/>.
+
+  The GNU General Public License does not permit incorporating your program
+into proprietary programs.  If your program is a subroutine library, you
+may consider it more useful to permit linking proprietary applications with
+the library.  If this is what you want to do, use the GNU Lesser General
+Public License instead of this License.  But first, please read
+<http://www.gnu.org/philosophy/why-not-lgpl.html>.
+
+
+
+OpenSSL exception
+-----------------
 
 In addition, as a special exception, the copyright holders give
 permission to link the code of portions of this program with the
@@ -352,4 +690,4 @@
 for all of the code used other than OpenSSL.  If you modify
 file(s) with this exception, you may extend this exception to your
 version of the file(s), but you are not obligated to do so.
-
+  
\ No newline at end of file

=== modified file 'Makefile.in'
--- Makefile.in	2010-01-17 13:05:04 +0000
+++ Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -17,6 +17,23 @@
 
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -74,6 +91,12 @@
 am__base_list = \
   sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
   sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+  test -z "$$files" \
+    || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+    || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+         $(am__cd) "$$dir" && rm -f $$files; }; \
+  }
 am__installdirs = "$(DESTDIR)$(bindir)" "$(DESTDIR)$(pkgconfigdir)"
 SCRIPTS = $(bin_SCRIPTS)
 SOURCES =
@@ -85,6 +108,11 @@
 	install-pdf-recursive install-ps-recursive install-recursive \
 	installcheck-recursive installdirs-recursive pdf-recursive \
 	ps-recursive uninstall-recursive
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 DATA = $(pkgconfig_DATA)
 RECURSIVE_CLEAN_TARGETS = mostlyclean-recursive clean-recursive	\
   distclean-recursive maintainer-clean-recursive
@@ -98,9 +126,11 @@
 distdir = $(PACKAGE)-$(VERSION)
 top_distdir = $(distdir)
 am__remove_distdir = \
-  { test ! -d "$(distdir)" \
-    || { find "$(distdir)" -type d ! -perm -200 -exec chmod u+w {} ';' \
-         && rm -fr "$(distdir)"; }; }
+  if test -d "$(distdir)"; then \
+    find "$(distdir)" -type d ! -perm -200 -exec chmod u+w {} ';' \
+      && rm -rf "$(distdir)" \
+      || { sleep 5 && rm -rf "$(distdir)"; }; \
+  else :; fi
 am__relativize = \
   dir0=`pwd`; \
   sed_first='s,^\([^/]*\)/.*$$,\1,'; \
@@ -129,6 +159,8 @@
 DIST_ARCHIVES = $(distdir).tar.gz
 GZIP_ENV = --best
 distuninstallcheck_listfiles = find . -type f -print
+am__distuninstallcheck_listfiles = $(distuninstallcheck_listfiles) \
+  | sed 's|^\./|$(prefix)/|' | grep -v '$(infodir)/dir$$'
 distcleancheck_listfiles = find . -type f -print
 ACLOCAL = @ACLOCAL@
 AMTAR = @AMTAR@
@@ -149,6 +181,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -158,6 +191,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -173,7 +207,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -203,6 +239,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -237,7 +274,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -262,7 +298,7 @@
 	$(MAKE) $(AM_MAKEFLAGS) all-recursive
 
 .SUFFIXES:
-am--refresh:
+am--refresh: Makefile
 	@:
 $(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
 	@for dep in $?; do \
@@ -298,10 +334,8 @@
 $(am__aclocal_m4_deps):
 
 config.h.unix: stamp-h1
-	@if test ! -f $@; then \
-	  rm -f stamp-h1; \
-	  $(MAKE) $(AM_MAKEFLAGS) stamp-h1; \
-	else :; fi
+	@if test ! -f $@; then rm -f stamp-h1; else :; fi
+	@if test ! -f $@; then $(MAKE) $(AM_MAKEFLAGS) stamp-h1; else :; fi
 
 stamp-h1: $(srcdir)/config.h.unix.in $(top_builddir)/config.status
 	@rm -f stamp-h1
@@ -319,8 +353,11 @@
 	cd $(top_builddir) && $(SHELL) ./config.status $@
 install-binSCRIPTS: $(bin_SCRIPTS)
 	@$(NORMAL_INSTALL)
-	test -z "$(bindir)" || $(MKDIR_P) "$(DESTDIR)$(bindir)"
 	@list='$(bin_SCRIPTS)'; test -n "$(bindir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(bindir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(bindir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  if test -f "$$d$$p"; then echo "$$d$$p"; echo "$$p"; else :; fi; \
@@ -348,9 +385,7 @@
 	@list='$(bin_SCRIPTS)'; test -n "$(bindir)" || exit 0; \
 	files=`for p in $$list; do echo "$$p"; done | \
 	       sed -e 's,.*/,,;$(transform)'`; \
-	test -n "$$list" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(bindir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(bindir)" && rm -f $$files
+	dir='$(DESTDIR)$(bindir)'; $(am__uninstall_files_from_dir)
 
 mostlyclean-libtool:
 	-rm -f *.lo
@@ -362,8 +397,11 @@
 	-rm -f libtool config.lt
 install-pkgconfigDATA: $(pkgconfig_DATA)
 	@$(NORMAL_INSTALL)
-	test -z "$(pkgconfigdir)" || $(MKDIR_P) "$(DESTDIR)$(pkgconfigdir)"
 	@list='$(pkgconfig_DATA)'; test -n "$(pkgconfigdir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(pkgconfigdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(pkgconfigdir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -377,9 +415,7 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(pkgconfig_DATA)'; test -n "$(pkgconfigdir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(pkgconfigdir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(pkgconfigdir)" && rm -f $$files
+	dir='$(DESTDIR)$(pkgconfigdir)'; $(am__uninstall_files_from_dir)
 
 # This directory's subdirectories are mostly independent; you can cd
 # into them and run `make' without going through this Makefile.
@@ -388,7 +424,7 @@
 #     (which will cause the Makefiles to be regenerated when you run `make');
 # (2) otherwise, pass the desired values on the `make' command line.
 $(RECURSIVE_TARGETS):
-	@failcom='exit 1'; \
+	@fail= failcom='exit 1'; \
 	for f in x $$MAKEFLAGS; do \
 	  case $$f in \
 	    *=* | --[!k]*);; \
@@ -413,7 +449,7 @@
 	fi; test -z "$$fail"
 
 $(RECURSIVE_CLEAN_TARGETS):
-	@failcom='exit 1'; \
+	@fail= failcom='exit 1'; \
 	for f in x $$MAKEFLAGS; do \
 	  case $$f in \
 	    *=* | --[!k]*);; \
@@ -550,13 +586,10 @@
 	done
 	@list='$(DIST_SUBDIRS)'; for subdir in $$list; do \
 	  if test "$$subdir" = .; then :; else \
-	    test -d "$(distdir)/$$subdir" \
-	    || $(MKDIR_P) "$(distdir)/$$subdir" \
-	    || exit 1; \
-	  fi; \
-	done
-	@list='$(DIST_SUBDIRS)'; for subdir in $$list; do \
-	  if test "$$subdir" = .; then :; else \
+	    $(am__make_dryrun) \
+	      || test -d "$(distdir)/$$subdir" \
+	      || $(MKDIR_P) "$(distdir)/$$subdir" \
+	      || exit 1; \
 	    dir1=$$subdir; dir2="$(distdir)/$$subdir"; \
 	    $(am__relativize); \
 	    new_distdir=$$reldir; \
@@ -577,7 +610,8 @@
 	  fi; \
 	done
 	-test -n "$(am__skip_mode_fix)" \
-	|| find "$(distdir)" -type d ! -perm -777 -exec chmod a+rwx {} \; -o \
+	|| find "$(distdir)" -type d ! -perm -755 \
+		-exec chmod u+rwx,go+rx {} \; -o \
 	  ! -type d ! -perm -444 -links 1 -exec chmod a+r {} \; -o \
 	  ! -type d ! -perm -400 -exec chmod a+r {} \; -o \
 	  ! -type d ! -perm -444 -exec $(install_sh) -c -m a+r {} {} \; \
@@ -587,7 +621,11 @@
 	$(am__remove_distdir)
 
 dist-bzip2: distdir
-	tardir=$(distdir) && $(am__tar) | bzip2 -9 -c >$(distdir).tar.bz2
+	tardir=$(distdir) && $(am__tar) | BZIP2=$${BZIP2--9} bzip2 -c >$(distdir).tar.bz2
+	$(am__remove_distdir)
+
+dist-lzip: distdir
+	tardir=$(distdir) && $(am__tar) | lzip -c $${LZIP_OPT--9} >$(distdir).tar.lz
 	$(am__remove_distdir)
 
 dist-lzma: distdir
@@ -595,7 +633,7 @@
 	$(am__remove_distdir)
 
 dist-xz: distdir
-	tardir=$(distdir) && $(am__tar) | xz -c >$(distdir).tar.xz
+	tardir=$(distdir) && $(am__tar) | XZ_OPT=$${XZ_OPT--e} xz -c >$(distdir).tar.xz
 	$(am__remove_distdir)
 
 dist-tarZ: distdir
@@ -621,21 +659,23 @@
 distcheck: dist
 	case '$(DIST_ARCHIVES)' in \
 	*.tar.gz*) \
-	  GZIP=$(GZIP_ENV) gunzip -c $(distdir).tar.gz | $(am__untar) ;;\
+	  GZIP=$(GZIP_ENV) gzip -dc $(distdir).tar.gz | $(am__untar) ;;\
 	*.tar.bz2*) \
-	  bunzip2 -c $(distdir).tar.bz2 | $(am__untar) ;;\
+	  bzip2 -dc $(distdir).tar.bz2 | $(am__untar) ;;\
 	*.tar.lzma*) \
-	  unlzma -c $(distdir).tar.lzma | $(am__untar) ;;\
+	  lzma -dc $(distdir).tar.lzma | $(am__untar) ;;\
+	*.tar.lz*) \
+	  lzip -dc $(distdir).tar.lz | $(am__untar) ;;\
 	*.tar.xz*) \
 	  xz -dc $(distdir).tar.xz | $(am__untar) ;;\
 	*.tar.Z*) \
 	  uncompress -c $(distdir).tar.Z | $(am__untar) ;;\
 	*.shar.gz*) \
-	  GZIP=$(GZIP_ENV) gunzip -c $(distdir).shar.gz | unshar ;;\
+	  GZIP=$(GZIP_ENV) gzip -dc $(distdir).shar.gz | unshar ;;\
 	*.zip*) \
 	  unzip $(distdir).zip ;;\
 	esac
-	chmod -R a-w $(distdir); chmod a+w $(distdir)
+	chmod -R a-w $(distdir); chmod u+w $(distdir)
 	mkdir $(distdir)/_build
 	mkdir $(distdir)/_inst
 	chmod a-w $(distdir)
@@ -645,6 +685,7 @@
 	  && am__cwd=`pwd` \
 	  && $(am__cd) $(distdir)/_build \
 	  && ../configure --srcdir=.. --prefix="$$dc_install_base" \
+	    $(AM_DISTCHECK_CONFIGURE_FLAGS) \
 	    $(DISTCHECK_CONFIGURE_FLAGS) \
 	  && $(MAKE) $(AM_MAKEFLAGS) \
 	  && $(MAKE) $(AM_MAKEFLAGS) dvi \
@@ -673,8 +714,16 @@
 	  list='$(DIST_ARCHIVES)'; for i in $$list; do echo $$i; done) | \
 	  sed -e 1h -e 1s/./=/g -e 1p -e 1x -e '$$p' -e '$$x'
 distuninstallcheck:
-	@$(am__cd) '$(distuninstallcheck_dir)' \
-	&& test `$(distuninstallcheck_listfiles) | wc -l` -le 1 \
+	@test -n '$(distuninstallcheck_dir)' || { \
+	  echo 'ERROR: trying to run $@ with an empty' \
+	       '$$(distuninstallcheck_dir)' >&2; \
+	  exit 1; \
+	}; \
+	$(am__cd) '$(distuninstallcheck_dir)' || { \
+	  echo 'ERROR: cannot chdir into $(distuninstallcheck_dir)' >&2; \
+	  exit 1; \
+	}; \
+	test `$(am__distuninstallcheck_listfiles) | wc -l` -eq 0 \
 	   || { echo "ERROR: files left after uninstall:" ; \
 	        if test -n "$(DESTDIR)"; then \
 	          echo "  (check DESTDIR support)"; \
@@ -708,10 +757,15 @@
 
 installcheck: installcheck-recursive
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:
@@ -799,8 +853,8 @@
 .PHONY: $(RECURSIVE_CLEAN_TARGETS) $(RECURSIVE_TARGETS) CTAGS GTAGS \
 	all all-am am--refresh check check-am clean clean-generic \
 	clean-libtool ctags ctags-recursive dist dist-all dist-bzip2 \
-	dist-gzip dist-lzma dist-shar dist-tarZ dist-xz dist-zip \
-	distcheck distclean distclean-generic distclean-hdr \
+	dist-gzip dist-lzip dist-lzma dist-shar dist-tarZ dist-xz \
+	dist-zip distcheck distclean distclean-generic distclean-hdr \
 	distclean-libtool distclean-tags distcleancheck distdir \
 	distuninstallcheck dvi dvi-am html html-am info info-am \
 	install install-am install-binSCRIPTS install-data \

=== modified file 'README'
--- README	2010-01-17 13:05:04 +0000
+++ README	2014-01-16 10:42:06 +0000
@@ -5,7 +5,7 @@
 For build instructions on Symbian/Nokia S60 see README.symbian.
 
 
-For API documentation run doxygen, or go to http://camaya.net/api/gloox/
+For API documentation run make apidox, run doxygen directly, or go to http://camaya.net/api/gloox/
 
 If you plan to contribute to gloox, please be aware of the following:
 

=== modified file 'README.symbian'
--- README.symbian	2010-01-17 13:05:04 +0000
+++ README.symbian	2014-01-16 10:42:06 +0000
@@ -5,6 +5,8 @@
 - Linux cross-compile environment (see http://martin.st/symbian)
 - Carbide.c++ 2.0
 
+You will need the Open C/C++ plugin for the S60 SDK.
+
 No other compilers are officially supported at this point. Please let me know about
 your experiences with other compilers.
 

=== modified file 'UPGRADING'
--- UPGRADING	2010-01-17 13:05:04 +0000
+++ UPGRADING	2014-01-16 10:42:06 +0000
@@ -5,12 +5,8 @@
  * It lists the API changes that were made and how to change your code to achieve the same
  * (or better) functionality as with the earlier version.
  *
- * @section contents Contents
- * @ref upgrading_09_10 <br>
- * @ref deprecated_10 <br>
- * @ref removed_10 <br>
- * @ref semantics_10 <br>
- *
+ * @tableofcontents
+ * 
  * @section upgrading_09_10 1. Upgrading from 0.9.x to 1.0
  *
  * Besides the changes detailed below, a major change is that the Stanza class now is an abstract
@@ -320,4 +316,9 @@
  * Further, the function has been renamed to
  * @link gloox::SIProfileFT::declineFT() declineFT() @endlink.
  *
+ * @section upgrading_10_101 2. Upgrading from to 1.0 to 1.0.1
+ * 
+ * NB: 1.0.1 is not binary-compatible to 1.0. The reason for that is the addition of support for XEP-0174, which made it
+ * necessary to add a parameter to @link gloox::ClientBase::handleStartNode( const Tag* ) ClientBase::handleStartNode() @endlink.
+ * 
  */

=== modified file 'aclocal.m4'
--- aclocal.m4	2010-01-17 13:05:04 +0000
+++ aclocal.m4	2014-01-16 10:42:06 +0000
@@ -1,7 +1,8 @@
-# generated automatically by aclocal 1.11 -*- Autoconf -*-
+# generated automatically by aclocal 1.11.6 -*- Autoconf -*-
 
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-# 2005, 2006, 2007, 2008, 2009  Free Software Foundation, Inc.
+# 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation,
+# Inc.
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -13,8 +14,8 @@
 
 m4_ifndef([AC_AUTOCONF_VERSION],
   [m4_copy([m4_PACKAGE_VERSION], [AC_AUTOCONF_VERSION])])dnl
-m4_if(m4_defn([AC_AUTOCONF_VERSION]), [2.64],,
-[m4_warning([this file was generated for autoconf 2.64.
+m4_if(m4_defn([AC_AUTOCONF_VERSION]), [2.69],,
+[m4_warning([this file was generated for autoconf 2.69.
 You have another version of autoconf.  It may work, but is not guaranteed to.
 If you have problems, you may need to regenerate the build system entirely.
 To do so, use the procedure documented by the package, typically `autoreconf'.])])
@@ -22,7 +23,8 @@
 # libtool.m4 - Configure libtool for the host system. -*-Autoconf-*-
 #
 #   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005,
-#                 2006, 2007, 2008 Free Software Foundation, Inc.
+#                 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+#                 Foundation, Inc.
 #   Written by Gordon Matzigkeit, 1996
 #
 # This file is free software; the Free Software Foundation gives
@@ -31,7 +33,8 @@
 
 m4_define([_LT_COPYING], [dnl
 #   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005,
-#                 2006, 2007, 2008 Free Software Foundation, Inc.
+#                 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+#                 Foundation, Inc.
 #   Written by Gordon Matzigkeit, 1996
 #
 #   This file is part of GNU Libtool.
@@ -58,7 +61,7 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 ])
 
-# serial 56 LT_INIT
+# serial 57 LT_INIT
 
 
 # LT_PREREQ(VERSION)
@@ -87,6 +90,7 @@
 # ------------------
 AC_DEFUN([LT_INIT],
 [AC_PREREQ([2.58])dnl We use AC_INCLUDES_DEFAULT
+AC_REQUIRE([AC_CONFIG_AUX_DIR_DEFAULT])dnl
 AC_BEFORE([$0], [LT_LANG])dnl
 AC_BEFORE([$0], [LT_OUTPUT])dnl
 AC_BEFORE([$0], [LTDL_INIT])dnl
@@ -103,6 +107,8 @@
 AC_REQUIRE([LTOBSOLETE_VERSION])dnl
 m4_require([_LT_PROG_LTMAIN])dnl
 
+_LT_SHELL_INIT([SHELL=${CONFIG_SHELL-/bin/sh}])
+
 dnl Parse OPTIONS
 _LT_SET_OPTIONS([$0], [$1])
 
@@ -139,7 +145,7 @@
     *) break;;
   esac
 done
-cc_basename=`$ECHO "X$cc_temp" | $Xsed -e 's%.*/%%' -e "s%^$host_alias-%%"`
+cc_basename=`$ECHO "$cc_temp" | $SED "s%.*/%%; s%^$host_alias-%%"`
 ])
 
 
@@ -159,6 +165,11 @@
 m4_defun([_LT_SETUP],
 [AC_REQUIRE([AC_CANONICAL_HOST])dnl
 AC_REQUIRE([AC_CANONICAL_BUILD])dnl
+AC_REQUIRE([_LT_PREPARE_SED_QUOTE_VARS])dnl
+AC_REQUIRE([_LT_PROG_ECHO_BACKSLASH])dnl
+
+_LT_DECL([], [PATH_SEPARATOR], [1], [The PATH separator for the build system])dnl
+dnl
 _LT_DECL([], [host_alias], [0], [The host system])dnl
 _LT_DECL([], [host], [0])dnl
 _LT_DECL([], [host_os], [0])dnl
@@ -181,10 +192,13 @@
 dnl
 m4_require([_LT_FILEUTILS_DEFAULTS])dnl
 m4_require([_LT_CHECK_SHELL_FEATURES])dnl
+m4_require([_LT_PATH_CONVERSION_FUNCTIONS])dnl
 m4_require([_LT_CMD_RELOAD])dnl
 m4_require([_LT_CHECK_MAGIC_METHOD])dnl
+m4_require([_LT_CHECK_SHAREDLIB_FROM_LINKLIB])dnl
 m4_require([_LT_CMD_OLD_ARCHIVE])dnl
 m4_require([_LT_CMD_GLOBAL_SYMBOLS])dnl
+m4_require([_LT_WITH_SYSROOT])dnl
 
 _LT_CONFIG_LIBTOOL_INIT([
 # See if we are running on zsh, and set the options which allow our
@@ -200,7 +214,6 @@
 _LT_CHECK_OBJDIR
 
 m4_require([_LT_TAG_COMPILER])dnl
-_LT_PROG_ECHO_BACKSLASH
 
 case $host_os in
 aix3*)
@@ -214,23 +227,6 @@
   ;;
 esac
 
-# Sed substitution that helps us do robust quoting.  It backslashifies
-# metacharacters that are still active within double-quoted strings.
-sed_quote_subst='s/\([["`$\\]]\)/\\\1/g'
-
-# Same as above, but do not quote variable references.
-double_quote_subst='s/\([["`\\]]\)/\\\1/g'
-
-# Sed substitution to delay expansion of an escaped shell variable in a
-# double_quote_subst'ed string.
-delay_variable_subst='s/\\\\\\\\\\\$/\\\\\\$/g'
-
-# Sed substitution to delay expansion of an escaped single quote.
-delay_single_quote_subst='s/'\''/'\'\\\\\\\'\''/g'
-
-# Sed substitution to avoid accidental globbing in evaled expressions
-no_glob_subst='s/\*/\\\*/g'
-
 # Global variables:
 ofile=libtool
 can_build_shared=yes
@@ -271,6 +267,28 @@
 ])# _LT_SETUP
 
 
+# _LT_PREPARE_SED_QUOTE_VARS
+# --------------------------
+# Define a few sed substitution that help us do robust quoting.
+m4_defun([_LT_PREPARE_SED_QUOTE_VARS],
+[# Backslashify metacharacters that are still active within
+# double-quoted strings.
+sed_quote_subst='s/\([["`$\\]]\)/\\\1/g'
+
+# Same as above, but do not quote variable references.
+double_quote_subst='s/\([["`\\]]\)/\\\1/g'
+
+# Sed substitution to delay expansion of an escaped shell variable in a
+# double_quote_subst'ed string.
+delay_variable_subst='s/\\\\\\\\\\\$/\\\\\\$/g'
+
+# Sed substitution to delay expansion of an escaped single quote.
+delay_single_quote_subst='s/'\''/'\'\\\\\\\'\''/g'
+
+# Sed substitution to avoid accidental globbing in evaled expressions
+no_glob_subst='s/\*/\\\*/g'
+])
+
 # _LT_PROG_LTMAIN
 # ---------------
 # Note that this code is called both from `configure', and `config.status'
@@ -423,7 +441,7 @@
 # declaration there will have the same value as in `configure'.  VARNAME
 # must have a single quote delimited value for this to work.
 m4_define([_LT_CONFIG_STATUS_DECLARE],
-[$1='`$ECHO "X$][$1" | $Xsed -e "$delay_single_quote_subst"`'])
+[$1='`$ECHO "$][$1" | $SED "$delay_single_quote_subst"`'])
 
 
 # _LT_CONFIG_STATUS_DECLARATIONS
@@ -433,7 +451,7 @@
 # embedded single quotes properly.  In configure, this macro expands
 # each variable declared with _LT_DECL (and _LT_TAGDECL) into:
 #
-#    <var>='`$ECHO "X$<var>" | $Xsed -e "$delay_single_quote_subst"`'
+#    <var>='`$ECHO "$<var>" | $SED "$delay_single_quote_subst"`'
 m4_defun([_LT_CONFIG_STATUS_DECLARATIONS],
 [m4_foreach([_lt_var], m4_quote(lt_decl_all_varnames),
     [m4_n([_LT_CONFIG_STATUS_DECLARE(_lt_var)])])])
@@ -532,12 +550,20 @@
 LTCFLAGS='$LTCFLAGS'
 compiler='$compiler_DEFAULT'
 
+# A function that is used when there is no print builtin or printf.
+func_fallback_echo ()
+{
+  eval 'cat <<_LTECHO_EOF
+\$[]1
+_LTECHO_EOF'
+}
+
 # Quote evaled strings.
 for var in lt_decl_all_varnames([[ \
 ]], lt_decl_quote_varnames); do
-    case \`eval \\\\\$ECHO "X\\\\\$\$var"\` in
+    case \`eval \\\\\$ECHO \\\\""\\\\\$\$var"\\\\"\` in
     *[[\\\\\\\`\\"\\\$]]*)
-      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"X\\\$\$var\\" | \\\$Xsed -e \\"\\\$sed_quote_subst\\"\\\`\\\\\\""
+      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"\\\$\$var\\" | \\\$SED \\"\\\$sed_quote_subst\\"\\\`\\\\\\""
       ;;
     *)
       eval "lt_\$var=\\\\\\"\\\$\$var\\\\\\""
@@ -548,9 +574,9 @@
 # Double-quote double-evaled strings.
 for var in lt_decl_all_varnames([[ \
 ]], lt_decl_dquote_varnames); do
-    case \`eval \\\\\$ECHO "X\\\\\$\$var"\` in
+    case \`eval \\\\\$ECHO \\\\""\\\\\$\$var"\\\\"\` in
     *[[\\\\\\\`\\"\\\$]]*)
-      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"X\\\$\$var\\" | \\\$Xsed -e \\"\\\$double_quote_subst\\" -e \\"\\\$sed_quote_subst\\" -e \\"\\\$delay_variable_subst\\"\\\`\\\\\\""
+      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"\\\$\$var\\" | \\\$SED -e \\"\\\$double_quote_subst\\" -e \\"\\\$sed_quote_subst\\" -e \\"\\\$delay_variable_subst\\"\\\`\\\\\\""
       ;;
     *)
       eval "lt_\$var=\\\\\\"\\\$\$var\\\\\\""
@@ -558,16 +584,38 @@
     esac
 done
 
-# Fix-up fallback echo if it was mangled by the above quoting rules.
-case \$lt_ECHO in
-*'\\\[$]0 --fallback-echo"')dnl "
-  lt_ECHO=\`\$ECHO "X\$lt_ECHO" | \$Xsed -e 's/\\\\\\\\\\\\\\\[$]0 --fallback-echo"\[$]/\[$]0 --fallback-echo"/'\`
-  ;;
-esac
-
 _LT_OUTPUT_LIBTOOL_INIT
 ])
 
+# _LT_GENERATED_FILE_INIT(FILE, [COMMENT])
+# ------------------------------------
+# Generate a child script FILE with all initialization necessary to
+# reuse the environment learned by the parent script, and make the
+# file executable.  If COMMENT is supplied, it is inserted after the
+# `#!' sequence but before initialization text begins.  After this
+# macro, additional text can be appended to FILE to form the body of
+# the child script.  The macro ends with non-zero status if the
+# file could not be fully written (such as if the disk is full).
+m4_ifdef([AS_INIT_GENERATED],
+[m4_defun([_LT_GENERATED_FILE_INIT],[AS_INIT_GENERATED($@)])],
+[m4_defun([_LT_GENERATED_FILE_INIT],
+[m4_require([AS_PREPARE])]dnl
+[m4_pushdef([AS_MESSAGE_LOG_FD])]dnl
+[lt_write_fail=0
+cat >$1 <<_ASEOF || lt_write_fail=1
+#! $SHELL
+# Generated by $as_me.
+$2
+SHELL=\${CONFIG_SHELL-$SHELL}
+export SHELL
+_ASEOF
+cat >>$1 <<\_ASEOF || lt_write_fail=1
+AS_SHELL_SANITIZE
+_AS_PREPARE
+exec AS_MESSAGE_FD>&1
+_ASEOF
+test $lt_write_fail = 0 && chmod +x $1[]dnl
+m4_popdef([AS_MESSAGE_LOG_FD])])])# _LT_GENERATED_FILE_INIT
 
 # LT_OUTPUT
 # ---------
@@ -577,20 +625,11 @@
 AC_DEFUN([LT_OUTPUT],
 [: ${CONFIG_LT=./config.lt}
 AC_MSG_NOTICE([creating $CONFIG_LT])
-cat >"$CONFIG_LT" <<_LTEOF
-#! $SHELL
-# Generated by $as_me.
-# Run this file to recreate a libtool stub with the current configuration.
+_LT_GENERATED_FILE_INIT(["$CONFIG_LT"],
+[# Run this file to recreate a libtool stub with the current configuration.])
 
+cat >>"$CONFIG_LT" <<\_LTEOF
 lt_cl_silent=false
-SHELL=\${CONFIG_SHELL-$SHELL}
-_LTEOF
-
-cat >>"$CONFIG_LT" <<\_LTEOF
-AS_SHELL_SANITIZE
-_AS_PREPARE
-
-exec AS_MESSAGE_FD>&1
 exec AS_MESSAGE_LOG_FD>>config.log
 {
   echo
@@ -616,7 +655,7 @@
 m4_ifset([AC_PACKAGE_VERSION], [ AC_PACKAGE_VERSION])
 configured by $[0], generated by m4_PACKAGE_STRING.
 
-Copyright (C) 2008 Free Software Foundation, Inc.
+Copyright (C) 2011 Free Software Foundation, Inc.
 This config.lt script is free software; the Free Software Foundation
 gives unlimited permision to copy, distribute and modify it."
 
@@ -661,15 +700,13 @@
 # appending to config.log, which fails on DOS, as config.log is still kept
 # open by configure.  Here we exec the FD to /dev/null, effectively closing
 # config.log, so it can be properly (re)opened and appended to by config.lt.
-if test "$no_create" != yes; then
-  lt_cl_success=:
-  test "$silent" = yes &&
-    lt_config_lt_args="$lt_config_lt_args --quiet"
-  exec AS_MESSAGE_LOG_FD>/dev/null
-  $SHELL "$CONFIG_LT" $lt_config_lt_args || lt_cl_success=false
-  exec AS_MESSAGE_LOG_FD>>config.log
-  $lt_cl_success || AS_EXIT(1)
-fi
+lt_cl_success=:
+test "$silent" = yes &&
+  lt_config_lt_args="$lt_config_lt_args --quiet"
+exec AS_MESSAGE_LOG_FD>/dev/null
+$SHELL "$CONFIG_LT" $lt_config_lt_args || lt_cl_success=false
+exec AS_MESSAGE_LOG_FD>>config.log
+$lt_cl_success || AS_EXIT(1)
 ])# LT_OUTPUT
 
 
@@ -732,15 +769,12 @@
   # if finds mixed CR/LF and LF-only lines.  Since sed operates in
   # text mode, it properly converts lines to CR/LF.  This bash problem
   # is reportedly fixed, but why not run on old versions too?
-  sed '/^# Generated shell functions inserted here/q' "$ltmain" >> "$cfgfile" \
-    || (rm -f "$cfgfile"; exit 1)
-
-  _LT_PROG_XSI_SHELLFNS
-
-  sed -n '/^# Generated shell functions inserted here/,$p' "$ltmain" >> "$cfgfile" \
-    || (rm -f "$cfgfile"; exit 1)
-
-  mv -f "$cfgfile" "$ofile" ||
+  sed '$q' "$ltmain" >> "$cfgfile" \
+     || (rm -f "$cfgfile"; exit 1)
+
+  _LT_PROG_REPLACE_SHELLFNS
+
+   mv -f "$cfgfile" "$ofile" ||
     (rm -f "$ofile" && cp "$cfgfile" "$ofile" && rm -f "$cfgfile")
   chmod +x "$ofile"
 ],
@@ -785,6 +819,7 @@
 m4_case([$1],
   [C],			[_LT_LANG(C)],
   [C++],		[_LT_LANG(CXX)],
+  [Go],			[_LT_LANG(GO)],
   [Java],		[_LT_LANG(GCJ)],
   [Fortran 77],		[_LT_LANG(F77)],
   [Fortran],		[_LT_LANG(FC)],
@@ -806,6 +841,29 @@
 ])# _LT_LANG
 
 
+m4_ifndef([AC_PROG_GO], [
+# NOTE: This macro has been submitted for inclusion into   #
+#  GNU Autoconf as AC_PROG_GO.  When it is available in    #
+#  a released version of Autoconf we should remove this    #
+#  macro and use it instead.                               #
+m4_defun([AC_PROG_GO],
+[AC_LANG_PUSH(Go)dnl
+AC_ARG_VAR([GOC],     [Go compiler command])dnl
+AC_ARG_VAR([GOFLAGS], [Go compiler flags])dnl
+_AC_ARG_VAR_LDFLAGS()dnl
+AC_CHECK_TOOL(GOC, gccgo)
+if test -z "$GOC"; then
+  if test -n "$ac_tool_prefix"; then
+    AC_CHECK_PROG(GOC, [${ac_tool_prefix}gccgo], [${ac_tool_prefix}gccgo])
+  fi
+fi
+if test -z "$GOC"; then
+  AC_CHECK_PROG(GOC, gccgo, gccgo, false)
+fi
+])#m4_defun
+])#m4_ifndef
+
+
 # _LT_LANG_DEFAULT_CONFIG
 # -----------------------
 m4_defun([_LT_LANG_DEFAULT_CONFIG],
@@ -836,6 +894,10 @@
        m4_ifdef([LT_PROG_GCJ],
 	[m4_define([LT_PROG_GCJ], defn([LT_PROG_GCJ])[LT_LANG(GCJ)])])])])])
 
+AC_PROVIDE_IFELSE([AC_PROG_GO],
+  [LT_LANG(GO)],
+  [m4_define([AC_PROG_GO], defn([AC_PROG_GO])[LT_LANG(GO)])])
+
 AC_PROVIDE_IFELSE([LT_PROG_RC],
   [LT_LANG(RC)],
   [m4_define([LT_PROG_RC], defn([LT_PROG_RC])[LT_LANG(RC)])])
@@ -846,11 +908,13 @@
 AU_DEFUN([AC_LIBTOOL_F77], [LT_LANG(Fortran 77)])
 AU_DEFUN([AC_LIBTOOL_FC], [LT_LANG(Fortran)])
 AU_DEFUN([AC_LIBTOOL_GCJ], [LT_LANG(Java)])
+AU_DEFUN([AC_LIBTOOL_RC], [LT_LANG(Windows Resource)])
 dnl aclocal-1.4 backwards compatibility:
 dnl AC_DEFUN([AC_LIBTOOL_CXX], [])
 dnl AC_DEFUN([AC_LIBTOOL_F77], [])
 dnl AC_DEFUN([AC_LIBTOOL_FC], [])
 dnl AC_DEFUN([AC_LIBTOOL_GCJ], [])
+dnl AC_DEFUN([AC_LIBTOOL_RC], [])
 
 
 # _LT_TAG_COMPILER
@@ -936,7 +1000,13 @@
 	$LTCC $LTCFLAGS $LDFLAGS -o libconftest.dylib \
 	  -dynamiclib -Wl,-single_module conftest.c 2>conftest.err
         _lt_result=$?
-	if test -f libconftest.dylib && test ! -s conftest.err && test $_lt_result = 0; then
+	# If there is a non-empty error log, and "single_module"
+	# appears in it, assume the flag caused a linker warning
+        if test -s conftest.err && $GREP single_module conftest.err; then
+	  cat conftest.err >&AS_MESSAGE_LOG_FD
+	# Otherwise, if the output was created with a 0 exit code from
+	# the compiler, it worked.
+	elif test -f libconftest.dylib && test $_lt_result -eq 0; then
 	  lt_cv_apple_cc_single_mod=yes
 	else
 	  cat conftest.err >&AS_MESSAGE_LOG_FD
@@ -944,6 +1014,7 @@
 	rm -rf libconftest.dylib*
 	rm -f conftest.*
       fi])
+
     AC_CACHE_CHECK([for -exported_symbols_list linker flag],
       [lt_cv_ld_exported_symbols_list],
       [lt_cv_ld_exported_symbols_list=no
@@ -955,6 +1026,34 @@
 	[lt_cv_ld_exported_symbols_list=no])
 	LDFLAGS="$save_LDFLAGS"
     ])
+
+    AC_CACHE_CHECK([for -force_load linker flag],[lt_cv_ld_force_load],
+      [lt_cv_ld_force_load=no
+      cat > conftest.c << _LT_EOF
+int forced_loaded() { return 2;}
+_LT_EOF
+      echo "$LTCC $LTCFLAGS -c -o conftest.o conftest.c" >&AS_MESSAGE_LOG_FD
+      $LTCC $LTCFLAGS -c -o conftest.o conftest.c 2>&AS_MESSAGE_LOG_FD
+      echo "$AR cru libconftest.a conftest.o" >&AS_MESSAGE_LOG_FD
+      $AR cru libconftest.a conftest.o 2>&AS_MESSAGE_LOG_FD
+      echo "$RANLIB libconftest.a" >&AS_MESSAGE_LOG_FD
+      $RANLIB libconftest.a 2>&AS_MESSAGE_LOG_FD
+      cat > conftest.c << _LT_EOF
+int main() { return 0;}
+_LT_EOF
+      echo "$LTCC $LTCFLAGS $LDFLAGS -o conftest conftest.c -Wl,-force_load,./libconftest.a" >&AS_MESSAGE_LOG_FD
+      $LTCC $LTCFLAGS $LDFLAGS -o conftest conftest.c -Wl,-force_load,./libconftest.a 2>conftest.err
+      _lt_result=$?
+      if test -s conftest.err && $GREP force_load conftest.err; then
+	cat conftest.err >&AS_MESSAGE_LOG_FD
+      elif test -f conftest && test $_lt_result -eq 0 && $GREP forced_load conftest >/dev/null 2>&1 ; then
+	lt_cv_ld_force_load=yes
+      else
+	cat conftest.err >&AS_MESSAGE_LOG_FD
+      fi
+        rm -f conftest.err libconftest.a conftest conftest.c
+        rm -rf conftest.dSYM
+    ])
     case $host_os in
     rhapsody* | darwin1.[[012]])
       _lt_dar_allow_undefined='${wl}-undefined ${wl}suppress' ;;
@@ -982,7 +1081,7 @@
     else
       _lt_dar_export_syms='~$NMEDIT -s $output_objdir/${libname}-symbols.expsym ${lib}'
     fi
-    if test "$DSYMUTIL" != ":"; then
+    if test "$DSYMUTIL" != ":" && test "$lt_cv_ld_force_load" = "no"; then
       _lt_dsymutil='~$DSYMUTIL $lib || :'
     else
       _lt_dsymutil=
@@ -992,8 +1091,8 @@
 ])
 
 
-# _LT_DARWIN_LINKER_FEATURES
-# --------------------------
+# _LT_DARWIN_LINKER_FEATURES([TAG])
+# ---------------------------------
 # Checks for linker and compiler features on darwin
 m4_defun([_LT_DARWIN_LINKER_FEATURES],
 [
@@ -1002,7 +1101,13 @@
   _LT_TAGVAR(hardcode_direct, $1)=no
   _LT_TAGVAR(hardcode_automatic, $1)=yes
   _LT_TAGVAR(hardcode_shlibpath_var, $1)=unsupported
-  _LT_TAGVAR(whole_archive_flag_spec, $1)=''
+  if test "$lt_cv_ld_force_load" = "yes"; then
+    _LT_TAGVAR(whole_archive_flag_spec, $1)='`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience ${wl}-force_load,$conv\"; done; func_echo_all \"$new_convenience\"`'
+    m4_case([$1], [F77], [_LT_TAGVAR(compiler_needs_object, $1)=yes],
+                  [FC],  [_LT_TAGVAR(compiler_needs_object, $1)=yes])
+  else
+    _LT_TAGVAR(whole_archive_flag_spec, $1)=''
+  fi
   _LT_TAGVAR(link_all_deplibs, $1)=yes
   _LT_TAGVAR(allow_undefined_flag, $1)="$_lt_dar_allow_undefined"
   case $cc_basename in
@@ -1010,7 +1115,7 @@
      *) _lt_dar_can_shared=$GCC ;;
   esac
   if test "$_lt_dar_can_shared" = "yes"; then
-    output_verbose_link_cmd=echo
+    output_verbose_link_cmd=func_echo_all
     _LT_TAGVAR(archive_cmds, $1)="\$CC -dynamiclib \$allow_undefined_flag -o \$lib \$libobjs \$deplibs \$compiler_flags -install_name \$rpath/\$soname \$verstring $_lt_dar_single_mod${_lt_dsymutil}"
     _LT_TAGVAR(module_cmds, $1)="\$CC \$allow_undefined_flag -o \$lib -bundle \$libobjs \$deplibs \$compiler_flags${_lt_dsymutil}"
     _LT_TAGVAR(archive_expsym_cmds, $1)="sed 's,^,_,' < \$export_symbols > \$output_objdir/\${libname}-symbols.expsym~\$CC -dynamiclib \$allow_undefined_flag -o \$lib \$libobjs \$deplibs \$compiler_flags -install_name \$rpath/\$soname \$verstring ${_lt_dar_single_mod}${_lt_dar_export_syms}${_lt_dsymutil}"
@@ -1026,203 +1131,142 @@
   fi
 ])
 
-# _LT_SYS_MODULE_PATH_AIX
-# -----------------------
+# _LT_SYS_MODULE_PATH_AIX([TAGNAME])
+# ----------------------------------
 # Links a minimal program and checks the executable
 # for the system default hardcoded library path. In most cases,
 # this is /usr/lib:/lib, but when the MPI compilers are used
 # the location of the communication and MPI libs are included too.
 # If we don't find anything, use the default library path according
 # to the aix ld manual.
+# Store the results from the different compilers for each TAGNAME.
+# Allow to override them for all tags through lt_cv_aix_libpath.
 m4_defun([_LT_SYS_MODULE_PATH_AIX],
 [m4_require([_LT_DECL_SED])dnl
-AC_LINK_IFELSE(AC_LANG_PROGRAM,[
-lt_aix_libpath_sed='
-    /Import File Strings/,/^$/ {
-	/^0/ {
-	    s/^0  *\(.*\)$/\1/
-	    p
-	}
-    }'
-aix_libpath=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-# Check for a 64-bit object if we didn't find anything.
-if test -z "$aix_libpath"; then
-  aix_libpath=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-fi],[])
-if test -z "$aix_libpath"; then aix_libpath="/usr/lib:/lib"; fi
+if test "${lt_cv_aix_libpath+set}" = set; then
+  aix_libpath=$lt_cv_aix_libpath
+else
+  AC_CACHE_VAL([_LT_TAGVAR([lt_cv_aix_libpath_], [$1])],
+  [AC_LINK_IFELSE([AC_LANG_PROGRAM],[
+  lt_aix_libpath_sed='[
+      /Import File Strings/,/^$/ {
+	  /^0/ {
+	      s/^0  *\([^ ]*\) *$/\1/
+	      p
+	  }
+      }]'
+  _LT_TAGVAR([lt_cv_aix_libpath_], [$1])=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  # Check for a 64-bit object if we didn't find anything.
+  if test -z "$_LT_TAGVAR([lt_cv_aix_libpath_], [$1])"; then
+    _LT_TAGVAR([lt_cv_aix_libpath_], [$1])=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  fi],[])
+  if test -z "$_LT_TAGVAR([lt_cv_aix_libpath_], [$1])"; then
+    _LT_TAGVAR([lt_cv_aix_libpath_], [$1])="/usr/lib:/lib"
+  fi
+  ])
+  aix_libpath=$_LT_TAGVAR([lt_cv_aix_libpath_], [$1])
+fi
 ])# _LT_SYS_MODULE_PATH_AIX
 
 
 # _LT_SHELL_INIT(ARG)
 # -------------------
 m4_define([_LT_SHELL_INIT],
-[ifdef([AC_DIVERSION_NOTICE],
-	     [AC_DIVERT_PUSH(AC_DIVERSION_NOTICE)],
-	 [AC_DIVERT_PUSH(NOTICE)])
-$1
-AC_DIVERT_POP
-])# _LT_SHELL_INIT
+[m4_divert_text([M4SH-INIT], [$1
+])])# _LT_SHELL_INIT
+
 
 
 # _LT_PROG_ECHO_BACKSLASH
 # -----------------------
-# Add some code to the start of the generated configure script which
-# will find an echo command which doesn't interpret backslashes.
+# Find how we can fake an echo command that does not interpret backslash.
+# In particular, with Autoconf 2.60 or later we add some code to the start
+# of the generated configure script which will find a shell with a builtin
+# printf (which we can use as an echo command).
 m4_defun([_LT_PROG_ECHO_BACKSLASH],
-[_LT_SHELL_INIT([
-# Check that we are running under the correct shell.
-SHELL=${CONFIG_SHELL-/bin/sh}
-
-case X$lt_ECHO in
-X*--fallback-echo)
-  # Remove one level of quotation (which was required for Make).
-  ECHO=`echo "$lt_ECHO" | sed 's,\\\\\[$]\\[$]0,'[$]0','`
-  ;;
+[ECHO='\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\'
+ECHO=$ECHO$ECHO$ECHO$ECHO$ECHO
+ECHO=$ECHO$ECHO$ECHO$ECHO$ECHO$ECHO
+
+AC_MSG_CHECKING([how to print strings])
+# Test print first, because it will be a builtin if present.
+if test "X`( print -r -- -n ) 2>/dev/null`" = X-n && \
+   test "X`print -r -- $ECHO 2>/dev/null`" = "X$ECHO"; then
+  ECHO='print -r --'
+elif test "X`printf %s $ECHO 2>/dev/null`" = "X$ECHO"; then
+  ECHO='printf %s\n'
+else
+  # Use this function as a fallback that always works.
+  func_fallback_echo ()
+  {
+    eval 'cat <<_LTECHO_EOF
+$[]1
+_LTECHO_EOF'
+  }
+  ECHO='func_fallback_echo'
+fi
+
+# func_echo_all arg...
+# Invoke $ECHO with all args, space-separated.
+func_echo_all ()
+{
+    $ECHO "$*" 
+}
+
+case "$ECHO" in
+  printf*) AC_MSG_RESULT([printf]) ;;
+  print*) AC_MSG_RESULT([print -r]) ;;
+  *) AC_MSG_RESULT([cat]) ;;
 esac
 
-ECHO=${lt_ECHO-echo}
-if test "X[$]1" = X--no-reexec; then
-  # Discard the --no-reexec flag, and continue.
-  shift
-elif test "X[$]1" = X--fallback-echo; then
-  # Avoid inline document here, it may be left over
-  :
-elif test "X`{ $ECHO '\t'; } 2>/dev/null`" = 'X\t' ; then
-  # Yippee, $ECHO works!
-  :
-else
-  # Restart under the correct shell.
-  exec $SHELL "[$]0" --no-reexec ${1+"[$]@"}
-fi
-
-if test "X[$]1" = X--fallback-echo; then
-  # used as fallback echo
-  shift
-  cat <<_LT_EOF
-[$]*
-_LT_EOF
-  exit 0
-fi
-
-# The HP-UX ksh and POSIX shell print the target directory to stdout
-# if CDPATH is set.
-(unset CDPATH) >/dev/null 2>&1 && unset CDPATH
-
-if test -z "$lt_ECHO"; then
-  if test "X${echo_test_string+set}" != Xset; then
-    # find a string as large as possible, as long as the shell can cope with it
-    for cmd in 'sed 50q "[$]0"' 'sed 20q "[$]0"' 'sed 10q "[$]0"' 'sed 2q "[$]0"' 'echo test'; do
-      # expected sizes: less than 2Kb, 1Kb, 512 bytes, 16 bytes, ...
-      if { echo_test_string=`eval $cmd`; } 2>/dev/null &&
-	 { test "X$echo_test_string" = "X$echo_test_string"; } 2>/dev/null
-      then
-        break
-      fi
-    done
-  fi
-
-  if test "X`{ $ECHO '\t'; } 2>/dev/null`" = 'X\t' &&
-     echo_testing_string=`{ $ECHO "$echo_test_string"; } 2>/dev/null` &&
-     test "X$echo_testing_string" = "X$echo_test_string"; then
-    :
-  else
-    # The Solaris, AIX, and Digital Unix default echo programs unquote
-    # backslashes.  This makes it impossible to quote backslashes using
-    #   echo "$something" | sed 's/\\/\\\\/g'
-    #
-    # So, first we look for a working echo in the user's PATH.
-
-    lt_save_ifs="$IFS"; IFS=$PATH_SEPARATOR
-    for dir in $PATH /usr/ucb; do
-      IFS="$lt_save_ifs"
-      if (test -f $dir/echo || test -f $dir/echo$ac_exeext) &&
-         test "X`($dir/echo '\t') 2>/dev/null`" = 'X\t' &&
-         echo_testing_string=`($dir/echo "$echo_test_string") 2>/dev/null` &&
-         test "X$echo_testing_string" = "X$echo_test_string"; then
-        ECHO="$dir/echo"
-        break
-      fi
-    done
-    IFS="$lt_save_ifs"
-
-    if test "X$ECHO" = Xecho; then
-      # We didn't find a better echo, so look for alternatives.
-      if test "X`{ print -r '\t'; } 2>/dev/null`" = 'X\t' &&
-         echo_testing_string=`{ print -r "$echo_test_string"; } 2>/dev/null` &&
-         test "X$echo_testing_string" = "X$echo_test_string"; then
-        # This shell has a builtin print -r that does the trick.
-        ECHO='print -r'
-      elif { test -f /bin/ksh || test -f /bin/ksh$ac_exeext; } &&
-	   test "X$CONFIG_SHELL" != X/bin/ksh; then
-        # If we have ksh, try running configure again with it.
-        ORIGINAL_CONFIG_SHELL=${CONFIG_SHELL-/bin/sh}
-        export ORIGINAL_CONFIG_SHELL
-        CONFIG_SHELL=/bin/ksh
-        export CONFIG_SHELL
-        exec $CONFIG_SHELL "[$]0" --no-reexec ${1+"[$]@"}
-      else
-        # Try using printf.
-        ECHO='printf %s\n'
-        if test "X`{ $ECHO '\t'; } 2>/dev/null`" = 'X\t' &&
-	   echo_testing_string=`{ $ECHO "$echo_test_string"; } 2>/dev/null` &&
-	   test "X$echo_testing_string" = "X$echo_test_string"; then
-	  # Cool, printf works
-	  :
-        elif echo_testing_string=`($ORIGINAL_CONFIG_SHELL "[$]0" --fallback-echo '\t') 2>/dev/null` &&
-	     test "X$echo_testing_string" = 'X\t' &&
-	     echo_testing_string=`($ORIGINAL_CONFIG_SHELL "[$]0" --fallback-echo "$echo_test_string") 2>/dev/null` &&
-	     test "X$echo_testing_string" = "X$echo_test_string"; then
-	  CONFIG_SHELL=$ORIGINAL_CONFIG_SHELL
-	  export CONFIG_SHELL
-	  SHELL="$CONFIG_SHELL"
-	  export SHELL
-	  ECHO="$CONFIG_SHELL [$]0 --fallback-echo"
-        elif echo_testing_string=`($CONFIG_SHELL "[$]0" --fallback-echo '\t') 2>/dev/null` &&
-	     test "X$echo_testing_string" = 'X\t' &&
-	     echo_testing_string=`($CONFIG_SHELL "[$]0" --fallback-echo "$echo_test_string") 2>/dev/null` &&
-	     test "X$echo_testing_string" = "X$echo_test_string"; then
-	  ECHO="$CONFIG_SHELL [$]0 --fallback-echo"
-        else
-	  # maybe with a smaller string...
-	  prev=:
-
-	  for cmd in 'echo test' 'sed 2q "[$]0"' 'sed 10q "[$]0"' 'sed 20q "[$]0"' 'sed 50q "[$]0"'; do
-	    if { test "X$echo_test_string" = "X`eval $cmd`"; } 2>/dev/null
-	    then
-	      break
-	    fi
-	    prev="$cmd"
-	  done
-
-	  if test "$prev" != 'sed 50q "[$]0"'; then
-	    echo_test_string=`eval $prev`
-	    export echo_test_string
-	    exec ${ORIGINAL_CONFIG_SHELL-${CONFIG_SHELL-/bin/sh}} "[$]0" ${1+"[$]@"}
-	  else
-	    # Oops.  We lost completely, so just stick with echo.
-	    ECHO=echo
-	  fi
-        fi
-      fi
-    fi
-  fi
-fi
-
-# Copy echo and quote the copy suitably for passing to libtool from
-# the Makefile, instead of quoting the original, which is used later.
-lt_ECHO=$ECHO
-if test "X$lt_ECHO" = "X$CONFIG_SHELL [$]0 --fallback-echo"; then
-   lt_ECHO="$CONFIG_SHELL \\\$\[$]0 --fallback-echo"
-fi
-
-AC_SUBST(lt_ECHO)
-])
+m4_ifdef([_AS_DETECT_SUGGESTED],
+[_AS_DETECT_SUGGESTED([
+  test -n "${ZSH_VERSION+set}${BASH_VERSION+set}" || (
+    ECHO='\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\'
+    ECHO=$ECHO$ECHO$ECHO$ECHO$ECHO
+    ECHO=$ECHO$ECHO$ECHO$ECHO$ECHO$ECHO
+    PATH=/empty FPATH=/empty; export PATH FPATH
+    test "X`printf %s $ECHO`" = "X$ECHO" \
+      || test "X`print -r -- $ECHO`" = "X$ECHO" )])])
+
 _LT_DECL([], [SHELL], [1], [Shell to use when invoking shell scripts])
-_LT_DECL([], [ECHO], [1],
-    [An echo program that does not interpret backslashes])
+_LT_DECL([], [ECHO], [1], [An echo program that protects backslashes])
 ])# _LT_PROG_ECHO_BACKSLASH
 
 
+# _LT_WITH_SYSROOT
+# ----------------
+AC_DEFUN([_LT_WITH_SYSROOT],
+[AC_MSG_CHECKING([for sysroot])
+AC_ARG_WITH([sysroot],
+[  --with-sysroot[=DIR] Search for dependent libraries within DIR
+                        (or the compiler's sysroot if not specified).],
+[], [with_sysroot=no])
+
+dnl lt_sysroot will always be passed unquoted.  We quote it here
+dnl in case the user passed a directory name.
+lt_sysroot=
+case ${with_sysroot} in #(
+ yes)
+   if test "$GCC" = yes; then
+     lt_sysroot=`$CC --print-sysroot 2>/dev/null`
+   fi
+   ;; #(
+ /*)
+   lt_sysroot=`echo "$with_sysroot" | sed -e "$sed_quote_subst"`
+   ;; #(
+ no|'')
+   ;; #(
+ *)
+   AC_MSG_RESULT([${with_sysroot}])
+   AC_MSG_ERROR([The sysroot must be an absolute path.])
+   ;;
+esac
+
+ AC_MSG_RESULT([${lt_sysroot:-no}])
+_LT_DECL([], [lt_sysroot], [0], [The root where to search for ]dnl
+[dependent libraries, and in which our libraries should be installed.])])
+
 # _LT_ENABLE_LOCK
 # ---------------
 m4_defun([_LT_ENABLE_LOCK],
@@ -1251,7 +1295,7 @@
   ;;
 *-*-irix6*)
   # Find out which ABI we are using.
-  echo '[#]line __oline__ "configure"' > conftest.$ac_ext
+  echo '[#]line '$LINENO' "configure"' > conftest.$ac_ext
   if AC_TRY_EVAL(ac_compile); then
     if test "$lt_cv_prog_gnu_ld" = yes; then
       case `/usr/bin/file conftest.$ac_objext` in
@@ -1344,14 +1388,27 @@
     CFLAGS="$SAVE_CFLAGS"
   fi
   ;;
-sparc*-*solaris*)
+*-*solaris*)
   # Find out which ABI we are using.
   echo 'int i;' > conftest.$ac_ext
   if AC_TRY_EVAL(ac_compile); then
     case `/usr/bin/file conftest.o` in
     *64-bit*)
       case $lt_cv_prog_gnu_ld in
-      yes*) LD="${LD-ld} -m elf64_sparc" ;;
+      yes*)
+        case $host in
+        i?86-*-solaris*)
+          LD="${LD-ld} -m elf_x86_64"
+          ;;
+        sparc*-*-solaris*)
+          LD="${LD-ld} -m elf64_sparc"
+          ;;
+        esac
+        # GNU ld 2.21 introduced _sol2 emulations.  Use them if available.
+        if ${LD-ld} -V | grep _sol2 >/dev/null 2>&1; then
+          LD="${LD-ld}_sol2"
+        fi
+        ;;
       *)
 	if ${LD-ld} -64 -r -o conftest2.o conftest.o >/dev/null 2>&1; then
 	  LD="${LD-ld} -64"
@@ -1369,14 +1426,47 @@
 ])# _LT_ENABLE_LOCK
 
 
+# _LT_PROG_AR
+# -----------
+m4_defun([_LT_PROG_AR],
+[AC_CHECK_TOOLS(AR, [ar], false)
+: ${AR=ar}
+: ${AR_FLAGS=cru}
+_LT_DECL([], [AR], [1], [The archiver])
+_LT_DECL([], [AR_FLAGS], [1], [Flags to create an archive])
+
+AC_CACHE_CHECK([for archiver @FILE support], [lt_cv_ar_at_file],
+  [lt_cv_ar_at_file=no
+   AC_COMPILE_IFELSE([AC_LANG_PROGRAM],
+     [echo conftest.$ac_objext > conftest.lst
+      lt_ar_try='$AR $AR_FLAGS libconftest.a @conftest.lst >&AS_MESSAGE_LOG_FD'
+      AC_TRY_EVAL([lt_ar_try])
+      if test "$ac_status" -eq 0; then
+	# Ensure the archiver fails upon bogus file names.
+	rm -f conftest.$ac_objext libconftest.a
+	AC_TRY_EVAL([lt_ar_try])
+	if test "$ac_status" -ne 0; then
+          lt_cv_ar_at_file=@
+        fi
+      fi
+      rm -f conftest.* libconftest.a
+     ])
+  ])
+
+if test "x$lt_cv_ar_at_file" = xno; then
+  archiver_list_spec=
+else
+  archiver_list_spec=$lt_cv_ar_at_file
+fi
+_LT_DECL([], [archiver_list_spec], [1],
+  [How to feed a file listing to the archiver])
+])# _LT_PROG_AR
+
+
 # _LT_CMD_OLD_ARCHIVE
 # -------------------
 m4_defun([_LT_CMD_OLD_ARCHIVE],
-[AC_CHECK_TOOL(AR, ar, false)
-test -z "$AR" && AR=ar
-test -z "$AR_FLAGS" && AR_FLAGS=cru
-_LT_DECL([], [AR], [1], [The archiver])
-_LT_DECL([], [AR_FLAGS], [1])
+[_LT_PROG_AR
 
 AC_CHECK_TOOL(STRIP, strip, :)
 test -z "$STRIP" && STRIP=:
@@ -1395,18 +1485,27 @@
 if test -n "$RANLIB"; then
   case $host_os in
   openbsd*)
-    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB -t \$oldlib"
+    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB -t \$tool_oldlib"
     ;;
   *)
-    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB \$oldlib"
+    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB \$tool_oldlib"
     ;;
   esac
-  old_archive_cmds="$old_archive_cmds~\$RANLIB \$oldlib"
+  old_archive_cmds="$old_archive_cmds~\$RANLIB \$tool_oldlib"
 fi
+
+case $host_os in
+  darwin*)
+    lock_old_archive_extraction=yes ;;
+  *)
+    lock_old_archive_extraction=no ;;
+esac
 _LT_DECL([], [old_postinstall_cmds], [2])
 _LT_DECL([], [old_postuninstall_cmds], [2])
 _LT_TAGDECL([], [old_archive_cmds], [2],
     [Commands used to build an old-style archive])
+_LT_DECL([], [lock_old_archive_extraction], [0],
+    [Whether to use a lock for old archive extraction])
 ])# _LT_CMD_OLD_ARCHIVE
 
 
@@ -1431,15 +1530,15 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [[^ ]]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:__oline__: $lt_compile\"" >&AS_MESSAGE_LOG_FD)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&AS_MESSAGE_LOG_FD)
    (eval "$lt_compile" 2>conftest.err)
    ac_status=$?
    cat conftest.err >&AS_MESSAGE_LOG_FD
-   echo "$as_me:__oline__: \$? = $ac_status" >&AS_MESSAGE_LOG_FD
+   echo "$as_me:$LINENO: \$? = $ac_status" >&AS_MESSAGE_LOG_FD
    if (exit $ac_status) && test -s "$ac_outfile"; then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings other than the usual output.
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' >conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' >conftest.exp
      $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
      if test ! -s conftest.er2 || diff conftest.exp conftest.er2 >/dev/null; then
        $2=yes
@@ -1479,7 +1578,7 @@
      if test -s conftest.err; then
        # Append any errors to the config.log.
        cat conftest.err 1>&AS_MESSAGE_LOG_FD
-       $ECHO "X$_lt_linker_boilerplate" | $Xsed -e '/^$/d' > conftest.exp
+       $ECHO "$_lt_linker_boilerplate" | $SED '/^$/d' > conftest.exp
        $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
        if diff conftest.exp conftest.er2 >/dev/null; then
          $2=yes
@@ -1542,6 +1641,11 @@
     lt_cv_sys_max_cmd_len=8192;
     ;;
 
+  mint*)
+    # On MiNT this can take a long time and run out of memory.
+    lt_cv_sys_max_cmd_len=8192;
+    ;;
+
   amigaos*)
     # On AmigaOS with pdksh, this test takes hours, literally.
     # So we just punt and use a minimum line length of 8192.
@@ -1567,6 +1671,11 @@
     lt_cv_sys_max_cmd_len=196608
     ;;
 
+  os2*)
+    # The test takes a long time on OS/2.
+    lt_cv_sys_max_cmd_len=8192
+    ;;
+
   osf*)
     # Dr. Hans Ekkehard Plesser reports seeing a kernel panic running configure
     # due to this test when exec_disable_arg_limit is 1 on Tru64. It is not
@@ -1606,8 +1715,8 @@
       # If test is not a shell built-in, we'll probably end up computing a
       # maximum length that is only half of the actual maximum length, but
       # we can't tell.
-      while { test "X"`$SHELL [$]0 --fallback-echo "X$teststring$teststring" 2>/dev/null` \
-	         = "XX$teststring$teststring"; } >/dev/null 2>&1 &&
+      while { test "X"`env echo "$teststring$teststring" 2>/dev/null` \
+	         = "X$teststring$teststring"; } >/dev/null 2>&1 &&
 	      test $i != 17 # 1/2 MB should be enough
       do
         i=`expr $i + 1`
@@ -1658,7 +1767,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-[#line __oline__ "configure"
+[#line $LINENO "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -1699,7 +1808,13 @@
 #  endif
 #endif
 
-void fnord() { int i=42;}
+/* When -fvisbility=hidden is used, assume the code has been annotated
+   correspondingly for the symbols needed.  */
+#if defined(__GNUC__) && (((__GNUC__ == 3) && (__GNUC_MINOR__ >= 3)) || (__GNUC__ > 3))
+int fnord () __attribute__((visibility("default")));
+#endif
+
+int fnord () { return 42; }
 int main ()
 {
   void *self = dlopen (0, LT_DLGLOBAL|LT_DLLAZY_OR_NOW);
@@ -1708,7 +1823,11 @@
   if (self)
     {
       if (dlsym (self,"fnord"))       status = $lt_dlno_uscore;
-      else if (dlsym( self,"_fnord")) status = $lt_dlneed_uscore;
+      else
+        {
+	  if (dlsym( self,"_fnord"))  status = $lt_dlneed_uscore;
+          else puts (dlerror ());
+	}
       /* dlclose (self); */
     }
   else
@@ -1884,16 +2003,16 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [[^ ]]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:__oline__: $lt_compile\"" >&AS_MESSAGE_LOG_FD)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&AS_MESSAGE_LOG_FD)
    (eval "$lt_compile" 2>out/conftest.err)
    ac_status=$?
    cat out/conftest.err >&AS_MESSAGE_LOG_FD
-   echo "$as_me:__oline__: \$? = $ac_status" >&AS_MESSAGE_LOG_FD
+   echo "$as_me:$LINENO: \$? = $ac_status" >&AS_MESSAGE_LOG_FD
    if (exit $ac_status) && test -s out/conftest2.$ac_objext
    then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' > out/conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' > out/conftest.exp
      $SED '/^$/d; /^ *+/d' out/conftest.err >out/conftest.er2
      if test ! -s out/conftest.er2 || diff out/conftest.exp out/conftest.er2 >/dev/null; then
        _LT_TAGVAR(lt_cv_prog_compiler_c_o, $1)=yes
@@ -2052,6 +2171,7 @@
 m4_require([_LT_FILEUTILS_DEFAULTS])dnl
 m4_require([_LT_DECL_OBJDUMP])dnl
 m4_require([_LT_DECL_SED])dnl
+m4_require([_LT_CHECK_SHELL_FEATURES])dnl
 AC_MSG_CHECKING([dynamic linker characteristics])
 m4_if([$1],
 	[], [
@@ -2060,16 +2180,23 @@
     darwin*) lt_awk_arg="/^libraries:/,/LR/" ;;
     *) lt_awk_arg="/^libraries:/" ;;
   esac
-  lt_search_path_spec=`$CC -print-search-dirs | awk $lt_awk_arg | $SED -e "s/^libraries://" -e "s,=/,/,g"`
-  if $ECHO "$lt_search_path_spec" | $GREP ';' >/dev/null ; then
+  case $host_os in
+    mingw* | cegcc*) lt_sed_strip_eq="s,=\([[A-Za-z]]:\),\1,g" ;;
+    *) lt_sed_strip_eq="s,=/,/,g" ;;
+  esac
+  lt_search_path_spec=`$CC -print-search-dirs | awk $lt_awk_arg | $SED -e "s/^libraries://" -e $lt_sed_strip_eq`
+  case $lt_search_path_spec in
+  *\;*)
     # if the path contains ";" then we assume it to be the separator
     # otherwise default to the standard path separator (i.e. ":") - it is
     # assumed that no part of a normal pathname contains ";" but that should
     # okay in the real world where ";" in dirpaths is itself problematic.
-    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED -e 's/;/ /g'`
-  else
-    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED  -e "s/$PATH_SEPARATOR/ /g"`
-  fi
+    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED 's/;/ /g'`
+    ;;
+  *)
+    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED "s/$PATH_SEPARATOR/ /g"`
+    ;;
+  esac
   # Ok, now we have the path, separated by spaces, we can step through it
   # and add multilib dir if necessary.
   lt_tmp_lt_search_path_spec=
@@ -2082,7 +2209,7 @@
 	lt_tmp_lt_search_path_spec="$lt_tmp_lt_search_path_spec $lt_sys_path"
     fi
   done
-  lt_search_path_spec=`$ECHO $lt_tmp_lt_search_path_spec | awk '
+  lt_search_path_spec=`$ECHO "$lt_tmp_lt_search_path_spec" | awk '
 BEGIN {RS=" "; FS="/|\n";} {
   lt_foo="";
   lt_count=0;
@@ -2102,7 +2229,13 @@
   if (lt_foo != "") { lt_freq[[lt_foo]]++; }
   if (lt_freq[[lt_foo]] == 1) { print lt_foo; }
 }'`
-  sys_lib_search_path_spec=`$ECHO $lt_search_path_spec`
+  # AWK program above erroneously prepends '/' to C:/dos/paths
+  # for these hosts.
+  case $host_os in
+    mingw* | cegcc*) lt_search_path_spec=`$ECHO "$lt_search_path_spec" |\
+      $SED 's,/\([[A-Za-z]]:\),\1,g'` ;;
+  esac
+  sys_lib_search_path_spec=`$ECHO "$lt_search_path_spec" | $lt_NL2SP`
 else
   sys_lib_search_path_spec="/lib /usr/lib /usr/local/lib"
 fi])
@@ -2128,7 +2261,7 @@
 
 case $host_os in
 aix3*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix $libname.a'
   shlibpath_var=LIBPATH
 
@@ -2137,7 +2270,7 @@
   ;;
 
 aix[[4-9]]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   hardcode_into_libs=yes
@@ -2190,7 +2323,7 @@
   m68k)
     library_names_spec='$libname.ixlibrary $libname.a'
     # Create ${libname}_ixlibrary.a entries in /sys/libs.
-    finish_eval='for lib in `ls $libdir/*.ixlibrary 2>/dev/null`; do libname=`$ECHO "X$lib" | $Xsed -e '\''s%^.*/\([[^/]]*\)\.ixlibrary$%\1%'\''`; test $RM /sys/libs/${libname}_ixlibrary.a; $show "cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a"; cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a || exit 1; done'
+    finish_eval='for lib in `ls $libdir/*.ixlibrary 2>/dev/null`; do libname=`func_echo_all "$lib" | $SED '\''s%^.*/\([[^/]]*\)\.ixlibrary$%\1%'\''`; test $RM /sys/libs/${libname}_ixlibrary.a; $show "cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a"; cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a || exit 1; done'
     ;;
   esac
   ;;
@@ -2202,7 +2335,7 @@
   ;;
 
 bsdi[[45]]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
@@ -2221,8 +2354,9 @@
   need_version=no
   need_lib_prefix=no
 
-  case $GCC,$host_os in
-  yes,cygwin* | yes,mingw* | yes,pw32* | yes,cegcc*)
+  case $GCC,$cc_basename in
+  yes,*)
+    # gcc
     library_names_spec='$libname.dll.a'
     # DLL is installed to $(libdir)/../bin by postinstall_cmds
     postinstall_cmds='base_file=`basename \${file}`~
@@ -2243,36 +2377,83 @@
     cygwin*)
       # Cygwin DLLs use 'cyg' prefix rather than 'lib'
       soname_spec='`echo ${libname} | sed -e 's/^lib/cyg/'``echo ${release} | $SED -e 's/[[.]]/-/g'`${versuffix}${shared_ext}'
-      sys_lib_search_path_spec="/usr/lib /lib/w32api /lib /usr/local/lib"
+m4_if([$1], [],[
+      sys_lib_search_path_spec="$sys_lib_search_path_spec /usr/lib/w32api"])
       ;;
     mingw* | cegcc*)
       # MinGW DLLs use traditional 'lib' prefix
       soname_spec='${libname}`echo ${release} | $SED -e 's/[[.]]/-/g'`${versuffix}${shared_ext}'
-      sys_lib_search_path_spec=`$CC -print-search-dirs | $GREP "^libraries:" | $SED -e "s/^libraries://" -e "s,=/,/,g"`
-      if $ECHO "$sys_lib_search_path_spec" | [$GREP ';[c-zC-Z]:/' >/dev/null]; then
-        # It is most probably a Windows format PATH printed by
-        # mingw gcc, but we are running on Cygwin. Gcc prints its search
-        # path with ; separators, and with drive letters. We can handle the
-        # drive letters (cygwin fileutils understands them), so leave them,
-        # especially as we might pass files found there to a mingw objdump,
-        # which wouldn't understand a cygwinified path. Ahh.
-        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e 's/;/ /g'`
-      else
-        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED  -e "s/$PATH_SEPARATOR/ /g"`
-      fi
       ;;
     pw32*)
       # pw32 DLLs use 'pw' prefix rather than 'lib'
       library_names_spec='`echo ${libname} | sed -e 's/^lib/pw/'``echo ${release} | $SED -e 's/[[.]]/-/g'`${versuffix}${shared_ext}'
       ;;
     esac
+    dynamic_linker='Win32 ld.exe'
+    ;;
+
+  *,cl*)
+    # Native MSVC
+    libname_spec='$name'
+    soname_spec='${libname}`echo ${release} | $SED -e 's/[[.]]/-/g'`${versuffix}${shared_ext}'
+    library_names_spec='${libname}.dll.lib'
+
+    case $build_os in
+    mingw*)
+      sys_lib_search_path_spec=
+      lt_save_ifs=$IFS
+      IFS=';'
+      for lt_path in $LIB
+      do
+        IFS=$lt_save_ifs
+        # Let DOS variable expansion print the short 8.3 style file name.
+        lt_path=`cd "$lt_path" 2>/dev/null && cmd //C "for %i in (".") do @echo %~si"`
+        sys_lib_search_path_spec="$sys_lib_search_path_spec $lt_path"
+      done
+      IFS=$lt_save_ifs
+      # Convert to MSYS style.
+      sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | sed -e 's|\\\\|/|g' -e 's| \\([[a-zA-Z]]\\):| /\\1|g' -e 's|^ ||'`
+      ;;
+    cygwin*)
+      # Convert to unix form, then to dos form, then back to unix form
+      # but this time dos style (no spaces!) so that the unix form looks
+      # like /cygdrive/c/PROGRA~1:/cygdr...
+      sys_lib_search_path_spec=`cygpath --path --unix "$LIB"`
+      sys_lib_search_path_spec=`cygpath --path --dos "$sys_lib_search_path_spec" 2>/dev/null`
+      sys_lib_search_path_spec=`cygpath --path --unix "$sys_lib_search_path_spec" | $SED -e "s/$PATH_SEPARATOR/ /g"`
+      ;;
+    *)
+      sys_lib_search_path_spec="$LIB"
+      if $ECHO "$sys_lib_search_path_spec" | [$GREP ';[c-zC-Z]:/' >/dev/null]; then
+        # It is most probably a Windows format PATH.
+        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e 's/;/ /g'`
+      else
+        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e "s/$PATH_SEPARATOR/ /g"`
+      fi
+      # FIXME: find the short name or the path components, as spaces are
+      # common. (e.g. "Program Files" -> "PROGRA~1")
+      ;;
+    esac
+
+    # DLL is installed to $(libdir)/../bin by postinstall_cmds
+    postinstall_cmds='base_file=`basename \${file}`~
+      dlpath=`$SHELL 2>&1 -c '\''. $dir/'\''\${base_file}'\''i; echo \$dlname'\''`~
+      dldir=$destdir/`dirname \$dlpath`~
+      test -d \$dldir || mkdir -p \$dldir~
+      $install_prog $dir/$dlname \$dldir/$dlname'
+    postuninstall_cmds='dldll=`$SHELL 2>&1 -c '\''. $file; echo \$dlname'\''`~
+      dlpath=$dir/\$dldll~
+       $RM \$dlpath'
+    shlibpath_overrides_runpath=yes
+    dynamic_linker='Win32 link.exe'
     ;;
 
   *)
+    # Assume MSVC wrapper
     library_names_spec='${libname}`echo ${release} | $SED -e 's/[[.]]/-/g'`${versuffix}${shared_ext} $libname.lib'
+    dynamic_linker='Win32 ld.exe'
     ;;
   esac
-  dynamic_linker='Win32 ld.exe'
   # FIXME: first we should search . and the directory the executable is in
   shlibpath_var=PATH
   ;;
@@ -2293,7 +2474,7 @@
   ;;
 
 dgux*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname$shared_ext'
@@ -2301,10 +2482,6 @@
   shlibpath_var=LD_LIBRARY_PATH
   ;;
 
-freebsd1*)
-  dynamic_linker=no
-  ;;
-
 freebsd* | dragonfly*)
   # DragonFly does not have aout.  When/if they implement a new
   # versioning mechanism, adjust this.
@@ -2312,7 +2489,7 @@
     objformat=`/usr/bin/objformat`
   else
     case $host_os in
-    freebsd[[123]]*) objformat=aout ;;
+    freebsd[[23]].*) objformat=aout ;;
     *) objformat=elf ;;
     esac
   fi
@@ -2330,7 +2507,7 @@
   esac
   shlibpath_var=LD_LIBRARY_PATH
   case $host_os in
-  freebsd2*)
+  freebsd2.*)
     shlibpath_overrides_runpath=yes
     ;;
   freebsd3.[[01]]* | freebsdelf3.[[01]]*)
@@ -2349,13 +2526,16 @@
   esac
   ;;
 
-gnu*)
-  version_type=linux
+haiku*)
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
+  dynamic_linker="$host_os runtime_loader"
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}${major} ${libname}${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
-  shlibpath_var=LD_LIBRARY_PATH
+  shlibpath_var=LIBRARY_PATH
+  shlibpath_overrides_runpath=yes
+  sys_lib_dlsearch_path_spec='/boot/home/config/lib /boot/common/lib /boot/system/lib'
   hardcode_into_libs=yes
   ;;
 
@@ -2401,12 +2581,14 @@
     soname_spec='${libname}${release}${shared_ext}$major'
     ;;
   esac
-  # HP-UX runs *really* slowly unless shared libraries are mode 555.
+  # HP-UX runs *really* slowly unless shared libraries are mode 555, ...
   postinstall_cmds='chmod 555 $lib'
+  # or fails outright, so override atomically:
+  install_override_mode=555
   ;;
 
 interix[[3-9]]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major ${libname}${shared_ext}'
@@ -2422,7 +2604,7 @@
     nonstopux*) version_type=nonstopux ;;
     *)
 	if test "$lt_cv_prog_gnu_ld" = yes; then
-		version_type=linux
+		version_type=linux # correct to gnu/linux during the next big refactor
 	else
 		version_type=irix
 	fi ;;
@@ -2459,9 +2641,9 @@
   dynamic_linker=no
   ;;
 
-# This must be Linux ELF.
-linux* | k*bsd*-gnu)
-  version_type=linux
+# This must be glibc/ELF.
+linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -2469,16 +2651,21 @@
   finish_cmds='PATH="\$PATH:/sbin" ldconfig -n $libdir'
   shlibpath_var=LD_LIBRARY_PATH
   shlibpath_overrides_runpath=no
+
   # Some binutils ld are patched to set DT_RUNPATH
-  save_LDFLAGS=$LDFLAGS
-  save_libdir=$libdir
-  eval "libdir=/foo; wl=\"$_LT_TAGVAR(lt_prog_compiler_wl, $1)\"; \
-       LDFLAGS=\"\$LDFLAGS $_LT_TAGVAR(hardcode_libdir_flag_spec, $1)\""
-  AC_LINK_IFELSE([AC_LANG_PROGRAM([],[])],
-    [AS_IF([ ($OBJDUMP -p conftest$ac_exeext) 2>/dev/null | grep "RUNPATH.*$libdir" >/dev/null],
-       [shlibpath_overrides_runpath=yes])])
-  LDFLAGS=$save_LDFLAGS
-  libdir=$save_libdir
+  AC_CACHE_VAL([lt_cv_shlibpath_overrides_runpath],
+    [lt_cv_shlibpath_overrides_runpath=no
+    save_LDFLAGS=$LDFLAGS
+    save_libdir=$libdir
+    eval "libdir=/foo; wl=\"$_LT_TAGVAR(lt_prog_compiler_wl, $1)\"; \
+	 LDFLAGS=\"\$LDFLAGS $_LT_TAGVAR(hardcode_libdir_flag_spec, $1)\""
+    AC_LINK_IFELSE([AC_LANG_PROGRAM([],[])],
+      [AS_IF([ ($OBJDUMP -p conftest$ac_exeext) 2>/dev/null | grep "RUNPATH.*$libdir" >/dev/null],
+	 [lt_cv_shlibpath_overrides_runpath=yes])])
+    LDFLAGS=$save_LDFLAGS
+    libdir=$save_libdir
+    ])
+  shlibpath_overrides_runpath=$lt_cv_shlibpath_overrides_runpath
 
   # This implies no fast_install, which is unacceptable.
   # Some rework will be needed to allow for fast_install
@@ -2487,7 +2674,7 @@
 
   # Append ld.so.conf contents to the search path
   if test -f /etc/ld.so.conf; then
-    lt_ld_extra=`awk '/^include / { system(sprintf("cd /etc; cat %s 2>/dev/null", \[$]2)); skip = 1; } { if (!skip) print \[$]0; skip = 0; }' < /etc/ld.so.conf | $SED -e 's/#.*//;/^[	 ]*hwcap[	 ]/d;s/[:,	]/ /g;s/=[^=]*$//;s/=[^= ]* / /g;/^$/d' | tr '\n' ' '`
+    lt_ld_extra=`awk '/^include / { system(sprintf("cd /etc; cat %s 2>/dev/null", \[$]2)); skip = 1; } { if (!skip) print \[$]0; skip = 0; }' < /etc/ld.so.conf | $SED -e 's/#.*//;/^[	 ]*hwcap[	 ]/d;s/[:,	]/ /g;s/=[^=]*$//;s/=[^= ]* / /g;s/"//g;/^$/d' | tr '\n' ' '`
     sys_lib_dlsearch_path_spec="/lib /usr/lib $lt_ld_extra"
   fi
 
@@ -2531,7 +2718,7 @@
   ;;
 
 newsos6)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   shlibpath_var=LD_LIBRARY_PATH
   shlibpath_overrides_runpath=yes
@@ -2600,7 +2787,7 @@
   ;;
 
 solaris*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -2625,7 +2812,7 @@
   ;;
 
 sysv4 | sysv4.3*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
   shlibpath_var=LD_LIBRARY_PATH
@@ -2649,7 +2836,7 @@
 
 sysv4*MP*)
   if test -d /usr/nec ;then
-    version_type=linux
+    version_type=linux # correct to gnu/linux during the next big refactor
     library_names_spec='$libname${shared_ext}.$versuffix $libname${shared_ext}.$major $libname${shared_ext}'
     soname_spec='$libname${shared_ext}.$major'
     shlibpath_var=LD_LIBRARY_PATH
@@ -2680,7 +2867,7 @@
 
 tpf*)
   # TPF is a cross-target only.  Preferred cross-host = GNU/Linux.
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -2690,7 +2877,7 @@
   ;;
 
 uts4*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
   shlibpath_var=LD_LIBRARY_PATH
@@ -2732,6 +2919,8 @@
     The last name is the one that the linker finds with -lNAME]])
 _LT_DECL([], [soname_spec], [1],
     [[The coded name of the library, if different from the real name]])
+_LT_DECL([], [install_override_mode], [1],
+    [Permission mode override for installation of shared libraries])
 _LT_DECL([], [postinstall_cmds], [2],
     [Command to use after installation of a shared archive])
 _LT_DECL([], [postuninstall_cmds], [2],
@@ -2844,6 +3033,7 @@
 AC_REQUIRE([AC_CANONICAL_BUILD])dnl
 m4_require([_LT_DECL_SED])dnl
 m4_require([_LT_DECL_EGREP])dnl
+m4_require([_LT_PROG_ECHO_BACKSLASH])dnl
 
 AC_ARG_WITH([gnu-ld],
     [AS_HELP_STRING([--with-gnu-ld],
@@ -2965,6 +3155,11 @@
 esac
 reload_cmds='$LD$reload_flag -o $output$reload_objs'
 case $host_os in
+  cygwin* | mingw* | pw32* | cegcc*)
+    if test "$GCC" != yes; then
+      reload_cmds=false
+    fi
+    ;;
   darwin*)
     if test "$GCC" = yes; then
       reload_cmds='$LTCC $LTCFLAGS -nostdlib ${wl}-r -o $output$reload_objs'
@@ -2973,8 +3168,8 @@
     fi
     ;;
 esac
-_LT_DECL([], [reload_flag], [1], [How to create reloadable object files])dnl
-_LT_DECL([], [reload_cmds], [2])dnl
+_LT_TAGDECL([], [reload_flag], [1], [How to create reloadable object files])dnl
+_LT_TAGDECL([], [reload_cmds], [2])dnl
 ])# _LT_CMD_RELOAD
 
 
@@ -3026,16 +3221,18 @@
   # Base MSYS/MinGW do not provide the 'file' command needed by
   # func_win32_libid shell function, so use a weaker test based on 'objdump',
   # unless we find 'file', for example because we are cross-compiling.
-  if ( file / ) >/dev/null 2>&1; then
+  # func_win32_libid assumes BSD nm, so disallow it if using MS dumpbin.
+  if ( test "$lt_cv_nm_interface" = "BSD nm" && file / ) >/dev/null 2>&1; then
     lt_cv_deplibs_check_method='file_magic ^x86 archive import|^x86 DLL'
     lt_cv_file_magic_cmd='func_win32_libid'
   else
-    lt_cv_deplibs_check_method='file_magic file format pei*-i386(.*architecture: i386)?'
+    # Keep this pattern in sync with the one in func_win32_libid.
+    lt_cv_deplibs_check_method='file_magic file format (pei*-i386(.*architecture: i386)?|pe-arm-wince|pe-x86-64)'
     lt_cv_file_magic_cmd='$OBJDUMP -f'
   fi
   ;;
 
-cegcc)
+cegcc*)
   # use the weaker test based on 'objdump'. See mingw*.
   lt_cv_deplibs_check_method='file_magic file format pe-arm-.*little(.*architecture: arm)?'
   lt_cv_file_magic_cmd='$OBJDUMP -f'
@@ -3061,7 +3258,7 @@
   fi
   ;;
 
-gnu*)
+haiku*)
   lt_cv_deplibs_check_method=pass_all
   ;;
 
@@ -3073,11 +3270,11 @@
     lt_cv_file_magic_test_file=/usr/lib/hpux32/libc.so
     ;;
   hppa*64*)
-    [lt_cv_deplibs_check_method='file_magic (s[0-9][0-9][0-9]|ELF-[0-9][0-9]) shared object file - PA-RISC [0-9].[0-9]']
+    [lt_cv_deplibs_check_method='file_magic (s[0-9][0-9][0-9]|ELF[ -][0-9][0-9])(-bit)?( [LM]SB)? shared object( file)?[, -]* PA-RISC [0-9]\.[0-9]']
     lt_cv_file_magic_test_file=/usr/lib/pa20_64/libc.sl
     ;;
   *)
-    lt_cv_deplibs_check_method='file_magic (s[[0-9]][[0-9]][[0-9]]|PA-RISC[[0-9]].[[0-9]]) shared library'
+    lt_cv_deplibs_check_method='file_magic (s[[0-9]][[0-9]][[0-9]]|PA-RISC[[0-9]]\.[[0-9]]) shared library'
     lt_cv_file_magic_test_file=/usr/lib/libc.sl
     ;;
   esac
@@ -3098,8 +3295,8 @@
   lt_cv_deplibs_check_method=pass_all
   ;;
 
-# This must be Linux ELF.
-linux* | k*bsd*-gnu)
+# This must be glibc/ELF.
+linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
   lt_cv_deplibs_check_method=pass_all
   ;;
 
@@ -3177,6 +3374,21 @@
   ;;
 esac
 ])
+
+file_magic_glob=
+want_nocaseglob=no
+if test "$build" = "$host"; then
+  case $host_os in
+  mingw* | pw32*)
+    if ( shopt | grep nocaseglob ) >/dev/null 2>&1; then
+      want_nocaseglob=yes
+    else
+      file_magic_glob=`echo aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ | $SED -e "s/\(..\)/s\/[[\1]]\/[[\1]]\/g;/g"`
+    fi
+    ;;
+  esac
+fi
+
 file_magic_cmd=$lt_cv_file_magic_cmd
 deplibs_check_method=$lt_cv_deplibs_check_method
 test -z "$deplibs_check_method" && deplibs_check_method=unknown
@@ -3184,7 +3396,11 @@
 _LT_DECL([], [deplibs_check_method], [1],
     [Method to check whether dependent libraries are shared objects])
 _LT_DECL([], [file_magic_cmd], [1],
-    [Command to use when deplibs_check_method == "file_magic"])
+    [Command to use when deplibs_check_method = "file_magic"])
+_LT_DECL([], [file_magic_glob], [1],
+    [How to find potential files when deplibs_check_method = "file_magic"])
+_LT_DECL([], [want_nocaseglob], [1],
+    [Find potential files using nocaseglob when deplibs_check_method = "file_magic"])
 ])# _LT_CHECK_MAGIC_METHOD
 
 
@@ -3241,7 +3457,19 @@
   NM="$lt_cv_path_NM"
 else
   # Didn't find any BSD compatible name lister, look for dumpbin.
-  AC_CHECK_TOOLS(DUMPBIN, ["dumpbin -symbols" "link -dump -symbols"], :)
+  if test -n "$DUMPBIN"; then :
+    # Let the user override the test.
+  else
+    AC_CHECK_TOOLS(DUMPBIN, [dumpbin "link -dump"], :)
+    case `$DUMPBIN -symbols /dev/null 2>&1 | sed '1q'` in
+    *COFF*)
+      DUMPBIN="$DUMPBIN -symbols"
+      ;;
+    *)
+      DUMPBIN=:
+      ;;
+    esac
+  fi
   AC_SUBST([DUMPBIN])
   if test "$DUMPBIN" != ":"; then
     NM="$DUMPBIN"
@@ -3254,13 +3482,13 @@
 AC_CACHE_CHECK([the name lister ($NM) interface], [lt_cv_nm_interface],
   [lt_cv_nm_interface="BSD nm"
   echo "int some_variable = 0;" > conftest.$ac_ext
-  (eval echo "\"\$as_me:__oline__: $ac_compile\"" >&AS_MESSAGE_LOG_FD)
+  (eval echo "\"\$as_me:$LINENO: $ac_compile\"" >&AS_MESSAGE_LOG_FD)
   (eval "$ac_compile" 2>conftest.err)
   cat conftest.err >&AS_MESSAGE_LOG_FD
-  (eval echo "\"\$as_me:__oline__: $NM \\\"conftest.$ac_objext\\\"\"" >&AS_MESSAGE_LOG_FD)
+  (eval echo "\"\$as_me:$LINENO: $NM \\\"conftest.$ac_objext\\\"\"" >&AS_MESSAGE_LOG_FD)
   (eval "$NM \"conftest.$ac_objext\"" 2>conftest.err > conftest.out)
   cat conftest.err >&AS_MESSAGE_LOG_FD
-  (eval echo "\"\$as_me:__oline__: output\"" >&AS_MESSAGE_LOG_FD)
+  (eval echo "\"\$as_me:$LINENO: output\"" >&AS_MESSAGE_LOG_FD)
   cat conftest.out >&AS_MESSAGE_LOG_FD
   if $GREP 'External.*some_variable' conftest.out > /dev/null; then
     lt_cv_nm_interface="MS dumpbin"
@@ -3275,6 +3503,67 @@
 dnl AC_DEFUN([AM_PROG_NM], [])
 dnl AC_DEFUN([AC_PROG_NM], [])
 
+# _LT_CHECK_SHAREDLIB_FROM_LINKLIB
+# --------------------------------
+# how to determine the name of the shared library
+# associated with a specific link library.
+#  -- PORTME fill in with the dynamic library characteristics
+m4_defun([_LT_CHECK_SHAREDLIB_FROM_LINKLIB],
+[m4_require([_LT_DECL_EGREP])
+m4_require([_LT_DECL_OBJDUMP])
+m4_require([_LT_DECL_DLLTOOL])
+AC_CACHE_CHECK([how to associate runtime and link libraries],
+lt_cv_sharedlib_from_linklib_cmd,
+[lt_cv_sharedlib_from_linklib_cmd='unknown'
+
+case $host_os in
+cygwin* | mingw* | pw32* | cegcc*)
+  # two different shell functions defined in ltmain.sh
+  # decide which to use based on capabilities of $DLLTOOL
+  case `$DLLTOOL --help 2>&1` in
+  *--identify-strict*)
+    lt_cv_sharedlib_from_linklib_cmd=func_cygming_dll_for_implib
+    ;;
+  *)
+    lt_cv_sharedlib_from_linklib_cmd=func_cygming_dll_for_implib_fallback
+    ;;
+  esac
+  ;;
+*)
+  # fallback: assume linklib IS sharedlib
+  lt_cv_sharedlib_from_linklib_cmd="$ECHO"
+  ;;
+esac
+])
+sharedlib_from_linklib_cmd=$lt_cv_sharedlib_from_linklib_cmd
+test -z "$sharedlib_from_linklib_cmd" && sharedlib_from_linklib_cmd=$ECHO
+
+_LT_DECL([], [sharedlib_from_linklib_cmd], [1],
+    [Command to associate shared and link libraries])
+])# _LT_CHECK_SHAREDLIB_FROM_LINKLIB
+
+
+# _LT_PATH_MANIFEST_TOOL
+# ----------------------
+# locate the manifest tool
+m4_defun([_LT_PATH_MANIFEST_TOOL],
+[AC_CHECK_TOOL(MANIFEST_TOOL, mt, :)
+test -z "$MANIFEST_TOOL" && MANIFEST_TOOL=mt
+AC_CACHE_CHECK([if $MANIFEST_TOOL is a manifest tool], [lt_cv_path_mainfest_tool],
+  [lt_cv_path_mainfest_tool=no
+  echo "$as_me:$LINENO: $MANIFEST_TOOL '-?'" >&AS_MESSAGE_LOG_FD
+  $MANIFEST_TOOL '-?' 2>conftest.err > conftest.out
+  cat conftest.err >&AS_MESSAGE_LOG_FD
+  if $GREP 'Manifest Tool' conftest.out > /dev/null; then
+    lt_cv_path_mainfest_tool=yes
+  fi
+  rm -f conftest*])
+if test "x$lt_cv_path_mainfest_tool" != xyes; then
+  MANIFEST_TOOL=:
+fi
+_LT_DECL([], [MANIFEST_TOOL], [1], [Manifest tool])dnl
+])# _LT_PATH_MANIFEST_TOOL
+
 
 # LT_LIB_M
 # --------
@@ -3283,7 +3572,7 @@
 [AC_REQUIRE([AC_CANONICAL_HOST])dnl
 LIBM=
 case $host in
-*-*-beos* | *-*-cygwin* | *-*-pw32* | *-*-darwin*)
+*-*-beos* | *-*-cegcc* | *-*-cygwin* | *-*-haiku* | *-*-pw32* | *-*-darwin*)
   # These system don't have libm, or don't need it
   ;;
 *-ncr-sysv4.3*)
@@ -3311,7 +3600,12 @@
 _LT_TAGVAR(lt_prog_compiler_no_builtin_flag, $1)=
 
 if test "$GCC" = yes; then
-  _LT_TAGVAR(lt_prog_compiler_no_builtin_flag, $1)=' -fno-builtin'
+  case $cc_basename in
+  nvcc*)
+    _LT_TAGVAR(lt_prog_compiler_no_builtin_flag, $1)=' -Xcompiler -fno-builtin' ;;
+  *)
+    _LT_TAGVAR(lt_prog_compiler_no_builtin_flag, $1)=' -fno-builtin' ;;
+  esac
 
   _LT_COMPILER_OPTION([if $compiler supports -fno-rtti -fno-exceptions],
     lt_cv_prog_compiler_rtti_exceptions,
@@ -3328,6 +3622,7 @@
 m4_defun([_LT_CMD_GLOBAL_SYMBOLS],
 [AC_REQUIRE([AC_CANONICAL_HOST])dnl
 AC_REQUIRE([AC_PROG_CC])dnl
+AC_REQUIRE([AC_PROG_AWK])dnl
 AC_REQUIRE([LT_PATH_NM])dnl
 AC_REQUIRE([LT_PATH_LD])dnl
 m4_require([_LT_DECL_SED])dnl
@@ -3395,8 +3690,8 @@
 lt_cv_sys_global_symbol_to_cdecl="sed -n -e 's/^T .* \(.*\)$/extern int \1();/p' -e 's/^$symcode* .* \(.*\)$/extern char \1;/p'"
 
 # Transform an extracted symbol line into symbol name and symbol address
-lt_cv_sys_global_symbol_to_c_name_address="sed -n -e 's/^: \([[^ ]]*\) $/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([[^ ]]*\) \([[^ ]]*\)$/  {\"\2\", (void *) \&\2},/p'"
-lt_cv_sys_global_symbol_to_c_name_address_lib_prefix="sed -n -e 's/^: \([[^ ]]*\) $/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([[^ ]]*\) \(lib[[^ ]]*\)$/  {\"\2\", (void *) \&\2},/p' -e 's/^$symcode* \([[^ ]]*\) \([[^ ]]*\)$/  {\"lib\2\", (void *) \&\2},/p'"
+lt_cv_sys_global_symbol_to_c_name_address="sed -n -e 's/^: \([[^ ]]*\)[[ ]]*$/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([[^ ]]*\) \([[^ ]]*\)$/  {\"\2\", (void *) \&\2},/p'"
+lt_cv_sys_global_symbol_to_c_name_address_lib_prefix="sed -n -e 's/^: \([[^ ]]*\)[[ ]]*$/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([[^ ]]*\) \(lib[[^ ]]*\)$/  {\"\2\", (void *) \&\2},/p' -e 's/^$symcode* \([[^ ]]*\) \([[^ ]]*\)$/  {\"lib\2\", (void *) \&\2},/p'"
 
 # Handle CRLF in mingw tool chain
 opt_cr=
@@ -3420,6 +3715,7 @@
     # which start with @ or ?.
     lt_cv_sys_global_symbol_pipe="$AWK ['"\
 "     {last_section=section; section=\$ 3};"\
+"     /^COFF SYMBOL TABLE/{for(i in hide) delete hide[i]};"\
 "     /Section length .*#relocs.*(pick any)/{hide[last_section]=1};"\
 "     \$ 0!~/External *\|/{next};"\
 "     / 0+ UNDEF /{next}; / UNDEF \([^|]\)*()/{next};"\
@@ -3432,6 +3728,7 @@
   else
     lt_cv_sys_global_symbol_pipe="sed -n -e 's/^.*[[	 ]]\($symcode$symcode*\)[[	 ]][[	 ]]*$ac_symprfx$sympat$opt_cr$/$symxfrm/p'"
   fi
+  lt_cv_sys_global_symbol_pipe="$lt_cv_sys_global_symbol_pipe | sed '/ __gnu_lto/d'"
 
   # Check to see that the pipe works correctly.
   pipe_works=no
@@ -3453,7 +3750,7 @@
   if AC_TRY_EVAL(ac_compile); then
     # Now try to grab the symbols.
     nlist=conftest.nm
-    if AC_TRY_EVAL(NM conftest.$ac_objext \| $lt_cv_sys_global_symbol_pipe \> $nlist) && test -s "$nlist"; then
+    if AC_TRY_EVAL(NM conftest.$ac_objext \| "$lt_cv_sys_global_symbol_pipe" \> $nlist) && test -s "$nlist"; then
       # Try sorting and uniquifying the output.
       if sort "$nlist" | uniq > "$nlist"T; then
 	mv -f "$nlist"T "$nlist"
@@ -3465,6 +3762,18 @@
       if $GREP ' nm_test_var$' "$nlist" >/dev/null; then
 	if $GREP ' nm_test_func$' "$nlist" >/dev/null; then
 	  cat <<_LT_EOF > conftest.$ac_ext
+/* Keep this code in sync between libtool.m4, ltmain, lt_system.h, and tests.  */
+#if defined(_WIN32) || defined(__CYGWIN__) || defined(_WIN32_WCE)
+/* DATA imports from DLLs on WIN32 con't be const, because runtime
+   relocations are performed -- see ld's documentation on pseudo-relocs.  */
+# define LT@&t@_DLSYM_CONST
+#elif defined(__osf__)
+/* This system does not cope well with relocations in const data.  */
+# define LT@&t@_DLSYM_CONST
+#else
+# define LT@&t@_DLSYM_CONST const
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -3476,7 +3785,7 @@
 	  cat <<_LT_EOF >> conftest.$ac_ext
 
 /* The mapping between symbol names and symbols.  */
-const struct {
+LT@&t@_DLSYM_CONST struct {
   const char *name;
   void       *address;
 }
@@ -3502,15 +3811,15 @@
 _LT_EOF
 	  # Now try linking the two files.
 	  mv conftest.$ac_objext conftstm.$ac_objext
-	  lt_save_LIBS="$LIBS"
-	  lt_save_CFLAGS="$CFLAGS"
+	  lt_globsym_save_LIBS=$LIBS
+	  lt_globsym_save_CFLAGS=$CFLAGS
 	  LIBS="conftstm.$ac_objext"
 	  CFLAGS="$CFLAGS$_LT_TAGVAR(lt_prog_compiler_no_builtin_flag, $1)"
 	  if AC_TRY_EVAL(ac_link) && test -s conftest${ac_exeext}; then
 	    pipe_works=yes
 	  fi
-	  LIBS="$lt_save_LIBS"
-	  CFLAGS="$lt_save_CFLAGS"
+	  LIBS=$lt_globsym_save_LIBS
+	  CFLAGS=$lt_globsym_save_CFLAGS
 	else
 	  echo "cannot find nm_test_func in $nlist" >&AS_MESSAGE_LOG_FD
 	fi
@@ -3543,6 +3852,13 @@
   AC_MSG_RESULT(ok)
 fi
 
+# Response file support.
+if test "$lt_cv_nm_interface" = "MS dumpbin"; then
+  nm_file_list_spec='@'
+elif $NM --help 2>/dev/null | grep '[[@]]FILE' >/dev/null; then
+  nm_file_list_spec='@'
+fi
+
 _LT_DECL([global_symbol_pipe], [lt_cv_sys_global_symbol_pipe], [1],
     [Take the output of nm and produce a listing of raw symbols and C names])
 _LT_DECL([global_symbol_to_cdecl], [lt_cv_sys_global_symbol_to_cdecl], [1],
@@ -3553,6 +3869,8 @@
 _LT_DECL([global_symbol_to_c_name_address_lib_prefix],
     [lt_cv_sys_global_symbol_to_c_name_address_lib_prefix], [1],
     [Transform the output of nm in a C name address pair when lib prefix is needed])
+_LT_DECL([], [nm_file_list_spec], [1],
+    [Specify filename containing input files for $NM])
 ]) # _LT_CMD_GLOBAL_SYMBOLS
 
 
@@ -3564,7 +3882,6 @@
 _LT_TAGVAR(lt_prog_compiler_pic, $1)=
 _LT_TAGVAR(lt_prog_compiler_static, $1)=
 
-AC_MSG_CHECKING([for $compiler option to produce PIC])
 m4_if([$1], [CXX], [
   # C++ specific cases for pic, static, wl, etc.
   if test "$GXX" = yes; then
@@ -3615,6 +3932,11 @@
       # DJGPP does not support shared libraries at all
       _LT_TAGVAR(lt_prog_compiler_pic, $1)=
       ;;
+    haiku*)
+      # PIC is the default for Haiku.
+      # The "-static" flag exists, but is broken.
+      _LT_TAGVAR(lt_prog_compiler_static, $1)=
+      ;;
     interix[[3-9]]*)
       # Interix 3.x gcc -fpic/-fPIC options generate broken code.
       # Instead, we relocate shared libraries at runtime.
@@ -3664,6 +3986,12 @@
 	  ;;
 	esac
 	;;
+      mingw* | cygwin* | os2* | pw32* | cegcc*)
+	# This hack is so that the source file can tell whether it is being
+	# built for inclusion in a dll (and should export symbols for example).
+	m4_if([$1], [GCJ], [],
+	  [_LT_TAGVAR(lt_prog_compiler_pic, $1)='-DDLL_EXPORT'])
+	;;
       dgux*)
 	case $cc_basename in
 	  ec++*)
@@ -3720,7 +4048,7 @@
 	    ;;
 	esac
 	;;
-      linux* | k*bsd*-gnu)
+      linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
 	case $cc_basename in
 	  KCC*)
 	    # KAI C++ Compiler
@@ -3753,8 +4081,8 @@
 	    _LT_TAGVAR(lt_prog_compiler_pic, $1)=
 	    _LT_TAGVAR(lt_prog_compiler_static, $1)='-non_shared'
 	    ;;
-	  xlc* | xlC*)
-	    # IBM XL 8.0 on PPC
+	  xlc* | xlC* | bgxl[[cC]]* | mpixl[[cC]]*)
+	    # IBM XL 8.0, 9.0 on PPC and BlueGene
 	    _LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,'
 	    _LT_TAGVAR(lt_prog_compiler_pic, $1)='-qpic'
 	    _LT_TAGVAR(lt_prog_compiler_static, $1)='-qstaticlink'
@@ -3816,7 +4144,7 @@
 	;;
       solaris*)
 	case $cc_basename in
-	  CC*)
+	  CC* | sunCC*)
 	    # Sun C++ 4.2, 5.x and Centerline C++
 	    _LT_TAGVAR(lt_prog_compiler_pic, $1)='-KPIC'
 	    _LT_TAGVAR(lt_prog_compiler_static, $1)='-Bstatic'
@@ -3920,6 +4248,12 @@
       _LT_TAGVAR(lt_prog_compiler_pic, $1)='-fno-common'
       ;;
 
+    haiku*)
+      # PIC is the default for Haiku.
+      # The "-static" flag exists, but is broken.
+      _LT_TAGVAR(lt_prog_compiler_static, $1)=
+      ;;
+
     hpux*)
       # PIC is the default for 64-bit PA HP-UX, but not for 32-bit
       # PA HP-UX.  On IA64 HP-UX, PIC is the default but the pic flag
@@ -3962,6 +4296,15 @@
       _LT_TAGVAR(lt_prog_compiler_pic, $1)='-fPIC'
       ;;
     esac
+
+    case $cc_basename in
+    nvcc*) # Cuda Compiler Driver 2.2
+      _LT_TAGVAR(lt_prog_compiler_wl, $1)='-Xlinker '
+      if test -n "$_LT_TAGVAR(lt_prog_compiler_pic, $1)"; then
+        _LT_TAGVAR(lt_prog_compiler_pic, $1)="-Xcompiler $_LT_TAGVAR(lt_prog_compiler_pic, $1)"
+      fi
+      ;;
+    esac
   else
     # PORTME Check for flag to pass linker flags through the system compiler.
     case $host_os in
@@ -4004,7 +4347,7 @@
       _LT_TAGVAR(lt_prog_compiler_static, $1)='-non_shared'
       ;;
 
-    linux* | k*bsd*-gnu)
+    linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
       case $cc_basename in
       # old Intel for x86_64 which still supported -KPIC.
       ecc*)
@@ -4025,7 +4368,13 @@
 	_LT_TAGVAR(lt_prog_compiler_pic, $1)='--shared'
 	_LT_TAGVAR(lt_prog_compiler_static, $1)='--static'
 	;;
-      pgcc* | pgf77* | pgf90* | pgf95*)
+      nagfor*)
+	# NAG Fortran compiler
+	_LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,-Wl,,'
+	_LT_TAGVAR(lt_prog_compiler_pic, $1)='-PIC'
+	_LT_TAGVAR(lt_prog_compiler_static, $1)='-Bstatic'
+	;;
+      pgcc* | pgf77* | pgf90* | pgf95* | pgfortran*)
         # Portland Group compilers (*not* the Pentium gcc compiler,
 	# which looks to be a dead project)
 	_LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,'
@@ -4037,25 +4386,40 @@
         # All Alpha code is PIC.
         _LT_TAGVAR(lt_prog_compiler_static, $1)='-non_shared'
         ;;
-      xl*)
-	# IBM XL C 8.0/Fortran 10.1 on PPC
+      xl* | bgxl* | bgf* | mpixl*)
+	# IBM XL C 8.0/Fortran 10.1, 11.1 on PPC and BlueGene
 	_LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,'
 	_LT_TAGVAR(lt_prog_compiler_pic, $1)='-qpic'
 	_LT_TAGVAR(lt_prog_compiler_static, $1)='-qstaticlink'
 	;;
       *)
 	case `$CC -V 2>&1 | sed 5q` in
+	*Sun\ Ceres\ Fortran* | *Sun*Fortran*\ [[1-7]].* | *Sun*Fortran*\ 8.[[0-3]]*)
+	  # Sun Fortran 8.3 passes all unrecognized flags to the linker
+	  _LT_TAGVAR(lt_prog_compiler_pic, $1)='-KPIC'
+	  _LT_TAGVAR(lt_prog_compiler_static, $1)='-Bstatic'
+	  _LT_TAGVAR(lt_prog_compiler_wl, $1)=''
+	  ;;
+	*Sun\ F* | *Sun*Fortran*)
+	  _LT_TAGVAR(lt_prog_compiler_pic, $1)='-KPIC'
+	  _LT_TAGVAR(lt_prog_compiler_static, $1)='-Bstatic'
+	  _LT_TAGVAR(lt_prog_compiler_wl, $1)='-Qoption ld '
+	  ;;
 	*Sun\ C*)
 	  # Sun C 5.9
 	  _LT_TAGVAR(lt_prog_compiler_pic, $1)='-KPIC'
 	  _LT_TAGVAR(lt_prog_compiler_static, $1)='-Bstatic'
 	  _LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,'
 	  ;;
-	*Sun\ F*)
-	  # Sun Fortran 8.3 passes all unrecognized flags to the linker
-	  _LT_TAGVAR(lt_prog_compiler_pic, $1)='-KPIC'
+        *Intel*\ [[CF]]*Compiler*)
+	  _LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,'
+	  _LT_TAGVAR(lt_prog_compiler_pic, $1)='-fPIC'
+	  _LT_TAGVAR(lt_prog_compiler_static, $1)='-static'
+	  ;;
+	*Portland\ Group*)
+	  _LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,'
+	  _LT_TAGVAR(lt_prog_compiler_pic, $1)='-fpic'
 	  _LT_TAGVAR(lt_prog_compiler_static, $1)='-Bstatic'
-	  _LT_TAGVAR(lt_prog_compiler_wl, $1)=''
 	  ;;
 	esac
 	;;
@@ -4087,7 +4451,7 @@
       _LT_TAGVAR(lt_prog_compiler_pic, $1)='-KPIC'
       _LT_TAGVAR(lt_prog_compiler_static, $1)='-Bstatic'
       case $cc_basename in
-      f77* | f90* | f95*)
+      f77* | f90* | f95* | sunf77* | sunf90* | sunf95*)
 	_LT_TAGVAR(lt_prog_compiler_wl, $1)='-Qoption ld ';;
       *)
 	_LT_TAGVAR(lt_prog_compiler_wl, $1)='-Wl,';;
@@ -4144,9 +4508,11 @@
     _LT_TAGVAR(lt_prog_compiler_pic, $1)="$_LT_TAGVAR(lt_prog_compiler_pic, $1)@&t@m4_if([$1],[],[ -DPIC],[m4_if([$1],[CXX],[ -DPIC],[])])"
     ;;
 esac
-AC_MSG_RESULT([$_LT_TAGVAR(lt_prog_compiler_pic, $1)])
-_LT_TAGDECL([wl], [lt_prog_compiler_wl], [1],
-	[How to pass a linker flag through the compiler])
+
+AC_CACHE_CHECK([for $compiler option to produce PIC],
+  [_LT_TAGVAR(lt_cv_prog_compiler_pic, $1)],
+  [_LT_TAGVAR(lt_cv_prog_compiler_pic, $1)=$_LT_TAGVAR(lt_prog_compiler_pic, $1)])
+_LT_TAGVAR(lt_prog_compiler_pic, $1)=$_LT_TAGVAR(lt_cv_prog_compiler_pic, $1)
 
 #
 # Check to make sure the PIC flag actually works.
@@ -4165,6 +4531,8 @@
 _LT_TAGDECL([pic_flag], [lt_prog_compiler_pic], [1],
 	[Additional compiler flags for building library objects])
 
+_LT_TAGDECL([wl], [lt_prog_compiler_wl], [1],
+	[How to pass a linker flag through the compiler])
 #
 # Check to make sure the static flag actually works.
 #
@@ -4185,6 +4553,7 @@
 m4_defun([_LT_LINKER_SHLIBS],
 [AC_REQUIRE([LT_PATH_LD])dnl
 AC_REQUIRE([LT_PATH_NM])dnl
+m4_require([_LT_PATH_MANIFEST_TOOL])dnl
 m4_require([_LT_FILEUTILS_DEFAULTS])dnl
 m4_require([_LT_DECL_EGREP])dnl
 m4_require([_LT_DECL_SED])dnl
@@ -4193,30 +4562,40 @@
 AC_MSG_CHECKING([whether the $compiler linker ($LD) supports shared libraries])
 m4_if([$1], [CXX], [
   _LT_TAGVAR(export_symbols_cmds, $1)='$NM $libobjs $convenience | $global_symbol_pipe | $SED '\''s/.* //'\'' | sort | uniq > $export_symbols'
+  _LT_TAGVAR(exclude_expsyms, $1)=['_GLOBAL_OFFSET_TABLE_|_GLOBAL__F[ID]_.*']
   case $host_os in
   aix[[4-9]]*)
     # If we're using GNU nm, then we don't want the "-C" option.
     # -C means demangle to AIX nm, but means don't demangle with GNU nm
+    # Also, AIX nm treats weak defined symbols like other global defined
+    # symbols, whereas GNU nm marks them as "W".
     if $NM -V 2>&1 | $GREP 'GNU' > /dev/null; then
-      _LT_TAGVAR(export_symbols_cmds, $1)='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && ([substr](\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
+      _LT_TAGVAR(export_symbols_cmds, $1)='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B") || (\$ 2 == "W")) && ([substr](\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
     else
       _LT_TAGVAR(export_symbols_cmds, $1)='$NM -BCpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && ([substr](\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
     fi
     ;;
   pw32*)
     _LT_TAGVAR(export_symbols_cmds, $1)="$ltdll_cmds"
-  ;;
+    ;;
   cygwin* | mingw* | cegcc*)
-    _LT_TAGVAR(export_symbols_cmds, $1)='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[[BCDGRS]][[ ]]/s/.*[[ ]]\([[^ ]]*\)/\1 DATA/;/^.*[[ ]]__nm__/s/^.*[[ ]]__nm__\([[^ ]]*\)[[ ]][[^ ]]*/\1 DATA/;/^I[[ ]]/d;/^[[AITW]][[ ]]/s/.* //'\'' | sort | uniq > $export_symbols'
-  ;;
-  linux* | k*bsd*-gnu)
+    case $cc_basename in
+    cl*)
+      _LT_TAGVAR(exclude_expsyms, $1)='_NULL_IMPORT_DESCRIPTOR|_IMPORT_DESCRIPTOR_.*'
+      ;;
+    *)
+      _LT_TAGVAR(export_symbols_cmds, $1)='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[[BCDGRS]][[ ]]/s/.*[[ ]]\([[^ ]]*\)/\1 DATA/;s/^.*[[ ]]__nm__\([[^ ]]*\)[[ ]][[^ ]]*/\1 DATA/;/^I[[ ]]/d;/^[[AITW]][[ ]]/s/.* //'\'' | sort | uniq > $export_symbols'
+      _LT_TAGVAR(exclude_expsyms, $1)=['[_]+GLOBAL_OFFSET_TABLE_|[_]+GLOBAL__[FID]_.*|[_]+head_[A-Za-z0-9_]+_dll|[A-Za-z0-9_]+_dll_iname']
+      ;;
+    esac
+    ;;
+  linux* | k*bsd*-gnu | gnu*)
     _LT_TAGVAR(link_all_deplibs, $1)=no
-  ;;
+    ;;
   *)
     _LT_TAGVAR(export_symbols_cmds, $1)='$NM $libobjs $convenience | $global_symbol_pipe | $SED '\''s/.* //'\'' | sort | uniq > $export_symbols'
-  ;;
+    ;;
   esac
-  _LT_TAGVAR(exclude_expsyms, $1)=['_GLOBAL_OFFSET_TABLE_|_GLOBAL__F[ID]_.*']
 ], [
   runpath_var=
   _LT_TAGVAR(allow_undefined_flag, $1)=
@@ -4231,7 +4610,6 @@
   _LT_TAGVAR(hardcode_direct, $1)=no
   _LT_TAGVAR(hardcode_direct_absolute, $1)=no
   _LT_TAGVAR(hardcode_libdir_flag_spec, $1)=
-  _LT_TAGVAR(hardcode_libdir_flag_spec_ld, $1)=
   _LT_TAGVAR(hardcode_libdir_separator, $1)=
   _LT_TAGVAR(hardcode_minus_L, $1)=no
   _LT_TAGVAR(hardcode_shlibpath_var, $1)=unsupported
@@ -4276,13 +4654,39 @@
   openbsd*)
     with_gnu_ld=no
     ;;
-  linux* | k*bsd*-gnu)
+  linux* | k*bsd*-gnu | gnu*)
     _LT_TAGVAR(link_all_deplibs, $1)=no
     ;;
   esac
 
   _LT_TAGVAR(ld_shlibs, $1)=yes
+
+  # On some targets, GNU ld is compatible enough with the native linker
+  # that we're better off using the native interface for both.
+  lt_use_gnu_ld_interface=no
   if test "$with_gnu_ld" = yes; then
+    case $host_os in
+      aix*)
+	# The AIX port of GNU ld has always aspired to compatibility
+	# with the native linker.  However, as the warning in the GNU ld
+	# block says, versions before 2.19.5* couldn't really create working
+	# shared libraries, regardless of the interface used.
+	case `$LD -v 2>&1` in
+	  *\ \(GNU\ Binutils\)\ 2.19.5*) ;;
+	  *\ \(GNU\ Binutils\)\ 2.[[2-9]]*) ;;
+	  *\ \(GNU\ Binutils\)\ [[3-9]]*) ;;
+	  *)
+	    lt_use_gnu_ld_interface=yes
+	    ;;
+	esac
+	;;
+      *)
+	lt_use_gnu_ld_interface=yes
+	;;
+    esac
+  fi
+
+  if test "$lt_use_gnu_ld_interface" = yes; then
     # If archive_cmds runs LD, not CC, wlarc should be empty
     wlarc='${wl}'
 
@@ -4300,6 +4704,7 @@
     fi
     supports_anon_versioning=no
     case `$LD -v 2>&1` in
+      *GNU\ gold*) supports_anon_versioning=yes ;;
       *\ [[01]].* | *\ 2.[[0-9]].* | *\ 2.10.*) ;; # catch versions < 2.11
       *\ 2.11.93.0.2\ *) supports_anon_versioning=yes ;; # RH7.3 ...
       *\ 2.11.92.0.12\ *) supports_anon_versioning=yes ;; # Mandrake 8.2 ...
@@ -4315,11 +4720,12 @@
 	_LT_TAGVAR(ld_shlibs, $1)=no
 	cat <<_LT_EOF 1>&2
 
-*** Warning: the GNU linker, at least up to release 2.9.1, is reported
+*** Warning: the GNU linker, at least up to release 2.19, is reported
 *** to be unable to reliably create shared libraries on AIX.
 *** Therefore, libtool is disabling shared libraries support.  If you
-*** really care for shared libraries, you may want to modify your PATH
-*** so that a non-GNU linker is found, and then restart.
+*** really care for shared libraries, you may want to install binutils
+*** 2.20 or above, or modify your PATH so that a non-GNU linker is found.
+*** You will then need to restart the configuration process.
 
 _LT_EOF
       fi
@@ -4355,10 +4761,12 @@
       # _LT_TAGVAR(hardcode_libdir_flag_spec, $1) is actually meaningless,
       # as there is no search path for DLLs.
       _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-L$libdir'
+      _LT_TAGVAR(export_dynamic_flag_spec, $1)='${wl}--export-all-symbols'
       _LT_TAGVAR(allow_undefined_flag, $1)=unsupported
       _LT_TAGVAR(always_export_symbols, $1)=no
       _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=yes
-      _LT_TAGVAR(export_symbols_cmds, $1)='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[[BCDGRS]][[ ]]/s/.*[[ ]]\([[^ ]]*\)/\1 DATA/'\'' | $SED -e '\''/^[[AITW]][[ ]]/s/.*[[ ]]//'\'' | sort | uniq > $export_symbols'
+      _LT_TAGVAR(export_symbols_cmds, $1)='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[[BCDGRS]][[ ]]/s/.*[[ ]]\([[^ ]]*\)/\1 DATA/;s/^.*[[ ]]__nm__\([[^ ]]*\)[[ ]][[^ ]]*/\1 DATA/;/^I[[ ]]/d;/^[[AITW]][[ ]]/s/.* //'\'' | sort | uniq > $export_symbols'
+      _LT_TAGVAR(exclude_expsyms, $1)=['[_]+GLOBAL_OFFSET_TABLE_|[_]+GLOBAL__[FID]_.*|[_]+head_[A-Za-z0-9_]+_dll|[A-Za-z0-9_]+_dll_iname']
 
       if $LD --help 2>&1 | $GREP 'auto-import' > /dev/null; then
         _LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
@@ -4376,6 +4784,11 @@
       fi
       ;;
 
+    haiku*)
+      _LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+      _LT_TAGVAR(link_all_deplibs, $1)=yes
+      ;;
+
     interix[[3-9]]*)
       _LT_TAGVAR(hardcode_direct, $1)=no
       _LT_TAGVAR(hardcode_shlibpath_var, $1)=no
@@ -4391,7 +4804,7 @@
       _LT_TAGVAR(archive_expsym_cmds, $1)='sed "s,^,_," $export_symbols >$output_objdir/$soname.expsym~$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-h,$soname ${wl}--retain-symbols-file,$output_objdir/$soname.expsym ${wl}--image-base,`expr ${RANDOM-$$} % 4096 / 2 \* 262144 + 1342177280` -o $lib'
       ;;
 
-    gnu* | linux* | tpf* | k*bsd*-gnu)
+    gnu* | linux* | tpf* | k*bsd*-gnu | kopensolaris*-gnu)
       tmp_diet=no
       if test "$host_os" = linux-dietlibc; then
 	case $cc_basename in
@@ -4401,15 +4814,16 @@
       if $LD --help 2>&1 | $EGREP ': supported targets:.* elf' > /dev/null \
 	 && test "$tmp_diet" = no
       then
-	tmp_addflag=
+	tmp_addflag=' $pic_flag'
 	tmp_sharedflag='-shared'
 	case $cc_basename,$host_cpu in
         pgcc*)				# Portland Group C compiler
-	  _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	  _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	  tmp_addflag=' $pic_flag'
 	  ;;
-	pgf77* | pgf90* | pgf95*)	# Portland Group f77 and f90 compilers
-	  _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	pgf77* | pgf90* | pgf95* | pgfortran*)
+					# Portland Group f77 and f90 compilers
+	  _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	  tmp_addflag=' $pic_flag -Mnomain' ;;
 	ecc*,ia64* | icc*,ia64*)	# Intel C compiler on ia64
 	  tmp_addflag=' -i_dynamic' ;;
@@ -4420,13 +4834,17 @@
 	lf95*)				# Lahey Fortran 8.1
 	  _LT_TAGVAR(whole_archive_flag_spec, $1)=
 	  tmp_sharedflag='--shared' ;;
-	xl[[cC]]*)			# IBM XL C 8.0 on PPC (deal with xlf below)
+	xl[[cC]]* | bgxl[[cC]]* | mpixl[[cC]]*) # IBM XL C 8.0 on PPC (deal with xlf below)
 	  tmp_sharedflag='-qmkshrobj'
 	  tmp_addflag= ;;
+	nvcc*)	# Cuda Compiler Driver 2.2
+	  _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
+	  _LT_TAGVAR(compiler_needs_object, $1)=yes
+	  ;;
 	esac
 	case `$CC -V 2>&1 | sed 5q` in
 	*Sun\ C*)			# Sun C 5.9
-	  _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	  _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	  _LT_TAGVAR(compiler_needs_object, $1)=yes
 	  tmp_sharedflag='-G' ;;
 	*Sun\ F*)			# Sun Fortran 8.3
@@ -4442,17 +4860,16 @@
         fi
 
 	case $cc_basename in
-	xlf*)
+	xlf* | bgf* | bgxlf* | mpixlf*)
 	  # IBM XL Fortran 10.1 on PPC cannot create shared libs itself
 	  _LT_TAGVAR(whole_archive_flag_spec, $1)='--whole-archive$convenience --no-whole-archive'
-	  _LT_TAGVAR(hardcode_libdir_flag_spec, $1)=
-	  _LT_TAGVAR(hardcode_libdir_flag_spec_ld, $1)='-rpath $libdir'
-	  _LT_TAGVAR(archive_cmds, $1)='$LD -shared $libobjs $deplibs $compiler_flags -soname $soname -o $lib'
+	  _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath ${wl}$libdir'
+	  _LT_TAGVAR(archive_cmds, $1)='$LD -shared $libobjs $deplibs $linker_flags -soname $soname -o $lib'
 	  if test "x$supports_anon_versioning" = xyes; then
 	    _LT_TAGVAR(archive_expsym_cmds, $1)='echo "{ global:" > $output_objdir/$libname.ver~
 	      cat $export_symbols | sed -e "s/\(.*\)/\1;/" >> $output_objdir/$libname.ver~
 	      echo "local: *; };" >> $output_objdir/$libname.ver~
-	      $LD -shared $libobjs $deplibs $compiler_flags -soname $soname -version-script $output_objdir/$libname.ver -o $lib'
+	      $LD -shared $libobjs $deplibs $linker_flags -soname $soname -version-script $output_objdir/$libname.ver -o $lib'
 	  fi
 	  ;;
 	esac
@@ -4466,8 +4883,8 @@
 	_LT_TAGVAR(archive_cmds, $1)='$LD -Bshareable $libobjs $deplibs $linker_flags -o $lib'
 	wlarc=
       else
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
-	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
       fi
       ;;
 
@@ -4485,8 +4902,8 @@
 
 _LT_EOF
       elif $LD --help 2>&1 | $GREP ': supported targets:.* elf' > /dev/null; then
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
-	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
       else
 	_LT_TAGVAR(ld_shlibs, $1)=no
       fi
@@ -4532,8 +4949,8 @@
 
     *)
       if $LD --help 2>&1 | $GREP ': supported targets:.* elf' > /dev/null; then
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
-	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
       else
 	_LT_TAGVAR(ld_shlibs, $1)=no
       fi
@@ -4573,8 +4990,10 @@
       else
 	# If we're using GNU nm, then we don't want the "-C" option.
 	# -C means demangle to AIX nm, but means don't demangle with GNU nm
+	# Also, AIX nm treats weak defined symbols like other global
+	# defined symbols, whereas GNU nm marks them as "W".
 	if $NM -V 2>&1 | $GREP 'GNU' > /dev/null; then
-	  _LT_TAGVAR(export_symbols_cmds, $1)='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && ([substr](\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
+	  _LT_TAGVAR(export_symbols_cmds, $1)='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B") || (\$ 2 == "W")) && ([substr](\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
 	else
 	  _LT_TAGVAR(export_symbols_cmds, $1)='$NM -BCpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && ([substr](\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
 	fi
@@ -4662,9 +5081,9 @@
 	_LT_TAGVAR(allow_undefined_flag, $1)='-berok'
         # Determine the default libpath from the value encoded in an
         # empty executable.
-        _LT_SYS_MODULE_PATH_AIX
+        _LT_SYS_MODULE_PATH_AIX([$1])
         _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-blibpath:$libdir:'"$aix_libpath"
-        _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then $ECHO "X${wl}${allow_undefined_flag}" | $Xsed; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
+        _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then func_echo_all "${wl}${allow_undefined_flag}"; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
       else
 	if test "$host_cpu" = ia64; then
 	  _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-R $libdir:/usr/lib:/lib'
@@ -4673,14 +5092,19 @@
 	else
 	 # Determine the default libpath from the value encoded in an
 	 # empty executable.
-	 _LT_SYS_MODULE_PATH_AIX
+	 _LT_SYS_MODULE_PATH_AIX([$1])
 	 _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-blibpath:$libdir:'"$aix_libpath"
 	  # Warning - without using the other run time loading flags,
 	  # -berok will link without error, but may produce a broken library.
 	  _LT_TAGVAR(no_undefined_flag, $1)=' ${wl}-bernotok'
 	  _LT_TAGVAR(allow_undefined_flag, $1)=' ${wl}-berok'
-	  # Exported symbols can be pulled into shared objects from archives
-	  _LT_TAGVAR(whole_archive_flag_spec, $1)='$convenience'
+	  if test "$with_gnu_ld" = yes; then
+	    # We only use this code for GNU lds that support --whole-archive.
+	    _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive$convenience ${wl}--no-whole-archive'
+	  else
+	    # Exported symbols can be pulled into shared objects from archives
+	    _LT_TAGVAR(whole_archive_flag_spec, $1)='$convenience'
+	  fi
 	  _LT_TAGVAR(archive_cmds_need_lc, $1)=yes
 	  # This is similar to how AIX traditionally builds its shared libraries.
 	  _LT_TAGVAR(archive_expsym_cmds, $1)="\$CC $shared_flag"' -o $output_objdir/$soname $libobjs $deplibs ${wl}-bnoentry $compiler_flags ${wl}-bE:$export_symbols${allow_undefined_flag}~$AR $AR_FLAGS $output_objdir/$libname$release.a $output_objdir/$soname'
@@ -4712,20 +5136,64 @@
       # Microsoft Visual C++.
       # hardcode_libdir_flag_spec is actually meaningless, as there is
       # no search path for DLLs.
-      _LT_TAGVAR(hardcode_libdir_flag_spec, $1)=' '
-      _LT_TAGVAR(allow_undefined_flag, $1)=unsupported
-      # Tell ltmain to make .lib files, not .a files.
-      libext=lib
-      # Tell ltmain to make .dll files, not .so files.
-      shrext_cmds=".dll"
-      # FIXME: Setting linknames here is a bad hack.
-      _LT_TAGVAR(archive_cmds, $1)='$CC -o $lib $libobjs $compiler_flags `$ECHO "X$deplibs" | $Xsed -e '\''s/ -lc$//'\''` -link -dll~linknames='
-      # The linker will automatically build a .lib file if we build a DLL.
-      _LT_TAGVAR(old_archive_from_new_cmds, $1)='true'
-      # FIXME: Should let the user specify the lib program.
-      _LT_TAGVAR(old_archive_cmds, $1)='lib -OUT:$oldlib$oldobjs$old_deplibs'
-      _LT_TAGVAR(fix_srcfile_path, $1)='`cygpath -w "$srcfile"`'
-      _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=yes
+      case $cc_basename in
+      cl*)
+	# Native MSVC
+	_LT_TAGVAR(hardcode_libdir_flag_spec, $1)=' '
+	_LT_TAGVAR(allow_undefined_flag, $1)=unsupported
+	_LT_TAGVAR(always_export_symbols, $1)=yes
+	_LT_TAGVAR(file_list_spec, $1)='@'
+	# Tell ltmain to make .lib files, not .a files.
+	libext=lib
+	# Tell ltmain to make .dll files, not .so files.
+	shrext_cmds=".dll"
+	# FIXME: Setting linknames here is a bad hack.
+	_LT_TAGVAR(archive_cmds, $1)='$CC -o $output_objdir/$soname $libobjs $compiler_flags $deplibs -Wl,-dll~linknames='
+	_LT_TAGVAR(archive_expsym_cmds, $1)='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
+	    sed -n -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' -e '1\\\!p' < $export_symbols > $output_objdir/$soname.exp;
+	  else
+	    sed -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' < $export_symbols > $output_objdir/$soname.exp;
+	  fi~
+	  $CC -o $tool_output_objdir$soname $libobjs $compiler_flags $deplibs "@$tool_output_objdir$soname.exp" -Wl,-DLL,-IMPLIB:"$tool_output_objdir$libname.dll.lib"~
+	  linknames='
+	# The linker will not automatically build a static lib if we build a DLL.
+	# _LT_TAGVAR(old_archive_from_new_cmds, $1)='true'
+	_LT_TAGVAR(enable_shared_with_static_runtimes, $1)=yes
+	_LT_TAGVAR(exclude_expsyms, $1)='_NULL_IMPORT_DESCRIPTOR|_IMPORT_DESCRIPTOR_.*'
+	_LT_TAGVAR(export_symbols_cmds, $1)='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[[BCDGRS]][[ ]]/s/.*[[ ]]\([[^ ]]*\)/\1,DATA/'\'' | $SED -e '\''/^[[AITW]][[ ]]/s/.*[[ ]]//'\'' | sort | uniq > $export_symbols'
+	# Don't use ranlib
+	_LT_TAGVAR(old_postinstall_cmds, $1)='chmod 644 $oldlib'
+	_LT_TAGVAR(postlink_cmds, $1)='lt_outputfile="@OUTPUT@"~
+	  lt_tool_outputfile="@TOOL_OUTPUT@"~
+	  case $lt_outputfile in
+	    *.exe|*.EXE) ;;
+	    *)
+	      lt_outputfile="$lt_outputfile.exe"
+	      lt_tool_outputfile="$lt_tool_outputfile.exe"
+	      ;;
+	  esac~
+	  if test "$MANIFEST_TOOL" != ":" && test -f "$lt_outputfile.manifest"; then
+	    $MANIFEST_TOOL -manifest "$lt_tool_outputfile.manifest" -outputresource:"$lt_tool_outputfile" || exit 1;
+	    $RM "$lt_outputfile.manifest";
+	  fi'
+	;;
+      *)
+	# Assume MSVC wrapper
+	_LT_TAGVAR(hardcode_libdir_flag_spec, $1)=' '
+	_LT_TAGVAR(allow_undefined_flag, $1)=unsupported
+	# Tell ltmain to make .lib files, not .a files.
+	libext=lib
+	# Tell ltmain to make .dll files, not .so files.
+	shrext_cmds=".dll"
+	# FIXME: Setting linknames here is a bad hack.
+	_LT_TAGVAR(archive_cmds, $1)='$CC -o $lib $libobjs $compiler_flags `func_echo_all "$deplibs" | $SED '\''s/ -lc$//'\''` -link -dll~linknames='
+	# The linker will automatically build a .lib file if we build a DLL.
+	_LT_TAGVAR(old_archive_from_new_cmds, $1)='true'
+	# FIXME: Should let the user specify the lib program.
+	_LT_TAGVAR(old_archive_cmds, $1)='lib -OUT:$oldlib$oldobjs$old_deplibs'
+	_LT_TAGVAR(enable_shared_with_static_runtimes, $1)=yes
+	;;
+      esac
       ;;
 
     darwin* | rhapsody*)
@@ -4738,10 +5206,6 @@
       _LT_TAGVAR(hardcode_shlibpath_var, $1)=no
       ;;
 
-    freebsd1*)
-      _LT_TAGVAR(ld_shlibs, $1)=no
-      ;;
-
     # FreeBSD 2.2.[012] allows us to include c++rt0.o to get C++ constructor
     # support.  Future versions do this automatically, but an explicit c++rt0.o
     # does not break anything, and helps significantly (at the cost of a little
@@ -4754,7 +5218,7 @@
       ;;
 
     # Unfortunately, older versions of FreeBSD 2 do not have this feature.
-    freebsd2*)
+    freebsd2.*)
       _LT_TAGVAR(archive_cmds, $1)='$LD -Bshareable -o $lib $libobjs $deplibs $linker_flags'
       _LT_TAGVAR(hardcode_direct, $1)=yes
       _LT_TAGVAR(hardcode_minus_L, $1)=yes
@@ -4763,7 +5227,7 @@
 
     # FreeBSD 3 and greater uses gcc -shared to do shared libraries.
     freebsd* | dragonfly*)
-      _LT_TAGVAR(archive_cmds, $1)='$CC -shared -o $lib $libobjs $deplibs $compiler_flags'
+      _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag -o $lib $libobjs $deplibs $compiler_flags'
       _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-R$libdir'
       _LT_TAGVAR(hardcode_direct, $1)=yes
       _LT_TAGVAR(hardcode_shlibpath_var, $1)=no
@@ -4771,7 +5235,7 @@
 
     hpux9*)
       if test "$GCC" = yes; then
-	_LT_TAGVAR(archive_cmds, $1)='$RM $output_objdir/$soname~$CC -shared -fPIC ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $libobjs $deplibs $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$RM $output_objdir/$soname~$CC -shared $pic_flag ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $libobjs $deplibs $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
       else
 	_LT_TAGVAR(archive_cmds, $1)='$RM $output_objdir/$soname~$LD -b +b $install_libdir -o $output_objdir/$soname $libobjs $deplibs $linker_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
       fi
@@ -4786,14 +5250,13 @@
       ;;
 
     hpux10*)
-      if test "$GCC" = yes -a "$with_gnu_ld" = no; then
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared -fPIC ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
+      if test "$GCC" = yes && test "$with_gnu_ld" = no; then
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
       else
 	_LT_TAGVAR(archive_cmds, $1)='$LD -b +h $soname +b $install_libdir -o $lib $libobjs $deplibs $linker_flags'
       fi
       if test "$with_gnu_ld" = no; then
 	_LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}+b ${wl}$libdir'
-	_LT_TAGVAR(hardcode_libdir_flag_spec_ld, $1)='+b $libdir'
 	_LT_TAGVAR(hardcode_libdir_separator, $1)=:
 	_LT_TAGVAR(hardcode_direct, $1)=yes
 	_LT_TAGVAR(hardcode_direct_absolute, $1)=yes
@@ -4805,16 +5268,16 @@
       ;;
 
     hpux11*)
-      if test "$GCC" = yes -a "$with_gnu_ld" = no; then
+      if test "$GCC" = yes && test "$with_gnu_ld" = no; then
 	case $host_cpu in
 	hppa*64*)
 	  _LT_TAGVAR(archive_cmds, $1)='$CC -shared ${wl}+h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	ia64*)
-	  _LT_TAGVAR(archive_cmds, $1)='$CC -shared -fPIC ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $libobjs $deplibs $compiler_flags'
+	  _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	*)
-	  _LT_TAGVAR(archive_cmds, $1)='$CC -shared -fPIC ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
+	  _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	esac
       else
@@ -4826,7 +5289,14 @@
 	  _LT_TAGVAR(archive_cmds, $1)='$CC -b ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	*)
-	  _LT_TAGVAR(archive_cmds, $1)='$CC -b ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
+	m4_if($1, [], [
+	  # Older versions of the 11.00 compiler do not understand -b yet
+	  # (HP92453-01 A.11.01.20 doesn't, HP92453-01 B.11.X.35175-35176.GP does)
+	  _LT_LINKER_OPTION([if $CC understands -b],
+	    _LT_TAGVAR(lt_cv_prog_compiler__b, $1), [-b],
+	    [_LT_TAGVAR(archive_cmds, $1)='$CC -b ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'],
+	    [_LT_TAGVAR(archive_cmds, $1)='$LD -b +h $soname +b $install_libdir -o $lib $libobjs $deplibs $linker_flags'])],
+	  [_LT_TAGVAR(archive_cmds, $1)='$CC -b ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'])
 	  ;;
 	esac
       fi
@@ -4854,19 +5324,34 @@
 
     irix5* | irix6* | nonstopux*)
       if test "$GCC" = yes; then
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 	# Try to use the -exported_symbol ld option, if it does not
 	# work, assume that -exports_file does not work either and
 	# implicitly export all symbols.
-        save_LDFLAGS="$LDFLAGS"
-        LDFLAGS="$LDFLAGS -shared ${wl}-exported_symbol ${wl}foo ${wl}-update_registry ${wl}/dev/null"
-        AC_LINK_IFELSE(int foo(void) {},
-          _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations ${wl}-exports_file ${wl}$export_symbols -o $lib'
-        )
-        LDFLAGS="$save_LDFLAGS"
+	# This should be the same for all languages, so no per-tag cache variable.
+	AC_CACHE_CHECK([whether the $host_os linker accepts -exported_symbol],
+	  [lt_cv_irix_exported_symbol],
+	  [save_LDFLAGS="$LDFLAGS"
+	   LDFLAGS="$LDFLAGS -shared ${wl}-exported_symbol ${wl}foo ${wl}-update_registry ${wl}/dev/null"
+	   AC_LINK_IFELSE(
+	     [AC_LANG_SOURCE(
+	        [AC_LANG_CASE([C], [[int foo (void) { return 0; }]],
+			      [C++], [[int foo (void) { return 0; }]],
+			      [Fortran 77], [[
+      subroutine foo
+      end]],
+			      [Fortran], [[
+      subroutine foo
+      end]])])],
+	      [lt_cv_irix_exported_symbol=yes],
+	      [lt_cv_irix_exported_symbol=no])
+           LDFLAGS="$save_LDFLAGS"])
+	if test "$lt_cv_irix_exported_symbol" = yes; then
+          _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations ${wl}-exports_file ${wl}$export_symbols -o $lib'
+	fi
       else
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
-	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -exports_file $export_symbols -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
+	_LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -exports_file $export_symbols -o $lib'
       fi
       _LT_TAGVAR(archive_cmds_need_lc, $1)='no'
       _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath ${wl}$libdir'
@@ -4928,17 +5413,17 @@
       _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-L$libdir'
       _LT_TAGVAR(hardcode_minus_L, $1)=yes
       _LT_TAGVAR(allow_undefined_flag, $1)=unsupported
-      _LT_TAGVAR(archive_cmds, $1)='$ECHO "LIBRARY $libname INITINSTANCE" > $output_objdir/$libname.def~$ECHO "DESCRIPTION \"$libname\"" >> $output_objdir/$libname.def~$ECHO DATA >> $output_objdir/$libname.def~$ECHO " SINGLE NONSHARED" >> $output_objdir/$libname.def~$ECHO EXPORTS >> $output_objdir/$libname.def~emxexp $libobjs >> $output_objdir/$libname.def~$CC -Zdll -Zcrtdll -o $lib $libobjs $deplibs $compiler_flags $output_objdir/$libname.def'
+      _LT_TAGVAR(archive_cmds, $1)='$ECHO "LIBRARY $libname INITINSTANCE" > $output_objdir/$libname.def~$ECHO "DESCRIPTION \"$libname\"" >> $output_objdir/$libname.def~echo DATA >> $output_objdir/$libname.def~echo " SINGLE NONSHARED" >> $output_objdir/$libname.def~echo EXPORTS >> $output_objdir/$libname.def~emxexp $libobjs >> $output_objdir/$libname.def~$CC -Zdll -Zcrtdll -o $lib $libobjs $deplibs $compiler_flags $output_objdir/$libname.def'
       _LT_TAGVAR(old_archive_from_new_cmds, $1)='emximp -o $output_objdir/$libname.a $output_objdir/$libname.def'
       ;;
 
     osf3*)
       if test "$GCC" = yes; then
 	_LT_TAGVAR(allow_undefined_flag, $1)=' ${wl}-expect_unresolved ${wl}\*'
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
       else
 	_LT_TAGVAR(allow_undefined_flag, $1)=' -expect_unresolved \*'
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
       fi
       _LT_TAGVAR(archive_cmds_need_lc, $1)='no'
       _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath ${wl}$libdir'
@@ -4948,13 +5433,13 @@
     osf4* | osf5*)	# as osf3* with the addition of -msym flag
       if test "$GCC" = yes; then
 	_LT_TAGVAR(allow_undefined_flag, $1)=' ${wl}-expect_unresolved ${wl}\*'
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $pic_flag $libobjs $deplibs $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 	_LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath ${wl}$libdir'
       else
 	_LT_TAGVAR(allow_undefined_flag, $1)=' -expect_unresolved \*'
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -msym -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -msym -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 	_LT_TAGVAR(archive_expsym_cmds, $1)='for i in `cat $export_symbols`; do printf "%s %s\\n" -exported_symbol "\$i" >> $lib.exp; done; printf "%s\\n" "-hidden">> $lib.exp~
-	$CC -shared${allow_undefined_flag} ${wl}-input ${wl}$lib.exp $compiler_flags $libobjs $deplibs -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib~$RM $lib.exp'
+	$CC -shared${allow_undefined_flag} ${wl}-input ${wl}$lib.exp $compiler_flags $libobjs $deplibs -soname $soname `test -n "$verstring" && $ECHO "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib~$RM $lib.exp'
 
 	# Both c and cxx compiler support -rpath directly
 	_LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-rpath $libdir'
@@ -4967,9 +5452,9 @@
       _LT_TAGVAR(no_undefined_flag, $1)=' -z defs'
       if test "$GCC" = yes; then
 	wlarc='${wl}'
-	_LT_TAGVAR(archive_cmds, $1)='$CC -shared ${wl}-z ${wl}text ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags'
+	_LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag ${wl}-z ${wl}text ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags'
 	_LT_TAGVAR(archive_expsym_cmds, $1)='echo "{ global:" > $lib.exp~cat $export_symbols | $SED -e "s/\(.*\)/\1;/" >> $lib.exp~echo "local: *; };" >> $lib.exp~
-	  $CC -shared ${wl}-z ${wl}text ${wl}-M ${wl}$lib.exp ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags~$RM $lib.exp'
+	  $CC -shared $pic_flag ${wl}-z ${wl}text ${wl}-M ${wl}$lib.exp ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags~$RM $lib.exp'
       else
 	case `$CC -V 2>&1` in
 	*"Compilers 5.0"*)
@@ -5145,36 +5630,38 @@
       # Test whether the compiler implicitly links with -lc since on some
       # systems, -lgcc has to come before -lc. If gcc already passes -lc
       # to ld, don't add -lc before -lgcc.
-      AC_MSG_CHECKING([whether -lc should be explicitly linked in])
-      $RM conftest*
-      echo "$lt_simple_compile_test_code" > conftest.$ac_ext
+      AC_CACHE_CHECK([whether -lc should be explicitly linked in],
+	[lt_cv_]_LT_TAGVAR(archive_cmds_need_lc, $1),
+	[$RM conftest*
+	echo "$lt_simple_compile_test_code" > conftest.$ac_ext
 
-      if AC_TRY_EVAL(ac_compile) 2>conftest.err; then
-        soname=conftest
-        lib=conftest
-        libobjs=conftest.$ac_objext
-        deplibs=
-        wl=$_LT_TAGVAR(lt_prog_compiler_wl, $1)
-	pic_flag=$_LT_TAGVAR(lt_prog_compiler_pic, $1)
-        compiler_flags=-v
-        linker_flags=-v
-        verstring=
-        output_objdir=.
-        libname=conftest
-        lt_save_allow_undefined_flag=$_LT_TAGVAR(allow_undefined_flag, $1)
-        _LT_TAGVAR(allow_undefined_flag, $1)=
-        if AC_TRY_EVAL(_LT_TAGVAR(archive_cmds, $1) 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1)
-        then
-	  _LT_TAGVAR(archive_cmds_need_lc, $1)=no
-        else
-	  _LT_TAGVAR(archive_cmds_need_lc, $1)=yes
-        fi
-        _LT_TAGVAR(allow_undefined_flag, $1)=$lt_save_allow_undefined_flag
-      else
-        cat conftest.err 1>&5
-      fi
-      $RM conftest*
-      AC_MSG_RESULT([$_LT_TAGVAR(archive_cmds_need_lc, $1)])
+	if AC_TRY_EVAL(ac_compile) 2>conftest.err; then
+	  soname=conftest
+	  lib=conftest
+	  libobjs=conftest.$ac_objext
+	  deplibs=
+	  wl=$_LT_TAGVAR(lt_prog_compiler_wl, $1)
+	  pic_flag=$_LT_TAGVAR(lt_prog_compiler_pic, $1)
+	  compiler_flags=-v
+	  linker_flags=-v
+	  verstring=
+	  output_objdir=.
+	  libname=conftest
+	  lt_save_allow_undefined_flag=$_LT_TAGVAR(allow_undefined_flag, $1)
+	  _LT_TAGVAR(allow_undefined_flag, $1)=
+	  if AC_TRY_EVAL(_LT_TAGVAR(archive_cmds, $1) 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1)
+	  then
+	    lt_cv_[]_LT_TAGVAR(archive_cmds_need_lc, $1)=no
+	  else
+	    lt_cv_[]_LT_TAGVAR(archive_cmds_need_lc, $1)=yes
+	  fi
+	  _LT_TAGVAR(allow_undefined_flag, $1)=$lt_save_allow_undefined_flag
+	else
+	  cat conftest.err 1>&5
+	fi
+	$RM conftest*
+	])
+      _LT_TAGVAR(archive_cmds_need_lc, $1)=$lt_cv_[]_LT_TAGVAR(archive_cmds_need_lc, $1)
       ;;
     esac
   fi
@@ -5211,9 +5698,6 @@
 _LT_TAGDECL([], [hardcode_libdir_flag_spec], [1],
     [Flag to hardcode $libdir into a binary during linking.
     This must work even if $libdir does not exist])
-_LT_TAGDECL([], [hardcode_libdir_flag_spec_ld], [1],
-    [[If ld is used when linking, flag to hardcode $libdir into a binary
-    during linking.  This must work even if $libdir does not exist]])
 _LT_TAGDECL([], [hardcode_libdir_separator], [1],
     [Whether we need a single "-rpath" flag with a separated argument])
 _LT_TAGDECL([], [hardcode_direct], [0],
@@ -5239,8 +5723,6 @@
     to runtime path list])
 _LT_TAGDECL([], [link_all_deplibs], [0],
     [Whether libtool must link a program against all its dependency libraries])
-_LT_TAGDECL([], [fix_srcfile_path], [1],
-    [Fix the shell variable $srcfile for the compiler])
 _LT_TAGDECL([], [always_export_symbols], [0],
     [Set to "yes" if exported symbols are required])
 _LT_TAGDECL([], [export_symbols_cmds], [2],
@@ -5251,6 +5733,8 @@
     [Symbols that must always be exported])
 _LT_TAGDECL([], [prelink_cmds], [2],
     [Commands necessary for linking programs (against libraries) with templates])
+_LT_TAGDECL([], [postlink_cmds], [2],
+    [Commands necessary for finishing linking programs])
 _LT_TAGDECL([], [file_list_spec], [1],
     [Specify filename containing input files])
 dnl FIXME: Not yet implemented
@@ -5340,14 +5824,15 @@
 ])# _LT_LANG_C_CONFIG
 
 
-# _LT_PROG_CXX
-# ------------
-# Since AC_PROG_CXX is broken, in that it returns g++ if there is no c++
-# compiler, we have our own version here.
-m4_defun([_LT_PROG_CXX],
-[
-pushdef([AC_MSG_ERROR], [_lt_caught_CXX_error=yes])
-AC_PROG_CXX
+# _LT_LANG_CXX_CONFIG([TAG])
+# --------------------------
+# Ensure that the configuration variables for a C++ compiler are suitably
+# defined.  These variables are subsequently used by _LT_CONFIG to write
+# the compiler configuration to `libtool'.
+m4_defun([_LT_LANG_CXX_CONFIG],
+[m4_require([_LT_FILEUTILS_DEFAULTS])dnl
+m4_require([_LT_DECL_EGREP])dnl
+m4_require([_LT_PATH_MANIFEST_TOOL])dnl
 if test -n "$CXX" && ( test "X$CXX" != "Xno" &&
     ( (test "X$CXX" = "Xg++" && `g++ -v >/dev/null 2>&1` ) ||
     (test "X$CXX" != "Xg++"))) ; then
@@ -5355,22 +5840,6 @@
 else
   _lt_caught_CXX_error=yes
 fi
-popdef([AC_MSG_ERROR])
-])# _LT_PROG_CXX
-
-dnl aclocal-1.4 backwards compatibility:
-dnl AC_DEFUN([_LT_PROG_CXX], [])
-
-
-# _LT_LANG_CXX_CONFIG([TAG])
-# --------------------------
-# Ensure that the configuration variables for a C++ compiler are suitably
-# defined.  These variables are subsequently used by _LT_CONFIG to write
-# the compiler configuration to `libtool'.
-m4_defun([_LT_LANG_CXX_CONFIG],
-[AC_REQUIRE([_LT_PROG_CXX])dnl
-m4_require([_LT_FILEUTILS_DEFAULTS])dnl
-m4_require([_LT_DECL_EGREP])dnl
 
 AC_LANG_PUSH(C++)
 _LT_TAGVAR(archive_cmds_need_lc, $1)=no
@@ -5382,7 +5851,6 @@
 _LT_TAGVAR(hardcode_direct, $1)=no
 _LT_TAGVAR(hardcode_direct_absolute, $1)=no
 _LT_TAGVAR(hardcode_libdir_flag_spec, $1)=
-_LT_TAGVAR(hardcode_libdir_flag_spec_ld, $1)=
 _LT_TAGVAR(hardcode_libdir_separator, $1)=
 _LT_TAGVAR(hardcode_minus_L, $1)=no
 _LT_TAGVAR(hardcode_shlibpath_var, $1)=unsupported
@@ -5392,6 +5860,8 @@
 _LT_TAGVAR(module_expsym_cmds, $1)=
 _LT_TAGVAR(link_all_deplibs, $1)=unknown
 _LT_TAGVAR(old_archive_cmds, $1)=$old_archive_cmds
+_LT_TAGVAR(reload_flag, $1)=$reload_flag
+_LT_TAGVAR(reload_cmds, $1)=$reload_cmds
 _LT_TAGVAR(no_undefined_flag, $1)=
 _LT_TAGVAR(whole_archive_flag_spec, $1)=
 _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=no
@@ -5423,6 +5893,7 @@
 
   # Allow CC to be a program name with arguments.
   lt_save_CC=$CC
+  lt_save_CFLAGS=$CFLAGS
   lt_save_LD=$LD
   lt_save_GCC=$GCC
   GCC=$GXX
@@ -5440,6 +5911,7 @@
   fi
   test -z "${LDCXX+set}" || LD=$LDCXX
   CC=${CXX-"c++"}
+  CFLAGS=$CXXFLAGS
   compiler=$CC
   _LT_TAGVAR(compiler, $1)=$CC
   _LT_CC_BASENAME([$compiler])
@@ -5461,8 +5933,8 @@
       # Check if GNU C++ uses GNU ld as the underlying linker, since the
       # archiving commands below assume that GNU ld is being used.
       if test "$with_gnu_ld" = yes; then
-        _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname -o $lib'
-        _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+        _LT_TAGVAR(archive_cmds, $1)='$CC $pic_flag -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname -o $lib'
+        _LT_TAGVAR(archive_expsym_cmds, $1)='$CC $pic_flag -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
 
         _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath ${wl}$libdir'
         _LT_TAGVAR(export_dynamic_flag_spec, $1)='${wl}--export-dynamic'
@@ -5494,7 +5966,7 @@
       # Commands to make compiler produce verbose output that lists
       # what "hidden" libraries, object files and flags are used when
       # linking a shared library.
-      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 
     else
       GXX=no
@@ -5603,10 +6075,10 @@
           _LT_TAGVAR(allow_undefined_flag, $1)='-berok'
           # Determine the default libpath from the value encoded in an empty
           # executable.
-          _LT_SYS_MODULE_PATH_AIX
+          _LT_SYS_MODULE_PATH_AIX([$1])
           _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-blibpath:$libdir:'"$aix_libpath"
 
-          _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then $ECHO "X${wl}${allow_undefined_flag}" | $Xsed; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
+          _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then func_echo_all "${wl}${allow_undefined_flag}"; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
         else
           if test "$host_cpu" = ia64; then
 	    _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-R $libdir:/usr/lib:/lib'
@@ -5615,14 +6087,19 @@
           else
 	    # Determine the default libpath from the value encoded in an
 	    # empty executable.
-	    _LT_SYS_MODULE_PATH_AIX
+	    _LT_SYS_MODULE_PATH_AIX([$1])
 	    _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-blibpath:$libdir:'"$aix_libpath"
 	    # Warning - without using the other run time loading flags,
 	    # -berok will link without error, but may produce a broken library.
 	    _LT_TAGVAR(no_undefined_flag, $1)=' ${wl}-bernotok'
 	    _LT_TAGVAR(allow_undefined_flag, $1)=' ${wl}-berok'
-	    # Exported symbols can be pulled into shared objects from archives
-	    _LT_TAGVAR(whole_archive_flag_spec, $1)='$convenience'
+	    if test "$with_gnu_ld" = yes; then
+	      # We only use this code for GNU lds that support --whole-archive.
+	      _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive$convenience ${wl}--no-whole-archive'
+	    else
+	      # Exported symbols can be pulled into shared objects from archives
+	      _LT_TAGVAR(whole_archive_flag_spec, $1)='$convenience'
+	    fi
 	    _LT_TAGVAR(archive_cmds_need_lc, $1)=yes
 	    # This is similar to how AIX traditionally builds its shared
 	    # libraries.
@@ -5652,28 +6129,75 @@
         ;;
 
       cygwin* | mingw* | pw32* | cegcc*)
-        # _LT_TAGVAR(hardcode_libdir_flag_spec, $1) is actually meaningless,
-        # as there is no search path for DLLs.
-        _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-L$libdir'
-        _LT_TAGVAR(allow_undefined_flag, $1)=unsupported
-        _LT_TAGVAR(always_export_symbols, $1)=no
-        _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=yes
+	case $GXX,$cc_basename in
+	,cl* | no,cl*)
+	  # Native MSVC
+	  # hardcode_libdir_flag_spec is actually meaningless, as there is
+	  # no search path for DLLs.
+	  _LT_TAGVAR(hardcode_libdir_flag_spec, $1)=' '
+	  _LT_TAGVAR(allow_undefined_flag, $1)=unsupported
+	  _LT_TAGVAR(always_export_symbols, $1)=yes
+	  _LT_TAGVAR(file_list_spec, $1)='@'
+	  # Tell ltmain to make .lib files, not .a files.
+	  libext=lib
+	  # Tell ltmain to make .dll files, not .so files.
+	  shrext_cmds=".dll"
+	  # FIXME: Setting linknames here is a bad hack.
+	  _LT_TAGVAR(archive_cmds, $1)='$CC -o $output_objdir/$soname $libobjs $compiler_flags $deplibs -Wl,-dll~linknames='
+	  _LT_TAGVAR(archive_expsym_cmds, $1)='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
+	      $SED -n -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' -e '1\\\!p' < $export_symbols > $output_objdir/$soname.exp;
+	    else
+	      $SED -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' < $export_symbols > $output_objdir/$soname.exp;
+	    fi~
+	    $CC -o $tool_output_objdir$soname $libobjs $compiler_flags $deplibs "@$tool_output_objdir$soname.exp" -Wl,-DLL,-IMPLIB:"$tool_output_objdir$libname.dll.lib"~
+	    linknames='
+	  # The linker will not automatically build a static lib if we build a DLL.
+	  # _LT_TAGVAR(old_archive_from_new_cmds, $1)='true'
+	  _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=yes
+	  # Don't use ranlib
+	  _LT_TAGVAR(old_postinstall_cmds, $1)='chmod 644 $oldlib'
+	  _LT_TAGVAR(postlink_cmds, $1)='lt_outputfile="@OUTPUT@"~
+	    lt_tool_outputfile="@TOOL_OUTPUT@"~
+	    case $lt_outputfile in
+	      *.exe|*.EXE) ;;
+	      *)
+		lt_outputfile="$lt_outputfile.exe"
+		lt_tool_outputfile="$lt_tool_outputfile.exe"
+		;;
+	    esac~
+	    func_to_tool_file "$lt_outputfile"~
+	    if test "$MANIFEST_TOOL" != ":" && test -f "$lt_outputfile.manifest"; then
+	      $MANIFEST_TOOL -manifest "$lt_tool_outputfile.manifest" -outputresource:"$lt_tool_outputfile" || exit 1;
+	      $RM "$lt_outputfile.manifest";
+	    fi'
+	  ;;
+	*)
+	  # g++
+	  # _LT_TAGVAR(hardcode_libdir_flag_spec, $1) is actually meaningless,
+	  # as there is no search path for DLLs.
+	  _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-L$libdir'
+	  _LT_TAGVAR(export_dynamic_flag_spec, $1)='${wl}--export-all-symbols'
+	  _LT_TAGVAR(allow_undefined_flag, $1)=unsupported
+	  _LT_TAGVAR(always_export_symbols, $1)=no
+	  _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=yes
 
-        if $LD --help 2>&1 | $GREP 'auto-import' > /dev/null; then
-          _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
-          # If the export-symbols file already is a .def file (1st line
-          # is EXPORTS), use it as is; otherwise, prepend...
-          _LT_TAGVAR(archive_expsym_cmds, $1)='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
-	    cp $export_symbols $output_objdir/$soname.def;
-          else
-	    echo EXPORTS > $output_objdir/$soname.def;
-	    cat $export_symbols >> $output_objdir/$soname.def;
-          fi~
-          $CC -shared -nostdlib $output_objdir/$soname.def $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
-        else
-          _LT_TAGVAR(ld_shlibs, $1)=no
-        fi
-        ;;
+	  if $LD --help 2>&1 | $GREP 'auto-import' > /dev/null; then
+	    _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
+	    # If the export-symbols file already is a .def file (1st line
+	    # is EXPORTS), use it as is; otherwise, prepend...
+	    _LT_TAGVAR(archive_expsym_cmds, $1)='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
+	      cp $export_symbols $output_objdir/$soname.def;
+	    else
+	      echo EXPORTS > $output_objdir/$soname.def;
+	      cat $export_symbols >> $output_objdir/$soname.def;
+	    fi~
+	    $CC -shared -nostdlib $output_objdir/$soname.def $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
+	  else
+	    _LT_TAGVAR(ld_shlibs, $1)=no
+	  fi
+	  ;;
+	esac
+	;;
       darwin* | rhapsody*)
         _LT_DARWIN_LINKER_FEATURES($1)
 	;;
@@ -5696,7 +6220,7 @@
         esac
         ;;
 
-      freebsd[[12]]*)
+      freebsd2.*)
         # C++ shared libraries reported to be fairly broken before
 	# switch to ELF
         _LT_TAGVAR(ld_shlibs, $1)=no
@@ -5712,7 +6236,9 @@
         _LT_TAGVAR(ld_shlibs, $1)=yes
         ;;
 
-      gnu*)
+      haiku*)
+        _LT_TAGVAR(archive_cmds, $1)='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+        _LT_TAGVAR(link_all_deplibs, $1)=yes
         ;;
 
       hpux9*)
@@ -5739,11 +6265,11 @@
             # explicitly linking system object files so we need to strip them
             # from the output so that they don't get included in the library
             # dependencies.
-            output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $EGREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+            output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $EGREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
             ;;
           *)
             if test "$GXX" = yes; then
-              _LT_TAGVAR(archive_cmds, $1)='$RM $output_objdir/$soname~$CC -shared -nostdlib -fPIC ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
+              _LT_TAGVAR(archive_cmds, $1)='$RM $output_objdir/$soname~$CC -shared -nostdlib $pic_flag ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
             else
               # FIXME: insert proper C++ library support
               _LT_TAGVAR(ld_shlibs, $1)=no
@@ -5804,7 +6330,7 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $GREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $GREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
 	    ;;
           *)
 	    if test "$GXX" = yes; then
@@ -5814,10 +6340,10 @@
 	            _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib -fPIC ${wl}+h ${wl}$soname -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	            ;;
 	          ia64*)
-	            _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib -fPIC ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
+	            _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $pic_flag ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	            ;;
 	          *)
-	            _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib -fPIC ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
+	            _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $pic_flag ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	            ;;
 	        esac
 	      fi
@@ -5847,7 +6373,7 @@
         case $cc_basename in
           CC*)
 	    # SGI C++
-	    _LT_TAGVAR(archive_cmds, $1)='$CC -shared -all -multigot $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	    _LT_TAGVAR(archive_cmds, $1)='$CC -shared -all -multigot $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 
 	    # Archives containing C++ object files must be created using
 	    # "CC -ar", where "CC" is the IRIX C++ compiler.  This is
@@ -5858,9 +6384,9 @@
           *)
 	    if test "$GXX" = yes; then
 	      if test "$with_gnu_ld" = no; then
-	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 	      else
-	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` -o $lib'
+	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` -o $lib'
 	      fi
 	    fi
 	    _LT_TAGVAR(link_all_deplibs, $1)=yes
@@ -5871,7 +6397,7 @@
         _LT_TAGVAR(inherit_rpath, $1)=yes
         ;;
 
-      linux* | k*bsd*-gnu)
+      linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
         case $cc_basename in
           KCC*)
 	    # Kuck and Associates, Inc. (KAI) C++ Compiler
@@ -5889,7 +6415,7 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`$CC $CFLAGS -v conftest.$objext -o libconftest$shared_ext 2>&1 | $GREP "ld"`; rm -f libconftest$shared_ext; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`$CC $CFLAGS -v conftest.$objext -o libconftest$shared_ext 2>&1 | $GREP "ld"`; rm -f libconftest$shared_ext; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
 
 	    _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath,$libdir'
 	    _LT_TAGVAR(export_dynamic_flag_spec, $1)='${wl}--export-dynamic'
@@ -5926,26 +6452,26 @@
           pgCC* | pgcpp*)
             # Portland Group C++ compiler
 	    case `$CC -V` in
-	    *pgCC\ [[1-5]]* | *pgcpp\ [[1-5]]*)
+	    *pgCC\ [[1-5]].* | *pgcpp\ [[1-5]].*)
 	      _LT_TAGVAR(prelink_cmds, $1)='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $objs $libobjs $compile_deplibs~
-		compile_command="$compile_command `find $tpldir -name \*.o | $NL2SP`"'
+		compile_command="$compile_command `find $tpldir -name \*.o | sort | $NL2SP`"'
 	      _LT_TAGVAR(old_archive_cmds, $1)='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $oldobjs$old_deplibs~
-		$AR $AR_FLAGS $oldlib$oldobjs$old_deplibs `find $tpldir -name \*.o | $NL2SP`~
+		$AR $AR_FLAGS $oldlib$oldobjs$old_deplibs `find $tpldir -name \*.o | sort | $NL2SP`~
 		$RANLIB $oldlib'
 	      _LT_TAGVAR(archive_cmds, $1)='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $predep_objects $libobjs $deplibs $convenience $postdep_objects~
-		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname -o $lib'
+		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | sort | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname -o $lib'
 	      _LT_TAGVAR(archive_expsym_cmds, $1)='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $predep_objects $libobjs $deplibs $convenience $postdep_objects~
-		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname ${wl}-retain-symbols-file ${wl}$export_symbols -o $lib'
+		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | sort | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname ${wl}-retain-symbols-file ${wl}$export_symbols -o $lib'
 	      ;;
-	    *) # Version 6 will use weak symbols
+	    *) # Version 6 and above use weak symbols
 	      _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname -o $lib'
 	      _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -shared $pic_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname ${wl}-retain-symbols-file ${wl}$export_symbols -o $lib'
 	      ;;
@@ -5953,7 +6479,7 @@
 
 	    _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}--rpath ${wl}$libdir'
 	    _LT_TAGVAR(export_dynamic_flag_spec, $1)='${wl}--export-dynamic'
-	    _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	    _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
             ;;
 	  cxx*)
 	    # Compaq C++
@@ -5972,9 +6498,9 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld"`; templist=`$ECHO "X$templist" | $Xsed -e "s/\(^.*ld.*\)\( .*ld .*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld"`; templist=`func_echo_all "$templist" | $SED "s/\(^.*ld.*\)\( .*ld .*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "X$list" | $Xsed'
 	    ;;
-	  xl*)
+	  xl* | mpixl* | bgxl*)
 	    # IBM XL 8.0 on PPC, with GNU ld
 	    _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath ${wl}$libdir'
 	    _LT_TAGVAR(export_dynamic_flag_spec, $1)='${wl}--export-dynamic'
@@ -5994,13 +6520,13 @@
 	      _LT_TAGVAR(archive_cmds, $1)='$CC -G${allow_undefined_flag} -h$soname -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	      _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -G${allow_undefined_flag} -h$soname -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-retain-symbols-file ${wl}$export_symbols'
 	      _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-R$libdir'
-	      _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	      _LT_TAGVAR(whole_archive_flag_spec, $1)='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	      _LT_TAGVAR(compiler_needs_object, $1)=yes
 
 	      # Not sure whether something based on
 	      # $CC $CFLAGS -v conftest.$objext -o libconftest$shared_ext 2>&1
 	      # would be better.
-	      output_verbose_link_cmd='echo'
+	      output_verbose_link_cmd='func_echo_all'
 
 	      # Archives containing C++ object files must be created using
 	      # "CC -xar", where "CC" is the Sun C++ compiler.  This is
@@ -6069,7 +6595,7 @@
 	    _LT_TAGVAR(export_dynamic_flag_spec, $1)='${wl}-E'
 	    _LT_TAGVAR(whole_archive_flag_spec, $1)="$wlarc"'--whole-archive$convenience '"$wlarc"'--no-whole-archive'
 	  fi
-	  output_verbose_link_cmd=echo
+	  output_verbose_link_cmd=func_echo_all
 	else
 	  _LT_TAGVAR(ld_shlibs, $1)=no
 	fi
@@ -6104,15 +6630,15 @@
 	    case $host in
 	      osf3*)
 	        _LT_TAGVAR(allow_undefined_flag, $1)=' ${wl}-expect_unresolved ${wl}\*'
-	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $soname `test -n "$verstring" && $ECHO "X${wl}-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $soname `test -n "$verstring" && func_echo_all "${wl}-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 	        _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-rpath ${wl}$libdir'
 		;;
 	      *)
 	        _LT_TAGVAR(allow_undefined_flag, $1)=' -expect_unresolved \*'
-	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 	        _LT_TAGVAR(archive_expsym_cmds, $1)='for i in `cat $export_symbols`; do printf "%s %s\\n" -exported_symbol "\$i" >> $lib.exp; done~
 	          echo "-hidden">> $lib.exp~
-	          $CC -shared$allow_undefined_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname ${wl}-input ${wl}$lib.exp  `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib~
+	          $CC -shared$allow_undefined_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname ${wl}-input ${wl}$lib.exp  `test -n "$verstring" && $ECHO "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib~
 	          $RM $lib.exp'
 	        _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='-rpath $libdir'
 		;;
@@ -6128,17 +6654,17 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld" | $GREP -v "ld:"`; templist=`$ECHO "X$templist" | $Xsed -e "s/\(^.*ld.*\)\( .*ld.*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld" | $GREP -v "ld:"`; templist=`func_echo_all "$templist" | $SED "s/\(^.*ld.*\)\( .*ld.*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
 	    ;;
 	  *)
 	    if test "$GXX" = yes && test "$with_gnu_ld" = no; then
 	      _LT_TAGVAR(allow_undefined_flag, $1)=' ${wl}-expect_unresolved ${wl}\*'
 	      case $host in
 	        osf3*)
-	          _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	          _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 		  ;;
 	        *)
-	          _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	          _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 		  ;;
 	      esac
 
@@ -6148,7 +6674,7 @@
 	      # Commands to make compiler produce verbose output that lists
 	      # what "hidden" libraries, object files and flags are used when
 	      # linking a shared library.
-	      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+	      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 
 	    else
 	      # FIXME: insert proper C++ library support
@@ -6184,7 +6710,7 @@
 
       solaris*)
         case $cc_basename in
-          CC*)
+          CC* | sunCC*)
 	    # Sun C++ 4.2, 5.x and Centerline C++
             _LT_TAGVAR(archive_cmds_need_lc,$1)=yes
 	    _LT_TAGVAR(no_undefined_flag, $1)=' -zdefs'
@@ -6205,7 +6731,7 @@
 	    esac
 	    _LT_TAGVAR(link_all_deplibs, $1)=yes
 
-	    output_verbose_link_cmd='echo'
+	    output_verbose_link_cmd='func_echo_all'
 
 	    # Archives containing C++ object files must be created using
 	    # "CC -xar", where "CC" is the Sun C++ compiler.  This is
@@ -6225,14 +6751,14 @@
 	    if test "$GXX" = yes && test "$with_gnu_ld" = no; then
 	      _LT_TAGVAR(no_undefined_flag, $1)=' ${wl}-z ${wl}defs'
 	      if $CC --version | $GREP -v '^2\.7' > /dev/null; then
-	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared -nostdlib $LDFLAGS $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-h $wl$soname -o $lib'
+	        _LT_TAGVAR(archive_cmds, $1)='$CC -shared $pic_flag -nostdlib $LDFLAGS $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-h $wl$soname -o $lib'
 	        _LT_TAGVAR(archive_expsym_cmds, $1)='echo "{ global:" > $lib.exp~cat $export_symbols | $SED -e "s/\(.*\)/\1;/" >> $lib.exp~echo "local: *; };" >> $lib.exp~
-		  $CC -shared -nostdlib ${wl}-M $wl$lib.exp -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~$RM $lib.exp'
+		  $CC -shared $pic_flag -nostdlib ${wl}-M $wl$lib.exp -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~$RM $lib.exp'
 
 	        # Commands to make compiler produce verbose output that lists
 	        # what "hidden" libraries, object files and flags are used when
 	        # linking a shared library.
-	        output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+	        output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 	      else
 	        # g++ 2.7 appears to require `-G' NOT `-shared' on this
 	        # platform.
@@ -6243,7 +6769,7 @@
 	        # Commands to make compiler produce verbose output that lists
 	        # what "hidden" libraries, object files and flags are used when
 	        # linking a shared library.
-	        output_verbose_link_cmd='$CC -G $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+	        output_verbose_link_cmd='$CC -G $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 	      fi
 
 	      _LT_TAGVAR(hardcode_libdir_flag_spec, $1)='${wl}-R $wl$libdir'
@@ -6297,6 +6823,10 @@
           CC*)
 	    _LT_TAGVAR(archive_cmds, $1)='$CC -G ${wl}-h,$soname -o $lib $libobjs $deplibs $compiler_flags'
 	    _LT_TAGVAR(archive_expsym_cmds, $1)='$CC -G ${wl}-Bexport:$export_symbols ${wl}-h,$soname -o $lib $libobjs $deplibs $compiler_flags'
+	    _LT_TAGVAR(old_archive_cmds, $1)='$CC -Tprelink_objects $oldobjs~
+	      '"$_LT_TAGVAR(old_archive_cmds, $1)"
+	    _LT_TAGVAR(reload_cmds, $1)='$CC -Tprelink_objects $reload_objs~
+	      '"$_LT_TAGVAR(reload_cmds, $1)"
 	    ;;
 	  *)
 	    _LT_TAGVAR(archive_cmds, $1)='$CC -shared ${wl}-h,$soname -o $lib $libobjs $deplibs $compiler_flags'
@@ -6352,6 +6882,7 @@
   fi # test -n "$compiler"
 
   CC=$lt_save_CC
+  CFLAGS=$lt_save_CFLAGS
   LDCXX=$LD
   LD=$lt_save_LD
   GCC=$lt_save_GCC
@@ -6366,6 +6897,29 @@
 ])# _LT_LANG_CXX_CONFIG
 
 
+# _LT_FUNC_STRIPNAME_CNF
+# ----------------------
+# func_stripname_cnf prefix suffix name
+# strip PREFIX and SUFFIX off of NAME.
+# PREFIX and SUFFIX must not contain globbing or regex special
+# characters, hashes, percent signs, but SUFFIX may contain a leading
+# dot (in which case that matches only a dot).
+#
+# This function is identical to the (non-XSI) version of func_stripname,
+# except this one can be used by m4 code that may be executed by configure,
+# rather than the libtool script.
+m4_defun([_LT_FUNC_STRIPNAME_CNF],[dnl
+AC_REQUIRE([_LT_DECL_SED])
+AC_REQUIRE([_LT_PROG_ECHO_BACKSLASH])
+func_stripname_cnf ()
+{
+  case ${2} in
+  .*) func_stripname_result=`$ECHO "${3}" | $SED "s%^${1}%%; s%\\\\${2}\$%%"`;;
+  *)  func_stripname_result=`$ECHO "${3}" | $SED "s%^${1}%%; s%${2}\$%%"`;;
+  esac
+} # func_stripname_cnf
+])# _LT_FUNC_STRIPNAME_CNF
+
 # _LT_SYS_HIDDEN_LIBDEPS([TAGNAME])
 # ---------------------------------
 # Figure out "hidden" library dependencies from verbose
@@ -6374,6 +6928,7 @@
 # objects, libraries and library flags.
 m4_defun([_LT_SYS_HIDDEN_LIBDEPS],
 [m4_require([_LT_FILEUTILS_DEFAULTS])dnl
+AC_REQUIRE([_LT_FUNC_STRIPNAME_CNF])dnl
 # Dependencies to place before and after the object being linked:
 _LT_TAGVAR(predep_objects, $1)=
 _LT_TAGVAR(postdep_objects, $1)=
@@ -6423,7 +6978,20 @@
   }
 };
 _LT_EOF
+], [$1], [GO], [cat > conftest.$ac_ext <<_LT_EOF
+package foo
+func foo() {
+}
+_LT_EOF
 ])
+
+_lt_libdeps_save_CFLAGS=$CFLAGS
+case "$CC $CFLAGS " in #(
+*\ -flto*\ *) CFLAGS="$CFLAGS -fno-lto" ;;
+*\ -fwhopr*\ *) CFLAGS="$CFLAGS -fno-whopr" ;;
+*\ -fuse-linker-plugin*\ *) CFLAGS="$CFLAGS -fno-use-linker-plugin" ;;
+esac
+
 dnl Parse the compiler output and extract the necessary
 dnl objects, libraries and library flags.
 if AC_TRY_EVAL(ac_compile); then
@@ -6435,7 +7003,7 @@
   pre_test_object_deps_done=no
 
   for p in `eval "$output_verbose_link_cmd"`; do
-    case $p in
+    case ${prev}${p} in
 
     -L* | -R* | -l*)
        # Some compilers place space between "-{L,R}" and the path.
@@ -6444,13 +7012,22 @@
           test $p = "-R"; then
 	 prev=$p
 	 continue
-       else
-	 prev=
        fi
 
+       # Expand the sysroot to ease extracting the directories later.
+       if test -z "$prev"; then
+         case $p in
+         -L*) func_stripname_cnf '-L' '' "$p"; prev=-L; p=$func_stripname_result ;;
+         -R*) func_stripname_cnf '-R' '' "$p"; prev=-R; p=$func_stripname_result ;;
+         -l*) func_stripname_cnf '-l' '' "$p"; prev=-l; p=$func_stripname_result ;;
+         esac
+       fi
+       case $p in
+       =*) func_stripname_cnf '=' '' "$p"; p=$lt_sysroot$func_stripname_result ;;
+       esac
        if test "$pre_test_object_deps_done" = no; then
-	 case $p in
-	 -L* | -R*)
+	 case ${prev} in
+	 -L | -R)
 	   # Internal compiler library paths should come after those
 	   # provided the user.  The postdeps already come after the
 	   # user supplied libs so there is no need to process them.
@@ -6470,8 +7047,10 @@
 	   _LT_TAGVAR(postdeps, $1)="${_LT_TAGVAR(postdeps, $1)} ${prev}${p}"
 	 fi
        fi
+       prev=
        ;;
 
+    *.lto.$objext) ;; # Ignore GCC LTO objects
     *.$objext)
        # This assumes that the test object file only shows up
        # once in the compiler output.
@@ -6507,6 +7086,7 @@
 fi
 
 $RM -f confest.$objext
+CFLAGS=$_lt_libdeps_save_CFLAGS
 
 # PORTME: override above test on systems where it is broken
 m4_if([$1], [CXX],
@@ -6543,7 +7123,7 @@
 
 solaris*)
   case $cc_basename in
-  CC*)
+  CC* | sunCC*)
     # The more standards-conforming stlport4 library is
     # incompatible with the Cstd library. Avoid specifying
     # it if it's in CXXFLAGS. Ignore libCrun as
@@ -6587,32 +7167,16 @@
 ])# _LT_SYS_HIDDEN_LIBDEPS
 
 
-# _LT_PROG_F77
-# ------------
-# Since AC_PROG_F77 is broken, in that it returns the empty string
-# if there is no fortran compiler, we have our own version here.
-m4_defun([_LT_PROG_F77],
-[
-pushdef([AC_MSG_ERROR], [_lt_disable_F77=yes])
-AC_PROG_F77
-if test -z "$F77" || test "X$F77" = "Xno"; then
-  _lt_disable_F77=yes
-fi
-popdef([AC_MSG_ERROR])
-])# _LT_PROG_F77
-
-dnl aclocal-1.4 backwards compatibility:
-dnl AC_DEFUN([_LT_PROG_F77], [])
-
-
 # _LT_LANG_F77_CONFIG([TAG])
 # --------------------------
 # Ensure that the configuration variables for a Fortran 77 compiler are
 # suitably defined.  These variables are subsequently used by _LT_CONFIG
 # to write the compiler configuration to `libtool'.
 m4_defun([_LT_LANG_F77_CONFIG],
-[AC_REQUIRE([_LT_PROG_F77])dnl
-AC_LANG_PUSH(Fortran 77)
+[AC_LANG_PUSH(Fortran 77)
+if test -z "$F77" || test "X$F77" = "Xno"; then
+  _lt_disable_F77=yes
+fi
 
 _LT_TAGVAR(archive_cmds_need_lc, $1)=no
 _LT_TAGVAR(allow_undefined_flag, $1)=
@@ -6622,7 +7186,6 @@
 _LT_TAGVAR(hardcode_direct, $1)=no
 _LT_TAGVAR(hardcode_direct_absolute, $1)=no
 _LT_TAGVAR(hardcode_libdir_flag_spec, $1)=
-_LT_TAGVAR(hardcode_libdir_flag_spec_ld, $1)=
 _LT_TAGVAR(hardcode_libdir_separator, $1)=
 _LT_TAGVAR(hardcode_minus_L, $1)=no
 _LT_TAGVAR(hardcode_automatic, $1)=no
@@ -6631,6 +7194,8 @@
 _LT_TAGVAR(module_expsym_cmds, $1)=
 _LT_TAGVAR(link_all_deplibs, $1)=unknown
 _LT_TAGVAR(old_archive_cmds, $1)=$old_archive_cmds
+_LT_TAGVAR(reload_flag, $1)=$reload_flag
+_LT_TAGVAR(reload_cmds, $1)=$reload_cmds
 _LT_TAGVAR(no_undefined_flag, $1)=
 _LT_TAGVAR(whole_archive_flag_spec, $1)=
 _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=no
@@ -6670,7 +7235,9 @@
   # Allow CC to be a program name with arguments.
   lt_save_CC="$CC"
   lt_save_GCC=$GCC
+  lt_save_CFLAGS=$CFLAGS
   CC=${F77-"f77"}
+  CFLAGS=$FFLAGS
   compiler=$CC
   _LT_TAGVAR(compiler, $1)=$CC
   _LT_CC_BASENAME([$compiler])
@@ -6724,38 +7291,24 @@
 
   GCC=$lt_save_GCC
   CC="$lt_save_CC"
+  CFLAGS="$lt_save_CFLAGS"
 fi # test "$_lt_disable_F77" != yes
 
 AC_LANG_POP
 ])# _LT_LANG_F77_CONFIG
 
 
-# _LT_PROG_FC
-# -----------
-# Since AC_PROG_FC is broken, in that it returns the empty string
-# if there is no fortran compiler, we have our own version here.
-m4_defun([_LT_PROG_FC],
-[
-pushdef([AC_MSG_ERROR], [_lt_disable_FC=yes])
-AC_PROG_FC
-if test -z "$FC" || test "X$FC" = "Xno"; then
-  _lt_disable_FC=yes
-fi
-popdef([AC_MSG_ERROR])
-])# _LT_PROG_FC
-
-dnl aclocal-1.4 backwards compatibility:
-dnl AC_DEFUN([_LT_PROG_FC], [])
-
-
 # _LT_LANG_FC_CONFIG([TAG])
 # -------------------------
 # Ensure that the configuration variables for a Fortran compiler are
 # suitably defined.  These variables are subsequently used by _LT_CONFIG
 # to write the compiler configuration to `libtool'.
 m4_defun([_LT_LANG_FC_CONFIG],
-[AC_REQUIRE([_LT_PROG_FC])dnl
-AC_LANG_PUSH(Fortran)
+[AC_LANG_PUSH(Fortran)
+
+if test -z "$FC" || test "X$FC" = "Xno"; then
+  _lt_disable_FC=yes
+fi
 
 _LT_TAGVAR(archive_cmds_need_lc, $1)=no
 _LT_TAGVAR(allow_undefined_flag, $1)=
@@ -6765,7 +7318,6 @@
 _LT_TAGVAR(hardcode_direct, $1)=no
 _LT_TAGVAR(hardcode_direct_absolute, $1)=no
 _LT_TAGVAR(hardcode_libdir_flag_spec, $1)=
-_LT_TAGVAR(hardcode_libdir_flag_spec_ld, $1)=
 _LT_TAGVAR(hardcode_libdir_separator, $1)=
 _LT_TAGVAR(hardcode_minus_L, $1)=no
 _LT_TAGVAR(hardcode_automatic, $1)=no
@@ -6774,6 +7326,8 @@
 _LT_TAGVAR(module_expsym_cmds, $1)=
 _LT_TAGVAR(link_all_deplibs, $1)=unknown
 _LT_TAGVAR(old_archive_cmds, $1)=$old_archive_cmds
+_LT_TAGVAR(reload_flag, $1)=$reload_flag
+_LT_TAGVAR(reload_cmds, $1)=$reload_cmds
 _LT_TAGVAR(no_undefined_flag, $1)=
 _LT_TAGVAR(whole_archive_flag_spec, $1)=
 _LT_TAGVAR(enable_shared_with_static_runtimes, $1)=no
@@ -6813,7 +7367,9 @@
   # Allow CC to be a program name with arguments.
   lt_save_CC="$CC"
   lt_save_GCC=$GCC
+  lt_save_CFLAGS=$CFLAGS
   CC=${FC-"f95"}
+  CFLAGS=$FCFLAGS
   compiler=$CC
   GCC=$ac_cv_fc_compiler_gnu
 
@@ -6869,7 +7425,8 @@
   fi # test -n "$compiler"
 
   GCC=$lt_save_GCC
-  CC="$lt_save_CC"
+  CC=$lt_save_CC
+  CFLAGS=$lt_save_CFLAGS
 fi # test "$_lt_disable_FC" != yes
 
 AC_LANG_POP
@@ -6906,10 +7463,12 @@
 _LT_LINKER_BOILERPLATE
 
 # Allow CC to be a program name with arguments.
-lt_save_CC="$CC"
+lt_save_CC=$CC
+lt_save_CFLAGS=$CFLAGS
 lt_save_GCC=$GCC
 GCC=yes
 CC=${GCJ-"gcj"}
+CFLAGS=$GCJFLAGS
 compiler=$CC
 _LT_TAGVAR(compiler, $1)=$CC
 _LT_TAGVAR(LD, $1)="$LD"
@@ -6919,6 +7478,8 @@
 _LT_TAGVAR(archive_cmds_need_lc, $1)=no
 
 _LT_TAGVAR(old_archive_cmds, $1)=$old_archive_cmds
+_LT_TAGVAR(reload_flag, $1)=$reload_flag
+_LT_TAGVAR(reload_cmds, $1)=$reload_cmds
 
 if test -n "$compiler"; then
   _LT_COMPILER_NO_RTTI($1)
@@ -6934,10 +7495,78 @@
 AC_LANG_RESTORE
 
 GCC=$lt_save_GCC
-CC="$lt_save_CC"
+CC=$lt_save_CC
+CFLAGS=$lt_save_CFLAGS
 ])# _LT_LANG_GCJ_CONFIG
 
 
+# _LT_LANG_GO_CONFIG([TAG])
+# --------------------------
+# Ensure that the configuration variables for the GNU Go compiler
+# are suitably defined.  These variables are subsequently used by _LT_CONFIG
+# to write the compiler configuration to `libtool'.
+m4_defun([_LT_LANG_GO_CONFIG],
+[AC_REQUIRE([LT_PROG_GO])dnl
+AC_LANG_SAVE
+
+# Source file extension for Go test sources.
+ac_ext=go
+
+# Object file extension for compiled Go test sources.
+objext=o
+_LT_TAGVAR(objext, $1)=$objext
+
+# Code to be used in simple compile tests
+lt_simple_compile_test_code="package main; func main() { }"
+
+# Code to be used in simple link tests
+lt_simple_link_test_code='package main; func main() { }'
+
+# ltmain only uses $CC for tagged configurations so make sure $CC is set.
+_LT_TAG_COMPILER
+
+# save warnings/boilerplate of simple test code
+_LT_COMPILER_BOILERPLATE
+_LT_LINKER_BOILERPLATE
+
+# Allow CC to be a program name with arguments.
+lt_save_CC=$CC
+lt_save_CFLAGS=$CFLAGS
+lt_save_GCC=$GCC
+GCC=yes
+CC=${GOC-"gccgo"}
+CFLAGS=$GOFLAGS
+compiler=$CC
+_LT_TAGVAR(compiler, $1)=$CC
+_LT_TAGVAR(LD, $1)="$LD"
+_LT_CC_BASENAME([$compiler])
+
+# Go did not exist at the time GCC didn't implicitly link libc in.
+_LT_TAGVAR(archive_cmds_need_lc, $1)=no
+
+_LT_TAGVAR(old_archive_cmds, $1)=$old_archive_cmds
+_LT_TAGVAR(reload_flag, $1)=$reload_flag
+_LT_TAGVAR(reload_cmds, $1)=$reload_cmds
+
+if test -n "$compiler"; then
+  _LT_COMPILER_NO_RTTI($1)
+  _LT_COMPILER_PIC($1)
+  _LT_COMPILER_C_O($1)
+  _LT_COMPILER_FILE_LOCKS($1)
+  _LT_LINKER_SHLIBS($1)
+  _LT_LINKER_HARDCODE_LIBPATH($1)
+
+  _LT_CONFIG($1)
+fi
+
+AC_LANG_RESTORE
+
+GCC=$lt_save_GCC
+CC=$lt_save_CC
+CFLAGS=$lt_save_CFLAGS
+])# _LT_LANG_GO_CONFIG
+
+
 # _LT_LANG_RC_CONFIG([TAG])
 # -------------------------
 # Ensure that the configuration variables for the Windows resource compiler
@@ -6969,9 +7598,11 @@
 
 # Allow CC to be a program name with arguments.
 lt_save_CC="$CC"
+lt_save_CFLAGS=$CFLAGS
 lt_save_GCC=$GCC
 GCC=
 CC=${RC-"windres"}
+CFLAGS=
 compiler=$CC
 _LT_TAGVAR(compiler, $1)=$CC
 _LT_CC_BASENAME([$compiler])
@@ -6984,7 +7615,8 @@
 
 GCC=$lt_save_GCC
 AC_LANG_RESTORE
-CC="$lt_save_CC"
+CC=$lt_save_CC
+CFLAGS=$lt_save_CFLAGS
 ])# _LT_LANG_RC_CONFIG
 
 
@@ -7004,6 +7636,13 @@
 dnl AC_DEFUN([LT_AC_PROG_GCJ], [])
 
 
+# LT_PROG_GO
+# ----------
+AC_DEFUN([LT_PROG_GO],
+[AC_CHECK_TOOL(GOC, gccgo,)
+])
+
+
 # LT_PROG_RC
 # ----------
 AC_DEFUN([LT_PROG_RC],
@@ -7043,6 +7682,15 @@
 AC_SUBST([OBJDUMP])
 ])
 
+# _LT_DECL_DLLTOOL
+# ----------------
+# Ensure DLLTOOL variable is set.
+m4_defun([_LT_DECL_DLLTOOL],
+[AC_CHECK_TOOL(DLLTOOL, dlltool, false)
+test -z "$DLLTOOL" && DLLTOOL=dlltool
+_LT_DECL([], [DLLTOOL], [1], [DLL creation program])
+AC_SUBST([DLLTOOL])
+])
 
 # _LT_DECL_SED
 # ------------
@@ -7134,8 +7782,8 @@
 # Try some XSI features
 xsi_shell=no
 ( _lt_dummy="a/b/c"
-  test "${_lt_dummy##*/},${_lt_dummy%/*},"${_lt_dummy%"$_lt_dummy"}, \
-      = c,a/b,, \
+  test "${_lt_dummy##*/},${_lt_dummy%/*},${_lt_dummy#??}"${_lt_dummy%"$_lt_dummy"}, \
+      = c,a/b,b/c, \
     && eval 'test $(( 1 + 1 )) -eq 2 \
     && test "${#_lt_dummy}" -eq 5' ) >/dev/null 2>&1 \
   && xsi_shell=yes
@@ -7174,222 +7822,177 @@
 ])# _LT_CHECK_SHELL_FEATURES
 
 
-# _LT_PROG_XSI_SHELLFNS
-# ---------------------
-# Bourne and XSI compatible variants of some useful shell functions.
-m4_defun([_LT_PROG_XSI_SHELLFNS],
-[case $xsi_shell in
-  yes)
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_dirname file append nondir_replacement
-# Compute the dirname of FILE.  If nonempty, add APPEND to the result,
-# otherwise set result to NONDIR_REPLACEMENT.
-func_dirname ()
-{
-  case ${1} in
-    */*) func_dirname_result="${1%/*}${2}" ;;
-    *  ) func_dirname_result="${3}" ;;
-  esac
-}
-
-# func_basename file
-func_basename ()
-{
-  func_basename_result="${1##*/}"
-}
-
-# func_dirname_and_basename file append nondir_replacement
-# perform func_basename and func_dirname in a single function
-# call:
-#   dirname:  Compute the dirname of FILE.  If nonempty,
-#             add APPEND to the result, otherwise set result
-#             to NONDIR_REPLACEMENT.
-#             value returned in "$func_dirname_result"
-#   basename: Compute filename of FILE.
-#             value retuned in "$func_basename_result"
-# Implementation must be kept synchronized with func_dirname
-# and func_basename. For efficiency, we do not delegate to
-# those functions but instead duplicate the functionality here.
-func_dirname_and_basename ()
-{
-  case ${1} in
-    */*) func_dirname_result="${1%/*}${2}" ;;
-    *  ) func_dirname_result="${3}" ;;
-  esac
-  func_basename_result="${1##*/}"
-}
-
-# func_stripname prefix suffix name
-# strip PREFIX and SUFFIX off of NAME.
-# PREFIX and SUFFIX must not contain globbing or regex special
-# characters, hashes, percent signs, but SUFFIX may contain a leading
-# dot (in which case that matches only a dot).
-func_stripname ()
-{
-  # pdksh 5.2.14 does not do ${X%$Y} correctly if both X and Y are
-  # positional parameters, so assign one to ordinary parameter first.
-  func_stripname_result=${3}
-  func_stripname_result=${func_stripname_result#"${1}"}
-  func_stripname_result=${func_stripname_result%"${2}"}
-}
-
-# func_opt_split
-func_opt_split ()
-{
-  func_opt_split_opt=${1%%=*}
-  func_opt_split_arg=${1#*=}
-}
-
-# func_lo2o object
-func_lo2o ()
-{
-  case ${1} in
-    *.lo) func_lo2o_result=${1%.lo}.${objext} ;;
-    *)    func_lo2o_result=${1} ;;
-  esac
-}
-
-# func_xform libobj-or-source
-func_xform ()
-{
-  func_xform_result=${1%.*}.lo
-}
-
-# func_arith arithmetic-term...
-func_arith ()
-{
-  func_arith_result=$(( $[*] ))
-}
-
-# func_len string
-# STRING may not start with a hyphen.
-func_len ()
-{
-  func_len_result=${#1}
-}
-
-_LT_EOF
-    ;;
-  *) # Bourne compatible functions.
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_dirname file append nondir_replacement
-# Compute the dirname of FILE.  If nonempty, add APPEND to the result,
-# otherwise set result to NONDIR_REPLACEMENT.
-func_dirname ()
-{
-  # Extract subdirectory from the argument.
-  func_dirname_result=`$ECHO "X${1}" | $Xsed -e "$dirname"`
-  if test "X$func_dirname_result" = "X${1}"; then
-    func_dirname_result="${3}"
-  else
-    func_dirname_result="$func_dirname_result${2}"
-  fi
-}
-
-# func_basename file
-func_basename ()
-{
-  func_basename_result=`$ECHO "X${1}" | $Xsed -e "$basename"`
-}
-
-dnl func_dirname_and_basename
-dnl A portable version of this function is already defined in general.m4sh
-dnl so there is no need for it here.
-
-# func_stripname prefix suffix name
-# strip PREFIX and SUFFIX off of NAME.
-# PREFIX and SUFFIX must not contain globbing or regex special
-# characters, hashes, percent signs, but SUFFIX may contain a leading
-# dot (in which case that matches only a dot).
-# func_strip_suffix prefix name
-func_stripname ()
-{
-  case ${2} in
-    .*) func_stripname_result=`$ECHO "X${3}" \
-           | $Xsed -e "s%^${1}%%" -e "s%\\\\${2}\$%%"`;;
-    *)  func_stripname_result=`$ECHO "X${3}" \
-           | $Xsed -e "s%^${1}%%" -e "s%${2}\$%%"`;;
-  esac
-}
-
-# sed scripts:
-my_sed_long_opt='1s/^\(-[[^=]]*\)=.*/\1/;q'
-my_sed_long_arg='1s/^-[[^=]]*=//'
-
-# func_opt_split
-func_opt_split ()
-{
-  func_opt_split_opt=`$ECHO "X${1}" | $Xsed -e "$my_sed_long_opt"`
-  func_opt_split_arg=`$ECHO "X${1}" | $Xsed -e "$my_sed_long_arg"`
-}
-
-# func_lo2o object
-func_lo2o ()
-{
-  func_lo2o_result=`$ECHO "X${1}" | $Xsed -e "$lo2o"`
-}
-
-# func_xform libobj-or-source
-func_xform ()
-{
-  func_xform_result=`$ECHO "X${1}" | $Xsed -e 's/\.[[^.]]*$/.lo/'`
-}
-
-# func_arith arithmetic-term...
-func_arith ()
-{
-  func_arith_result=`expr "$[@]"`
-}
-
-# func_len string
-# STRING may not start with a hyphen.
-func_len ()
-{
-  func_len_result=`expr "$[1]" : ".*" 2>/dev/null || echo $max_cmd_len`
-}
-
-_LT_EOF
-esac
-
-case $lt_shell_append in
-  yes)
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_append var value
-# Append VALUE to the end of shell variable VAR.
-func_append ()
-{
-  eval "$[1]+=\$[2]"
-}
-_LT_EOF
-    ;;
-  *)
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_append var value
-# Append VALUE to the end of shell variable VAR.
-func_append ()
-{
-  eval "$[1]=\$$[1]\$[2]"
-}
-
-_LT_EOF
-    ;;
-  esac
-])
+# _LT_PROG_FUNCTION_REPLACE (FUNCNAME, REPLACEMENT-BODY)
+# ------------------------------------------------------
+# In `$cfgfile', look for function FUNCNAME delimited by `^FUNCNAME ()$' and
+# '^} FUNCNAME ', and replace its body with REPLACEMENT-BODY.
+m4_defun([_LT_PROG_FUNCTION_REPLACE],
+[dnl {
+sed -e '/^$1 ()$/,/^} # $1 /c\
+$1 ()\
+{\
+m4_bpatsubsts([$2], [$], [\\], [^\([	 ]\)], [\\\1])
+} # Extended-shell $1 implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+])
+
+
+# _LT_PROG_REPLACE_SHELLFNS
+# -------------------------
+# Replace existing portable implementations of several shell functions with
+# equivalent extended shell implementations where those features are available..
+m4_defun([_LT_PROG_REPLACE_SHELLFNS],
+[if test x"$xsi_shell" = xyes; then
+  _LT_PROG_FUNCTION_REPLACE([func_dirname], [dnl
+    case ${1} in
+      */*) func_dirname_result="${1%/*}${2}" ;;
+      *  ) func_dirname_result="${3}" ;;
+    esac])
+
+  _LT_PROG_FUNCTION_REPLACE([func_basename], [dnl
+    func_basename_result="${1##*/}"])
+
+  _LT_PROG_FUNCTION_REPLACE([func_dirname_and_basename], [dnl
+    case ${1} in
+      */*) func_dirname_result="${1%/*}${2}" ;;
+      *  ) func_dirname_result="${3}" ;;
+    esac
+    func_basename_result="${1##*/}"])
+
+  _LT_PROG_FUNCTION_REPLACE([func_stripname], [dnl
+    # pdksh 5.2.14 does not do ${X%$Y} correctly if both X and Y are
+    # positional parameters, so assign one to ordinary parameter first.
+    func_stripname_result=${3}
+    func_stripname_result=${func_stripname_result#"${1}"}
+    func_stripname_result=${func_stripname_result%"${2}"}])
+
+  _LT_PROG_FUNCTION_REPLACE([func_split_long_opt], [dnl
+    func_split_long_opt_name=${1%%=*}
+    func_split_long_opt_arg=${1#*=}])
+
+  _LT_PROG_FUNCTION_REPLACE([func_split_short_opt], [dnl
+    func_split_short_opt_arg=${1#??}
+    func_split_short_opt_name=${1%"$func_split_short_opt_arg"}])
+
+  _LT_PROG_FUNCTION_REPLACE([func_lo2o], [dnl
+    case ${1} in
+      *.lo) func_lo2o_result=${1%.lo}.${objext} ;;
+      *)    func_lo2o_result=${1} ;;
+    esac])
+
+  _LT_PROG_FUNCTION_REPLACE([func_xform], [    func_xform_result=${1%.*}.lo])
+
+  _LT_PROG_FUNCTION_REPLACE([func_arith], [    func_arith_result=$(( $[*] ))])
+
+  _LT_PROG_FUNCTION_REPLACE([func_len], [    func_len_result=${#1}])
+fi
+
+if test x"$lt_shell_append" = xyes; then
+  _LT_PROG_FUNCTION_REPLACE([func_append], [    eval "${1}+=\\${2}"])
+
+  _LT_PROG_FUNCTION_REPLACE([func_append_quoted], [dnl
+    func_quote_for_eval "${2}"
+dnl m4 expansion turns \\\\ into \\, and then the shell eval turns that into \
+    eval "${1}+=\\\\ \\$func_quote_for_eval_result"])
+
+  # Save a `func_append' function call where possible by direct use of '+='
+  sed -e 's%func_append \([[a-zA-Z_]]\{1,\}\) "%\1+="%g' $cfgfile > $cfgfile.tmp \
+    && mv -f "$cfgfile.tmp" "$cfgfile" \
+      || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+  test 0 -eq $? || _lt_function_replace_fail=:
+else
+  # Save a `func_append' function call even when '+=' is not available
+  sed -e 's%func_append \([[a-zA-Z_]]\{1,\}\) "%\1="$\1%g' $cfgfile > $cfgfile.tmp \
+    && mv -f "$cfgfile.tmp" "$cfgfile" \
+      || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+  test 0 -eq $? || _lt_function_replace_fail=:
+fi
+
+if test x"$_lt_function_replace_fail" = x":"; then
+  AC_MSG_WARN([Unable to substitute extended shell functions in $ofile])
+fi
+])
+
+# _LT_PATH_CONVERSION_FUNCTIONS
+# -----------------------------
+# Determine which file name conversion functions should be used by
+# func_to_host_file (and, implicitly, by func_to_host_path).  These are needed
+# for certain cross-compile configurations and native mingw.
+m4_defun([_LT_PATH_CONVERSION_FUNCTIONS],
+[AC_REQUIRE([AC_CANONICAL_HOST])dnl
+AC_REQUIRE([AC_CANONICAL_BUILD])dnl
+AC_MSG_CHECKING([how to convert $build file names to $host format])
+AC_CACHE_VAL(lt_cv_to_host_file_cmd,
+[case $host in
+  *-*-mingw* )
+    case $build in
+      *-*-mingw* ) # actually msys
+        lt_cv_to_host_file_cmd=func_convert_file_msys_to_w32
+        ;;
+      *-*-cygwin* )
+        lt_cv_to_host_file_cmd=func_convert_file_cygwin_to_w32
+        ;;
+      * ) # otherwise, assume *nix
+        lt_cv_to_host_file_cmd=func_convert_file_nix_to_w32
+        ;;
+    esac
+    ;;
+  *-*-cygwin* )
+    case $build in
+      *-*-mingw* ) # actually msys
+        lt_cv_to_host_file_cmd=func_convert_file_msys_to_cygwin
+        ;;
+      *-*-cygwin* )
+        lt_cv_to_host_file_cmd=func_convert_file_noop
+        ;;
+      * ) # otherwise, assume *nix
+        lt_cv_to_host_file_cmd=func_convert_file_nix_to_cygwin
+        ;;
+    esac
+    ;;
+  * ) # unhandled hosts (and "normal" native builds)
+    lt_cv_to_host_file_cmd=func_convert_file_noop
+    ;;
+esac
+])
+to_host_file_cmd=$lt_cv_to_host_file_cmd
+AC_MSG_RESULT([$lt_cv_to_host_file_cmd])
+_LT_DECL([to_host_file_cmd], [lt_cv_to_host_file_cmd],
+         [0], [convert $build file names to $host format])dnl
+
+AC_MSG_CHECKING([how to convert $build file names to toolchain format])
+AC_CACHE_VAL(lt_cv_to_tool_file_cmd,
+[#assume ordinary cross tools, or native build.
+lt_cv_to_tool_file_cmd=func_convert_file_noop
+case $host in
+  *-*-mingw* )
+    case $build in
+      *-*-mingw* ) # actually msys
+        lt_cv_to_tool_file_cmd=func_convert_file_msys_to_w32
+        ;;
+    esac
+    ;;
+esac
+])
+to_tool_file_cmd=$lt_cv_to_tool_file_cmd
+AC_MSG_RESULT([$lt_cv_to_tool_file_cmd])
+_LT_DECL([to_tool_file_cmd], [lt_cv_to_tool_file_cmd],
+         [0], [convert $build files to toolchain format])dnl
+])# _LT_PATH_CONVERSION_FUNCTIONS
 
 # Helper functions for option handling.                    -*- Autoconf -*-
 #
-#   Copyright (C) 2004, 2005, 2007, 2008 Free Software Foundation, Inc.
+#   Copyright (C) 2004, 2005, 2007, 2008, 2009 Free Software Foundation,
+#   Inc.
 #   Written by Gary V. Vaughan, 2004
 #
 # This file is free software; the Free Software Foundation gives
 # unlimited permission to copy and/or distribute it, with or without
 # modifications, as long as this notice is preserved.
 
-# serial 6 ltoptions.m4
+# serial 7 ltoptions.m4
 
 # This is to help aclocal find these macros, as it can't see m4_define.
 AC_DEFUN([LTOPTIONS_VERSION], [m4_if([1])])
@@ -7504,7 +8107,7 @@
 [enable_win32_dll=yes
 
 case $host in
-*-*-cygwin* | *-*-mingw* | *-*-pw32* | *-cegcc*)
+*-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-cegcc*)
   AC_CHECK_TOOL(AS, as, false)
   AC_CHECK_TOOL(DLLTOOL, dlltool, false)
   AC_CHECK_TOOL(OBJDUMP, objdump, false)
@@ -7512,13 +8115,13 @@
 esac
 
 test -z "$AS" && AS=as
-_LT_DECL([], [AS],      [0], [Assembler program])dnl
+_LT_DECL([], [AS],      [1], [Assembler program])dnl
 
 test -z "$DLLTOOL" && DLLTOOL=dlltool
-_LT_DECL([], [DLLTOOL], [0], [DLL creation program])dnl
+_LT_DECL([], [DLLTOOL], [1], [DLL creation program])dnl
 
 test -z "$OBJDUMP" && OBJDUMP=objdump
-_LT_DECL([], [OBJDUMP], [0], [Object dumper program])dnl
+_LT_DECL([], [OBJDUMP], [1], [Object dumper program])dnl
 ])# win32-dll
 
 AU_DEFUN([AC_LIBTOOL_WIN32_DLL],
@@ -7704,9 +8307,24 @@
 # MODE is either `yes' or `no'.  If omitted, it defaults to `both'.
 m4_define([_LT_WITH_PIC],
 [AC_ARG_WITH([pic],
-    [AS_HELP_STRING([--with-pic],
+    [AS_HELP_STRING([--with-pic@<:@=PKGS@:>@],
 	[try to use only PIC/non-PIC objects @<:@default=use both@:>@])],
-    [pic_mode="$withval"],
+    [lt_p=${PACKAGE-default}
+    case $withval in
+    yes|no) pic_mode=$withval ;;
+    *)
+      pic_mode=default
+      # Look at the argument we got.  We use all the common list separators.
+      lt_save_ifs="$IFS"; IFS="${IFS}$PATH_SEPARATOR,"
+      for lt_pkg in $withval; do
+	IFS="$lt_save_ifs"
+	if test "X$lt_pkg" = "X$lt_p"; then
+	  pic_mode=yes
+	fi
+      done
+      IFS="$lt_save_ifs"
+      ;;
+    esac],
     [pic_mode=default])
 
 test -z "$pic_mode" && pic_mode=m4_default([$1], [default])
@@ -7876,31 +8494,31 @@
 # unlimited permission to copy and/or distribute it, with or without
 # modifications, as long as this notice is preserved.
 
-# Generated from ltversion.in.
+# @configure_input@
 
-# serial 3012 ltversion.m4
+# serial 3337 ltversion.m4
 # This file is part of GNU Libtool
 
-m4_define([LT_PACKAGE_VERSION], [2.2.6])
-m4_define([LT_PACKAGE_REVISION], [1.3012])
+m4_define([LT_PACKAGE_VERSION], [2.4.2])
+m4_define([LT_PACKAGE_REVISION], [1.3337])
 
 AC_DEFUN([LTVERSION_VERSION],
-[macro_version='2.2.6'
-macro_revision='1.3012'
+[macro_version='2.4.2'
+macro_revision='1.3337'
 _LT_DECL(, macro_version, 0, [Which release of libtool.m4 was used?])
 _LT_DECL(, macro_revision, 0)
 ])
 
 # lt~obsolete.m4 -- aclocal satisfying obsolete definitions.    -*-Autoconf-*-
 #
-#   Copyright (C) 2004, 2005, 2007 Free Software Foundation, Inc.
+#   Copyright (C) 2004, 2005, 2007, 2009 Free Software Foundation, Inc.
 #   Written by Scott James Remnant, 2004.
 #
 # This file is free software; the Free Software Foundation gives
 # unlimited permission to copy and/or distribute it, with or without
 # modifications, as long as this notice is preserved.
 
-# serial 4 lt~obsolete.m4
+# serial 5 lt~obsolete.m4
 
 # These exist entirely to fool aclocal when bootstrapping libtool.
 #
@@ -7970,7 +8588,6 @@
 m4_ifndef([_LT_AC_LANG_CXX],		[AC_DEFUN([_LT_AC_LANG_CXX])])
 m4_ifndef([_LT_AC_LANG_F77],		[AC_DEFUN([_LT_AC_LANG_F77])])
 m4_ifndef([_LT_AC_LANG_GCJ],		[AC_DEFUN([_LT_AC_LANG_GCJ])])
-m4_ifndef([AC_LIBTOOL_RC],		[AC_DEFUN([AC_LIBTOOL_RC])])
 m4_ifndef([AC_LIBTOOL_LANG_C_CONFIG],	[AC_DEFUN([AC_LIBTOOL_LANG_C_CONFIG])])
 m4_ifndef([_LT_AC_LANG_C_CONFIG],	[AC_DEFUN([_LT_AC_LANG_C_CONFIG])])
 m4_ifndef([AC_LIBTOOL_LANG_CXX_CONFIG],	[AC_DEFUN([AC_LIBTOOL_LANG_CXX_CONFIG])])
@@ -7983,13 +8600,23 @@
 m4_ifndef([_LT_AC_LANG_RC_CONFIG],	[AC_DEFUN([_LT_AC_LANG_RC_CONFIG])])
 m4_ifndef([AC_LIBTOOL_CONFIG],		[AC_DEFUN([AC_LIBTOOL_CONFIG])])
 m4_ifndef([_LT_AC_FILE_LTDLL_C],	[AC_DEFUN([_LT_AC_FILE_LTDLL_C])])
+m4_ifndef([_LT_REQUIRED_DARWIN_CHECKS],	[AC_DEFUN([_LT_REQUIRED_DARWIN_CHECKS])])
+m4_ifndef([_LT_AC_PROG_CXXCPP],		[AC_DEFUN([_LT_AC_PROG_CXXCPP])])
+m4_ifndef([_LT_PREPARE_SED_QUOTE_VARS],	[AC_DEFUN([_LT_PREPARE_SED_QUOTE_VARS])])
+m4_ifndef([_LT_PROG_ECHO_BACKSLASH],	[AC_DEFUN([_LT_PROG_ECHO_BACKSLASH])])
+m4_ifndef([_LT_PROG_F77],		[AC_DEFUN([_LT_PROG_F77])])
+m4_ifndef([_LT_PROG_FC],		[AC_DEFUN([_LT_PROG_FC])])
+m4_ifndef([_LT_PROG_CXX],		[AC_DEFUN([_LT_PROG_CXX])])
 
-# Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2002, 2003, 2005, 2006, 2007, 2008, 2011 Free Software
+# Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_AUTOMAKE_VERSION(VERSION)
 # ----------------------------
 # Automake X.Y traces this macro to ensure aclocal.m4 has been
@@ -7999,7 +8626,7 @@
 [am__api_version='1.11'
 dnl Some users find AM_AUTOMAKE_VERSION and mistake it for a way to
 dnl require some minimum version.  Point them to the right macro.
-m4_if([$1], [1.11], [],
+m4_if([$1], [1.11.6], [],
       [AC_FATAL([Do not call $0, use AM_INIT_AUTOMAKE([$1]).])])dnl
 ])
 
@@ -8015,19 +8642,21 @@
 # Call AM_AUTOMAKE_VERSION and AM_AUTOMAKE_VERSION so they can be traced.
 # This function is AC_REQUIREd by AM_INIT_AUTOMAKE.
 AC_DEFUN([AM_SET_CURRENT_AUTOMAKE_VERSION],
-[AM_AUTOMAKE_VERSION([1.11])dnl
+[AM_AUTOMAKE_VERSION([1.11.6])dnl
 m4_ifndef([AC_AUTOCONF_VERSION],
   [m4_copy([m4_PACKAGE_VERSION], [AC_AUTOCONF_VERSION])])dnl
 _AM_AUTOCONF_VERSION(m4_defn([AC_AUTOCONF_VERSION]))])
 
 # AM_AUX_DIR_EXPAND                                         -*- Autoconf -*-
 
-# Copyright (C) 2001, 2003, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # For projects using AC_CONFIG_AUX_DIR([foo]), Autoconf sets
 # $ac_aux_dir to `$srcdir/foo'.  In other projects, it is set to
 # `$srcdir', `$srcdir/..', or `$srcdir/../..'.
@@ -8109,14 +8738,14 @@
 Usually this means the macro was only invoked conditionally.]])
 fi])])
 
-# Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2009
-# Free Software Foundation, Inc.
+# Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2009,
+# 2010, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 10
+# serial 12
 
 # There are a few dirty hacks below to avoid letting `AC_PROG_CC' be
 # written in clear, in which case automake, when reading aclocal.m4,
@@ -8156,6 +8785,7 @@
   # instance it was reported that on HP-UX the gcc test will end up
   # making a dummy file named `D' -- because `-MD' means `put the output
   # in D'.
+  rm -rf conftest.dir
   mkdir conftest.dir
   # Copy depcomp to subdir because otherwise we won't find it if we're
   # using a relative directory.
@@ -8220,7 +8850,7 @@
 	break
       fi
       ;;
-    msvisualcpp | msvcmsys)
+    msvc7 | msvc7msys | msvisualcpp | msvcmsys)
       # This compiler won't grok `-c -o', but also, the minuso test has
       # not run yet.  These depmodes are late enough in the game, and
       # so weak that their functioning should not be impacted.
@@ -8285,10 +8915,13 @@
 if test "x$enable_dependency_tracking" != xno; then
   am_depcomp="$ac_aux_dir/depcomp"
   AMDEPBACKSLASH='\'
+  am__nodep='_no'
 fi
 AM_CONDITIONAL([AMDEP], [test "x$enable_dependency_tracking" != xno])
 AC_SUBST([AMDEPBACKSLASH])dnl
 _AM_SUBST_NOTMAKE([AMDEPBACKSLASH])dnl
+AC_SUBST([am__nodep])dnl
+_AM_SUBST_NOTMAKE([am__nodep])dnl
 ])
 
 # Generate code to set up dependency tracking.              -*- Autoconf -*-
@@ -8522,12 +9155,15 @@
 done
 echo "timestamp for $_am_arg" >`AS_DIRNAME(["$_am_arg"])`/stamp-h[]$_am_stamp_count])
 
-# Copyright (C) 2001, 2003, 2005, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2008, 2011 Free Software Foundation,
+# Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_INSTALL_SH
 # ------------------
 # Define $install_sh.
@@ -8659,12 +9295,15 @@
 fi
 ])
 
-# Copyright (C) 2003, 2004, 2005, 2006  Free Software Foundation, Inc.
+# Copyright (C) 2003, 2004, 2005, 2006, 2011 Free Software Foundation,
+# Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_MKDIR_P
 # ---------------
 # Check for `mkdir -p'.
@@ -8687,13 +9326,14 @@
 
 # Helper functions for option handling.                     -*- Autoconf -*-
 
-# Copyright (C) 2001, 2002, 2003, 2005, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2002, 2003, 2005, 2008, 2010 Free Software
+# Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 4
+# serial 5
 
 # _AM_MANGLE_OPTION(NAME)
 # -----------------------
@@ -8701,13 +9341,13 @@
 [[_AM_OPTION_]m4_bpatsubst($1, [[^a-zA-Z0-9_]], [_])])
 
 # _AM_SET_OPTION(NAME)
-# ------------------------------
+# --------------------
 # Set option NAME.  Presently that only means defining a flag for this option.
 AC_DEFUN([_AM_SET_OPTION],
 [m4_define(_AM_MANGLE_OPTION([$1]), 1)])
 
 # _AM_SET_OPTIONS(OPTIONS)
-# ----------------------------------
+# ------------------------
 # OPTIONS is a space-separated list of Automake options.
 AC_DEFUN([_AM_SET_OPTIONS],
 [m4_foreach_w([_AM_Option], [$1], [_AM_SET_OPTION(_AM_Option)])])
@@ -8783,12 +9423,14 @@
 fi
 AC_MSG_RESULT(yes)])
 
-# Copyright (C) 2001, 2003, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2001, 2003, 2005, 2011 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
+# serial 1
+
 # AM_PROG_INSTALL_STRIP
 # ---------------------
 # One issue with vendor `install' (even GNU) is that you can't
@@ -8811,13 +9453,13 @@
 INSTALL_STRIP_PROGRAM="\$(install_sh) -c -s"
 AC_SUBST([INSTALL_STRIP_PROGRAM])])
 
-# Copyright (C) 2006, 2008  Free Software Foundation, Inc.
+# Copyright (C) 2006, 2008, 2010 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
 
-# serial 2
+# serial 3
 
 # _AM_SUBST_NOTMAKE(VARIABLE)
 # ---------------------------
@@ -8826,13 +9468,13 @@
 AC_DEFUN([_AM_SUBST_NOTMAKE])
 
 # AM_SUBST_NOTMAKE(VARIABLE)
-# ---------------------------
+# --------------------------
 # Public sister of _AM_SUBST_NOTMAKE.
 AC_DEFUN([AM_SUBST_NOTMAKE], [_AM_SUBST_NOTMAKE($@)])
 
 # Check how to create a tarball.                            -*- Autoconf -*-
 
-# Copyright (C) 2004, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2004, 2005, 2012 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -8854,10 +9496,11 @@
 # a tarball read from stdin.
 #     $(am__untar) < result.tar
 AC_DEFUN([_AM_PROG_TAR],
-[# Always define AMTAR for backward compatibility.
-AM_MISSING_PROG([AMTAR], [tar])
+[# Always define AMTAR for backward compatibility.  Yes, it's still used
+# in the wild :-(  We should find a proper way to deprecate it ...
+AC_SUBST([AMTAR], ['$${TAR-tar}'])
 m4_if([$1], [v7],
-     [am__tar='${AMTAR} chof - "$$tardir"'; am__untar='${AMTAR} xf -'],
+     [am__tar='$${TAR-tar} chof - "$$tardir"' am__untar='$${TAR-tar} xf -'],
      [m4_case([$1], [ustar],, [pax],,
               [m4_fatal([Unknown tar format])])
 AC_MSG_CHECKING([how to create a $1 tar archive])

=== modified file 'bld.inf'
--- bld.inf	2010-01-17 13:05:04 +0000
+++ bld.inf	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'config.guess'
--- config.guess	2010-01-17 13:05:04 +0000
+++ config.guess	2014-01-16 10:42:06 +0000
@@ -1,10 +1,10 @@
 #! /bin/sh
 # Attempt to guess a canonical system name.
 #   Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
-#   2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
-#   Free Software Foundation, Inc.
+#   2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010,
+#   2011, 2012 Free Software Foundation, Inc.
 
-timestamp='2009-04-27'
+timestamp='2012-02-10'
 
 # This file is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -17,9 +17,7 @@
 # General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 # As a special exception to the GNU General Public License, if you
 # distribute this file as part of a program that contains a
@@ -27,16 +25,16 @@
 # the same distribution terms that you use for the rest of that program.
 
 
-# Originally written by Per Bothner <per@bothner.com>.
-# Please send patches to <config-patches@gnu.org>.  Submit a context
-# diff and a properly formatted ChangeLog entry.
+# Originally written by Per Bothner.  Please send patches (context
+# diff format) to <config-patches@gnu.org> and include a ChangeLog
+# entry.
 #
 # This script attempts to guess a canonical system name similar to
 # config.sub.  If it succeeds, it prints the system name on stdout, and
 # exits with 0.  Otherwise, it exits with 1.
 #
-# The plan is that this can be called by configure scripts if you
-# don't specify an explicit build system type.
+# You can get the latest version of this script from:
+# http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.guess;hb=HEAD
 
 me=`echo "$0" | sed -e 's,.*/,,'`
 
@@ -56,8 +54,9 @@
 GNU config.guess ($timestamp)
 
 Originally written by Per Bothner.
-Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
+2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+Free Software Foundation, Inc.
 
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
@@ -144,7 +143,7 @@
 case "${UNAME_MACHINE}:${UNAME_SYSTEM}:${UNAME_RELEASE}:${UNAME_VERSION}" in
     *:NetBSD:*:*)
 	# NetBSD (nbsd) targets should (where applicable) match one or
-	# more of the tupples: *-*-netbsdelf*, *-*-netbsdaout*,
+	# more of the tuples: *-*-netbsdelf*, *-*-netbsdaout*,
 	# *-*-netbsdecoff* and *-*-netbsd*.  For targets that recently
 	# switched to ELF, *-*-netbsd* would select the old
 	# object file format.  This provides both forward
@@ -170,7 +169,7 @@
 	    arm*|i386|m68k|ns32k|sh3*|sparc|vax)
 		eval $set_cc_for_build
 		if echo __ELF__ | $CC_FOR_BUILD -E - 2>/dev/null \
-			| grep __ELF__ >/dev/null
+			| grep -q __ELF__
 		then
 		    # Once all utilities can be ECOFF (netbsdecoff) or a.out (netbsdaout).
 		    # Return netbsd for either.  FIX?
@@ -180,7 +179,7 @@
 		fi
 		;;
 	    *)
-	        os=netbsd
+		os=netbsd
 		;;
 	esac
 	# The OS release
@@ -223,7 +222,7 @@
 		UNAME_RELEASE=`/usr/sbin/sizer -v | awk '{print $3}'`
 		;;
 	*5.*)
-	        UNAME_RELEASE=`/usr/sbin/sizer -v | awk '{print $4}'`
+		UNAME_RELEASE=`/usr/sbin/sizer -v | awk '{print $4}'`
 		;;
 	esac
 	# According to Compaq, /usr/sbin/psrinfo has been available on
@@ -269,7 +268,10 @@
 	# A Xn.n version is an unreleased experimental baselevel.
 	# 1.2 uses "1.2" for uname -r.
 	echo ${UNAME_MACHINE}-dec-osf`echo ${UNAME_RELEASE} | sed -e 's/^[PVTX]//' | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz'`
-	exit ;;
+	# Reset EXIT trap before exiting to avoid spurious non-zero exit code.
+	exitcode=$?
+	trap '' 0
+	exit $exitcode ;;
     Alpha\ *:Windows_NT*:*)
 	# How do we know it's Interix rather than the generic POSIX subsystem?
 	# Should we change UNAME_MACHINE based on the output of uname instead
@@ -295,7 +297,7 @@
 	echo s390-ibm-zvmoe
 	exit ;;
     *:OS400:*:*)
-        echo powerpc-ibm-os400
+	echo powerpc-ibm-os400
 	exit ;;
     arm:RISC*:1.[012]*:*|arm:riscix:1.[012]*:*)
 	echo arm-acorn-riscix${UNAME_RELEASE}
@@ -333,6 +335,9 @@
     sun4*:SunOS:5.*:* | tadpole*:SunOS:5.*:*)
 	echo sparc-sun-solaris2`echo ${UNAME_RELEASE}|sed -e 's/[^.]*//'`
 	exit ;;
+    i86pc:AuroraUX:5.*:* | i86xen:AuroraUX:5.*:*)
+	echo i386-pc-auroraux${UNAME_RELEASE}
+	exit ;;
     i86pc:SunOS:5.*:* | i86xen:SunOS:5.*:*)
 	eval $set_cc_for_build
 	SUN_ARCH="i386"
@@ -391,23 +396,23 @@
     # MiNT.  But MiNT is downward compatible to TOS, so this should
     # be no problem.
     atarist[e]:*MiNT:*:* | atarist[e]:*mint:*:* | atarist[e]:*TOS:*:*)
-        echo m68k-atari-mint${UNAME_RELEASE}
+	echo m68k-atari-mint${UNAME_RELEASE}
 	exit ;;
     atari*:*MiNT:*:* | atari*:*mint:*:* | atarist[e]:*TOS:*:*)
 	echo m68k-atari-mint${UNAME_RELEASE}
-        exit ;;
+	exit ;;
     *falcon*:*MiNT:*:* | *falcon*:*mint:*:* | *falcon*:*TOS:*:*)
-        echo m68k-atari-mint${UNAME_RELEASE}
+	echo m68k-atari-mint${UNAME_RELEASE}
 	exit ;;
     milan*:*MiNT:*:* | milan*:*mint:*:* | *milan*:*TOS:*:*)
-        echo m68k-milan-mint${UNAME_RELEASE}
-        exit ;;
+	echo m68k-milan-mint${UNAME_RELEASE}
+	exit ;;
     hades*:*MiNT:*:* | hades*:*mint:*:* | *hades*:*TOS:*:*)
-        echo m68k-hades-mint${UNAME_RELEASE}
-        exit ;;
+	echo m68k-hades-mint${UNAME_RELEASE}
+	exit ;;
     *:*MiNT:*:* | *:*mint:*:* | *:*TOS:*:*)
-        echo m68k-unknown-mint${UNAME_RELEASE}
-        exit ;;
+	echo m68k-unknown-mint${UNAME_RELEASE}
+	exit ;;
     m68k:machten:*:*)
 	echo m68k-apple-machten${UNAME_RELEASE}
 	exit ;;
@@ -477,8 +482,8 @@
 	echo m88k-motorola-sysv3
 	exit ;;
     AViiON:dgux:*:*)
-        # DG/UX returns AViiON for all architectures
-        UNAME_PROCESSOR=`/usr/bin/uname -p`
+	# DG/UX returns AViiON for all architectures
+	UNAME_PROCESSOR=`/usr/bin/uname -p`
 	if [ $UNAME_PROCESSOR = mc88100 ] || [ $UNAME_PROCESSOR = mc88110 ]
 	then
 	    if [ ${TARGET_BINARY_INTERFACE}x = m88kdguxelfx ] || \
@@ -491,7 +496,7 @@
 	else
 	    echo i586-dg-dgux${UNAME_RELEASE}
 	fi
- 	exit ;;
+	exit ;;
     M88*:DolphinOS:*:*)	# DolphinOS (SVR3)
 	echo m88k-dolphin-sysv3
 	exit ;;
@@ -548,7 +553,7 @@
 		echo rs6000-ibm-aix3.2
 	fi
 	exit ;;
-    *:AIX:*:[456])
+    *:AIX:*:[4567])
 	IBM_CPU_ID=`/usr/sbin/lsdev -C -c processor -S available | sed 1q | awk '{ print $1 }'`
 	if /usr/sbin/lsattr -El ${IBM_CPU_ID} | grep ' POWER' >/dev/null 2>&1; then
 		IBM_ARCH=rs6000
@@ -591,52 +596,52 @@
 	    9000/[678][0-9][0-9])
 		if [ -x /usr/bin/getconf ]; then
 		    sc_cpu_version=`/usr/bin/getconf SC_CPU_VERSION 2>/dev/null`
-                    sc_kernel_bits=`/usr/bin/getconf SC_KERNEL_BITS 2>/dev/null`
-                    case "${sc_cpu_version}" in
-                      523) HP_ARCH="hppa1.0" ;; # CPU_PA_RISC1_0
-                      528) HP_ARCH="hppa1.1" ;; # CPU_PA_RISC1_1
-                      532)                      # CPU_PA_RISC2_0
-                        case "${sc_kernel_bits}" in
-                          32) HP_ARCH="hppa2.0n" ;;
-                          64) HP_ARCH="hppa2.0w" ;;
+		    sc_kernel_bits=`/usr/bin/getconf SC_KERNEL_BITS 2>/dev/null`
+		    case "${sc_cpu_version}" in
+		      523) HP_ARCH="hppa1.0" ;; # CPU_PA_RISC1_0
+		      528) HP_ARCH="hppa1.1" ;; # CPU_PA_RISC1_1
+		      532)                      # CPU_PA_RISC2_0
+			case "${sc_kernel_bits}" in
+			  32) HP_ARCH="hppa2.0n" ;;
+			  64) HP_ARCH="hppa2.0w" ;;
 			  '') HP_ARCH="hppa2.0" ;;   # HP-UX 10.20
-                        esac ;;
-                    esac
+			esac ;;
+		    esac
 		fi
 		if [ "${HP_ARCH}" = "" ]; then
 		    eval $set_cc_for_build
-		    sed 's/^              //' << EOF >$dummy.c
-
-              #define _HPUX_SOURCE
-              #include <stdlib.h>
-              #include <unistd.h>
-
-              int main ()
-              {
-              #if defined(_SC_KERNEL_BITS)
-                  long bits = sysconf(_SC_KERNEL_BITS);
-              #endif
-                  long cpu  = sysconf (_SC_CPU_VERSION);
-
-                  switch (cpu)
-              	{
-              	case CPU_PA_RISC1_0: puts ("hppa1.0"); break;
-              	case CPU_PA_RISC1_1: puts ("hppa1.1"); break;
-              	case CPU_PA_RISC2_0:
-              #if defined(_SC_KERNEL_BITS)
-              	    switch (bits)
-              		{
-              		case 64: puts ("hppa2.0w"); break;
-              		case 32: puts ("hppa2.0n"); break;
-              		default: puts ("hppa2.0"); break;
-              		} break;
-              #else  /* !defined(_SC_KERNEL_BITS) */
-              	    puts ("hppa2.0"); break;
-              #endif
-              	default: puts ("hppa1.0"); break;
-              	}
-                  exit (0);
-              }
+		    sed 's/^		//' << EOF >$dummy.c
+
+		#define _HPUX_SOURCE
+		#include <stdlib.h>
+		#include <unistd.h>
+
+		int main ()
+		{
+		#if defined(_SC_KERNEL_BITS)
+		    long bits = sysconf(_SC_KERNEL_BITS);
+		#endif
+		    long cpu  = sysconf (_SC_CPU_VERSION);
+
+		    switch (cpu)
+			{
+			case CPU_PA_RISC1_0: puts ("hppa1.0"); break;
+			case CPU_PA_RISC1_1: puts ("hppa1.1"); break;
+			case CPU_PA_RISC2_0:
+		#if defined(_SC_KERNEL_BITS)
+			    switch (bits)
+				{
+				case 64: puts ("hppa2.0w"); break;
+				case 32: puts ("hppa2.0n"); break;
+				default: puts ("hppa2.0"); break;
+				} break;
+		#else  /* !defined(_SC_KERNEL_BITS) */
+			    puts ("hppa2.0"); break;
+		#endif
+			default: puts ("hppa1.0"); break;
+			}
+		    exit (0);
+		}
 EOF
 		    (CCOPTS= $CC_FOR_BUILD -o $dummy $dummy.c 2>/dev/null) && HP_ARCH=`$dummy`
 		    test -z "$HP_ARCH" && HP_ARCH=hppa
@@ -656,7 +661,7 @@
 	    # => hppa64-hp-hpux11.23
 
 	    if echo __LP64__ | (CCOPTS= $CC_FOR_BUILD -E - 2>/dev/null) |
-		grep __LP64__ >/dev/null
+		grep -q __LP64__
 	    then
 		HP_ARCH="hppa2.0w"
 	    else
@@ -727,22 +732,22 @@
 	exit ;;
     C1*:ConvexOS:*:* | convex:ConvexOS:C1*:*)
 	echo c1-convex-bsd
-        exit ;;
+	exit ;;
     C2*:ConvexOS:*:* | convex:ConvexOS:C2*:*)
 	if getsysinfo -f scalar_acc
 	then echo c32-convex-bsd
 	else echo c2-convex-bsd
 	fi
-        exit ;;
+	exit ;;
     C34*:ConvexOS:*:* | convex:ConvexOS:C34*:*)
 	echo c34-convex-bsd
-        exit ;;
+	exit ;;
     C38*:ConvexOS:*:* | convex:ConvexOS:C38*:*)
 	echo c38-convex-bsd
-        exit ;;
+	exit ;;
     C4*:ConvexOS:*:* | convex:ConvexOS:C4*:*)
 	echo c4-convex-bsd
-        exit ;;
+	exit ;;
     CRAY*Y-MP:*:*:*)
 	echo ymp-cray-unicos${UNAME_RELEASE} | sed -e 's/\.[^.]*$/.X/'
 	exit ;;
@@ -766,14 +771,14 @@
 	exit ;;
     F30[01]:UNIX_System_V:*:* | F700:UNIX_System_V:*:*)
 	FUJITSU_PROC=`uname -m | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz'`
-        FUJITSU_SYS=`uname -p | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' | sed -e 's/\///'`
-        FUJITSU_REL=`echo ${UNAME_RELEASE} | sed -e 's/ /_/'`
-        echo "${FUJITSU_PROC}-fujitsu-${FUJITSU_SYS}${FUJITSU_REL}"
-        exit ;;
+	FUJITSU_SYS=`uname -p | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' | sed -e 's/\///'`
+	FUJITSU_REL=`echo ${UNAME_RELEASE} | sed -e 's/ /_/'`
+	echo "${FUJITSU_PROC}-fujitsu-${FUJITSU_SYS}${FUJITSU_REL}"
+	exit ;;
     5000:UNIX_System_V:4.*:*)
-        FUJITSU_SYS=`uname -p | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' | sed -e 's/\///'`
-        FUJITSU_REL=`echo ${UNAME_RELEASE} | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' | sed -e 's/ /_/'`
-        echo "sparc-fujitsu-${FUJITSU_SYS}${FUJITSU_REL}"
+	FUJITSU_SYS=`uname -p | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' | sed -e 's/\///'`
+	FUJITSU_REL=`echo ${UNAME_RELEASE} | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' | sed -e 's/ /_/'`
+	echo "sparc-fujitsu-${FUJITSU_SYS}${FUJITSU_REL}"
 	exit ;;
     i*86:BSD/386:*:* | i*86:BSD/OS:*:* | *:Ascend\ Embedded/OS:*:*)
 	echo ${UNAME_MACHINE}-pc-bsdi${UNAME_RELEASE}
@@ -785,13 +790,12 @@
 	echo ${UNAME_MACHINE}-unknown-bsdi${UNAME_RELEASE}
 	exit ;;
     *:FreeBSD:*:*)
-	case ${UNAME_MACHINE} in
-	    pc98)
-		echo i386-unknown-freebsd`echo ${UNAME_RELEASE}|sed -e 's/[-(].*//'` ;;
+	UNAME_PROCESSOR=`/usr/bin/uname -p`
+	case ${UNAME_PROCESSOR} in
 	    amd64)
 		echo x86_64-unknown-freebsd`echo ${UNAME_RELEASE}|sed -e 's/[-(].*//'` ;;
 	    *)
-		echo ${UNAME_MACHINE}-unknown-freebsd`echo ${UNAME_RELEASE}|sed -e 's/[-(].*//'` ;;
+		echo ${UNAME_PROCESSOR}-unknown-freebsd`echo ${UNAME_RELEASE}|sed -e 's/[-(].*//'` ;;
 	esac
 	exit ;;
     i*:CYGWIN*:*)
@@ -800,19 +804,22 @@
     *:MINGW*:*)
 	echo ${UNAME_MACHINE}-pc-mingw32
 	exit ;;
+    i*:MSYS*:*)
+	echo ${UNAME_MACHINE}-pc-msys
+	exit ;;
     i*:windows32*:*)
-    	# uname -m includes "-pc" on this system.
-    	echo ${UNAME_MACHINE}-mingw32
+	# uname -m includes "-pc" on this system.
+	echo ${UNAME_MACHINE}-mingw32
 	exit ;;
     i*:PW*:*)
 	echo ${UNAME_MACHINE}-pc-pw32
 	exit ;;
-    *:Interix*:[3456]*)
-    	case ${UNAME_MACHINE} in
+    *:Interix*:*)
+	case ${UNAME_MACHINE} in
 	    x86)
 		echo i586-pc-interix${UNAME_RELEASE}
 		exit ;;
-	    EM64T | authenticamd | genuineintel)
+	    authenticamd | genuineintel | EM64T)
 		echo x86_64-unknown-interix${UNAME_RELEASE}
 		exit ;;
 	    IA64)
@@ -822,6 +829,9 @@
     [345]86:Windows_95:* | [345]86:Windows_98:* | [345]86:Windows_NT:*)
 	echo i${UNAME_MACHINE}-pc-mks
 	exit ;;
+    8664:Windows_NT:*)
+	echo x86_64-pc-mks
+	exit ;;
     i*:Windows_NT*:* | Pentium*:Windows_NT*:*)
 	# How do we know it's Interix rather than the generic POSIX subsystem?
 	# It also conflicts with pre-2.0 versions of AT&T UWIN. Should we
@@ -851,6 +861,27 @@
     i*86:Minix:*:*)
 	echo ${UNAME_MACHINE}-pc-minix
 	exit ;;
+    aarch64:Linux:*:*)
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
+	exit ;;
+    aarch64_be:Linux:*:*)
+	UNAME_MACHINE=aarch64_be
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
+	exit ;;
+    alpha:Linux:*:*)
+	case `sed -n '/^cpu model/s/^.*: \(.*\)/\1/p' < /proc/cpuinfo` in
+	  EV5)   UNAME_MACHINE=alphaev5 ;;
+	  EV56)  UNAME_MACHINE=alphaev56 ;;
+	  PCA56) UNAME_MACHINE=alphapca56 ;;
+	  PCA57) UNAME_MACHINE=alphapca56 ;;
+	  EV6)   UNAME_MACHINE=alphaev6 ;;
+	  EV67)  UNAME_MACHINE=alphaev67 ;;
+	  EV68*) UNAME_MACHINE=alphaev68 ;;
+	esac
+	objdump --private-headers /bin/sh | grep -q ld.so.1
+	if test "$?" = 0 ; then LIBC="libc1" ; else LIBC="" ; fi
+	echo ${UNAME_MACHINE}-unknown-linux-gnu${LIBC}
+	exit ;;
     arm*:Linux:*:*)
 	eval $set_cc_for_build
 	if echo __ARM_EABI__ | $CC_FOR_BUILD -E - 2>/dev/null \
@@ -858,20 +889,40 @@
 	then
 	    echo ${UNAME_MACHINE}-unknown-linux-gnu
 	else
-	    echo ${UNAME_MACHINE}-unknown-linux-gnueabi
+	    if echo __ARM_PCS_VFP | $CC_FOR_BUILD -E - 2>/dev/null \
+		| grep -q __ARM_PCS_VFP
+	    then
+		echo ${UNAME_MACHINE}-unknown-linux-gnueabi
+	    else
+		echo ${UNAME_MACHINE}-unknown-linux-gnueabihf
+	    fi
 	fi
 	exit ;;
     avr32*:Linux:*:*)
 	echo ${UNAME_MACHINE}-unknown-linux-gnu
 	exit ;;
     cris:Linux:*:*)
-	echo cris-axis-linux-gnu
+	echo ${UNAME_MACHINE}-axis-linux-gnu
 	exit ;;
     crisv32:Linux:*:*)
-	echo crisv32-axis-linux-gnu
+	echo ${UNAME_MACHINE}-axis-linux-gnu
 	exit ;;
     frv:Linux:*:*)
-    	echo frv-unknown-linux-gnu
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
+	exit ;;
+    hexagon:Linux:*:*)
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
+	exit ;;
+    i*86:Linux:*:*)
+	LIBC=gnu
+	eval $set_cc_for_build
+	sed 's/^	//' << EOF >$dummy.c
+	#ifdef __dietlibc__
+	LIBC=dietlibc
+	#endif
+EOF
+	eval `$CC_FOR_BUILD -E $dummy.c 2>/dev/null | grep '^LIBC'`
+	echo "${UNAME_MACHINE}-pc-linux-${LIBC}"
 	exit ;;
     ia64:Linux:*:*)
 	echo ${UNAME_MACHINE}-unknown-linux-gnu
@@ -882,78 +933,34 @@
     m68*:Linux:*:*)
 	echo ${UNAME_MACHINE}-unknown-linux-gnu
 	exit ;;
-    mips:Linux:*:*)
-	eval $set_cc_for_build
-	sed 's/^	//' << EOF >$dummy.c
-	#undef CPU
-	#undef mips
-	#undef mipsel
-	#if defined(__MIPSEL__) || defined(__MIPSEL) || defined(_MIPSEL) || defined(MIPSEL)
-	CPU=mipsel
-	#else
-	#if defined(__MIPSEB__) || defined(__MIPSEB) || defined(_MIPSEB) || defined(MIPSEB)
-	CPU=mips
-	#else
-	CPU=
-	#endif
-	#endif
-EOF
-	eval "`$CC_FOR_BUILD -E $dummy.c 2>/dev/null | sed -n '
-	    /^CPU/{
-		s: ::g
-		p
-	    }'`"
-	test x"${CPU}" != x && { echo "${CPU}-unknown-linux-gnu"; exit; }
-	;;
-    mips64:Linux:*:*)
-	eval $set_cc_for_build
-	sed 's/^	//' << EOF >$dummy.c
-	#undef CPU
-	#undef mips64
-	#undef mips64el
-	#if defined(__MIPSEL__) || defined(__MIPSEL) || defined(_MIPSEL) || defined(MIPSEL)
-	CPU=mips64el
-	#else
-	#if defined(__MIPSEB__) || defined(__MIPSEB) || defined(_MIPSEB) || defined(MIPSEB)
-	CPU=mips64
-	#else
-	CPU=
-	#endif
-	#endif
-EOF
-	eval "`$CC_FOR_BUILD -E $dummy.c 2>/dev/null | sed -n '
-	    /^CPU/{
-		s: ::g
-		p
-	    }'`"
+    mips:Linux:*:* | mips64:Linux:*:*)
+	eval $set_cc_for_build
+	sed 's/^	//' << EOF >$dummy.c
+	#undef CPU
+	#undef ${UNAME_MACHINE}
+	#undef ${UNAME_MACHINE}el
+	#if defined(__MIPSEL__) || defined(__MIPSEL) || defined(_MIPSEL) || defined(MIPSEL)
+	CPU=${UNAME_MACHINE}el
+	#else
+	#if defined(__MIPSEB__) || defined(__MIPSEB) || defined(_MIPSEB) || defined(MIPSEB)
+	CPU=${UNAME_MACHINE}
+	#else
+	CPU=
+	#endif
+	#endif
+EOF
+	eval `$CC_FOR_BUILD -E $dummy.c 2>/dev/null | grep '^CPU'`
 	test x"${CPU}" != x && { echo "${CPU}-unknown-linux-gnu"; exit; }
 	;;
     or32:Linux:*:*)
-	echo or32-unknown-linux-gnu
-	exit ;;
-    ppc:Linux:*:*)
-	echo powerpc-unknown-linux-gnu
-	exit ;;
-    ppc64:Linux:*:*)
-	echo powerpc64-unknown-linux-gnu
-	exit ;;
-    alpha:Linux:*:*)
-	case `sed -n '/^cpu model/s/^.*: \(.*\)/\1/p' < /proc/cpuinfo` in
-	  EV5)   UNAME_MACHINE=alphaev5 ;;
-	  EV56)  UNAME_MACHINE=alphaev56 ;;
-	  PCA56) UNAME_MACHINE=alphapca56 ;;
-	  PCA57) UNAME_MACHINE=alphapca56 ;;
-	  EV6)   UNAME_MACHINE=alphaev6 ;;
-	  EV67)  UNAME_MACHINE=alphaev67 ;;
-	  EV68*) UNAME_MACHINE=alphaev68 ;;
-        esac
-	objdump --private-headers /bin/sh | grep ld.so.1 >/dev/null
-	if test "$?" = 0 ; then LIBC="libc1" ; else LIBC="" ; fi
-	echo ${UNAME_MACHINE}-unknown-linux-gnu${LIBC}
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
 	exit ;;
     padre:Linux:*:*)
 	echo sparc-unknown-linux-gnu
 	exit ;;
+    parisc64:Linux:*:* | hppa64:Linux:*:*)
+	echo hppa64-unknown-linux-gnu
+	exit ;;
     parisc:Linux:*:* | hppa:Linux:*:*)
 	# Look for CPU level
 	case `grep '^cpu[^a-z]*:' /proc/cpuinfo 2>/dev/null | cut -d' ' -f2` in
@@ -962,14 +969,17 @@
 	  *)    echo hppa-unknown-linux-gnu ;;
 	esac
 	exit ;;
-    parisc64:Linux:*:* | hppa64:Linux:*:*)
-	echo hppa64-unknown-linux-gnu
+    ppc64:Linux:*:*)
+	echo powerpc64-unknown-linux-gnu
+	exit ;;
+    ppc:Linux:*:*)
+	echo powerpc-unknown-linux-gnu
 	exit ;;
     s390:Linux:*:* | s390x:Linux:*:*)
 	echo ${UNAME_MACHINE}-ibm-linux
 	exit ;;
     sh64*:Linux:*:*)
-    	echo ${UNAME_MACHINE}-unknown-linux-gnu
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
 	exit ;;
     sh*:Linux:*:*)
 	echo ${UNAME_MACHINE}-unknown-linux-gnu
@@ -977,75 +987,18 @@
     sparc:Linux:*:* | sparc64:Linux:*:*)
 	echo ${UNAME_MACHINE}-unknown-linux-gnu
 	exit ;;
+    tile*:Linux:*:*)
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
+	exit ;;
     vax:Linux:*:*)
 	echo ${UNAME_MACHINE}-dec-linux-gnu
 	exit ;;
     x86_64:Linux:*:*)
-	echo x86_64-unknown-linux-gnu
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
 	exit ;;
     xtensa*:Linux:*:*)
-    	echo ${UNAME_MACHINE}-unknown-linux-gnu
+	echo ${UNAME_MACHINE}-unknown-linux-gnu
 	exit ;;
-    i*86:Linux:*:*)
-	# The BFD linker knows what the default object file format is, so
-	# first see if it will tell us. cd to the root directory to prevent
-	# problems with other programs or directories called `ld' in the path.
-	# Set LC_ALL=C to ensure ld outputs messages in English.
-	ld_supported_targets=`cd /; LC_ALL=C ld --help 2>&1 \
-			 | sed -ne '/supported targets:/!d
-				    s/[ 	][ 	]*/ /g
-				    s/.*supported targets: *//
-				    s/ .*//
-				    p'`
-        case "$ld_supported_targets" in
-	  elf32-i386)
-		TENTATIVE="${UNAME_MACHINE}-pc-linux-gnu"
-		;;
-	  a.out-i386-linux)
-		echo "${UNAME_MACHINE}-pc-linux-gnuaout"
-		exit ;;
-	  "")
-		# Either a pre-BFD a.out linker (linux-gnuoldld) or
-		# one that does not give us useful --help.
-		echo "${UNAME_MACHINE}-pc-linux-gnuoldld"
-		exit ;;
-	esac
-	# Determine whether the default compiler is a.out or elf
-	eval $set_cc_for_build
-	sed 's/^	//' << EOF >$dummy.c
-	#include <features.h>
-	#ifdef __ELF__
-	# ifdef __GLIBC__
-	#  if __GLIBC__ >= 2
-	LIBC=gnu
-	#  else
-	LIBC=gnulibc1
-	#  endif
-	# else
-	LIBC=gnulibc1
-	# endif
-	#else
-	#if defined(__INTEL_COMPILER) || defined(__PGI) || defined(__SUNPRO_C) || defined(__SUNPRO_CC)
-	LIBC=gnu
-	#else
-	LIBC=gnuaout
-	#endif
-	#endif
-	#ifdef __dietlibc__
-	LIBC=dietlibc
-	#endif
-EOF
-	eval "`$CC_FOR_BUILD -E $dummy.c 2>/dev/null | sed -n '
-	    /^LIBC/{
-		s: ::g
-		p
-	    }'`"
-	test x"${LIBC}" != x && {
-		echo "${UNAME_MACHINE}-pc-linux-${LIBC}"
-		exit
-	}
-	test x"${TENTATIVE}" != x && { echo "${TENTATIVE}"; exit; }
-	;;
     i*86:DYNIX/ptx:4*:*)
 	# ptx 4.0 does uname -s correctly, with DYNIX/ptx in there.
 	# earlier versions are messed up and put the nodename in both
@@ -1053,11 +1006,11 @@
 	echo i386-sequent-sysv4
 	exit ;;
     i*86:UNIX_SV:4.2MP:2.*)
-        # Unixware is an offshoot of SVR4, but it has its own version
-        # number series starting with 2...
-        # I am not positive that other SVR4 systems won't match this,
+	# Unixware is an offshoot of SVR4, but it has its own version
+	# number series starting with 2...
+	# I am not positive that other SVR4 systems won't match this,
 	# I just have to hope.  -- rms.
-        # Use sysv4.2uw... so that sysv4* matches it.
+	# Use sysv4.2uw... so that sysv4* matches it.
 	echo ${UNAME_MACHINE}-pc-sysv4.2uw${UNAME_VERSION}
 	exit ;;
     i*86:OS/2:*:*)
@@ -1074,7 +1027,7 @@
     i*86:syllable:*:*)
 	echo ${UNAME_MACHINE}-pc-syllable
 	exit ;;
-    i*86:LynxOS:2.*:* | i*86:LynxOS:3.[01]*:* | i*86:LynxOS:4.0*:*)
+    i*86:LynxOS:2.*:* | i*86:LynxOS:3.[01]*:* | i*86:LynxOS:4.[02]*:*)
 	echo i386-unknown-lynxos${UNAME_RELEASE}
 	exit ;;
     i*86:*DOS:*:*)
@@ -1089,7 +1042,7 @@
 	fi
 	exit ;;
     i*86:*:5:[678]*)
-    	# UnixWare 7.x, OpenUNIX and OpenServer 6.
+	# UnixWare 7.x, OpenUNIX and OpenServer 6.
 	case `/bin/uname -X | grep "^Machine"` in
 	    *486*)	     UNAME_MACHINE=i486 ;;
 	    *Pentium)	     UNAME_MACHINE=i586 ;;
@@ -1117,13 +1070,13 @@
 	exit ;;
     pc:*:*:*)
 	# Left here for compatibility:
-        # uname -m prints for DJGPP always 'pc', but it prints nothing about
-        # the processor, so we play safe by assuming i586.
+	# uname -m prints for DJGPP always 'pc', but it prints nothing about
+	# the processor, so we play safe by assuming i586.
 	# Note: whatever this is, it MUST be the same as what config.sub
 	# prints for the "djgpp" host, or else GDB configury will decide that
 	# this is a cross-build.
 	echo i586-pc-msdosdjgpp
-        exit ;;
+	exit ;;
     Intel:Mach:3*:*)
 	echo i386-pc-mach3
 	exit ;;
@@ -1158,8 +1111,8 @@
 	/bin/uname -p 2>/dev/null | /bin/grep entium >/dev/null \
 	  && { echo i586-ncr-sysv4.3${OS_REL}; exit; } ;;
     3[34]??:*:4.0:* | 3[34]??,*:*:4.0:*)
-        /bin/uname -p 2>/dev/null | grep 86 >/dev/null \
-          && { echo i486-ncr-sysv4; exit; } ;;
+	/bin/uname -p 2>/dev/null | grep 86 >/dev/null \
+	  && { echo i486-ncr-sysv4; exit; } ;;
     NCR*:*:4.2:* | MPRAS*:*:4.2:*)
 	OS_REL='.3'
 	test -r /etc/.relid \
@@ -1182,7 +1135,7 @@
     rs6000:LynxOS:2.*:*)
 	echo rs6000-unknown-lynxos${UNAME_RELEASE}
 	exit ;;
-    PowerPC:LynxOS:2.*:* | PowerPC:LynxOS:3.[01]*:* | PowerPC:LynxOS:4.0*:*)
+    PowerPC:LynxOS:2.*:* | PowerPC:LynxOS:3.[01]*:* | PowerPC:LynxOS:4.[02]*:*)
 	echo powerpc-unknown-lynxos${UNAME_RELEASE}
 	exit ;;
     SM[BE]S:UNIX_SV:*:*)
@@ -1202,10 +1155,10 @@
 		echo ns32k-sni-sysv
 	fi
 	exit ;;
-    PENTIUM:*:4.0*:*) # Unisys `ClearPath HMP IX 4000' SVR4/MP effort
-                      # says <Richard.M.Bartel@ccMail.Census.GOV>
-        echo i586-unisys-sysv4
-        exit ;;
+    PENTIUM:*:4.0*:*)	# Unisys `ClearPath HMP IX 4000' SVR4/MP effort
+			# says <Richard.M.Bartel@ccMail.Census.GOV>
+	echo i586-unisys-sysv4
+	exit ;;
     *:UNIX_System_V:4*:FTX*)
 	# From Gerald Hewes <hewes@openmarket.com>.
 	# How about differentiating between stratus architectures? -djm
@@ -1231,11 +1184,11 @@
 	exit ;;
     R[34]000:*System_V*:*:* | R4000:UNIX_SYSV:*:* | R*000:UNIX_SV:*:*)
 	if [ -d /usr/nec ]; then
-	        echo mips-nec-sysv${UNAME_RELEASE}
+		echo mips-nec-sysv${UNAME_RELEASE}
 	else
-	        echo mips-unknown-sysv${UNAME_RELEASE}
+		echo mips-unknown-sysv${UNAME_RELEASE}
 	fi
-        exit ;;
+	exit ;;
     BeBox:BeOS:*:*)	# BeOS running on hardware made by Be, PPC only.
 	echo powerpc-be-beos
 	exit ;;
@@ -1275,6 +1228,16 @@
     *:Darwin:*:*)
 	UNAME_PROCESSOR=`uname -p` || UNAME_PROCESSOR=unknown
 	case $UNAME_PROCESSOR in
+	    i386)
+		eval $set_cc_for_build
+		if [ "$CC_FOR_BUILD" != 'no_compiler_found' ]; then
+		  if (echo '#ifdef __LP64__'; echo IS_64BIT_ARCH; echo '#endif') | \
+		      (CCOPTS= $CC_FOR_BUILD -E - 2>/dev/null) | \
+		      grep IS_64BIT_ARCH >/dev/null
+		  then
+		      UNAME_PROCESSOR="x86_64"
+		  fi
+		fi ;;
 	    unknown) UNAME_PROCESSOR=powerpc ;;
 	esac
 	echo ${UNAME_PROCESSOR}-apple-darwin${UNAME_RELEASE}
@@ -1290,6 +1253,9 @@
     *:QNX:*:4*)
 	echo i386-pc-qnx
 	exit ;;
+    NEO-?:NONSTOP_KERNEL:*:*)
+	echo neo-tandem-nsk${UNAME_RELEASE}
+	exit ;;
     NSE-?:NONSTOP_KERNEL:*:*)
 	echo nse-tandem-nsk${UNAME_RELEASE}
 	exit ;;
@@ -1335,13 +1301,13 @@
 	echo pdp10-unknown-its
 	exit ;;
     SEI:*:*:SEIUX)
-        echo mips-sei-seiux${UNAME_RELEASE}
+	echo mips-sei-seiux${UNAME_RELEASE}
 	exit ;;
     *:DragonFly:*:*)
 	echo ${UNAME_MACHINE}-unknown-dragonfly`echo ${UNAME_RELEASE}|sed -e 's/[-(].*//'`
 	exit ;;
     *:*VMS:*:*)
-    	UNAME_MACHINE=`(uname -p) 2>/dev/null`
+	UNAME_MACHINE=`(uname -p) 2>/dev/null`
 	case "${UNAME_MACHINE}" in
 	    A*) echo alpha-dec-vms ; exit ;;
 	    I*) echo ia64-dec-vms ; exit ;;
@@ -1359,6 +1325,9 @@
     i*86:AROS:*:*)
 	echo ${UNAME_MACHINE}-pc-aros
 	exit ;;
+    x86_64:VMkernel:*:*)
+	echo ${UNAME_MACHINE}-unknown-esx
+	exit ;;
 esac
 
 #echo '(No uname command or uname output not recognized.)' 1>&2
@@ -1381,11 +1350,11 @@
 #include <sys/param.h>
   printf ("m68k-sony-newsos%s\n",
 #ifdef NEWSOS4
-          "4"
+	"4"
 #else
-	  ""
+	""
 #endif
-         ); exit (0);
+	); exit (0);
 #endif
 #endif
 

=== modified file 'config.h.unix.in'
--- config.h.unix.in	2010-01-17 13:05:04 +0000
+++ config.h.unix.in	2014-01-16 10:42:06 +0000
@@ -12,12 +12,18 @@
 /* Define to 1 if you have the <errno.h> header file. */
 #undef HAVE_ERRNO_H
 
+/* Define to 1 if GCC atomic builtins are available */
+#undef HAVE_GCC_ATOMIC_BUILTINS
+
 /* Define to 1 if you have the `getaddrinfo' function. */
 #undef HAVE_GETADDRINFO
 
 /* Define to 1 if you want TLS support (GnuTLS). Undefine HAVE_OPENSSL. */
 #undef HAVE_GNUTLS
 
+/* Define to 1 if you have GnuTLS 2.12.0 or above. */
+#undef HAVE_GNUTLS_SESSION_CHANNEL_BINDING
+
 /* Define to 1 if you have the <inttypes.h> header file. */
 #undef HAVE_INTTYPES_H
 
@@ -33,6 +39,9 @@
 /* Define to 1 if you have the `socket' library (-lsocket). */
 #undef HAVE_LIBSOCKET
 
+/* enable mdns support */
+#undef HAVE_MDNS
+
 /* Define to 1 if you have the <memory.h> header file. */
 #undef HAVE_MEMORY_H
 

=== modified file 'config.h.win'
--- config.h.win	2010-01-17 13:05:04 +0000
+++ config.h.win	2014-01-16 10:42:06 +0000
@@ -8,9 +8,16 @@
 /* Comment out if you don't want to use Win's native TLS functions */
 #define HAVE_WINTLS 1
 
+/* Uncomment if you are compiling for Windows 7 or above, or Windows Server 2008 R2 and above, and
+ * want to be able to use Channel Binding (with SASL SCRAM-SHA-1-PLUS). */
+// #define HAVE_WINTLS_CHANNEL_BINDING 1
+
 /* Uncomment if you have GnuTLS available and want to use it */
 // #define HAVE_GNUTLS 1
 
+/* Uncomment if you have GnuTLS 2.12.0 or above */
+// #define HAVE_GNUTLS_SESSION_CHANNEL_BINDING 1
+
 /* Uncomment if you have OpenSSL available and want to use it */
 // #define HAVE_OPENSSL 1
 

=== modified file 'config.sub'
--- config.sub	2010-01-17 13:05:04 +0000
+++ config.sub	2014-01-16 10:42:06 +0000
@@ -1,10 +1,10 @@
 #! /bin/sh
 # Configuration validation subroutine script.
 #   Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999,
-#   2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
-#   Free Software Foundation, Inc.
+#   2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010,
+#   2011, 2012 Free Software Foundation, Inc.
 
-timestamp='2009-04-17'
+timestamp='2012-04-18'
 
 # This file is (in principle) common to ALL GNU software.
 # The presence of a machine in this file suggests that SOME GNU software
@@ -21,9 +21,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 # As a special exception to the GNU General Public License, if you
 # distribute this file as part of a program that contains a
@@ -32,13 +30,16 @@
 
 
 # Please send patches to <config-patches@gnu.org>.  Submit a context
-# diff and a properly formatted ChangeLog entry.
+# diff and a properly formatted GNU ChangeLog entry.
 #
 # Configuration subroutine to validate and canonicalize a configuration type.
 # Supply the specified configuration type as an argument.
 # If it is invalid, we print an error message on stderr and exit with code 1.
 # Otherwise, we print the canonical config type on stdout and succeed.
 
+# You can get the latest version of this script from:
+# http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.sub;hb=HEAD
+
 # This file is supposed to be the same for all GNU packages
 # and recognize all the CPU types, system types and aliases
 # that are meaningful with *any* GNU software.
@@ -72,8 +73,9 @@
 version="\
 GNU config.sub ($timestamp)
 
-Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
+2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+Free Software Foundation, Inc.
 
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
@@ -120,13 +122,18 @@
 # Here we must recognize all the valid KERNEL-OS combinations.
 maybe_os=`echo $1 | sed 's/^\(.*\)-\([^-]*-[^-]*\)$/\2/'`
 case $maybe_os in
-  nto-qnx* | linux-gnu* | linux-dietlibc | linux-newlib* | linux-uclibc* | \
-  uclinux-uclibc* | uclinux-gnu* | kfreebsd*-gnu* | knetbsd*-gnu* | netbsd*-gnu* | \
+  nto-qnx* | linux-gnu* | linux-android* | linux-dietlibc | linux-newlib* | \
+  linux-uclibc* | uclinux-uclibc* | uclinux-gnu* | kfreebsd*-gnu* | \
+  knetbsd*-gnu* | netbsd*-gnu* | \
   kopensolaris*-gnu* | \
   storm-chaos* | os2-emx* | rtmk-nova*)
     os=-$maybe_os
     basic_machine=`echo $1 | sed 's/^\(.*\)-\([^-]*-[^-]*\)$/\1/'`
     ;;
+  android-linux)
+    os=-linux-android
+    basic_machine=`echo $1 | sed 's/^\(.*\)-\([^-]*-[^-]*\)$/\1/'`-unknown
+    ;;
   *)
     basic_machine=`echo $1 | sed 's/-[^-]*$//'`
     if [ $basic_machine != $1 ]
@@ -149,10 +156,13 @@
 	-convergent* | -ncr* | -news | -32* | -3600* | -3100* | -hitachi* |\
 	-c[123]* | -convex* | -sun | -crds | -omron* | -dg | -ultra | -tti* | \
 	-harris | -dolphin | -highlevel | -gould | -cbm | -ns | -masscomp | \
-	-apple | -axis | -knuth | -cray)
+	-apple | -axis | -knuth | -cray | -microblaze)
 		os=
 		basic_machine=$1
 		;;
+	-bluegene*)
+		os=-cnk
+		;;
 	-sim | -cisco | -oki | -wec | -winbond)
 		os=
 		basic_machine=$1
@@ -167,10 +177,10 @@
 		os=-chorusos
 		basic_machine=$1
 		;;
- 	-chorusrdb)
- 		os=-chorusrdb
+	-chorusrdb)
+		os=-chorusrdb
 		basic_machine=$1
- 		;;
+		;;
 	-hiux*)
 		os=-hiuxwe2
 		;;
@@ -215,6 +225,12 @@
 	-isc*)
 		basic_machine=`echo $1 | sed -e 's/86-.*/86-pc/'`
 		;;
+	-lynx*178)
+		os=-lynxos178
+		;;
+	-lynx*5)
+		os=-lynxos5
+		;;
 	-lynx*)
 		os=-lynxos
 		;;
@@ -239,17 +255,22 @@
 	# Some are omitted here because they have special meanings below.
 	1750a | 580 \
 	| a29k \
+	| aarch64 | aarch64_be \
 	| alpha | alphaev[4-8] | alphaev56 | alphaev6[78] | alphapca5[67] \
 	| alpha64 | alpha64ev[4-8] | alpha64ev56 | alpha64ev6[78] | alpha64pca5[67] \
 	| am33_2.0 \
 	| arc | arm | arm[bl]e | arme[lb] | armv[2345] | armv[345][lb] | avr | avr32 \
+        | be32 | be64 \
 	| bfin \
 	| c4x | clipper \
 	| d10v | d30v | dlx | dsp16xx \
+	| epiphany \
 	| fido | fr30 | frv \
 	| h8300 | h8500 | hppa | hppa1.[01] | hppa2.0 | hppa2.0[nw] | hppa64 \
+	| hexagon \
 	| i370 | i860 | i960 | ia64 \
 	| ip2k | iq2000 \
+	| le32 | le64 \
 	| lm32 \
 	| m32c | m32r | m32rle | m68000 | m68k | m88k \
 	| maxq | mb | microblaze | mcore | mep | metag \
@@ -275,27 +296,39 @@
 	| moxie \
 	| mt \
 	| msp430 \
+	| nds32 | nds32le | nds32be \
 	| nios | nios2 \
 	| ns16k | ns32k \
+	| open8 \
 	| or32 \
 	| pdp10 | pdp11 | pj | pjl \
-	| powerpc | powerpc64 | powerpc64le | powerpcle | ppcbe \
+	| powerpc | powerpc64 | powerpc64le | powerpcle \
 	| pyramid \
+	| rl78 | rx \
 	| score \
 	| sh | sh[1234] | sh[24]a | sh[24]aeb | sh[23]e | sh[34]eb | sheb | shbe | shle | sh[1234]le | sh3ele \
 	| sh64 | sh64le \
 	| sparc | sparc64 | sparc64b | sparc64v | sparc86x | sparclet | sparclite \
 	| sparcv8 | sparcv9 | sparcv9b | sparcv9v \
-	| spu | strongarm \
-	| tahoe | thumb | tic4x | tic80 | tron \
-	| v850 | v850e \
+	| spu \
+	| tahoe | tic4x | tic54x | tic55x | tic6x | tic80 | tron \
+	| ubicom32 \
+	| v850 | v850e | v850e1 | v850e2 | v850es | v850e2v3 \
 	| we32k \
-	| x86 | xc16x | xscale | xscalee[bl] | xstormy16 | xtensa \
+	| x86 | xc16x | xstormy16 | xtensa \
 	| z8k | z80)
 		basic_machine=$basic_machine-unknown
 		;;
-	m6811 | m68hc11 | m6812 | m68hc12)
-		# Motorola 68HC11/12.
+	c54x)
+		basic_machine=tic54x-unknown
+		;;
+	c55x)
+		basic_machine=tic55x-unknown
+		;;
+	c6x)
+		basic_machine=tic6x-unknown
+		;;
+	m6811 | m68hc11 | m6812 | m68hc12 | m68hcs12x | picochip)
 		basic_machine=$basic_machine-unknown
 		os=-none
 		;;
@@ -305,6 +338,21 @@
 		basic_machine=mt-unknown
 		;;
 
+	strongarm | thumb | xscale)
+		basic_machine=arm-unknown
+		;;
+	xgate)
+		basic_machine=$basic_machine-unknown
+		os=-none
+		;;
+	xscaleeb)
+		basic_machine=armeb-unknown
+		;;
+
+	xscaleel)
+		basic_machine=armel-unknown
+		;;
+
 	# We use `pc' rather than `unknown'
 	# because (1) that's what they normally are, and
 	# (2) the word "unknown" tends to confuse beginning users.
@@ -319,25 +367,29 @@
 	# Recognize the basic CPU types with company name.
 	580-* \
 	| a29k-* \
+	| aarch64-* | aarch64_be-* \
 	| alpha-* | alphaev[4-8]-* | alphaev56-* | alphaev6[78]-* \
 	| alpha64-* | alpha64ev[4-8]-* | alpha64ev56-* | alpha64ev6[78]-* \
 	| alphapca5[67]-* | alpha64pca5[67]-* | arc-* \
 	| arm-*  | armbe-* | armle-* | armeb-* | armv*-* \
 	| avr-* | avr32-* \
+	| be32-* | be64-* \
 	| bfin-* | bs2000-* \
-	| c[123]* | c30-* | [cjt]90-* | c4x-* | c54x-* | c55x-* | c6x-* \
+	| c[123]* | c30-* | [cjt]90-* | c4x-* \
 	| clipper-* | craynv-* | cydra-* \
 	| d10v-* | d30v-* | dlx-* \
 	| elxsi-* \
 	| f30[01]-* | f700-* | fido-* | fr30-* | frv-* | fx80-* \
 	| h8300-* | h8500-* \
 	| hppa-* | hppa1.[01]-* | hppa2.0-* | hppa2.0[nw]-* | hppa64-* \
+	| hexagon-* \
 	| i*86-* | i860-* | i960-* | ia64-* \
 	| ip2k-* | iq2000-* \
+	| le32-* | le64-* \
 	| lm32-* \
 	| m32c-* | m32r-* | m32rle-* \
 	| m68000-* | m680[012346]0-* | m68360-* | m683?2-* | m68k-* \
-	| m88110-* | m88k-* | maxq-* | mcore-* | metag-* \
+	| m88110-* | m88k-* | maxq-* | mcore-* | metag-* | microblaze-* \
 	| mips-* | mipsbe-* | mipseb-* | mipsel-* | mipsle-* \
 	| mips16-* \
 	| mips64-* | mips64el-* \
@@ -359,24 +411,29 @@
 	| mmix-* \
 	| mt-* \
 	| msp430-* \
+	| nds32-* | nds32le-* | nds32be-* \
 	| nios-* | nios2-* \
 	| none-* | np1-* | ns16k-* | ns32k-* \
+	| open8-* \
 	| orion-* \
 	| pdp10-* | pdp11-* | pj-* | pjl-* | pn-* | power-* \
-	| powerpc-* | powerpc64-* | powerpc64le-* | powerpcle-* | ppcbe-* \
+	| powerpc-* | powerpc64-* | powerpc64le-* | powerpcle-* \
 	| pyramid-* \
-	| romp-* | rs6000-* \
+	| rl78-* | romp-* | rs6000-* | rx-* \
 	| sh-* | sh[1234]-* | sh[24]a-* | sh[24]aeb-* | sh[23]e-* | sh[34]eb-* | sheb-* | shbe-* \
 	| shle-* | sh[1234]le-* | sh3ele-* | sh64-* | sh64le-* \
 	| sparc-* | sparc64-* | sparc64b-* | sparc64v-* | sparc86x-* | sparclet-* \
 	| sparclite-* \
-	| sparcv8-* | sparcv9-* | sparcv9b-* | sparcv9v-* | strongarm-* | sv1-* | sx?-* \
-	| tahoe-* | thumb-* \
-	| tic30-* | tic4x-* | tic54x-* | tic55x-* | tic6x-* | tic80-* | tile-* \
+	| sparcv8-* | sparcv9-* | sparcv9b-* | sparcv9v-* | sv1-* | sx?-* \
+	| tahoe-* \
+	| tic30-* | tic4x-* | tic54x-* | tic55x-* | tic6x-* | tic80-* \
+	| tile*-* \
 	| tron-* \
-	| v850-* | v850e-* | vax-* \
+	| ubicom32-* \
+	| v850-* | v850e-* | v850e1-* | v850es-* | v850e2-* | v850e2v3-* \
+	| vax-* \
 	| we32k-* \
-	| x86-* | x86_64-* | xc16x-* | xps100-* | xscale-* | xscalee[bl]-* \
+	| x86-* | x86_64-* | xc16x-* | xps100-* \
 	| xstormy16-* | xtensa*-* \
 	| ymp-* \
 	| z8k-* | z80-*)
@@ -401,7 +458,7 @@
 		basic_machine=a29k-amd
 		os=-udi
 		;;
-    	abacus)
+	abacus)
 		basic_machine=abacus-unknown
 		;;
 	adobe68k)
@@ -467,11 +524,24 @@
 		basic_machine=bfin-`echo $basic_machine | sed 's/^[^-]*-//'`
 		os=-linux
 		;;
+	bluegene*)
+		basic_machine=powerpc-ibm
+		os=-cnk
+		;;
+	c54x-*)
+		basic_machine=tic54x-`echo $basic_machine | sed 's/^[^-]*-//'`
+		;;
+	c55x-*)
+		basic_machine=tic55x-`echo $basic_machine | sed 's/^[^-]*-//'`
+		;;
+	c6x-*)
+		basic_machine=tic6x-`echo $basic_machine | sed 's/^[^-]*-//'`
+		;;
 	c90)
 		basic_machine=c90-cray
 		os=-unicos
 		;;
-        cegcc)
+	cegcc)
 		basic_machine=arm-unknown
 		os=-cegcc
 		;;
@@ -503,7 +573,7 @@
 		basic_machine=craynv-cray
 		os=-unicosmp
 		;;
-	cr16)
+	cr16 | cr16-*)
 		basic_machine=cr16-unknown
 		os=-elf
 		;;
@@ -661,7 +731,6 @@
 	i370-ibm* | ibm*)
 		basic_machine=i370-ibm
 		;;
-# I'm not sure what "Sysv32" means.  Should this be sysv3.2?
 	i*86v32)
 		basic_machine=`echo $1 | sed -e 's/86.*/86-pc/'`
 		os=-sysv32
@@ -719,6 +788,9 @@
 		basic_machine=ns32k-utek
 		os=-sysv
 		;;
+	microblaze)
+		basic_machine=microblaze-xilinx
+		;;
 	mingw32)
 		basic_machine=i386-pc
 		os=-mingw32
@@ -755,10 +827,18 @@
 	ms1-*)
 		basic_machine=`echo $basic_machine | sed -e 's/ms1-/mt-/'`
 		;;
+	msys)
+		basic_machine=i386-pc
+		os=-msys
+		;;
 	mvs)
 		basic_machine=i370-ibm
 		os=-mvs
 		;;
+	nacl)
+		basic_machine=le32-unknown
+		os=-nacl
+		;;
 	ncr3000)
 		basic_machine=i486-ncr
 		os=-sysv4
@@ -823,6 +903,12 @@
 	np1)
 		basic_machine=np1-gould
 		;;
+	neo-tandem)
+		basic_machine=neo-tandem
+		;;
+	nse-tandem)
+		basic_machine=nse-tandem
+		;;
 	nsr-tandem)
 		basic_machine=nsr-tandem
 		;;
@@ -905,9 +991,10 @@
 		;;
 	power)	basic_machine=power-ibm
 		;;
-	ppc)	basic_machine=powerpc-unknown
+	ppc | ppcbe)	basic_machine=powerpc-unknown
 		;;
-	ppc-*)	basic_machine=powerpc-`echo $basic_machine | sed 's/^[^-]*-//'`
+	ppc-* | ppcbe-*)
+		basic_machine=powerpc-`echo $basic_machine | sed 's/^[^-]*-//'`
 		;;
 	ppcle | powerpclittle | ppc-le | powerpc-little)
 		basic_machine=powerpcle-unknown
@@ -1001,6 +1088,9 @@
 		basic_machine=i860-stratus
 		os=-sysv4
 		;;
+	strongarm-* | thumb-*)
+		basic_machine=arm-`echo $basic_machine | sed 's/^[^-]*-//'`
+		;;
 	sun2)
 		basic_machine=m68000-sun
 		;;
@@ -1057,20 +1147,8 @@
 		basic_machine=t90-cray
 		os=-unicos
 		;;
-	tic54x | c54x*)
-		basic_machine=tic54x-unknown
-		os=-coff
-		;;
-	tic55x | c55x*)
-		basic_machine=tic55x-unknown
-		os=-coff
-		;;
-	tic6x | c6x*)
-		basic_machine=tic6x-unknown
-		os=-coff
-		;;
 	tile*)
-		basic_machine=tile-unknown
+		basic_machine=$basic_machine-unknown
 		os=-linux-gnu
 		;;
 	tx39)
@@ -1140,6 +1218,9 @@
 	xps | xps100)
 		basic_machine=xps100-honeywell
 		;;
+	xscale-* | xscalee[bl]-*)
+		basic_machine=`echo $basic_machine | sed 's/^xscale/arm/'`
+		;;
 	ymp)
 		basic_machine=ymp-cray
 		os=-unicos
@@ -1237,9 +1318,12 @@
 if [ x"$os" != x"" ]
 then
 case $os in
-        # First match some system type aliases
-        # that might get confused with valid system types.
+	# First match some system type aliases
+	# that might get confused with valid system types.
 	# -solaris* is a basic system type, with this one exception.
+	-auroraux)
+		os=-auroraux
+		;;
 	-solaris1 | -solaris1.*)
 		os=`echo $os | sed -e 's|solaris1|sunos4|'`
 		;;
@@ -1260,9 +1344,9 @@
 	# Each alternative MUST END IN A *, to match a version number.
 	# -sysv* is not here because it comes later, after sysvr4.
 	-gnu* | -bsd* | -mach* | -minix* | -genix* | -ultrix* | -irix* \
-	      | -*vms* | -sco* | -esix* | -isc* | -aix* | -sunos | -sunos[34]*\
-	      | -hpux* | -unos* | -osf* | -luna* | -dgux* | -solaris* | -sym* \
-	      | -kopensolaris* \
+	      | -*vms* | -sco* | -esix* | -isc* | -aix* | -cnk* | -sunos | -sunos[34]*\
+	      | -hpux* | -unos* | -osf* | -luna* | -dgux* | -auroraux* | -solaris* \
+	      | -sym* | -kopensolaris* \
 	      | -amigaos* | -amigados* | -msdos* | -newsos* | -unicos* | -aof* \
 	      | -aos* | -aros* \
 	      | -nindy* | -vxsim* | -vxworks* | -ebmon* | -hms* | -mvs* \
@@ -1274,8 +1358,9 @@
 	      | -ptx* | -coff* | -ecoff* | -winnt* | -domain* | -vsta* \
 	      | -udi* | -eabi* | -lites* | -ieee* | -go32* | -aux* \
 	      | -chorusos* | -chorusrdb* | -cegcc* \
-	      | -cygwin* | -pe* | -psos* | -moss* | -proelf* | -rtems* \
-	      | -mingw32* | -linux-gnu* | -linux-newlib* | -linux-uclibc* \
+	      | -cygwin* | -msys* | -pe* | -psos* | -moss* | -proelf* | -rtems* \
+	      | -mingw32* | -linux-gnu* | -linux-android* \
+	      | -linux-newlib* | -linux-uclibc* \
 	      | -uxpv* | -beos* | -mpeix* | -udk* \
 	      | -interix* | -uwin* | -mks* | -rhapsody* | -darwin* | -opened* \
 	      | -openstep* | -oskit* | -conix* | -pw32* | -nonstopux* \
@@ -1283,7 +1368,7 @@
 	      | -os2* | -vos* | -palmos* | -uclinux* | -nucleus* \
 	      | -morphos* | -superux* | -rtmk* | -rtmk-nova* | -windiss* \
 	      | -powermax* | -dnix* | -nx6 | -nx7 | -sei* | -dragonfly* \
-	      | -skyos* | -haiku* | -rdos* | -toppers* | -drops*)
+	      | -skyos* | -haiku* | -rdos* | -toppers* | -drops* | -es*)
 	# Remember, each alternative MUST END IN *, to match a version number.
 		;;
 	-qnx*)
@@ -1322,7 +1407,7 @@
 	-opened*)
 		os=-openedition
 		;;
-        -os400*)
+	-os400*)
 		os=-os400
 		;;
 	-wince*)
@@ -1371,7 +1456,7 @@
 	-sinix*)
 		os=-sysv4
 		;;
-        -tpf*)
+	-tpf*)
 		os=-tpf
 		;;
 	-triton*)
@@ -1416,6 +1501,8 @@
 	-dicos*)
 		os=-dicos
 		;;
+	-nacl*)
+		;;
 	-none)
 		;;
 	*)
@@ -1438,10 +1525,10 @@
 # system, and we'll never get to this point.
 
 case $basic_machine in
-        score-*)
+	score-*)
 		os=-elf
 		;;
-        spu-*)
+	spu-*)
 		os=-elf
 		;;
 	*-acorn)
@@ -1453,8 +1540,20 @@
 	arm*-semi)
 		os=-aout
 		;;
-        c4x-* | tic4x-*)
-        	os=-coff
+	c4x-* | tic4x-*)
+		os=-coff
+		;;
+	hexagon-*)
+		os=-elf
+		;;
+	tic54x-*)
+		os=-coff
+		;;
+	tic55x-*)
+		os=-coff
+		;;
+	tic6x-*)
+		os=-coff
 		;;
 	# This must come before the *-dec entry.
 	pdp10-*)
@@ -1474,14 +1573,11 @@
 		;;
 	m68000-sun)
 		os=-sunos3
-		# This also exists in the configure program, but was not the
-		# default.
-		# os=-sunos4
 		;;
 	m68*-cisco)
 		os=-aout
 		;;
-        mep-*)
+	mep-*)
 		os=-elf
 		;;
 	mips*-cisco)
@@ -1508,7 +1604,7 @@
 	*-ibm)
 		os=-aix
 		;;
-    	*-knuth)
+	*-knuth)
 		os=-mmixware
 		;;
 	*-wec)
@@ -1613,7 +1709,7 @@
 			-sunos*)
 				vendor=sun
 				;;
-			-aix*)
+			-cnk*|-aix*)
 				vendor=ibm
 				;;
 			-beos*)

=== modified file 'configure'
--- configure	2010-01-17 13:05:04 +0000
+++ configure	2014-01-16 10:42:06 +0000
@@ -1,12 +1,12 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.64 for gloox 1.0.
+# Generated by GNU Autoconf 2.69 for gloox 1.0.9.
 #
 # Report bugs to <js@camaya.net>.
 #
-# Copyright (C) 1992, 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2001,
-# 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software
-# Foundation, Inc.
+#
+# Copyright (C) 1992-1996, 1998-2012 Free Software Foundation, Inc.
+#
 #
 # This configure script is free software; the Free Software Foundation
 # gives unlimited permission to copy, distribute and modify it.
@@ -89,6 +89,7 @@
 IFS=" ""	$as_nl"
 
 # Find who we are.  Look in the path if we contain no directory separator.
+as_myself=
 case $0 in #((
   *[\\/]* ) as_myself=$0 ;;
   *) as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
@@ -133,6 +134,31 @@
 # CDPATH.
 (unset CDPATH) >/dev/null 2>&1 && unset CDPATH
 
+# Use a proper internal environment variable to ensure we don't fall
+  # into an infinite loop, continuously re-executing ourselves.
+  if test x"${_as_can_reexec}" != xno && test "x$CONFIG_SHELL" != x; then
+    _as_can_reexec=no; export _as_can_reexec;
+    # We cannot yet assume a decent shell, so we have to provide a
+# neutralization value for shells without unset; and this also
+# works around shells that cannot unset nonexistent variables.
+# Preserve -v and -x to the replacement shell.
+BASH_ENV=/dev/null
+ENV=/dev/null
+(unset BASH_ENV) >/dev/null 2>&1 && unset BASH_ENV ENV
+case $- in # ((((
+  *v*x* | *x*v* ) as_opts=-vx ;;
+  *v* ) as_opts=-v ;;
+  *x* ) as_opts=-x ;;
+  * ) as_opts= ;;
+esac
+exec $CONFIG_SHELL $as_opts "$as_myself" ${1+"$@"}
+# Admittedly, this is quite paranoid, since all the known shells bail
+# out after a failed `exec'.
+$as_echo "$0: could not re-execute with $CONFIG_SHELL" >&2
+as_fn_exit 255
+  fi
+  # We don't want this to propagate to other subprocesses.
+          { _as_can_reexec=; unset _as_can_reexec;}
 if test "x$CONFIG_SHELL" = x; then
   as_bourne_compatible="if test -n \"\${ZSH_VERSION+set}\" && (emulate sh) >/dev/null 2>&1; then :
   emulate sh
@@ -166,11 +192,20 @@
 else
   exitcode=1; echo positional parameters were not saved.
 fi
-test x\$exitcode = x0 || exit 1"
+test x\$exitcode = x0 || exit 1
+test -x / || exit 1"
   as_suggested="  as_lineno_1=";as_suggested=$as_suggested$LINENO;as_suggested=$as_suggested" as_lineno_1a=\$LINENO
   as_lineno_2=";as_suggested=$as_suggested$LINENO;as_suggested=$as_suggested" as_lineno_2a=\$LINENO
   eval 'test \"x\$as_lineno_1'\$as_run'\" != \"x\$as_lineno_2'\$as_run'\" &&
   test \"x\`expr \$as_lineno_1'\$as_run' + 1\`\" = \"x\$as_lineno_2'\$as_run'\"' || exit 1
+
+  test -n \"\${ZSH_VERSION+set}\${BASH_VERSION+set}\" || (
+    ECHO='\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\'
+    ECHO=\$ECHO\$ECHO\$ECHO\$ECHO\$ECHO
+    ECHO=\$ECHO\$ECHO\$ECHO\$ECHO\$ECHO\$ECHO
+    PATH=/empty FPATH=/empty; export PATH FPATH
+    test \"X\`printf %s \$ECHO\`\" = \"X\$ECHO\" \\
+      || test \"X\`print -r -- \$ECHO\`\" = \"X\$ECHO\" ) || exit 1
 test \$(( 1 + 1 )) = 2 || exit 1"
   if (eval "$as_required") 2>/dev/null; then :
   as_have_required=yes
@@ -211,14 +246,25 @@
 
 
       if test "x$CONFIG_SHELL" != x; then :
-  # We cannot yet assume a decent shell, so we have to provide a
-	# neutralization value for shells without unset; and this also
-	# works around shells that cannot unset nonexistent variables.
-	BASH_ENV=/dev/null
-	ENV=/dev/null
-	(unset BASH_ENV) >/dev/null 2>&1 && unset BASH_ENV ENV
-	export CONFIG_SHELL
-	exec "$CONFIG_SHELL" "$as_myself" ${1+"$@"}
+  export CONFIG_SHELL
+             # We cannot yet assume a decent shell, so we have to provide a
+# neutralization value for shells without unset; and this also
+# works around shells that cannot unset nonexistent variables.
+# Preserve -v and -x to the replacement shell.
+BASH_ENV=/dev/null
+ENV=/dev/null
+(unset BASH_ENV) >/dev/null 2>&1 && unset BASH_ENV ENV
+case $- in # ((((
+  *v*x* | *x*v* ) as_opts=-vx ;;
+  *v* ) as_opts=-v ;;
+  *x* ) as_opts=-x ;;
+  * ) as_opts= ;;
+esac
+exec $CONFIG_SHELL $as_opts "$as_myself" ${1+"$@"}
+# Admittedly, this is quite paranoid, since all the known shells bail
+# out after a failed `exec'.
+$as_echo "$0: could not re-execute with $CONFIG_SHELL" >&2
+exit 255
 fi
 
     if test x$as_have_required = xno; then :
@@ -317,10 +363,18 @@
       test -d "$as_dir" && break
     done
     test -z "$as_dirs" || eval "mkdir $as_dirs"
-  } || test -d "$as_dir" || as_fn_error "cannot create directory $as_dir"
+  } || test -d "$as_dir" || as_fn_error $? "cannot create directory $as_dir"
 
 
 } # as_fn_mkdir_p
+
+# as_fn_executable_p FILE
+# -----------------------
+# Test if FILE is an executable regular file.
+as_fn_executable_p ()
+{
+  test -f "$1" && test -x "$1"
+} # as_fn_executable_p
 # as_fn_append VAR VALUE
 # ----------------------
 # Append the text in VALUE to the end of the definition contained in VAR. Take
@@ -357,19 +411,19 @@
 fi # as_fn_arith
 
 
-# as_fn_error ERROR [LINENO LOG_FD]
-# ---------------------------------
+# as_fn_error STATUS ERROR [LINENO LOG_FD]
+# ----------------------------------------
 # Output "`basename $0`: error: ERROR" to stderr. If LINENO and LOG_FD are
 # provided, also output the error to LOG_FD, referencing LINENO. Then exit the
-# script with status $?, using 1 if that was 0.
+# script with STATUS, using 1 if that was 0.
 as_fn_error ()
 {
-  as_status=$?; test $as_status -eq 0 && as_status=1
-  if test "$3"; then
-    as_lineno=${as_lineno-"$2"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-    $as_echo "$as_me:${as_lineno-$LINENO}: error: $1" >&$3
+  as_status=$1; test $as_status -eq 0 && as_status=1
+  if test "$4"; then
+    as_lineno=${as_lineno-"$3"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
+    $as_echo "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
   fi
-  $as_echo "$as_me: error: $1" >&2
+  $as_echo "$as_me: error: $2" >&2
   as_fn_exit $as_status
 } # as_fn_error
 
@@ -442,6 +496,10 @@
   chmod +x "$as_me.lineno" ||
     { $as_echo "$as_me: error: cannot create $as_me.lineno; rerun with a POSIX shell" >&2; as_fn_exit 1; }
 
+  # If we had to re-execute with $CONFIG_SHELL, we're ensured to have
+  # already done that, so ensure we don't try to do so again and fall
+  # in an infinite loop.  This has already happened in practice.
+  _as_can_reexec=no; export _as_can_reexec
   # Don't try to exec as it changes $[0], causing all sort of problems
   # (the dirname of $[0] is not the place where we might find the
   # original and so on.  Autoconf is especially sensitive to this).
@@ -476,16 +534,16 @@
     # ... but there are two gotchas:
     # 1) On MSYS, both `ln -s file dir' and `ln file dir' fail.
     # 2) DJGPP < 2.04 has no symlinks; `ln -s' creates a wrapper executable.
-    # In both cases, we have to default to `cp -p'.
+    # In both cases, we have to default to `cp -pR'.
     ln -s conf$$.file conf$$.dir 2>/dev/null && test ! -f conf$$.exe ||
-      as_ln_s='cp -p'
+      as_ln_s='cp -pR'
   elif ln conf$$.file conf$$ 2>/dev/null; then
     as_ln_s=ln
   else
-    as_ln_s='cp -p'
+    as_ln_s='cp -pR'
   fi
 else
-  as_ln_s='cp -p'
+  as_ln_s='cp -pR'
 fi
 rm -f conf$$ conf$$.exe conf$$.dir/conf$$.file conf$$.file
 rmdir conf$$.dir 2>/dev/null
@@ -497,28 +555,8 @@
   as_mkdir_p=false
 fi
 
-if test -x / >/dev/null 2>&1; then
-  as_test_x='test -x'
-else
-  if ls -dL / >/dev/null 2>&1; then
-    as_ls_L_option=L
-  else
-    as_ls_L_option=
-  fi
-  as_test_x='
-    eval sh -c '\''
-      if test -d "$1"; then
-	test -d "$1/.";
-      else
-	case $1 in #(
-	-*)set "./$1";;
-	esac;
-	case `ls -ld'$as_ls_L_option' "$1" 2>/dev/null` in #((
-	???[sx]*):;;*)false;;esac;fi
-    '\'' sh
-  '
-fi
-as_executable_p=$as_test_x
+as_test_x='test -x'
+as_executable_p=as_fn_executable_p
 
 # Sed expression to map a string onto a valid CPP name.
 as_tr_cpp="eval sed 'y%*$as_cr_letters%P$as_cr_LETTERS%;s%[^_$as_cr_alnum]%_%g'"
@@ -526,160 +564,14 @@
 # Sed expression to map a string onto a valid variable name.
 as_tr_sh="eval sed 'y%*+%pp%;s%[^_$as_cr_alnum]%_%g'"
 
-
-
-# Check that we are running under the correct shell.
 SHELL=${CONFIG_SHELL-/bin/sh}
 
-case X$lt_ECHO in
-X*--fallback-echo)
-  # Remove one level of quotation (which was required for Make).
-  ECHO=`echo "$lt_ECHO" | sed 's,\\\\\$\\$0,'$0','`
-  ;;
-esac
-
-ECHO=${lt_ECHO-echo}
-if test "X$1" = X--no-reexec; then
-  # Discard the --no-reexec flag, and continue.
-  shift
-elif test "X$1" = X--fallback-echo; then
-  # Avoid inline document here, it may be left over
-  :
-elif test "X`{ $ECHO '\t'; } 2>/dev/null`" = 'X\t' ; then
-  # Yippee, $ECHO works!
-  :
-else
-  # Restart under the correct shell.
-  exec $SHELL "$0" --no-reexec ${1+"$@"}
-fi
-
-if test "X$1" = X--fallback-echo; then
-  # used as fallback echo
-  shift
-  cat <<_LT_EOF
-$*
-_LT_EOF
-  exit 0
-fi
-
-# The HP-UX ksh and POSIX shell print the target directory to stdout
-# if CDPATH is set.
-(unset CDPATH) >/dev/null 2>&1 && unset CDPATH
-
-if test -z "$lt_ECHO"; then
-  if test "X${echo_test_string+set}" != Xset; then
-    # find a string as large as possible, as long as the shell can cope with it
-    for cmd in 'sed 50q "$0"' 'sed 20q "$0"' 'sed 10q "$0"' 'sed 2q "$0"' 'echo test'; do
-      # expected sizes: less than 2Kb, 1Kb, 512 bytes, 16 bytes, ...
-      if { echo_test_string=`eval $cmd`; } 2>/dev/null &&
-	 { test "X$echo_test_string" = "X$echo_test_string"; } 2>/dev/null
-      then
-        break
-      fi
-    done
-  fi
-
-  if test "X`{ $ECHO '\t'; } 2>/dev/null`" = 'X\t' &&
-     echo_testing_string=`{ $ECHO "$echo_test_string"; } 2>/dev/null` &&
-     test "X$echo_testing_string" = "X$echo_test_string"; then
-    :
-  else
-    # The Solaris, AIX, and Digital Unix default echo programs unquote
-    # backslashes.  This makes it impossible to quote backslashes using
-    #   echo "$something" | sed 's/\\/\\\\/g'
-    #
-    # So, first we look for a working echo in the user's PATH.
-
-    lt_save_ifs="$IFS"; IFS=$PATH_SEPARATOR
-    for dir in $PATH /usr/ucb; do
-      IFS="$lt_save_ifs"
-      if (test -f $dir/echo || test -f $dir/echo$ac_exeext) &&
-         test "X`($dir/echo '\t') 2>/dev/null`" = 'X\t' &&
-         echo_testing_string=`($dir/echo "$echo_test_string") 2>/dev/null` &&
-         test "X$echo_testing_string" = "X$echo_test_string"; then
-        ECHO="$dir/echo"
-        break
-      fi
-    done
-    IFS="$lt_save_ifs"
-
-    if test "X$ECHO" = Xecho; then
-      # We didn't find a better echo, so look for alternatives.
-      if test "X`{ print -r '\t'; } 2>/dev/null`" = 'X\t' &&
-         echo_testing_string=`{ print -r "$echo_test_string"; } 2>/dev/null` &&
-         test "X$echo_testing_string" = "X$echo_test_string"; then
-        # This shell has a builtin print -r that does the trick.
-        ECHO='print -r'
-      elif { test -f /bin/ksh || test -f /bin/ksh$ac_exeext; } &&
-	   test "X$CONFIG_SHELL" != X/bin/ksh; then
-        # If we have ksh, try running configure again with it.
-        ORIGINAL_CONFIG_SHELL=${CONFIG_SHELL-/bin/sh}
-        export ORIGINAL_CONFIG_SHELL
-        CONFIG_SHELL=/bin/ksh
-        export CONFIG_SHELL
-        exec $CONFIG_SHELL "$0" --no-reexec ${1+"$@"}
-      else
-        # Try using printf.
-        ECHO='printf %s\n'
-        if test "X`{ $ECHO '\t'; } 2>/dev/null`" = 'X\t' &&
-	   echo_testing_string=`{ $ECHO "$echo_test_string"; } 2>/dev/null` &&
-	   test "X$echo_testing_string" = "X$echo_test_string"; then
-	  # Cool, printf works
-	  :
-        elif echo_testing_string=`($ORIGINAL_CONFIG_SHELL "$0" --fallback-echo '\t') 2>/dev/null` &&
-	     test "X$echo_testing_string" = 'X\t' &&
-	     echo_testing_string=`($ORIGINAL_CONFIG_SHELL "$0" --fallback-echo "$echo_test_string") 2>/dev/null` &&
-	     test "X$echo_testing_string" = "X$echo_test_string"; then
-	  CONFIG_SHELL=$ORIGINAL_CONFIG_SHELL
-	  export CONFIG_SHELL
-	  SHELL="$CONFIG_SHELL"
-	  export SHELL
-	  ECHO="$CONFIG_SHELL $0 --fallback-echo"
-        elif echo_testing_string=`($CONFIG_SHELL "$0" --fallback-echo '\t') 2>/dev/null` &&
-	     test "X$echo_testing_string" = 'X\t' &&
-	     echo_testing_string=`($CONFIG_SHELL "$0" --fallback-echo "$echo_test_string") 2>/dev/null` &&
-	     test "X$echo_testing_string" = "X$echo_test_string"; then
-	  ECHO="$CONFIG_SHELL $0 --fallback-echo"
-        else
-	  # maybe with a smaller string...
-	  prev=:
-
-	  for cmd in 'echo test' 'sed 2q "$0"' 'sed 10q "$0"' 'sed 20q "$0"' 'sed 50q "$0"'; do
-	    if { test "X$echo_test_string" = "X`eval $cmd`"; } 2>/dev/null
-	    then
-	      break
-	    fi
-	    prev="$cmd"
-	  done
-
-	  if test "$prev" != 'sed 50q "$0"'; then
-	    echo_test_string=`eval $prev`
-	    export echo_test_string
-	    exec ${ORIGINAL_CONFIG_SHELL-${CONFIG_SHELL-/bin/sh}} "$0" ${1+"$@"}
-	  else
-	    # Oops.  We lost completely, so just stick with echo.
-	    ECHO=echo
-	  fi
-        fi
-      fi
-    fi
-  fi
-fi
-
-# Copy echo and quote the copy suitably for passing to libtool from
-# the Makefile, instead of quoting the original, which is used later.
-lt_ECHO=$ECHO
-if test "X$lt_ECHO" = "X$CONFIG_SHELL $0 --fallback-echo"; then
-   lt_ECHO="$CONFIG_SHELL \\\$\$0 --fallback-echo"
-fi
-
-
-
-
-exec 7<&0 </dev/null 6>&1
+
+test -n "$DJDIR" || exec 7<&0 </dev/null
+exec 6>&1
 
 # Name of the host.
-# hostname on some systems (SVR3.2, Linux) returns a bogus exit status,
+# hostname on some systems (SVR3.2, old GNU/Linux) returns a bogus exit status,
 # so uname gets run too.
 ac_hostname=`(hostname || uname -n) 2>/dev/null | sed 1q`
 
@@ -698,8 +590,8 @@
 # Identity of this package.
 PACKAGE_NAME='gloox'
 PACKAGE_TARNAME='gloox'
-PACKAGE_VERSION='1.0'
-PACKAGE_STRING='gloox 1.0'
+PACKAGE_VERSION='1.0.9'
+PACKAGE_STRING='gloox 1.0.9'
 PACKAGE_BUGREPORT='js@camaya.net'
 PACKAGE_URL=''
 
@@ -746,10 +638,12 @@
 LIBOBJS
 MAYBE_EXAMPLES
 MAYBE_TESTS
+MAYBE_LIB_mdns
 PTHREAD_CFLAGS
 PTHREAD_LIBS
 PTHREAD_CC
 acx_pthread_config
+HAVE_GCC_ATOMIC_BUILTINS
 CXXCPP
 CPP
 OTOOL64
@@ -757,8 +651,10 @@
 LIPO
 NMEDIT
 DSYMUTIL
-lt_ECHO
+MANIFEST_TOOL
+ac_ct_AR
 AR
+DLLTOOL
 OBJDUMP
 LN_S
 NM
@@ -780,6 +676,7 @@
 am__fastdepCC_FALSE
 am__fastdepCC_TRUE
 CCDEPMODE
+am__nodep
 AMDEPBACKSLASH
 AMDEP_FALSE
 AMDEP_TRUE
@@ -872,6 +769,7 @@
 with_pic
 enable_fast_install
 with_gnu_ld
+with_sysroot
 enable_libtool_lock
 with_extra_include_path
 with_extra_library_path
@@ -882,6 +780,7 @@
 with_zlib
 enable_debug
 enable_getaddrinfo
+enable_mdns
 with_tests
 with_examples
 '
@@ -960,8 +859,9 @@
   fi
 
   case $ac_option in
-  *=*)	ac_optarg=`expr "X$ac_option" : '[^=]*=\(.*\)'` ;;
-  *)	ac_optarg=yes ;;
+  *=?*) ac_optarg=`expr "X$ac_option" : '[^=]*=\(.*\)'` ;;
+  *=)   ac_optarg= ;;
+  *)    ac_optarg=yes ;;
   esac
 
   # Accept the important Cygnus configure options, so we can diagnose typos.
@@ -1006,7 +906,7 @@
     ac_useropt=`expr "x$ac_option" : 'x-*disable-\(.*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid feature name: $ac_useropt"
+      as_fn_error $? "invalid feature name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -1032,7 +932,7 @@
     ac_useropt=`expr "x$ac_option" : 'x-*enable-\([^=]*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid feature name: $ac_useropt"
+      as_fn_error $? "invalid feature name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -1236,7 +1136,7 @@
     ac_useropt=`expr "x$ac_option" : 'x-*with-\([^=]*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid package name: $ac_useropt"
+      as_fn_error $? "invalid package name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -1252,7 +1152,7 @@
     ac_useropt=`expr "x$ac_option" : 'x-*without-\(.*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid package name: $ac_useropt"
+      as_fn_error $? "invalid package name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -1282,8 +1182,8 @@
   | --x-librar=* | --x-libra=* | --x-libr=* | --x-lib=* | --x-li=* | --x-l=*)
     x_libraries=$ac_optarg ;;
 
-  -*) as_fn_error "unrecognized option: \`$ac_option'
-Try \`$0 --help' for more information."
+  -*) as_fn_error $? "unrecognized option: \`$ac_option'
+Try \`$0 --help' for more information"
     ;;
 
   *=*)
@@ -1291,7 +1191,7 @@
     # Reject names that are not valid shell variable names.
     case $ac_envvar in #(
       '' | [0-9]* | *[!_$as_cr_alnum]* )
-      as_fn_error "invalid variable name: \`$ac_envvar'" ;;
+      as_fn_error $? "invalid variable name: \`$ac_envvar'" ;;
     esac
     eval $ac_envvar=\$ac_optarg
     export $ac_envvar ;;
@@ -1301,7 +1201,7 @@
     $as_echo "$as_me: WARNING: you should use --build, --host, --target" >&2
     expr "x$ac_option" : ".*[^-._$as_cr_alnum]" >/dev/null &&
       $as_echo "$as_me: WARNING: invalid host type: $ac_option" >&2
-    : ${build_alias=$ac_option} ${host_alias=$ac_option} ${target_alias=$ac_option}
+    : "${build_alias=$ac_option} ${host_alias=$ac_option} ${target_alias=$ac_option}"
     ;;
 
   esac
@@ -1309,13 +1209,13 @@
 
 if test -n "$ac_prev"; then
   ac_option=--`echo $ac_prev | sed 's/_/-/g'`
-  as_fn_error "missing argument to $ac_option"
+  as_fn_error $? "missing argument to $ac_option"
 fi
 
 if test -n "$ac_unrecognized_opts"; then
   case $enable_option_checking in
     no) ;;
-    fatal) as_fn_error "unrecognized options: $ac_unrecognized_opts" ;;
+    fatal) as_fn_error $? "unrecognized options: $ac_unrecognized_opts" ;;
     *)     $as_echo "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2 ;;
   esac
 fi
@@ -1338,7 +1238,7 @@
     [\\/$]* | ?:[\\/]* )  continue;;
     NONE | '' ) case $ac_var in *prefix ) continue;; esac;;
   esac
-  as_fn_error "expected an absolute directory name for --$ac_var: $ac_val"
+  as_fn_error $? "expected an absolute directory name for --$ac_var: $ac_val"
 done
 
 # There might be people who depend on the old broken behavior: `$host'
@@ -1352,8 +1252,6 @@
 if test "x$host_alias" != x; then
   if test "x$build_alias" = x; then
     cross_compiling=maybe
-    $as_echo "$as_me: WARNING: If you wanted to set the --build type, don't use --host.
-    If a cross compiler is detected then cross compile mode will be used." >&2
   elif test "x$build_alias" != "x$host_alias"; then
     cross_compiling=yes
   fi
@@ -1368,9 +1266,9 @@
 ac_pwd=`pwd` && test -n "$ac_pwd" &&
 ac_ls_di=`ls -di .` &&
 ac_pwd_ls_di=`cd "$ac_pwd" && ls -di .` ||
-  as_fn_error "working directory cannot be determined"
+  as_fn_error $? "working directory cannot be determined"
 test "X$ac_ls_di" = "X$ac_pwd_ls_di" ||
-  as_fn_error "pwd does not report name of working directory"
+  as_fn_error $? "pwd does not report name of working directory"
 
 
 # Find the source files, if location was not specified.
@@ -1409,11 +1307,11 @@
 fi
 if test ! -r "$srcdir/$ac_unique_file"; then
   test "$ac_srcdir_defaulted" = yes && srcdir="$ac_confdir or .."
-  as_fn_error "cannot find sources ($ac_unique_file) in $srcdir"
+  as_fn_error $? "cannot find sources ($ac_unique_file) in $srcdir"
 fi
 ac_msg="sources are in $srcdir, but \`cd $srcdir' does not work"
 ac_abs_confdir=`(
-	cd "$srcdir" && test -r "./$ac_unique_file" || as_fn_error "$ac_msg"
+	cd "$srcdir" && test -r "./$ac_unique_file" || as_fn_error $? "$ac_msg"
 	pwd)`
 # When building in place, set srcdir=.
 if test "$ac_abs_confdir" = "$ac_pwd"; then
@@ -1439,7 +1337,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures gloox 1.0 to adapt to many kinds of systems.
+\`configure' configures gloox 1.0.9 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1453,7 +1351,7 @@
       --help=short        display options specific to this package
       --help=recursive    display the short help of all the included packages
   -V, --version           display version information and exit
-  -q, --quiet, --silent   do not print \`checking...' messages
+  -q, --quiet, --silent   do not print \`checking ...' messages
       --cache-file=FILE   cache test results in FILE [disabled]
   -C, --config-cache      alias for \`--cache-file=config.cache'
   -n, --no-create         do not create output files
@@ -1509,7 +1407,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of gloox 1.0:";;
+     short | recursive ) echo "Configuration of gloox 1.0.9:";;
    esac
   cat <<\_ACEOF
 
@@ -1524,15 +1422,18 @@
   --enable-fast-install[=PKGS]
                           optimize for fast installation [default=yes]
   --disable-libtool-lock  avoid locking (might break parallel builds)
-  --enable-debug          turn on debugging default=no
-  --enable-getaddrinfo    use getaddrinfo for dns lookups default=no
+  --enable-debug          turn on debugging [default=no]
+  --enable-getaddrinfo    use getaddrinfo for dns lookups [default=no]
+  --enable-mdns           use mdns [default=no]
 
 Optional Packages:
   --with-PACKAGE[=ARG]    use PACKAGE [ARG=yes]
   --without-PACKAGE       do not use PACKAGE (same as --with-PACKAGE=no)
-  --with-pic              try to use only PIC/non-PIC objects [default=use
+  --with-pic[=PKGS]       try to use only PIC/non-PIC objects [default=use
                           both]
   --with-gnu-ld           assume the C compiler uses GNU ld [default=no]
+  --with-sysroot=DIR Search for dependent libraries within DIR
+                        (or the compiler's sysroot if not specified).
   --with-extra-include-path
                           use additional include paths
   --with-extra-library-path
@@ -1551,7 +1452,7 @@
   LDFLAGS     linker flags, e.g. -L<lib dir> if you have libraries in a
               nonstandard directory <lib dir>
   LIBS        libraries to pass to the linker, e.g. -l<library>
-  CPPFLAGS    C/C++/Objective C preprocessor flags, e.g. -I<include dir> if
+  CPPFLAGS    (Objective) C/C++ preprocessor flags, e.g. -I<include dir> if
               you have headers in a nonstandard directory <include dir>
   CXX         C++ compiler command
   CXXFLAGS    C++ compiler flags
@@ -1624,10 +1525,10 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-gloox configure 1.0
-generated by GNU Autoconf 2.64
+gloox configure 1.0.9
+generated by GNU Autoconf 2.69
 
-Copyright (C) 2009 Free Software Foundation, Inc.
+Copyright (C) 2012 Free Software Foundation, Inc.
 This configure script is free software; the Free Software Foundation
 gives unlimited permission to copy, distribute and modify it.
 _ACEOF
@@ -1671,8 +1572,8 @@
 
 	ac_retval=1
 fi
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
-  return $ac_retval
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
 
 } # ac_fn_c_try_compile
 
@@ -1709,8 +1610,8 @@
 
 	ac_retval=1
 fi
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
-  return $ac_retval
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
 
 } # ac_fn_cxx_try_compile
 
@@ -1741,7 +1642,7 @@
 	 test ! -s conftest.err
        } && test -s conftest$ac_exeext && {
 	 test "$cross_compiling" = yes ||
-	 $as_test_x conftest$ac_exeext
+	 test -x conftest$ac_exeext
        }; then :
   ac_retval=0
 else
@@ -1755,8 +1656,8 @@
   # interfere with the next link command; also delete a directory that is
   # left behind by Apple's compiler.  We do this before executing the actions.
   rm -rf conftest.dSYM conftest_ipa8_conftest.oo
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
-  return $ac_retval
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
 
 } # ac_fn_c_try_link
 
@@ -1769,7 +1670,7 @@
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
 $as_echo_n "checking for $2... " >&6; }
-if { as_var=$3; eval "test \"\${$as_var+set}\" = set"; }; then :
+if eval \${$3+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -1787,7 +1688,7 @@
 eval ac_res=\$$3
 	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
 $as_echo "$ac_res" >&6; }
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
 
 } # ac_fn_c_check_header_compile
 
@@ -1812,7 +1713,7 @@
     mv -f conftest.er1 conftest.err
   fi
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; } >/dev/null && {
+  test $ac_status = 0; } > conftest.i && {
 	 test -z "$ac_c_preproc_warn_flag$ac_c_werror_flag" ||
 	 test ! -s conftest.err
        }; then :
@@ -1823,8 +1724,8 @@
 
     ac_retval=1
 fi
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
-  return $ac_retval
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
 
 } # ac_fn_c_try_cpp
 
@@ -1865,8 +1766,8 @@
        ac_retval=$ac_status
 fi
   rm -rf conftest.dSYM conftest_ipa8_conftest.oo
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
-  return $ac_retval
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
 
 } # ac_fn_c_try_run
 
@@ -1878,7 +1779,7 @@
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
 $as_echo_n "checking for $2... " >&6; }
-if { as_var=$3; eval "test \"\${$as_var+set}\" = set"; }; then :
+if eval \${$3+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -1933,7 +1834,7 @@
 eval ac_res=\$$3
 	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
 $as_echo "$ac_res" >&6; }
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
 
 } # ac_fn_c_check_func
 
@@ -1958,7 +1859,7 @@
     mv -f conftest.er1 conftest.err
   fi
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; } >/dev/null && {
+  test $ac_status = 0; } > conftest.i && {
 	 test -z "$ac_cxx_preproc_warn_flag$ac_cxx_werror_flag" ||
 	 test ! -s conftest.err
        }; then :
@@ -1969,8 +1870,8 @@
 
     ac_retval=1
 fi
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
-  return $ac_retval
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
 
 } # ac_fn_cxx_try_cpp
 
@@ -2001,7 +1902,7 @@
 	 test ! -s conftest.err
        } && test -s conftest$ac_exeext && {
 	 test "$cross_compiling" = yes ||
-	 $as_test_x conftest$ac_exeext
+	 test -x conftest$ac_exeext
        }; then :
   ac_retval=0
 else
@@ -2015,8 +1916,8 @@
   # interfere with the next link command; also delete a directory that is
   # left behind by Apple's compiler.  We do this before executing the actions.
   rm -rf conftest.dSYM conftest_ipa8_conftest.oo
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
-  return $ac_retval
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
 
 } # ac_fn_cxx_try_link
 
@@ -2028,10 +1929,10 @@
 ac_fn_c_check_header_mongrel ()
 {
   as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  if { as_var=$3; eval "test \"\${$as_var+set}\" = set"; }; then :
+  if eval \${$3+:} false; then :
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
 $as_echo_n "checking for $2... " >&6; }
-if { as_var=$3; eval "test \"\${$as_var+set}\" = set"; }; then :
+if eval \${$3+:} false; then :
   $as_echo_n "(cached) " >&6
 fi
 eval ac_res=\$$3
@@ -2067,7 +1968,7 @@
 else
   ac_header_preproc=no
 fi
-rm -f conftest.err conftest.$ac_ext
+rm -f conftest.err conftest.i conftest.$ac_ext
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_header_preproc" >&5
 $as_echo "$ac_header_preproc" >&6; }
 
@@ -2090,17 +1991,15 @@
 $as_echo "$as_me: WARNING: $2:     section \"Present But Cannot Be Compiled\"" >&2;}
     { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $2: proceeding with the compiler's result" >&5
 $as_echo "$as_me: WARNING: $2: proceeding with the compiler's result" >&2;}
-( cat <<\_ASBOX
-## ---------------------------- ##
+( $as_echo "## ---------------------------- ##
 ## Report this to js@camaya.net ##
-## ---------------------------- ##
-_ASBOX
+## ---------------------------- ##"
      ) | sed "s/^/$as_me: WARNING:     /" >&2
     ;;
 esac
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $2" >&5
 $as_echo_n "checking for $2... " >&6; }
-if { as_var=$3; eval "test \"\${$as_var+set}\" = set"; }; then :
+if eval \${$3+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   eval "$3=\$ac_header_compiler"
@@ -2109,15 +2008,15 @@
 	       { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_res" >&5
 $as_echo "$ac_res" >&6; }
 fi
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
 
 } # ac_fn_c_check_header_mongrel
 cat >config.log <<_ACEOF
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by gloox $as_me 1.0, which was
-generated by GNU Autoconf 2.64.  Invocation command line was
+It was created by gloox $as_me 1.0.9, which was
+generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
 
@@ -2227,11 +2126,9 @@
   {
     echo
 
-    cat <<\_ASBOX
-## ---------------- ##
+    $as_echo "## ---------------- ##
 ## Cache variables. ##
-## ---------------- ##
-_ASBOX
+## ---------------- ##"
     echo
     # The following way of writing the cache mishandles newlines in values,
 (
@@ -2265,11 +2162,9 @@
 )
     echo
 
-    cat <<\_ASBOX
-## ----------------- ##
+    $as_echo "## ----------------- ##
 ## Output variables. ##
-## ----------------- ##
-_ASBOX
+## ----------------- ##"
     echo
     for ac_var in $ac_subst_vars
     do
@@ -2282,11 +2177,9 @@
     echo
 
     if test -n "$ac_subst_files"; then
-      cat <<\_ASBOX
-## ------------------- ##
+      $as_echo "## ------------------- ##
 ## File substitutions. ##
-## ------------------- ##
-_ASBOX
+## ------------------- ##"
       echo
       for ac_var in $ac_subst_files
       do
@@ -2300,11 +2193,9 @@
     fi
 
     if test -s confdefs.h; then
-      cat <<\_ASBOX
-## ----------- ##
+      $as_echo "## ----------- ##
 ## confdefs.h. ##
-## ----------- ##
-_ASBOX
+## ----------- ##"
       echo
       cat confdefs.h
       echo
@@ -2359,7 +2250,12 @@
 ac_site_file1=NONE
 ac_site_file2=NONE
 if test -n "$CONFIG_SITE"; then
-  ac_site_file1=$CONFIG_SITE
+  # We do not want a PATH search for config.site.
+  case $CONFIG_SITE in #((
+    -*)  ac_site_file1=./$CONFIG_SITE;;
+    */*) ac_site_file1=$CONFIG_SITE;;
+    *)   ac_site_file1=./$CONFIG_SITE;;
+  esac
 elif test "x$prefix" != xNONE; then
   ac_site_file1=$prefix/share/config.site
   ac_site_file2=$prefix/etc/config.site
@@ -2370,18 +2266,22 @@
 for ac_site_file in "$ac_site_file1" "$ac_site_file2"
 do
   test "x$ac_site_file" = xNONE && continue
-  if test -r "$ac_site_file"; then
+  if test /dev/null != "$ac_site_file" && test -r "$ac_site_file"; then
     { $as_echo "$as_me:${as_lineno-$LINENO}: loading site script $ac_site_file" >&5
 $as_echo "$as_me: loading site script $ac_site_file" >&6;}
     sed 's/^/| /' "$ac_site_file" >&5
-    . "$ac_site_file"
+    . "$ac_site_file" \
+      || { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "failed to load site script $ac_site_file
+See \`config.log' for more details" "$LINENO" 5; }
   fi
 done
 
 if test -r "$cache_file"; then
-  # Some versions of bash will fail to source /dev/null (special
-  # files actually), so we avoid doing that.
-  if test -f "$cache_file"; then
+  # Some versions of bash will fail to source /dev/null (special files
+  # actually), so we avoid doing that.  DJGPP emulates it as a regular file.
+  if test /dev/null != "$cache_file" && test -f "$cache_file"; then
     { $as_echo "$as_me:${as_lineno-$LINENO}: loading cache $cache_file" >&5
 $as_echo "$as_me: loading cache $cache_file" >&6;}
     case $cache_file in
@@ -2450,7 +2350,7 @@
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
   { $as_echo "$as_me:${as_lineno-$LINENO}: error: changes in the environment can compromise the build" >&5
 $as_echo "$as_me: error: changes in the environment can compromise the build" >&2;}
-  as_fn_error "run \`make distclean' and/or \`rm $cache_file' and start over" "$LINENO" 5
+  as_fn_error $? "run \`make distclean' and/or \`rm $cache_file' and start over" "$LINENO" 5
 fi
 ## -------------------- ##
 ## Main body of script. ##
@@ -2468,16 +2368,22 @@
 
 ac_aux_dir=
 for ac_dir in "$srcdir" "$srcdir/.." "$srcdir/../.."; do
-  for ac_t in install-sh install.sh shtool; do
-    if test -f "$ac_dir/$ac_t"; then
-      ac_aux_dir=$ac_dir
-      ac_install_sh="$ac_aux_dir/$ac_t -c"
-      break 2
-    fi
-  done
+  if test -f "$ac_dir/install-sh"; then
+    ac_aux_dir=$ac_dir
+    ac_install_sh="$ac_aux_dir/install-sh -c"
+    break
+  elif test -f "$ac_dir/install.sh"; then
+    ac_aux_dir=$ac_dir
+    ac_install_sh="$ac_aux_dir/install.sh -c"
+    break
+  elif test -f "$ac_dir/shtool"; then
+    ac_aux_dir=$ac_dir
+    ac_install_sh="$ac_aux_dir/shtool install -c"
+    break
+  fi
 done
 if test -z "$ac_aux_dir"; then
-  as_fn_error "cannot find install-sh, install.sh, or shtool in \"$srcdir\" \"$srcdir/..\" \"$srcdir/../..\"" "$LINENO" 5
+  as_fn_error $? "cannot find install-sh, install.sh, or shtool in \"$srcdir\" \"$srcdir/..\" \"$srcdir/../..\"" "$LINENO" 5
 fi
 
 # These three variables are undocumented and unsupported,
@@ -2506,7 +2412,7 @@
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for a BSD-compatible install" >&5
 $as_echo_n "checking for a BSD-compatible install... " >&6; }
 if test -z "$INSTALL"; then
-if test "${ac_cv_path_install+set}" = set; then :
+if ${ac_cv_path_install+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
@@ -2526,7 +2432,7 @@
     # by default.
     for ac_prog in ginstall scoinst install; do
       for ac_exec_ext in '' $ac_executable_extensions; do
-	if { test -f "$as_dir/$ac_prog$ac_exec_ext" && $as_test_x "$as_dir/$ac_prog$ac_exec_ext"; }; then
+	if as_fn_executable_p "$as_dir/$ac_prog$ac_exec_ext"; then
 	  if test $ac_prog = install &&
 	    grep dspmsg "$as_dir/$ac_prog$ac_exec_ext" >/dev/null 2>&1; then
 	    # AIX install.  It has an incompatible calling convention.
@@ -2593,11 +2499,11 @@
 '
 case `pwd` in
   *[\\\"\#\$\&\'\`$am_lf]*)
-    as_fn_error "unsafe absolute working directory name" "$LINENO" 5;;
+    as_fn_error $? "unsafe absolute working directory name" "$LINENO" 5;;
 esac
 case $srcdir in
   *[\\\"\#\$\&\'\`$am_lf\ \	]*)
-    as_fn_error "unsafe srcdir value: \`$srcdir'" "$LINENO" 5;;
+    as_fn_error $? "unsafe srcdir value: \`$srcdir'" "$LINENO" 5;;
 esac
 
 # Do `set' in a subshell so we don't clobber the current shell's
@@ -2619,7 +2525,7 @@
       # if, for instance, CONFIG_SHELL is bash and it inherits a
       # broken ls alias from the environment.  This has actually
       # happened.  Such a system could not be considered "sane".
-      as_fn_error "ls -t appears to fail.  Make sure there is not a broken
+      as_fn_error $? "ls -t appears to fail.  Make sure there is not a broken
 alias in your environment" "$LINENO" 5
    fi
 
@@ -2629,7 +2535,7 @@
    # Ok.
    :
 else
-   as_fn_error "newly created file is older than distributed files!
+   as_fn_error $? "newly created file is older than distributed files!
 Check your system clock" "$LINENO" 5
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
@@ -2683,7 +2589,7 @@
 set dummy ${ac_tool_prefix}strip; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_STRIP+set}" = set; then :
+if ${ac_cv_prog_STRIP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$STRIP"; then
@@ -2695,7 +2601,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_STRIP="${ac_tool_prefix}strip"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -2723,7 +2629,7 @@
 set dummy strip; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_STRIP+set}" = set; then :
+if ${ac_cv_prog_ac_ct_STRIP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_STRIP"; then
@@ -2735,7 +2641,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_STRIP="strip"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -2776,7 +2682,7 @@
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for a thread-safe mkdir -p" >&5
 $as_echo_n "checking for a thread-safe mkdir -p... " >&6; }
 if test -z "$MKDIR_P"; then
-  if test "${ac_cv_path_mkdir+set}" = set; then :
+  if ${ac_cv_path_mkdir+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
@@ -2786,7 +2692,7 @@
   test -z "$as_dir" && as_dir=.
     for ac_prog in mkdir gmkdir; do
 	 for ac_exec_ext in '' $ac_executable_extensions; do
-	   { test -f "$as_dir/$ac_prog$ac_exec_ext" && $as_test_x "$as_dir/$ac_prog$ac_exec_ext"; } || continue
+	   as_fn_executable_p "$as_dir/$ac_prog$ac_exec_ext" || continue
 	   case `"$as_dir/$ac_prog$ac_exec_ext" --version 2>&1` in #(
 	     'mkdir (GNU coreutils) '* | \
 	     'mkdir (coreutils) '* | \
@@ -2801,6 +2707,7 @@
 
 fi
 
+  test -d ./--version && rmdir ./--version
   if test "${ac_cv_path_mkdir+set}" = set; then
     MKDIR_P="$ac_cv_path_mkdir -p"
   else
@@ -2808,7 +2715,6 @@
     # value for MKDIR_P within a source directory, because that will
     # break other packages using the cache if that directory is
     # removed, or if the value is a relative name.
-    test -d ./--version && rmdir ./--version
     MKDIR_P="$ac_install_sh -d"
   fi
 fi
@@ -2827,7 +2733,7 @@
 set dummy $ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_AWK+set}" = set; then :
+if ${ac_cv_prog_AWK+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$AWK"; then
@@ -2839,7 +2745,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_AWK="$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -2867,7 +2773,7 @@
 $as_echo_n "checking whether ${MAKE-make} sets \$(MAKE)... " >&6; }
 set x ${MAKE-make}
 ac_make=`$as_echo "$2" | sed 's/+/p/g; s/[^a-zA-Z0-9_]/_/g'`
-if { as_var=ac_cv_prog_make_${ac_make}_set; eval "test \"\${$as_var+set}\" = set"; }; then :
+if eval \${ac_cv_prog_make_${ac_make}_set+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat >conftest.make <<\_ACEOF
@@ -2875,7 +2781,7 @@
 all:
 	@echo '@@@%%%=$(MAKE)=@@@%%%'
 _ACEOF
-# GNU make sometimes prints "make[1]: Entering...", which would confuse us.
+# GNU make sometimes prints "make[1]: Entering ...", which would confuse us.
 case `${MAKE-make} -f conftest.make 2>/dev/null` in
   *@@@%%%=?*=@@@%%%*)
     eval ac_cv_prog_make_${ac_make}_set=yes;;
@@ -2909,7 +2815,7 @@
   am__isrc=' -I$(srcdir)'
   # test to see if srcdir already configured
   if test -f $srcdir/config.status; then
-    as_fn_error "source directory already configured; run \"make distclean\" there first" "$LINENO" 5
+    as_fn_error $? "source directory already configured; run \"make distclean\" there first" "$LINENO" 5
   fi
 fi
 
@@ -2925,7 +2831,7 @@
 
 # Define the identity of the package.
  PACKAGE=gloox
- VERSION=1.0
+ VERSION=1.0.9
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2955,11 +2861,11 @@
 
 # We need awk for the "check" target.  The system "awk" is bad on
 # some platforms.
-# Always define AMTAR for backward compatibility.
-
-AMTAR=${AMTAR-"${am_missing_run}tar"}
-
-am__tar='${AMTAR} chof - "$$tardir"'; am__untar='${AMTAR} xf -'
+# Always define AMTAR for backward compatibility.  Yes, it's still used
+# in the wild :-(  We should find a proper way to deprecate it ...
+AMTAR='$${TAR-tar}'
+
+am__tar='$${TAR-tar} chof - "$$tardir"' am__untar='$${TAR-tar} xf -'
 
 
 
@@ -2976,27 +2882,27 @@
 
 # Make sure we can run config.sub.
 $SHELL "$ac_aux_dir/config.sub" sun4 >/dev/null 2>&1 ||
-  as_fn_error "cannot run $SHELL $ac_aux_dir/config.sub" "$LINENO" 5
+  as_fn_error $? "cannot run $SHELL $ac_aux_dir/config.sub" "$LINENO" 5
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking build system type" >&5
 $as_echo_n "checking build system type... " >&6; }
-if test "${ac_cv_build+set}" = set; then :
+if ${ac_cv_build+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_build_alias=$build_alias
 test "x$ac_build_alias" = x &&
   ac_build_alias=`$SHELL "$ac_aux_dir/config.guess"`
 test "x$ac_build_alias" = x &&
-  as_fn_error "cannot guess build type; you must specify one" "$LINENO" 5
+  as_fn_error $? "cannot guess build type; you must specify one" "$LINENO" 5
 ac_cv_build=`$SHELL "$ac_aux_dir/config.sub" $ac_build_alias` ||
-  as_fn_error "$SHELL $ac_aux_dir/config.sub $ac_build_alias failed" "$LINENO" 5
+  as_fn_error $? "$SHELL $ac_aux_dir/config.sub $ac_build_alias failed" "$LINENO" 5
 
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_build" >&5
 $as_echo "$ac_cv_build" >&6; }
 case $ac_cv_build in
 *-*-*) ;;
-*) as_fn_error "invalid value of canonical build" "$LINENO" 5;;
+*) as_fn_error $? "invalid value of canonical build" "$LINENO" 5;;
 esac
 build=$ac_cv_build
 ac_save_IFS=$IFS; IFS='-'
@@ -3014,14 +2920,14 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking host system type" >&5
 $as_echo_n "checking host system type... " >&6; }
-if test "${ac_cv_host+set}" = set; then :
+if ${ac_cv_host+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test "x$host_alias" = x; then
   ac_cv_host=$ac_cv_build
 else
   ac_cv_host=`$SHELL "$ac_aux_dir/config.sub" $host_alias` ||
-    as_fn_error "$SHELL $ac_aux_dir/config.sub $host_alias failed" "$LINENO" 5
+    as_fn_error $? "$SHELL $ac_aux_dir/config.sub $host_alias failed" "$LINENO" 5
 fi
 
 fi
@@ -3029,7 +2935,7 @@
 $as_echo "$ac_cv_host" >&6; }
 case $ac_cv_host in
 *-*-*) ;;
-*) as_fn_error "invalid value of canonical host" "$LINENO" 5;;
+*) as_fn_error $? "invalid value of canonical host" "$LINENO" 5;;
 esac
 host=$ac_cv_host
 ac_save_IFS=$IFS; IFS='-'
@@ -3057,7 +2963,7 @@
 set dummy ${ac_tool_prefix}gcc; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_CC+set}" = set; then :
+if ${ac_cv_prog_CC+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$CC"; then
@@ -3069,7 +2975,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_CC="${ac_tool_prefix}gcc"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -3097,7 +3003,7 @@
 set dummy gcc; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_CC+set}" = set; then :
+if ${ac_cv_prog_ac_ct_CC+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_CC"; then
@@ -3109,7 +3015,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_CC="gcc"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -3150,7 +3056,7 @@
 set dummy ${ac_tool_prefix}cc; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_CC+set}" = set; then :
+if ${ac_cv_prog_CC+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$CC"; then
@@ -3162,7 +3068,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_CC="${ac_tool_prefix}cc"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -3190,7 +3096,7 @@
 set dummy cc; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_CC+set}" = set; then :
+if ${ac_cv_prog_CC+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$CC"; then
@@ -3203,7 +3109,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     if test "$as_dir/$ac_word$ac_exec_ext" = "/usr/ucb/cc"; then
        ac_prog_rejected=yes
        continue
@@ -3249,7 +3155,7 @@
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_CC+set}" = set; then :
+if ${ac_cv_prog_CC+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$CC"; then
@@ -3261,7 +3167,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_CC="$ac_tool_prefix$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -3293,7 +3199,7 @@
 set dummy $ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_CC+set}" = set; then :
+if ${ac_cv_prog_ac_ct_CC+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_CC"; then
@@ -3305,7 +3211,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_CC="$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -3347,8 +3253,8 @@
 
 test -z "$CC" && { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "no acceptable C compiler found in \$PATH
-See \`config.log' for more details." "$LINENO" 5; }
+as_fn_error $? "no acceptable C compiler found in \$PATH
+See \`config.log' for more details" "$LINENO" 5; }
 
 # Provide some information about the compiler.
 $as_echo "$as_me:${as_lineno-$LINENO}: checking for C compiler version" >&5
@@ -3369,32 +3275,30 @@
 ... rest of stderr output deleted ...
          10q' conftest.err >conftest.er1
     cat conftest.er1 >&5
-    rm -f conftest.er1 conftest.err
   fi
+  rm -f conftest.er1 conftest.err
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }
 done
 
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-#include <stdio.h>
+
 int
 main ()
 {
-FILE *f = fopen ("conftest.out", "w");
- return ferror (f) || fclose (f) != 0;
 
   ;
   return 0;
 }
 _ACEOF
 ac_clean_files_save=$ac_clean_files
-ac_clean_files="$ac_clean_files a.out a.out.dSYM a.exe b.out conftest.out"
+ac_clean_files="$ac_clean_files a.out a.out.dSYM a.exe b.out"
 # Try to create an executable without -o first, disregard a.out.
 # It will help us diagnose broken compilers, and finding out an intuition
 # of exeext.
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for C compiler default output file name" >&5
-$as_echo_n "checking for C compiler default output file name... " >&6; }
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether the C compiler works" >&5
+$as_echo_n "checking whether the C compiler works... " >&6; }
 ac_link_default=`$as_echo "$ac_link" | sed 's/ -o *conftest[^ ]*//'`
 
 # The possible output files:
@@ -3456,62 +3360,28 @@
 else
   ac_file=''
 fi
+if test -z "$ac_file"; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+$as_echo "$as_me: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error 77 "C compiler cannot create executables
+See \`config.log' for more details" "$LINENO" 5; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+$as_echo "yes" >&6; }
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for C compiler default output file name" >&5
+$as_echo_n "checking for C compiler default output file name... " >&6; }
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_file" >&5
 $as_echo "$ac_file" >&6; }
-if test -z "$ac_file"; then :
-  $as_echo "$as_me: failed program was:" >&5
-sed 's/^/| /' conftest.$ac_ext >&5
-
-{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-{ as_fn_set_status 77
-as_fn_error "C compiler cannot create executables
-See \`config.log' for more details." "$LINENO" 5; }; }
-fi
 ac_exeext=$ac_cv_exeext
 
-# Check that the compiler produces executables we can run.  If not, either
-# the compiler is broken, or we cross compile.
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether the C compiler works" >&5
-$as_echo_n "checking whether the C compiler works... " >&6; }
-# If not cross compiling, check that we can run a simple program.
-if test "$cross_compiling" != yes; then
-  if { ac_try='./$ac_file'
-  { { case "(($ac_try" in
-  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
-  *) ac_try_echo=$ac_try;;
-esac
-eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
-  (eval "$ac_try") 2>&5
-  ac_status=$?
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; }; }; then
-    cross_compiling=no
-  else
-    if test "$cross_compiling" = maybe; then
-	cross_compiling=yes
-    else
-	{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "cannot run C compiled programs.
-If you meant to cross compile, use \`--host'.
-See \`config.log' for more details." "$LINENO" 5; }
-    fi
-  fi
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
-$as_echo "yes" >&6; }
-
-rm -f -r a.out a.out.dSYM a.exe conftest$ac_cv_exeext b.out conftest.out
+rm -f -r a.out a.out.dSYM a.exe conftest$ac_cv_exeext b.out
 ac_clean_files=$ac_clean_files_save
-# Check that the compiler produces executables we can run.  If not, either
-# the compiler is broken, or we cross compile.
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are cross compiling" >&5
-$as_echo_n "checking whether we are cross compiling... " >&6; }
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $cross_compiling" >&5
-$as_echo "$cross_compiling" >&6; }
-
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for suffix of executables" >&5
 $as_echo_n "checking for suffix of executables... " >&6; }
 if { { ac_try="$ac_link"
@@ -3541,19 +3411,78 @@
 else
   { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "cannot compute suffix of executables: cannot compile and link
-See \`config.log' for more details." "$LINENO" 5; }
+as_fn_error $? "cannot compute suffix of executables: cannot compile and link
+See \`config.log' for more details" "$LINENO" 5; }
 fi
-rm -f conftest$ac_cv_exeext
+rm -f conftest conftest$ac_cv_exeext
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_exeext" >&5
 $as_echo "$ac_cv_exeext" >&6; }
 
 rm -f conftest.$ac_ext
 EXEEXT=$ac_cv_exeext
 ac_exeext=$EXEEXT
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <stdio.h>
+int
+main ()
+{
+FILE *f = fopen ("conftest.out", "w");
+ return ferror (f) || fclose (f) != 0;
+
+  ;
+  return 0;
+}
+_ACEOF
+ac_clean_files="$ac_clean_files conftest.out"
+# Check that the compiler produces executables we can run.  If not, either
+# the compiler is broken, or we cross compile.
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are cross compiling" >&5
+$as_echo_n "checking whether we are cross compiling... " >&6; }
+if test "$cross_compiling" != yes; then
+  { { ac_try="$ac_link"
+case "(($ac_try" in
+  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
+  *) ac_try_echo=$ac_try;;
+esac
+eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
+$as_echo "$ac_try_echo"; } >&5
+  (eval "$ac_link") 2>&5
+  ac_status=$?
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+  if { ac_try='./conftest$ac_cv_exeext'
+  { { case "(($ac_try" in
+  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
+  *) ac_try_echo=$ac_try;;
+esac
+eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
+$as_echo "$ac_try_echo"; } >&5
+  (eval "$ac_try") 2>&5
+  ac_status=$?
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }; }; then
+    cross_compiling=no
+  else
+    if test "$cross_compiling" = maybe; then
+	cross_compiling=yes
+    else
+	{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "cannot run C compiled programs.
+If you meant to cross compile, use \`--host'.
+See \`config.log' for more details" "$LINENO" 5; }
+    fi
+  fi
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $cross_compiling" >&5
+$as_echo "$cross_compiling" >&6; }
+
+rm -f conftest.$ac_ext conftest$ac_cv_exeext conftest.out
+ac_clean_files=$ac_clean_files_save
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for suffix of object files" >&5
 $as_echo_n "checking for suffix of object files... " >&6; }
-if test "${ac_cv_objext+set}" = set; then :
+if ${ac_cv_objext+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -3593,8 +3522,8 @@
 
 { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "cannot compute suffix of object files: cannot compile
-See \`config.log' for more details." "$LINENO" 5; }
+as_fn_error $? "cannot compute suffix of object files: cannot compile
+See \`config.log' for more details" "$LINENO" 5; }
 fi
 rm -f conftest.$ac_cv_objext conftest.$ac_ext
 fi
@@ -3604,7 +3533,7 @@
 ac_objext=$OBJEXT
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C compiler" >&5
 $as_echo_n "checking whether we are using the GNU C compiler... " >&6; }
-if test "${ac_cv_c_compiler_gnu+set}" = set; then :
+if ${ac_cv_c_compiler_gnu+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -3641,7 +3570,7 @@
 ac_save_CFLAGS=$CFLAGS
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC accepts -g" >&5
 $as_echo_n "checking whether $CC accepts -g... " >&6; }
-if test "${ac_cv_prog_cc_g+set}" = set; then :
+if ${ac_cv_prog_cc_g+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_save_c_werror_flag=$ac_c_werror_flag
@@ -3719,7 +3648,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $CC option to accept ISO C89" >&5
 $as_echo_n "checking for $CC option to accept ISO C89... " >&6; }
-if test "${ac_cv_prog_cc_c89+set}" = set; then :
+if ${ac_cv_prog_cc_c89+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_cv_prog_cc_c89=no
@@ -3728,8 +3657,7 @@
 /* end confdefs.h.  */
 #include <stdarg.h>
 #include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+struct stat;
 /* Most of the following tests are stolen from RCS 5.7's src/conf.sh.  */
 struct buf { int x; };
 FILE * (*rcsopen) (struct buf *, struct stat *, int);
@@ -3865,6 +3793,7 @@
 if test "x$enable_dependency_tracking" != xno; then
   am_depcomp="$ac_aux_dir/depcomp"
   AMDEPBACKSLASH='\'
+  am__nodep='_no'
 fi
  if test "x$enable_dependency_tracking" != xno; then
   AMDEP_TRUE=
@@ -3880,7 +3809,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking dependency style of $depcc" >&5
 $as_echo_n "checking dependency style of $depcc... " >&6; }
-if test "${am_cv_CC_dependencies_compiler_type+set}" = set; then :
+if ${am_cv_CC_dependencies_compiler_type+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -z "$AMDEP_TRUE" && test -f "$am_depcomp"; then
@@ -3889,6 +3818,7 @@
   # instance it was reported that on HP-UX the gcc test will end up
   # making a dummy file named `D' -- because `-MD' means `put the output
   # in D'.
+  rm -rf conftest.dir
   mkdir conftest.dir
   # Copy depcomp to subdir because otherwise we won't find it if we're
   # using a relative directory.
@@ -3948,7 +3878,7 @@
 	break
       fi
       ;;
-    msvisualcpp | msvcmsys)
+    msvc7 | msvc7msys | msvisualcpp | msvcmsys)
       # This compiler won't grok `-c -o', but also, the minuso test has
       # not run yet.  These depmodes are late enough in the game, and
       # so weak that their functioning should not be impacted.
@@ -4019,7 +3949,7 @@
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_CXX+set}" = set; then :
+if ${ac_cv_prog_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$CXX"; then
@@ -4031,7 +3961,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_CXX="$ac_tool_prefix$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -4063,7 +3993,7 @@
 set dummy $ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_CXX+set}" = set; then :
+if ${ac_cv_prog_ac_ct_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_CXX"; then
@@ -4075,7 +4005,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_CXX="$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -4133,15 +4063,15 @@
 ... rest of stderr output deleted ...
          10q' conftest.err >conftest.er1
     cat conftest.er1 >&5
-    rm -f conftest.er1 conftest.err
   fi
+  rm -f conftest.er1 conftest.err
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }
 done
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C++ compiler" >&5
 $as_echo_n "checking whether we are using the GNU C++ compiler... " >&6; }
-if test "${ac_cv_cxx_compiler_gnu+set}" = set; then :
+if ${ac_cv_cxx_compiler_gnu+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -4178,7 +4108,7 @@
 ac_save_CXXFLAGS=$CXXFLAGS
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CXX accepts -g" >&5
 $as_echo_n "checking whether $CXX accepts -g... " >&6; }
-if test "${ac_cv_prog_cxx_g+set}" = set; then :
+if ${ac_cv_prog_cxx_g+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_save_cxx_werror_flag=$ac_cxx_werror_flag
@@ -4264,7 +4194,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking dependency style of $depcc" >&5
 $as_echo_n "checking dependency style of $depcc... " >&6; }
-if test "${am_cv_CXX_dependencies_compiler_type+set}" = set; then :
+if ${am_cv_CXX_dependencies_compiler_type+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -z "$AMDEP_TRUE" && test -f "$am_depcomp"; then
@@ -4273,6 +4203,7 @@
   # instance it was reported that on HP-UX the gcc test will end up
   # making a dummy file named `D' -- because `-MD' means `put the output
   # in D'.
+  rm -rf conftest.dir
   mkdir conftest.dir
   # Copy depcomp to subdir because otherwise we won't find it if we're
   # using a relative directory.
@@ -4332,7 +4263,7 @@
 	break
       fi
       ;;
-    msvisualcpp | msvcmsys)
+    msvc7 | msvc7msys | msvisualcpp | msvcmsys)
       # This compiler won't grok `-c -o', but also, the minuso test has
       # not run yet.  These depmodes are late enough in the game, and
       # so weak that their functioning should not be impacted.
@@ -4392,7 +4323,7 @@
 set dummy ${ac_tool_prefix}ranlib; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_RANLIB+set}" = set; then :
+if ${ac_cv_prog_RANLIB+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$RANLIB"; then
@@ -4404,7 +4335,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_RANLIB="${ac_tool_prefix}ranlib"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -4432,7 +4363,7 @@
 set dummy ranlib; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_RANLIB+set}" = set; then :
+if ${ac_cv_prog_ac_ct_RANLIB+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_RANLIB"; then
@@ -4444,7 +4375,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_RANLIB="ranlib"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -4487,8 +4418,8 @@
 
 
 
-macro_version='2.2.6'
-macro_revision='1.3012'
+macro_version='2.4.2'
+macro_revision='1.3337'
 
 
 
@@ -4504,9 +4435,78 @@
 
 ltmain="$ac_aux_dir/ltmain.sh"
 
+# Backslashify metacharacters that are still active within
+# double-quoted strings.
+sed_quote_subst='s/\(["`$\\]\)/\\\1/g'
+
+# Same as above, but do not quote variable references.
+double_quote_subst='s/\(["`\\]\)/\\\1/g'
+
+# Sed substitution to delay expansion of an escaped shell variable in a
+# double_quote_subst'ed string.
+delay_variable_subst='s/\\\\\\\\\\\$/\\\\\\$/g'
+
+# Sed substitution to delay expansion of an escaped single quote.
+delay_single_quote_subst='s/'\''/'\'\\\\\\\'\''/g'
+
+# Sed substitution to avoid accidental globbing in evaled expressions
+no_glob_subst='s/\*/\\\*/g'
+
+ECHO='\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\'
+ECHO=$ECHO$ECHO$ECHO$ECHO$ECHO
+ECHO=$ECHO$ECHO$ECHO$ECHO$ECHO$ECHO
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to print strings" >&5
+$as_echo_n "checking how to print strings... " >&6; }
+# Test print first, because it will be a builtin if present.
+if test "X`( print -r -- -n ) 2>/dev/null`" = X-n && \
+   test "X`print -r -- $ECHO 2>/dev/null`" = "X$ECHO"; then
+  ECHO='print -r --'
+elif test "X`printf %s $ECHO 2>/dev/null`" = "X$ECHO"; then
+  ECHO='printf %s\n'
+else
+  # Use this function as a fallback that always works.
+  func_fallback_echo ()
+  {
+    eval 'cat <<_LTECHO_EOF
+$1
+_LTECHO_EOF'
+  }
+  ECHO='func_fallback_echo'
+fi
+
+# func_echo_all arg...
+# Invoke $ECHO with all args, space-separated.
+func_echo_all ()
+{
+    $ECHO ""
+}
+
+case "$ECHO" in
+  printf*) { $as_echo "$as_me:${as_lineno-$LINENO}: result: printf" >&5
+$as_echo "printf" >&6; } ;;
+  print*) { $as_echo "$as_me:${as_lineno-$LINENO}: result: print -r" >&5
+$as_echo "print -r" >&6; } ;;
+  *) { $as_echo "$as_me:${as_lineno-$LINENO}: result: cat" >&5
+$as_echo "cat" >&6; } ;;
+esac
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for a sed that does not truncate output" >&5
 $as_echo_n "checking for a sed that does not truncate output... " >&6; }
-if test "${ac_cv_path_SED+set}" = set; then :
+if ${ac_cv_path_SED+:} false; then :
   $as_echo_n "(cached) " >&6
 else
             ac_script=s/aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb/
@@ -4526,7 +4526,7 @@
     for ac_prog in sed gsed; do
     for ac_exec_ext in '' $ac_executable_extensions; do
       ac_path_SED="$as_dir/$ac_prog$ac_exec_ext"
-      { test -f "$ac_path_SED" && $as_test_x "$ac_path_SED"; } || continue
+      as_fn_executable_p "$ac_path_SED" || continue
 # Check for GNU ac_path_SED and select it if it is found.
   # Check for GNU $ac_path_SED
 case `"$ac_path_SED" --version 2>&1` in
@@ -4561,7 +4561,7 @@
   done
 IFS=$as_save_IFS
   if test -z "$ac_cv_path_SED"; then
-    as_fn_error "no acceptable sed could be found in \$PATH" "$LINENO" 5
+    as_fn_error $? "no acceptable sed could be found in \$PATH" "$LINENO" 5
   fi
 else
   ac_cv_path_SED=$SED
@@ -4588,7 +4588,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for grep that handles long lines and -e" >&5
 $as_echo_n "checking for grep that handles long lines and -e... " >&6; }
-if test "${ac_cv_path_GREP+set}" = set; then :
+if ${ac_cv_path_GREP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -z "$GREP"; then
@@ -4602,7 +4602,7 @@
     for ac_prog in grep ggrep; do
     for ac_exec_ext in '' $ac_executable_extensions; do
       ac_path_GREP="$as_dir/$ac_prog$ac_exec_ext"
-      { test -f "$ac_path_GREP" && $as_test_x "$ac_path_GREP"; } || continue
+      as_fn_executable_p "$ac_path_GREP" || continue
 # Check for GNU ac_path_GREP and select it if it is found.
   # Check for GNU $ac_path_GREP
 case `"$ac_path_GREP" --version 2>&1` in
@@ -4637,7 +4637,7 @@
   done
 IFS=$as_save_IFS
   if test -z "$ac_cv_path_GREP"; then
-    as_fn_error "no acceptable grep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
+    as_fn_error $? "no acceptable grep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
   fi
 else
   ac_cv_path_GREP=$GREP
@@ -4651,7 +4651,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for egrep" >&5
 $as_echo_n "checking for egrep... " >&6; }
-if test "${ac_cv_path_EGREP+set}" = set; then :
+if ${ac_cv_path_EGREP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if echo a | $GREP -E '(a|b)' >/dev/null 2>&1
@@ -4668,7 +4668,7 @@
     for ac_prog in egrep; do
     for ac_exec_ext in '' $ac_executable_extensions; do
       ac_path_EGREP="$as_dir/$ac_prog$ac_exec_ext"
-      { test -f "$ac_path_EGREP" && $as_test_x "$ac_path_EGREP"; } || continue
+      as_fn_executable_p "$ac_path_EGREP" || continue
 # Check for GNU ac_path_EGREP and select it if it is found.
   # Check for GNU $ac_path_EGREP
 case `"$ac_path_EGREP" --version 2>&1` in
@@ -4703,7 +4703,7 @@
   done
 IFS=$as_save_IFS
   if test -z "$ac_cv_path_EGREP"; then
-    as_fn_error "no acceptable egrep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
+    as_fn_error $? "no acceptable egrep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
   fi
 else
   ac_cv_path_EGREP=$EGREP
@@ -4718,7 +4718,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for fgrep" >&5
 $as_echo_n "checking for fgrep... " >&6; }
-if test "${ac_cv_path_FGREP+set}" = set; then :
+if ${ac_cv_path_FGREP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if echo 'ab*c' | $GREP -F 'ab*c' >/dev/null 2>&1
@@ -4735,7 +4735,7 @@
     for ac_prog in fgrep; do
     for ac_exec_ext in '' $ac_executable_extensions; do
       ac_path_FGREP="$as_dir/$ac_prog$ac_exec_ext"
-      { test -f "$ac_path_FGREP" && $as_test_x "$ac_path_FGREP"; } || continue
+      as_fn_executable_p "$ac_path_FGREP" || continue
 # Check for GNU ac_path_FGREP and select it if it is found.
   # Check for GNU $ac_path_FGREP
 case `"$ac_path_FGREP" --version 2>&1` in
@@ -4770,7 +4770,7 @@
   done
 IFS=$as_save_IFS
   if test -z "$ac_cv_path_FGREP"; then
-    as_fn_error "no acceptable fgrep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
+    as_fn_error $? "no acceptable fgrep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
   fi
 else
   ac_cv_path_FGREP=$FGREP
@@ -4849,7 +4849,7 @@
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for non-GNU ld" >&5
 $as_echo_n "checking for non-GNU ld... " >&6; }
 fi
-if test "${lt_cv_path_LD+set}" = set; then :
+if ${lt_cv_path_LD+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -z "$LD"; then
@@ -4886,10 +4886,10 @@
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
 $as_echo "no" >&6; }
 fi
-test -z "$LD" && as_fn_error "no acceptable ld found in \$PATH" "$LINENO" 5
+test -z "$LD" && as_fn_error $? "no acceptable ld found in \$PATH" "$LINENO" 5
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking if the linker ($LD) is GNU ld" >&5
 $as_echo_n "checking if the linker ($LD) is GNU ld... " >&6; }
-if test "${lt_cv_prog_gnu_ld+set}" = set; then :
+if ${lt_cv_prog_gnu_ld+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   # I'd rather use --version here, but apparently some GNU lds only accept -v.
@@ -4916,7 +4916,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for BSD- or MS-compatible name lister (nm)" >&5
 $as_echo_n "checking for BSD- or MS-compatible name lister (nm)... " >&6; }
-if test "${lt_cv_path_NM+set}" = set; then :
+if ${lt_cv_path_NM+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$NM"; then
@@ -4969,14 +4969,17 @@
   NM="$lt_cv_path_NM"
 else
   # Didn't find any BSD compatible name lister, look for dumpbin.
-  if test -n "$ac_tool_prefix"; then
-  for ac_prog in "dumpbin -symbols" "link -dump -symbols"
+  if test -n "$DUMPBIN"; then :
+    # Let the user override the test.
+  else
+    if test -n "$ac_tool_prefix"; then
+  for ac_prog in dumpbin "link -dump"
   do
     # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_DUMPBIN+set}" = set; then :
+if ${ac_cv_prog_DUMPBIN+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$DUMPBIN"; then
@@ -4988,7 +4991,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_DUMPBIN="$ac_tool_prefix$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5014,13 +5017,13 @@
 fi
 if test -z "$DUMPBIN"; then
   ac_ct_DUMPBIN=$DUMPBIN
-  for ac_prog in "dumpbin -symbols" "link -dump -symbols"
+  for ac_prog in dumpbin "link -dump"
 do
   # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_DUMPBIN+set}" = set; then :
+if ${ac_cv_prog_ac_ct_DUMPBIN+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_DUMPBIN"; then
@@ -5032,7 +5035,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_DUMPBIN="$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5069,6 +5072,15 @@
   fi
 fi
 
+    case `$DUMPBIN -symbols /dev/null 2>&1 | sed '1q'` in
+    *COFF*)
+      DUMPBIN="$DUMPBIN -symbols"
+      ;;
+    *)
+      DUMPBIN=:
+      ;;
+    esac
+  fi
 
   if test "$DUMPBIN" != ":"; then
     NM="$DUMPBIN"
@@ -5083,18 +5095,18 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking the name lister ($NM) interface" >&5
 $as_echo_n "checking the name lister ($NM) interface... " >&6; }
-if test "${lt_cv_nm_interface+set}" = set; then :
+if ${lt_cv_nm_interface+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_nm_interface="BSD nm"
   echo "int some_variable = 0;" > conftest.$ac_ext
-  (eval echo "\"\$as_me:5091: $ac_compile\"" >&5)
+  (eval echo "\"\$as_me:$LINENO: $ac_compile\"" >&5)
   (eval "$ac_compile" 2>conftest.err)
   cat conftest.err >&5
-  (eval echo "\"\$as_me:5094: $NM \\\"conftest.$ac_objext\\\"\"" >&5)
+  (eval echo "\"\$as_me:$LINENO: $NM \\\"conftest.$ac_objext\\\"\"" >&5)
   (eval "$NM \"conftest.$ac_objext\"" 2>conftest.err > conftest.out)
   cat conftest.err >&5
-  (eval echo "\"\$as_me:5097: output\"" >&5)
+  (eval echo "\"\$as_me:$LINENO: output\"" >&5)
   cat conftest.out >&5
   if $GREP 'External.*some_variable' conftest.out > /dev/null; then
     lt_cv_nm_interface="MS dumpbin"
@@ -5118,7 +5130,7 @@
 # find the maximum length of command line arguments
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking the maximum length of command line arguments" >&5
 $as_echo_n "checking the maximum length of command line arguments... " >&6; }
-if test "${lt_cv_sys_max_cmd_len+set}" = set; then :
+if ${lt_cv_sys_max_cmd_len+:} false; then :
   $as_echo_n "(cached) " >&6
 else
     i=0
@@ -5151,6 +5163,11 @@
     lt_cv_sys_max_cmd_len=8192;
     ;;
 
+  mint*)
+    # On MiNT this can take a long time and run out of memory.
+    lt_cv_sys_max_cmd_len=8192;
+    ;;
+
   amigaos*)
     # On AmigaOS with pdksh, this test takes hours, literally.
     # So we just punt and use a minimum line length of 8192.
@@ -5176,6 +5193,11 @@
     lt_cv_sys_max_cmd_len=196608
     ;;
 
+  os2*)
+    # The test takes a long time on OS/2.
+    lt_cv_sys_max_cmd_len=8192
+    ;;
+
   osf*)
     # Dr. Hans Ekkehard Plesser reports seeing a kernel panic running configure
     # due to this test when exec_disable_arg_limit is 1 on Tru64. It is not
@@ -5215,8 +5237,8 @@
       # If test is not a shell built-in, we'll probably end up computing a
       # maximum length that is only half of the actual maximum length, but
       # we can't tell.
-      while { test "X"`$SHELL $0 --fallback-echo "X$teststring$teststring" 2>/dev/null` \
-	         = "XX$teststring$teststring"; } >/dev/null 2>&1 &&
+      while { test "X"`env echo "$teststring$teststring" 2>/dev/null` \
+	         = "X$teststring$teststring"; } >/dev/null 2>&1 &&
 	      test $i != 17 # 1/2 MB should be enough
       do
         i=`expr $i + 1`
@@ -5258,8 +5280,8 @@
 # Try some XSI features
 xsi_shell=no
 ( _lt_dummy="a/b/c"
-  test "${_lt_dummy##*/},${_lt_dummy%/*},"${_lt_dummy%"$_lt_dummy"}, \
-      = c,a/b,, \
+  test "${_lt_dummy##*/},${_lt_dummy%/*},${_lt_dummy#??}"${_lt_dummy%"$_lt_dummy"}, \
+      = c,a/b,b/c, \
     && eval 'test $(( 1 + 1 )) -eq 2 \
     && test "${#_lt_dummy}" -eq 5' ) >/dev/null 2>&1 \
   && xsi_shell=yes
@@ -5308,9 +5330,83 @@
 
 
 
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to convert $build file names to $host format" >&5
+$as_echo_n "checking how to convert $build file names to $host format... " >&6; }
+if ${lt_cv_to_host_file_cmd+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  case $host in
+  *-*-mingw* )
+    case $build in
+      *-*-mingw* ) # actually msys
+        lt_cv_to_host_file_cmd=func_convert_file_msys_to_w32
+        ;;
+      *-*-cygwin* )
+        lt_cv_to_host_file_cmd=func_convert_file_cygwin_to_w32
+        ;;
+      * ) # otherwise, assume *nix
+        lt_cv_to_host_file_cmd=func_convert_file_nix_to_w32
+        ;;
+    esac
+    ;;
+  *-*-cygwin* )
+    case $build in
+      *-*-mingw* ) # actually msys
+        lt_cv_to_host_file_cmd=func_convert_file_msys_to_cygwin
+        ;;
+      *-*-cygwin* )
+        lt_cv_to_host_file_cmd=func_convert_file_noop
+        ;;
+      * ) # otherwise, assume *nix
+        lt_cv_to_host_file_cmd=func_convert_file_nix_to_cygwin
+        ;;
+    esac
+    ;;
+  * ) # unhandled hosts (and "normal" native builds)
+    lt_cv_to_host_file_cmd=func_convert_file_noop
+    ;;
+esac
+
+fi
+
+to_host_file_cmd=$lt_cv_to_host_file_cmd
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_to_host_file_cmd" >&5
+$as_echo "$lt_cv_to_host_file_cmd" >&6; }
+
+
+
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to convert $build file names to toolchain format" >&5
+$as_echo_n "checking how to convert $build file names to toolchain format... " >&6; }
+if ${lt_cv_to_tool_file_cmd+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  #assume ordinary cross tools, or native build.
+lt_cv_to_tool_file_cmd=func_convert_file_noop
+case $host in
+  *-*-mingw* )
+    case $build in
+      *-*-mingw* ) # actually msys
+        lt_cv_to_tool_file_cmd=func_convert_file_msys_to_w32
+        ;;
+    esac
+    ;;
+esac
+
+fi
+
+to_tool_file_cmd=$lt_cv_to_tool_file_cmd
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_to_tool_file_cmd" >&5
+$as_echo "$lt_cv_to_tool_file_cmd" >&6; }
+
+
+
+
+
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $LD option to reload object files" >&5
 $as_echo_n "checking for $LD option to reload object files... " >&6; }
-if test "${lt_cv_ld_reload_flag+set}" = set; then :
+if ${lt_cv_ld_reload_flag+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_ld_reload_flag='-r'
@@ -5324,6 +5420,11 @@
 esac
 reload_cmds='$LD$reload_flag -o $output$reload_objs'
 case $host_os in
+  cygwin* | mingw* | pw32* | cegcc*)
+    if test "$GCC" != yes; then
+      reload_cmds=false
+    fi
+    ;;
   darwin*)
     if test "$GCC" = yes; then
       reload_cmds='$LTCC $LTCFLAGS -nostdlib ${wl}-r -o $output$reload_objs'
@@ -5346,7 +5447,7 @@
 set dummy ${ac_tool_prefix}objdump; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_OBJDUMP+set}" = set; then :
+if ${ac_cv_prog_OBJDUMP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$OBJDUMP"; then
@@ -5358,7 +5459,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_OBJDUMP="${ac_tool_prefix}objdump"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5386,7 +5487,7 @@
 set dummy objdump; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_OBJDUMP+set}" = set; then :
+if ${ac_cv_prog_ac_ct_OBJDUMP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_OBJDUMP"; then
@@ -5398,7 +5499,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_OBJDUMP="objdump"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5445,7 +5546,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking how to recognize dependent libraries" >&5
 $as_echo_n "checking how to recognize dependent libraries... " >&6; }
-if test "${lt_cv_deplibs_check_method+set}" = set; then :
+if ${lt_cv_deplibs_check_method+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_file_magic_cmd='$MAGIC_CMD'
@@ -5487,16 +5588,18 @@
   # Base MSYS/MinGW do not provide the 'file' command needed by
   # func_win32_libid shell function, so use a weaker test based on 'objdump',
   # unless we find 'file', for example because we are cross-compiling.
-  if ( file / ) >/dev/null 2>&1; then
+  # func_win32_libid assumes BSD nm, so disallow it if using MS dumpbin.
+  if ( test "$lt_cv_nm_interface" = "BSD nm" && file / ) >/dev/null 2>&1; then
     lt_cv_deplibs_check_method='file_magic ^x86 archive import|^x86 DLL'
     lt_cv_file_magic_cmd='func_win32_libid'
   else
-    lt_cv_deplibs_check_method='file_magic file format pei*-i386(.*architecture: i386)?'
+    # Keep this pattern in sync with the one in func_win32_libid.
+    lt_cv_deplibs_check_method='file_magic file format (pei*-i386(.*architecture: i386)?|pe-arm-wince|pe-x86-64)'
     lt_cv_file_magic_cmd='$OBJDUMP -f'
   fi
   ;;
 
-cegcc)
+cegcc*)
   # use the weaker test based on 'objdump'. See mingw*.
   lt_cv_deplibs_check_method='file_magic file format pe-arm-.*little(.*architecture: arm)?'
   lt_cv_file_magic_cmd='$OBJDUMP -f'
@@ -5522,7 +5625,7 @@
   fi
   ;;
 
-gnu*)
+haiku*)
   lt_cv_deplibs_check_method=pass_all
   ;;
 
@@ -5534,11 +5637,11 @@
     lt_cv_file_magic_test_file=/usr/lib/hpux32/libc.so
     ;;
   hppa*64*)
-    lt_cv_deplibs_check_method='file_magic (s[0-9][0-9][0-9]|ELF-[0-9][0-9]) shared object file - PA-RISC [0-9].[0-9]'
+    lt_cv_deplibs_check_method='file_magic (s[0-9][0-9][0-9]|ELF[ -][0-9][0-9])(-bit)?( [LM]SB)? shared object( file)?[, -]* PA-RISC [0-9]\.[0-9]'
     lt_cv_file_magic_test_file=/usr/lib/pa20_64/libc.sl
     ;;
   *)
-    lt_cv_deplibs_check_method='file_magic (s[0-9][0-9][0-9]|PA-RISC[0-9].[0-9]) shared library'
+    lt_cv_deplibs_check_method='file_magic (s[0-9][0-9][0-9]|PA-RISC[0-9]\.[0-9]) shared library'
     lt_cv_file_magic_test_file=/usr/lib/libc.sl
     ;;
   esac
@@ -5559,8 +5662,8 @@
   lt_cv_deplibs_check_method=pass_all
   ;;
 
-# This must be Linux ELF.
-linux* | k*bsd*-gnu)
+# This must be glibc/ELF.
+linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
   lt_cv_deplibs_check_method=pass_all
   ;;
 
@@ -5641,6 +5744,21 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_deplibs_check_method" >&5
 $as_echo "$lt_cv_deplibs_check_method" >&6; }
+
+file_magic_glob=
+want_nocaseglob=no
+if test "$build" = "$host"; then
+  case $host_os in
+  mingw* | pw32*)
+    if ( shopt | grep nocaseglob ) >/dev/null 2>&1; then
+      want_nocaseglob=yes
+    else
+      file_magic_glob=`echo aAbBcCdDeEfFgGhHiIjJkKlLmMnNoOpPqQrRsStTuUvVwWxXyYzZ | $SED -e "s/\(..\)/s\/[\1]\/[\1]\/g;/g"`
+    fi
+    ;;
+  esac
+fi
+
 file_magic_cmd=$lt_cv_file_magic_cmd
 deplibs_check_method=$lt_cv_deplibs_check_method
 test -z "$deplibs_check_method" && deplibs_check_method=unknown
@@ -5656,12 +5774,166 @@
 
 
 
-if test -n "$ac_tool_prefix"; then
-  # Extract the first word of "${ac_tool_prefix}ar", so it can be a program name with args.
-set dummy ${ac_tool_prefix}ar; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_AR+set}" = set; then :
+
+
+
+
+
+
+
+
+
+
+if test -n "$ac_tool_prefix"; then
+  # Extract the first word of "${ac_tool_prefix}dlltool", so it can be a program name with args.
+set dummy ${ac_tool_prefix}dlltool; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_DLLTOOL+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$DLLTOOL"; then
+  ac_cv_prog_DLLTOOL="$DLLTOOL" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_DLLTOOL="${ac_tool_prefix}dlltool"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+DLLTOOL=$ac_cv_prog_DLLTOOL
+if test -n "$DLLTOOL"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $DLLTOOL" >&5
+$as_echo "$DLLTOOL" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+fi
+if test -z "$ac_cv_prog_DLLTOOL"; then
+  ac_ct_DLLTOOL=$DLLTOOL
+  # Extract the first word of "dlltool", so it can be a program name with args.
+set dummy dlltool; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_ac_ct_DLLTOOL+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$ac_ct_DLLTOOL"; then
+  ac_cv_prog_ac_ct_DLLTOOL="$ac_ct_DLLTOOL" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_DLLTOOL="dlltool"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+ac_ct_DLLTOOL=$ac_cv_prog_ac_ct_DLLTOOL
+if test -n "$ac_ct_DLLTOOL"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_DLLTOOL" >&5
+$as_echo "$ac_ct_DLLTOOL" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+  if test "x$ac_ct_DLLTOOL" = x; then
+    DLLTOOL="false"
+  else
+    case $cross_compiling:$ac_tool_warned in
+yes:)
+{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+ac_tool_warned=yes ;;
+esac
+    DLLTOOL=$ac_ct_DLLTOOL
+  fi
+else
+  DLLTOOL="$ac_cv_prog_DLLTOOL"
+fi
+
+test -z "$DLLTOOL" && DLLTOOL=dlltool
+
+
+
+
+
+
+
+
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to associate runtime and link libraries" >&5
+$as_echo_n "checking how to associate runtime and link libraries... " >&6; }
+if ${lt_cv_sharedlib_from_linklib_cmd+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_sharedlib_from_linklib_cmd='unknown'
+
+case $host_os in
+cygwin* | mingw* | pw32* | cegcc*)
+  # two different shell functions defined in ltmain.sh
+  # decide which to use based on capabilities of $DLLTOOL
+  case `$DLLTOOL --help 2>&1` in
+  *--identify-strict*)
+    lt_cv_sharedlib_from_linklib_cmd=func_cygming_dll_for_implib
+    ;;
+  *)
+    lt_cv_sharedlib_from_linklib_cmd=func_cygming_dll_for_implib_fallback
+    ;;
+  esac
+  ;;
+*)
+  # fallback: assume linklib IS sharedlib
+  lt_cv_sharedlib_from_linklib_cmd="$ECHO"
+  ;;
+esac
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_sharedlib_from_linklib_cmd" >&5
+$as_echo "$lt_cv_sharedlib_from_linklib_cmd" >&6; }
+sharedlib_from_linklib_cmd=$lt_cv_sharedlib_from_linklib_cmd
+test -z "$sharedlib_from_linklib_cmd" && sharedlib_from_linklib_cmd=$ECHO
+
+
+
+
+
+
+
+
+if test -n "$ac_tool_prefix"; then
+  for ac_prog in ar
+  do
+    # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
+set dummy $ac_tool_prefix$ac_prog; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_AR+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$AR"; then
@@ -5673,8 +5945,8 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
-    ac_cv_prog_AR="${ac_tool_prefix}ar"
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_AR="$ac_tool_prefix$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
   fi
@@ -5694,14 +5966,18 @@
 fi
 
 
+    test -n "$AR" && break
+  done
 fi
-if test -z "$ac_cv_prog_AR"; then
+if test -z "$AR"; then
   ac_ct_AR=$AR
-  # Extract the first word of "ar", so it can be a program name with args.
-set dummy ar; ac_word=$2
+  for ac_prog in ar
+do
+  # Extract the first word of "$ac_prog", so it can be a program name with args.
+set dummy $ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_AR+set}" = set; then :
+if ${ac_cv_prog_ac_ct_AR+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_AR"; then
@@ -5713,8 +5989,8 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
-    ac_cv_prog_ac_ct_AR="ar"
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_AR="$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
   fi
@@ -5733,6 +6009,10 @@
 $as_echo "no" >&6; }
 fi
 
+
+  test -n "$ac_ct_AR" && break
+done
+
   if test "x$ac_ct_AR" = x; then
     AR="false"
   else
@@ -5744,16 +6024,72 @@
 esac
     AR=$ac_ct_AR
   fi
-else
-  AR="$ac_cv_prog_AR"
-fi
-
-test -z "$AR" && AR=ar
-test -z "$AR_FLAGS" && AR_FLAGS=cru
-
-
-
-
+fi
+
+: ${AR=ar}
+: ${AR_FLAGS=cru}
+
+
+
+
+
+
+
+
+
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for archiver @FILE support" >&5
+$as_echo_n "checking for archiver @FILE support... " >&6; }
+if ${lt_cv_ar_at_file+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_ar_at_file=no
+   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  echo conftest.$ac_objext > conftest.lst
+      lt_ar_try='$AR $AR_FLAGS libconftest.a @conftest.lst >&5'
+      { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$lt_ar_try\""; } >&5
+  (eval $lt_ar_try) 2>&5
+  ac_status=$?
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+      if test "$ac_status" -eq 0; then
+	# Ensure the archiver fails upon bogus file names.
+	rm -f conftest.$ac_objext libconftest.a
+	{ { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$lt_ar_try\""; } >&5
+  (eval $lt_ar_try) 2>&5
+  ac_status=$?
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+	if test "$ac_status" -ne 0; then
+          lt_cv_ar_at_file=@
+        fi
+      fi
+      rm -f conftest.* libconftest.a
+
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_ar_at_file" >&5
+$as_echo "$lt_cv_ar_at_file" >&6; }
+
+if test "x$lt_cv_ar_at_file" = xno; then
+  archiver_list_spec=
+else
+  archiver_list_spec=$lt_cv_ar_at_file
+fi
 
 
 
@@ -5766,7 +6102,7 @@
 set dummy ${ac_tool_prefix}strip; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_STRIP+set}" = set; then :
+if ${ac_cv_prog_STRIP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$STRIP"; then
@@ -5778,7 +6114,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_STRIP="${ac_tool_prefix}strip"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5806,7 +6142,7 @@
 set dummy strip; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_STRIP+set}" = set; then :
+if ${ac_cv_prog_ac_ct_STRIP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_STRIP"; then
@@ -5818,7 +6154,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_STRIP="strip"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5865,7 +6201,7 @@
 set dummy ${ac_tool_prefix}ranlib; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_RANLIB+set}" = set; then :
+if ${ac_cv_prog_RANLIB+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$RANLIB"; then
@@ -5877,7 +6213,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_RANLIB="${ac_tool_prefix}ranlib"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5905,7 +6241,7 @@
 set dummy ranlib; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_RANLIB+set}" = set; then :
+if ${ac_cv_prog_ac_ct_RANLIB+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_RANLIB"; then
@@ -5917,7 +6253,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_RANLIB="ranlib"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -5967,15 +6303,27 @@
 if test -n "$RANLIB"; then
   case $host_os in
   openbsd*)
-    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB -t \$oldlib"
+    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB -t \$tool_oldlib"
     ;;
   *)
-    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB \$oldlib"
+    old_postinstall_cmds="$old_postinstall_cmds~\$RANLIB \$tool_oldlib"
     ;;
   esac
-  old_archive_cmds="$old_archive_cmds~\$RANLIB \$oldlib"
+  old_archive_cmds="$old_archive_cmds~\$RANLIB \$tool_oldlib"
 fi
 
+case $host_os in
+  darwin*)
+    lock_old_archive_extraction=yes ;;
+  *)
+    lock_old_archive_extraction=no ;;
+esac
+
+
+
+
+
+
 
 
 
@@ -6022,7 +6370,7 @@
 # Check for command to grab the raw symbol name followed by C symbol from nm.
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking command to parse $NM output from $compiler object" >&5
 $as_echo_n "checking command to parse $NM output from $compiler object... " >&6; }
-if test "${lt_cv_sys_global_symbol_pipe+set}" = set; then :
+if ${lt_cv_sys_global_symbol_pipe+:} false; then :
   $as_echo_n "(cached) " >&6
 else
 
@@ -6083,8 +6431,8 @@
 lt_cv_sys_global_symbol_to_cdecl="sed -n -e 's/^T .* \(.*\)$/extern int \1();/p' -e 's/^$symcode* .* \(.*\)$/extern char \1;/p'"
 
 # Transform an extracted symbol line into symbol name and symbol address
-lt_cv_sys_global_symbol_to_c_name_address="sed -n -e 's/^: \([^ ]*\) $/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([^ ]*\) \([^ ]*\)$/  {\"\2\", (void *) \&\2},/p'"
-lt_cv_sys_global_symbol_to_c_name_address_lib_prefix="sed -n -e 's/^: \([^ ]*\) $/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([^ ]*\) \(lib[^ ]*\)$/  {\"\2\", (void *) \&\2},/p' -e 's/^$symcode* \([^ ]*\) \([^ ]*\)$/  {\"lib\2\", (void *) \&\2},/p'"
+lt_cv_sys_global_symbol_to_c_name_address="sed -n -e 's/^: \([^ ]*\)[ ]*$/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([^ ]*\) \([^ ]*\)$/  {\"\2\", (void *) \&\2},/p'"
+lt_cv_sys_global_symbol_to_c_name_address_lib_prefix="sed -n -e 's/^: \([^ ]*\)[ ]*$/  {\\\"\1\\\", (void *) 0},/p' -e 's/^$symcode* \([^ ]*\) \(lib[^ ]*\)$/  {\"\2\", (void *) \&\2},/p' -e 's/^$symcode* \([^ ]*\) \([^ ]*\)$/  {\"lib\2\", (void *) \&\2},/p'"
 
 # Handle CRLF in mingw tool chain
 opt_cr=
@@ -6108,6 +6456,7 @@
     # which start with @ or ?.
     lt_cv_sys_global_symbol_pipe="$AWK '"\
 "     {last_section=section; section=\$ 3};"\
+"     /^COFF SYMBOL TABLE/{for(i in hide) delete hide[i]};"\
 "     /Section length .*#relocs.*(pick any)/{hide[last_section]=1};"\
 "     \$ 0!~/External *\|/{next};"\
 "     / 0+ UNDEF /{next}; / UNDEF \([^|]\)*()/{next};"\
@@ -6120,6 +6469,7 @@
   else
     lt_cv_sys_global_symbol_pipe="sed -n -e 's/^.*[	 ]\($symcode$symcode*\)[	 ][	 ]*$ac_symprfx$sympat$opt_cr$/$symxfrm/p'"
   fi
+  lt_cv_sys_global_symbol_pipe="$lt_cv_sys_global_symbol_pipe | sed '/ __gnu_lto/d'"
 
   # Check to see that the pipe works correctly.
   pipe_works=no
@@ -6145,8 +6495,8 @@
   test $ac_status = 0; }; then
     # Now try to grab the symbols.
     nlist=conftest.nm
-    if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$NM conftest.$ac_objext \| $lt_cv_sys_global_symbol_pipe \> $nlist\""; } >&5
-  (eval $NM conftest.$ac_objext \| $lt_cv_sys_global_symbol_pipe \> $nlist) 2>&5
+    if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$NM conftest.$ac_objext \| "$lt_cv_sys_global_symbol_pipe" \> $nlist\""; } >&5
+  (eval $NM conftest.$ac_objext \| "$lt_cv_sys_global_symbol_pipe" \> $nlist) 2>&5
   ac_status=$?
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; } && test -s "$nlist"; then
@@ -6161,6 +6511,18 @@
       if $GREP ' nm_test_var$' "$nlist" >/dev/null; then
 	if $GREP ' nm_test_func$' "$nlist" >/dev/null; then
 	  cat <<_LT_EOF > conftest.$ac_ext
+/* Keep this code in sync between libtool.m4, ltmain, lt_system.h, and tests.  */
+#if defined(_WIN32) || defined(__CYGWIN__) || defined(_WIN32_WCE)
+/* DATA imports from DLLs on WIN32 con't be const, because runtime
+   relocations are performed -- see ld's documentation on pseudo-relocs.  */
+# define LT_DLSYM_CONST
+#elif defined(__osf__)
+/* This system does not cope well with relocations in const data.  */
+# define LT_DLSYM_CONST
+#else
+# define LT_DLSYM_CONST const
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -6172,7 +6534,7 @@
 	  cat <<_LT_EOF >> conftest.$ac_ext
 
 /* The mapping between symbol names and symbols.  */
-const struct {
+LT_DLSYM_CONST struct {
   const char *name;
   void       *address;
 }
@@ -6198,8 +6560,8 @@
 _LT_EOF
 	  # Now try linking the two files.
 	  mv conftest.$ac_objext conftstm.$ac_objext
-	  lt_save_LIBS="$LIBS"
-	  lt_save_CFLAGS="$CFLAGS"
+	  lt_globsym_save_LIBS=$LIBS
+	  lt_globsym_save_CFLAGS=$CFLAGS
 	  LIBS="conftstm.$ac_objext"
 	  CFLAGS="$CFLAGS$lt_prog_compiler_no_builtin_flag"
 	  if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_link\""; } >&5
@@ -6209,8 +6571,8 @@
   test $ac_status = 0; } && test -s conftest${ac_exeext}; then
 	    pipe_works=yes
 	  fi
-	  LIBS="$lt_save_LIBS"
-	  CFLAGS="$lt_save_CFLAGS"
+	  LIBS=$lt_globsym_save_LIBS
+	  CFLAGS=$lt_globsym_save_CFLAGS
 	else
 	  echo "cannot find nm_test_func in $nlist" >&5
 	fi
@@ -6247,23 +6609,71 @@
 $as_echo "ok" >&6; }
 fi
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+# Response file support.
+if test "$lt_cv_nm_interface" = "MS dumpbin"; then
+  nm_file_list_spec='@'
+elif $NM --help 2>/dev/null | grep '[@]FILE' >/dev/null; then
+  nm_file_list_spec='@'
+fi
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for sysroot" >&5
+$as_echo_n "checking for sysroot... " >&6; }
+
+# Check whether --with-sysroot was given.
+if test "${with_sysroot+set}" = set; then :
+  withval=$with_sysroot;
+else
+  with_sysroot=no
+fi
+
+
+lt_sysroot=
+case ${with_sysroot} in #(
+ yes)
+   if test "$GCC" = yes; then
+     lt_sysroot=`$CC --print-sysroot 2>/dev/null`
+   fi
+   ;; #(
+ /*)
+   lt_sysroot=`echo "$with_sysroot" | sed -e "$sed_quote_subst"`
+   ;; #(
+ no|'')
+   ;; #(
+ *)
+   { $as_echo "$as_me:${as_lineno-$LINENO}: result: ${with_sysroot}" >&5
+$as_echo "${with_sysroot}" >&6; }
+   as_fn_error $? "The sysroot must be an absolute path." "$LINENO" 5
+   ;;
+esac
+
+ { $as_echo "$as_me:${as_lineno-$LINENO}: result: ${lt_sysroot:-no}" >&5
+$as_echo "${lt_sysroot:-no}" >&6; }
 
 
 
@@ -6300,7 +6710,7 @@
   ;;
 *-*-irix6*)
   # Find out which ABI we are using.
-  echo '#line 6303 "configure"' > conftest.$ac_ext
+  echo '#line '$LINENO' "configure"' > conftest.$ac_ext
   if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_compile\""; } >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
@@ -6394,7 +6804,7 @@
   CFLAGS="$CFLAGS -belf"
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether the C compiler needs -belf" >&5
 $as_echo_n "checking whether the C compiler needs -belf... " >&6; }
-if test "${lt_cv_cc_needs_belf+set}" = set; then :
+if ${lt_cv_cc_needs_belf+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_ext=c
@@ -6435,7 +6845,7 @@
     CFLAGS="$SAVE_CFLAGS"
   fi
   ;;
-sparc*-*solaris*)
+*-*solaris*)
   # Find out which ABI we are using.
   echo 'int i;' > conftest.$ac_ext
   if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_compile\""; } >&5
@@ -6446,7 +6856,20 @@
     case `/usr/bin/file conftest.o` in
     *64-bit*)
       case $lt_cv_prog_gnu_ld in
-      yes*) LD="${LD-ld} -m elf64_sparc" ;;
+      yes*)
+        case $host in
+        i?86-*-solaris*)
+          LD="${LD-ld} -m elf_x86_64"
+          ;;
+        sparc*-*-solaris*)
+          LD="${LD-ld} -m elf64_sparc"
+          ;;
+        esac
+        # GNU ld 2.21 introduced _sol2 emulations.  Use them if available.
+        if ${LD-ld} -V | grep _sol2 >/dev/null 2>&1; then
+          LD="${LD-ld}_sol2"
+        fi
+        ;;
       *)
 	if ${LD-ld} -64 -r -o conftest2.o conftest.o >/dev/null 2>&1; then
 	  LD="${LD-ld} -64"
@@ -6462,6 +6885,123 @@
 
 need_locks="$enable_libtool_lock"
 
+if test -n "$ac_tool_prefix"; then
+  # Extract the first word of "${ac_tool_prefix}mt", so it can be a program name with args.
+set dummy ${ac_tool_prefix}mt; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_MANIFEST_TOOL+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$MANIFEST_TOOL"; then
+  ac_cv_prog_MANIFEST_TOOL="$MANIFEST_TOOL" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_MANIFEST_TOOL="${ac_tool_prefix}mt"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+MANIFEST_TOOL=$ac_cv_prog_MANIFEST_TOOL
+if test -n "$MANIFEST_TOOL"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $MANIFEST_TOOL" >&5
+$as_echo "$MANIFEST_TOOL" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+fi
+if test -z "$ac_cv_prog_MANIFEST_TOOL"; then
+  ac_ct_MANIFEST_TOOL=$MANIFEST_TOOL
+  # Extract the first word of "mt", so it can be a program name with args.
+set dummy mt; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_ac_ct_MANIFEST_TOOL+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$ac_ct_MANIFEST_TOOL"; then
+  ac_cv_prog_ac_ct_MANIFEST_TOOL="$ac_ct_MANIFEST_TOOL" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_MANIFEST_TOOL="mt"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+ac_ct_MANIFEST_TOOL=$ac_cv_prog_ac_ct_MANIFEST_TOOL
+if test -n "$ac_ct_MANIFEST_TOOL"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_MANIFEST_TOOL" >&5
+$as_echo "$ac_ct_MANIFEST_TOOL" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+  if test "x$ac_ct_MANIFEST_TOOL" = x; then
+    MANIFEST_TOOL=":"
+  else
+    case $cross_compiling:$ac_tool_warned in
+yes:)
+{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+ac_tool_warned=yes ;;
+esac
+    MANIFEST_TOOL=$ac_ct_MANIFEST_TOOL
+  fi
+else
+  MANIFEST_TOOL="$ac_cv_prog_MANIFEST_TOOL"
+fi
+
+test -z "$MANIFEST_TOOL" && MANIFEST_TOOL=mt
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking if $MANIFEST_TOOL is a manifest tool" >&5
+$as_echo_n "checking if $MANIFEST_TOOL is a manifest tool... " >&6; }
+if ${lt_cv_path_mainfest_tool+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_path_mainfest_tool=no
+  echo "$as_me:$LINENO: $MANIFEST_TOOL '-?'" >&5
+  $MANIFEST_TOOL '-?' 2>conftest.err > conftest.out
+  cat conftest.err >&5
+  if $GREP 'Manifest Tool' conftest.out > /dev/null; then
+    lt_cv_path_mainfest_tool=yes
+  fi
+  rm -f conftest*
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_path_mainfest_tool" >&5
+$as_echo "$lt_cv_path_mainfest_tool" >&6; }
+if test "x$lt_cv_path_mainfest_tool" != xyes; then
+  MANIFEST_TOOL=:
+fi
+
+
+
+
+
 
   case $host_os in
     rhapsody* | darwin*)
@@ -6470,7 +7010,7 @@
 set dummy ${ac_tool_prefix}dsymutil; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_DSYMUTIL+set}" = set; then :
+if ${ac_cv_prog_DSYMUTIL+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$DSYMUTIL"; then
@@ -6482,7 +7022,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_DSYMUTIL="${ac_tool_prefix}dsymutil"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6510,7 +7050,7 @@
 set dummy dsymutil; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_DSYMUTIL+set}" = set; then :
+if ${ac_cv_prog_ac_ct_DSYMUTIL+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_DSYMUTIL"; then
@@ -6522,7 +7062,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_DSYMUTIL="dsymutil"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6562,7 +7102,7 @@
 set dummy ${ac_tool_prefix}nmedit; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_NMEDIT+set}" = set; then :
+if ${ac_cv_prog_NMEDIT+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$NMEDIT"; then
@@ -6574,7 +7114,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_NMEDIT="${ac_tool_prefix}nmedit"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6602,7 +7142,7 @@
 set dummy nmedit; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_NMEDIT+set}" = set; then :
+if ${ac_cv_prog_ac_ct_NMEDIT+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_NMEDIT"; then
@@ -6614,7 +7154,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_NMEDIT="nmedit"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6654,7 +7194,7 @@
 set dummy ${ac_tool_prefix}lipo; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_LIPO+set}" = set; then :
+if ${ac_cv_prog_LIPO+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$LIPO"; then
@@ -6666,7 +7206,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_LIPO="${ac_tool_prefix}lipo"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6694,7 +7234,7 @@
 set dummy lipo; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_LIPO+set}" = set; then :
+if ${ac_cv_prog_ac_ct_LIPO+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_LIPO"; then
@@ -6706,7 +7246,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_LIPO="lipo"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6746,7 +7286,7 @@
 set dummy ${ac_tool_prefix}otool; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_OTOOL+set}" = set; then :
+if ${ac_cv_prog_OTOOL+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$OTOOL"; then
@@ -6758,7 +7298,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_OTOOL="${ac_tool_prefix}otool"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6786,7 +7326,7 @@
 set dummy otool; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_OTOOL+set}" = set; then :
+if ${ac_cv_prog_ac_ct_OTOOL+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_OTOOL"; then
@@ -6798,7 +7338,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_OTOOL="otool"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6838,7 +7378,7 @@
 set dummy ${ac_tool_prefix}otool64; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_OTOOL64+set}" = set; then :
+if ${ac_cv_prog_OTOOL64+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$OTOOL64"; then
@@ -6850,7 +7390,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_OTOOL64="${ac_tool_prefix}otool64"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6878,7 +7418,7 @@
 set dummy otool64; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_OTOOL64+set}" = set; then :
+if ${ac_cv_prog_ac_ct_OTOOL64+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_OTOOL64"; then
@@ -6890,7 +7430,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_OTOOL64="otool64"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -6953,7 +7493,7 @@
 
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for -single_module linker flag" >&5
 $as_echo_n "checking for -single_module linker flag... " >&6; }
-if test "${lt_cv_apple_cc_single_mod+set}" = set; then :
+if ${lt_cv_apple_cc_single_mod+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_apple_cc_single_mod=no
@@ -6969,7 +7509,13 @@
 	$LTCC $LTCFLAGS $LDFLAGS -o libconftest.dylib \
 	  -dynamiclib -Wl,-single_module conftest.c 2>conftest.err
         _lt_result=$?
-	if test -f libconftest.dylib && test ! -s conftest.err && test $_lt_result = 0; then
+	# If there is a non-empty error log, and "single_module"
+	# appears in it, assume the flag caused a linker warning
+        if test -s conftest.err && $GREP single_module conftest.err; then
+	  cat conftest.err >&5
+	# Otherwise, if the output was created with a 0 exit code from
+	# the compiler, it worked.
+	elif test -f libconftest.dylib && test $_lt_result -eq 0; then
 	  lt_cv_apple_cc_single_mod=yes
 	else
 	  cat conftest.err >&5
@@ -6980,9 +7526,10 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_apple_cc_single_mod" >&5
 $as_echo "$lt_cv_apple_cc_single_mod" >&6; }
+
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for -exported_symbols_list linker flag" >&5
 $as_echo_n "checking for -exported_symbols_list linker flag... " >&6; }
-if test "${lt_cv_ld_exported_symbols_list+set}" = set; then :
+if ${lt_cv_ld_exported_symbols_list+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_ld_exported_symbols_list=no
@@ -7012,6 +7559,41 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_ld_exported_symbols_list" >&5
 $as_echo "$lt_cv_ld_exported_symbols_list" >&6; }
+
+    { $as_echo "$as_me:${as_lineno-$LINENO}: checking for -force_load linker flag" >&5
+$as_echo_n "checking for -force_load linker flag... " >&6; }
+if ${lt_cv_ld_force_load+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_ld_force_load=no
+      cat > conftest.c << _LT_EOF
+int forced_loaded() { return 2;}
+_LT_EOF
+      echo "$LTCC $LTCFLAGS -c -o conftest.o conftest.c" >&5
+      $LTCC $LTCFLAGS -c -o conftest.o conftest.c 2>&5
+      echo "$AR cru libconftest.a conftest.o" >&5
+      $AR cru libconftest.a conftest.o 2>&5
+      echo "$RANLIB libconftest.a" >&5
+      $RANLIB libconftest.a 2>&5
+      cat > conftest.c << _LT_EOF
+int main() { return 0;}
+_LT_EOF
+      echo "$LTCC $LTCFLAGS $LDFLAGS -o conftest conftest.c -Wl,-force_load,./libconftest.a" >&5
+      $LTCC $LTCFLAGS $LDFLAGS -o conftest conftest.c -Wl,-force_load,./libconftest.a 2>conftest.err
+      _lt_result=$?
+      if test -s conftest.err && $GREP force_load conftest.err; then
+	cat conftest.err >&5
+      elif test -f conftest && test $_lt_result -eq 0 && $GREP forced_load conftest >/dev/null 2>&1 ; then
+	lt_cv_ld_force_load=yes
+      else
+	cat conftest.err >&5
+      fi
+        rm -f conftest.err libconftest.a conftest conftest.c
+        rm -rf conftest.dSYM
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_ld_force_load" >&5
+$as_echo "$lt_cv_ld_force_load" >&6; }
     case $host_os in
     rhapsody* | darwin1.[012])
       _lt_dar_allow_undefined='${wl}-undefined ${wl}suppress' ;;
@@ -7039,7 +7621,7 @@
     else
       _lt_dar_export_syms='~$NMEDIT -s $output_objdir/${libname}-symbols.expsym ${lib}'
     fi
-    if test "$DSYMUTIL" != ":"; then
+    if test "$DSYMUTIL" != ":" && test "$lt_cv_ld_force_load" = "no"; then
       _lt_dsymutil='~$DSYMUTIL $lib || :'
     else
       _lt_dsymutil=
@@ -7059,7 +7641,7 @@
   CPP=
 fi
 if test -z "$CPP"; then
-  if test "${ac_cv_prog_CPP+set}" = set; then :
+  if ${ac_cv_prog_CPP+:} false; then :
   $as_echo_n "(cached) " >&6
 else
       # Double quotes because CPP needs to be expanded
@@ -7089,7 +7671,7 @@
   # Broken: fails on valid input.
 continue
 fi
-rm -f conftest.err conftest.$ac_ext
+rm -f conftest.err conftest.i conftest.$ac_ext
 
   # OK, works on sane cases.  Now check whether nonexistent headers
   # can be detected and how.
@@ -7105,11 +7687,11 @@
 ac_preproc_ok=:
 break
 fi
-rm -f conftest.err conftest.$ac_ext
+rm -f conftest.err conftest.i conftest.$ac_ext
 
 done
 # Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
-rm -f conftest.err conftest.$ac_ext
+rm -f conftest.i conftest.err conftest.$ac_ext
 if $ac_preproc_ok; then :
   break
 fi
@@ -7148,7 +7730,7 @@
   # Broken: fails on valid input.
 continue
 fi
-rm -f conftest.err conftest.$ac_ext
+rm -f conftest.err conftest.i conftest.$ac_ext
 
   # OK, works on sane cases.  Now check whether nonexistent headers
   # can be detected and how.
@@ -7164,18 +7746,18 @@
 ac_preproc_ok=:
 break
 fi
-rm -f conftest.err conftest.$ac_ext
+rm -f conftest.err conftest.i conftest.$ac_ext
 
 done
 # Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
-rm -f conftest.err conftest.$ac_ext
+rm -f conftest.i conftest.err conftest.$ac_ext
 if $ac_preproc_ok; then :
 
 else
   { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "C preprocessor \"$CPP\" fails sanity check
-See \`config.log' for more details." "$LINENO" 5; }
+as_fn_error $? "C preprocessor \"$CPP\" fails sanity check
+See \`config.log' for more details" "$LINENO" 5; }
 fi
 
 ac_ext=c
@@ -7187,7 +7769,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for ANSI C header files" >&5
 $as_echo_n "checking for ANSI C header files... " >&6; }
-if test "${ac_cv_header_stdc+set}" = set; then :
+if ${ac_cv_header_stdc+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -7304,8 +7886,7 @@
   as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
 ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default
 "
-eval as_val=\$$as_ac_Header
-   if test "x$as_val" = x""yes; then :
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
   cat >>confdefs.h <<_ACEOF
 #define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
 _ACEOF
@@ -7319,7 +7900,7 @@
 do :
   ac_fn_c_check_header_compile "$LINENO" "dlfcn.h" "ac_cv_header_dlfcn_h" "$ac_includes_default
 "
-if test "x$ac_cv_header_dlfcn_h" = x""yes; then :
+if test "x$ac_cv_header_dlfcn_h" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_DLFCN_H 1
 _ACEOF
@@ -7330,528 +7911,14 @@
 
 
 
-ac_ext=cpp
-ac_cpp='$CXXCPP $CPPFLAGS'
-ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
-ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
-if test -z "$CXX"; then
-  if test -n "$CCC"; then
-    CXX=$CCC
-  else
-    if test -n "$ac_tool_prefix"; then
-  for ac_prog in g++ c++ gpp aCC CC cxx cc++ cl.exe FCC KCC RCC xlC_r xlC
-  do
-    # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
-set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_CXX+set}" = set; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$CXX"; then
-  ac_cv_prog_CXX="$CXX" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
-    ac_cv_prog_CXX="$ac_tool_prefix$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
-
-fi
-fi
-CXX=$ac_cv_prog_CXX
-if test -n "$CXX"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CXX" >&5
-$as_echo "$CXX" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
-
-
-    test -n "$CXX" && break
-  done
-fi
-if test -z "$CXX"; then
-  ac_ct_CXX=$CXX
-  for ac_prog in g++ c++ gpp aCC CC cxx cc++ cl.exe FCC KCC RCC xlC_r xlC
-do
-  # Extract the first word of "$ac_prog", so it can be a program name with args.
-set dummy $ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_CXX+set}" = set; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$ac_ct_CXX"; then
-  ac_cv_prog_ac_ct_CXX="$ac_ct_CXX" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
-    ac_cv_prog_ac_ct_CXX="$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
-
-fi
-fi
-ac_ct_CXX=$ac_cv_prog_ac_ct_CXX
-if test -n "$ac_ct_CXX"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CXX" >&5
-$as_echo "$ac_ct_CXX" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
-
-
-  test -n "$ac_ct_CXX" && break
-done
-
-  if test "x$ac_ct_CXX" = x; then
-    CXX="g++"
-  else
-    case $cross_compiling:$ac_tool_warned in
-yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
-ac_tool_warned=yes ;;
-esac
-    CXX=$ac_ct_CXX
-  fi
-fi
-
-  fi
-fi
-# Provide some information about the compiler.
-$as_echo "$as_me:${as_lineno-$LINENO}: checking for C++ compiler version" >&5
-set X $ac_compile
-ac_compiler=$2
-for ac_option in --version -v -V -qversion; do
-  { { ac_try="$ac_compiler $ac_option >&5"
-case "(($ac_try" in
-  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
-  *) ac_try_echo=$ac_try;;
-esac
-eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
-  (eval "$ac_compiler $ac_option >&5") 2>conftest.err
-  ac_status=$?
-  if test -s conftest.err; then
-    sed '10a\
-... rest of stderr output deleted ...
-         10q' conftest.err >conftest.er1
-    cat conftest.er1 >&5
-    rm -f conftest.er1 conftest.err
-  fi
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; }
-done
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C++ compiler" >&5
-$as_echo_n "checking whether we are using the GNU C++ compiler... " >&6; }
-if test "${ac_cv_cxx_compiler_gnu+set}" = set; then :
-  $as_echo_n "(cached) " >&6
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-#ifndef __GNUC__
-       choke me
-#endif
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
-  ac_compiler_gnu=yes
-else
-  ac_compiler_gnu=no
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-ac_cv_cxx_compiler_gnu=$ac_compiler_gnu
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_cxx_compiler_gnu" >&5
-$as_echo "$ac_cv_cxx_compiler_gnu" >&6; }
-if test $ac_compiler_gnu = yes; then
-  GXX=yes
-else
-  GXX=
-fi
-ac_test_CXXFLAGS=${CXXFLAGS+set}
-ac_save_CXXFLAGS=$CXXFLAGS
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CXX accepts -g" >&5
-$as_echo_n "checking whether $CXX accepts -g... " >&6; }
-if test "${ac_cv_prog_cxx_g+set}" = set; then :
-  $as_echo_n "(cached) " >&6
-else
-  ac_save_cxx_werror_flag=$ac_cxx_werror_flag
-   ac_cxx_werror_flag=yes
-   ac_cv_prog_cxx_g=no
-   CXXFLAGS="-g"
-   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
-  ac_cv_prog_cxx_g=yes
-else
-  CXXFLAGS=""
-      cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
-
-else
-  ac_cxx_werror_flag=$ac_save_cxx_werror_flag
-	 CXXFLAGS="-g"
-	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_cxx_try_compile "$LINENO"; then :
-  ac_cv_prog_cxx_g=yes
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-   ac_cxx_werror_flag=$ac_save_cxx_werror_flag
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_prog_cxx_g" >&5
-$as_echo "$ac_cv_prog_cxx_g" >&6; }
-if test "$ac_test_CXXFLAGS" = set; then
-  CXXFLAGS=$ac_save_CXXFLAGS
-elif test $ac_cv_prog_cxx_g = yes; then
-  if test "$GXX" = yes; then
-    CXXFLAGS="-g -O2"
-  else
-    CXXFLAGS="-g"
-  fi
-else
-  if test "$GXX" = yes; then
-    CXXFLAGS="-O2"
-  else
-    CXXFLAGS=
-  fi
-fi
-ac_ext=c
-ac_cpp='$CPP $CPPFLAGS'
-ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
-ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
-
-depcc="$CXX"  am_compiler_list=
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking dependency style of $depcc" >&5
-$as_echo_n "checking dependency style of $depcc... " >&6; }
-if test "${am_cv_CXX_dependencies_compiler_type+set}" = set; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -z "$AMDEP_TRUE" && test -f "$am_depcomp"; then
-  # We make a subdir and do the tests there.  Otherwise we can end up
-  # making bogus files that we don't know about and never remove.  For
-  # instance it was reported that on HP-UX the gcc test will end up
-  # making a dummy file named `D' -- because `-MD' means `put the output
-  # in D'.
-  mkdir conftest.dir
-  # Copy depcomp to subdir because otherwise we won't find it if we're
-  # using a relative directory.
-  cp "$am_depcomp" conftest.dir
-  cd conftest.dir
-  # We will build objects and dependencies in a subdirectory because
-  # it helps to detect inapplicable dependency modes.  For instance
-  # both Tru64's cc and ICC support -MD to output dependencies as a
-  # side effect of compilation, but ICC will put the dependencies in
-  # the current directory while Tru64 will put them in the object
-  # directory.
-  mkdir sub
-
-  am_cv_CXX_dependencies_compiler_type=none
-  if test "$am_compiler_list" = ""; then
-     am_compiler_list=`sed -n 's/^#*\([a-zA-Z0-9]*\))$/\1/p' < ./depcomp`
-  fi
-  am__universal=false
-  case " $depcc " in #(
-     *\ -arch\ *\ -arch\ *) am__universal=true ;;
-     esac
-
-  for depmode in $am_compiler_list; do
-    # Setup a source with many dependencies, because some compilers
-    # like to wrap large dependency lists on column 80 (with \), and
-    # we should not choose a depcomp mode which is confused by this.
-    #
-    # We need to recreate these files for each test, as the compiler may
-    # overwrite some of them when testing with obscure command lines.
-    # This happens at least with the AIX C compiler.
-    : > sub/conftest.c
-    for i in 1 2 3 4 5 6; do
-      echo '#include "conftst'$i'.h"' >> sub/conftest.c
-      # Using `: > sub/conftst$i.h' creates only sub/conftst1.h with
-      # Solaris 8's {/usr,}/bin/sh.
-      touch sub/conftst$i.h
-    done
-    echo "${am__include} ${am__quote}sub/conftest.Po${am__quote}" > confmf
-
-    # We check with `-c' and `-o' for the sake of the "dashmstdout"
-    # mode.  It turns out that the SunPro C++ compiler does not properly
-    # handle `-M -o', and we need to detect this.  Also, some Intel
-    # versions had trouble with output in subdirs
-    am__obj=sub/conftest.${OBJEXT-o}
-    am__minus_obj="-o $am__obj"
-    case $depmode in
-    gcc)
-      # This depmode causes a compiler race in universal mode.
-      test "$am__universal" = false || continue
-      ;;
-    nosideeffect)
-      # after this tag, mechanisms are not by side-effect, so they'll
-      # only be used when explicitly requested
-      if test "x$enable_dependency_tracking" = xyes; then
-	continue
-      else
-	break
-      fi
-      ;;
-    msvisualcpp | msvcmsys)
-      # This compiler won't grok `-c -o', but also, the minuso test has
-      # not run yet.  These depmodes are late enough in the game, and
-      # so weak that their functioning should not be impacted.
-      am__obj=conftest.${OBJEXT-o}
-      am__minus_obj=
-      ;;
-    none) break ;;
-    esac
-    if depmode=$depmode \
-       source=sub/conftest.c object=$am__obj \
-       depfile=sub/conftest.Po tmpdepfile=sub/conftest.TPo \
-       $SHELL ./depcomp $depcc -c $am__minus_obj sub/conftest.c \
-         >/dev/null 2>conftest.err &&
-       grep sub/conftst1.h sub/conftest.Po > /dev/null 2>&1 &&
-       grep sub/conftst6.h sub/conftest.Po > /dev/null 2>&1 &&
-       grep $am__obj sub/conftest.Po > /dev/null 2>&1 &&
-       ${MAKE-make} -s -f confmf > /dev/null 2>&1; then
-      # icc doesn't choke on unknown options, it will just issue warnings
-      # or remarks (even with -Werror).  So we grep stderr for any message
-      # that says an option was ignored or not supported.
-      # When given -MP, icc 7.0 and 7.1 complain thusly:
-      #   icc: Command line warning: ignoring option '-M'; no argument required
-      # The diagnosis changed in icc 8.0:
-      #   icc: Command line remark: option '-MP' not supported
-      if (grep 'ignoring option' conftest.err ||
-          grep 'not supported' conftest.err) >/dev/null 2>&1; then :; else
-        am_cv_CXX_dependencies_compiler_type=$depmode
-        break
-      fi
-    fi
-  done
-
-  cd ..
-  rm -rf conftest.dir
-else
-  am_cv_CXX_dependencies_compiler_type=none
-fi
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $am_cv_CXX_dependencies_compiler_type" >&5
-$as_echo "$am_cv_CXX_dependencies_compiler_type" >&6; }
-CXXDEPMODE=depmode=$am_cv_CXX_dependencies_compiler_type
-
- if
-  test "x$enable_dependency_tracking" != xno \
-  && test "$am_cv_CXX_dependencies_compiler_type" = gcc3; then
-  am__fastdepCXX_TRUE=
-  am__fastdepCXX_FALSE='#'
-else
-  am__fastdepCXX_TRUE='#'
-  am__fastdepCXX_FALSE=
-fi
-
-
-if test -n "$CXX" && ( test "X$CXX" != "Xno" &&
-    ( (test "X$CXX" = "Xg++" && `g++ -v >/dev/null 2>&1` ) ||
-    (test "X$CXX" != "Xg++"))) ; then
-  ac_ext=cpp
-ac_cpp='$CXXCPP $CPPFLAGS'
-ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
-ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to run the C++ preprocessor" >&5
-$as_echo_n "checking how to run the C++ preprocessor... " >&6; }
-if test -z "$CXXCPP"; then
-  if test "${ac_cv_prog_CXXCPP+set}" = set; then :
-  $as_echo_n "(cached) " >&6
-else
-      # Double quotes because CXXCPP needs to be expanded
-    for CXXCPP in "$CXX -E" "/lib/cpp"
-    do
-      ac_preproc_ok=false
-for ac_cxx_preproc_warn_flag in '' yes
-do
-  # Use a header file that comes with gcc, so configuring glibc
-  # with a fresh cross-compiler works.
-  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-  # <limits.h> exists even on freestanding compilers.
-  # On the NeXT, cc -E runs the code through the compiler's parser,
-  # not just through cpp. "Syntax error" is here to catch this case.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
-		     Syntax error
-_ACEOF
-if ac_fn_cxx_try_cpp "$LINENO"; then :
-
-else
-  # Broken: fails on valid input.
-continue
-fi
-rm -f conftest.err conftest.$ac_ext
-
-  # OK, works on sane cases.  Now check whether nonexistent headers
-  # can be detected and how.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <ac_nonexistent.h>
-_ACEOF
-if ac_fn_cxx_try_cpp "$LINENO"; then :
-  # Broken: success on invalid input.
-continue
-else
-  # Passes both tests.
-ac_preproc_ok=:
-break
-fi
-rm -f conftest.err conftest.$ac_ext
-
-done
-# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
-rm -f conftest.err conftest.$ac_ext
-if $ac_preproc_ok; then :
-  break
-fi
-
-    done
-    ac_cv_prog_CXXCPP=$CXXCPP
-
-fi
-  CXXCPP=$ac_cv_prog_CXXCPP
-else
-  ac_cv_prog_CXXCPP=$CXXCPP
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $CXXCPP" >&5
-$as_echo "$CXXCPP" >&6; }
-ac_preproc_ok=false
-for ac_cxx_preproc_warn_flag in '' yes
-do
-  # Use a header file that comes with gcc, so configuring glibc
-  # with a fresh cross-compiler works.
-  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-  # <limits.h> exists even on freestanding compilers.
-  # On the NeXT, cc -E runs the code through the compiler's parser,
-  # not just through cpp. "Syntax error" is here to catch this case.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
-		     Syntax error
-_ACEOF
-if ac_fn_cxx_try_cpp "$LINENO"; then :
-
-else
-  # Broken: fails on valid input.
-continue
-fi
-rm -f conftest.err conftest.$ac_ext
-
-  # OK, works on sane cases.  Now check whether nonexistent headers
-  # can be detected and how.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <ac_nonexistent.h>
-_ACEOF
-if ac_fn_cxx_try_cpp "$LINENO"; then :
-  # Broken: success on invalid input.
-continue
-else
-  # Passes both tests.
-ac_preproc_ok=:
-break
-fi
-rm -f conftest.err conftest.$ac_ext
-
-done
-# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
-rm -f conftest.err conftest.$ac_ext
-if $ac_preproc_ok; then :
-
-else
-  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-_lt_caught_CXX_error=yes; }
-fi
-
-ac_ext=c
-ac_cpp='$CPP $CPPFLAGS'
-ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
-ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
-
-else
-  _lt_caught_CXX_error=yes
-fi
+
+func_stripname_cnf ()
+{
+  case ${2} in
+  .*) func_stripname_result=`$ECHO "${3}" | $SED "s%^${1}%%; s%\\\\${2}\$%%"`;;
+  *)  func_stripname_result=`$ECHO "${3}" | $SED "s%^${1}%%; s%${2}\$%%"`;;
+  esac
+} # func_stripname_cnf
 
 
 
@@ -7932,7 +7999,22 @@
 
 # Check whether --with-pic was given.
 if test "${with_pic+set}" = set; then :
-  withval=$with_pic; pic_mode="$withval"
+  withval=$with_pic; lt_p=${PACKAGE-default}
+    case $withval in
+    yes|no) pic_mode=$withval ;;
+    *)
+      pic_mode=default
+      # Look at the argument we got.  We use all the common list separators.
+      lt_save_ifs="$IFS"; IFS="${IFS}$PATH_SEPARATOR,"
+      for lt_pkg in $withval; do
+	IFS="$lt_save_ifs"
+	if test "X$lt_pkg" = "X$lt_p"; then
+	  pic_mode=yes
+	fi
+      done
+      IFS="$lt_save_ifs"
+      ;;
+    esac
 else
   pic_mode=default
 fi
@@ -8009,6 +8091,11 @@
 
 
 
+
+
+
+
+
 test -z "$LN_S" && LN_S="ln -s"
 
 
@@ -8030,7 +8117,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for objdir" >&5
 $as_echo_n "checking for objdir... " >&6; }
-if test "${lt_cv_objdir+set}" = set; then :
+if ${lt_cv_objdir+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   rm -f .libs 2>/dev/null
@@ -8058,19 +8145,6 @@
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
 case $host_os in
 aix3*)
   # AIX sometimes has problems with the GCC collect2 program.  For some
@@ -8083,23 +8157,6 @@
   ;;
 esac
 
-# Sed substitution that helps us do robust quoting.  It backslashifies
-# metacharacters that are still active within double-quoted strings.
-sed_quote_subst='s/\(["`$\\]\)/\\\1/g'
-
-# Same as above, but do not quote variable references.
-double_quote_subst='s/\(["`\\]\)/\\\1/g'
-
-# Sed substitution to delay expansion of an escaped shell variable in a
-# double_quote_subst'ed string.
-delay_variable_subst='s/\\\\\\\\\\\$/\\\\\\$/g'
-
-# Sed substitution to delay expansion of an escaped single quote.
-delay_single_quote_subst='s/'\''/'\'\\\\\\\'\''/g'
-
-# Sed substitution to avoid accidental globbing in evaled expressions
-no_glob_subst='s/\*/\\\*/g'
-
 # Global variables:
 ofile=libtool
 can_build_shared=yes
@@ -8128,7 +8185,7 @@
     *) break;;
   esac
 done
-cc_basename=`$ECHO "X$cc_temp" | $Xsed -e 's%.*/%%' -e "s%^$host_alias-%%"`
+cc_basename=`$ECHO "$cc_temp" | $SED "s%.*/%%; s%^$host_alias-%%"`
 
 
 # Only perform the check for file, if the check method requires it
@@ -8138,7 +8195,7 @@
   if test "$file_magic_cmd" = '$MAGIC_CMD'; then
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for ${ac_tool_prefix}file" >&5
 $as_echo_n "checking for ${ac_tool_prefix}file... " >&6; }
-if test "${lt_cv_path_MAGIC_CMD+set}" = set; then :
+if ${lt_cv_path_MAGIC_CMD+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   case $MAGIC_CMD in
@@ -8204,7 +8261,7 @@
   if test -n "$ac_tool_prefix"; then
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for file" >&5
 $as_echo_n "checking for file... " >&6; }
-if test "${lt_cv_path_MAGIC_CMD+set}" = set; then :
+if ${lt_cv_path_MAGIC_CMD+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   case $MAGIC_CMD in
@@ -8333,11 +8390,16 @@
 lt_prog_compiler_no_builtin_flag=
 
 if test "$GCC" = yes; then
-  lt_prog_compiler_no_builtin_flag=' -fno-builtin'
+  case $cc_basename in
+  nvcc*)
+    lt_prog_compiler_no_builtin_flag=' -Xcompiler -fno-builtin' ;;
+  *)
+    lt_prog_compiler_no_builtin_flag=' -fno-builtin' ;;
+  esac
 
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler supports -fno-rtti -fno-exceptions" >&5
 $as_echo_n "checking if $compiler supports -fno-rtti -fno-exceptions... " >&6; }
-if test "${lt_cv_prog_compiler_rtti_exceptions+set}" = set; then :
+if ${lt_cv_prog_compiler_rtti_exceptions+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_rtti_exceptions=no
@@ -8353,15 +8415,15 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [^ ]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:8356: $lt_compile\"" >&5)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&5)
    (eval "$lt_compile" 2>conftest.err)
    ac_status=$?
    cat conftest.err >&5
-   echo "$as_me:8360: \$? = $ac_status" >&5
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
    if (exit $ac_status) && test -s "$ac_outfile"; then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings other than the usual output.
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' >conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' >conftest.exp
      $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
      if test ! -s conftest.er2 || diff conftest.exp conftest.er2 >/dev/null; then
        lt_cv_prog_compiler_rtti_exceptions=yes
@@ -8390,8 +8452,6 @@
 lt_prog_compiler_pic=
 lt_prog_compiler_static=
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $compiler option to produce PIC" >&5
-$as_echo_n "checking for $compiler option to produce PIC... " >&6; }
 
   if test "$GCC" = yes; then
     lt_prog_compiler_wl='-Wl,'
@@ -8439,6 +8499,12 @@
       lt_prog_compiler_pic='-fno-common'
       ;;
 
+    haiku*)
+      # PIC is the default for Haiku.
+      # The "-static" flag exists, but is broken.
+      lt_prog_compiler_static=
+      ;;
+
     hpux*)
       # PIC is the default for 64-bit PA HP-UX, but not for 32-bit
       # PA HP-UX.  On IA64 HP-UX, PIC is the default but the pic flag
@@ -8481,6 +8547,15 @@
       lt_prog_compiler_pic='-fPIC'
       ;;
     esac
+
+    case $cc_basename in
+    nvcc*) # Cuda Compiler Driver 2.2
+      lt_prog_compiler_wl='-Xlinker '
+      if test -n "$lt_prog_compiler_pic"; then
+        lt_prog_compiler_pic="-Xcompiler $lt_prog_compiler_pic"
+      fi
+      ;;
+    esac
   else
     # PORTME Check for flag to pass linker flags through the system compiler.
     case $host_os in
@@ -8522,7 +8597,7 @@
       lt_prog_compiler_static='-non_shared'
       ;;
 
-    linux* | k*bsd*-gnu)
+    linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
       case $cc_basename in
       # old Intel for x86_64 which still supported -KPIC.
       ecc*)
@@ -8543,7 +8618,13 @@
 	lt_prog_compiler_pic='--shared'
 	lt_prog_compiler_static='--static'
 	;;
-      pgcc* | pgf77* | pgf90* | pgf95*)
+      nagfor*)
+	# NAG Fortran compiler
+	lt_prog_compiler_wl='-Wl,-Wl,,'
+	lt_prog_compiler_pic='-PIC'
+	lt_prog_compiler_static='-Bstatic'
+	;;
+      pgcc* | pgf77* | pgf90* | pgf95* | pgfortran*)
         # Portland Group compilers (*not* the Pentium gcc compiler,
 	# which looks to be a dead project)
 	lt_prog_compiler_wl='-Wl,'
@@ -8555,25 +8636,40 @@
         # All Alpha code is PIC.
         lt_prog_compiler_static='-non_shared'
         ;;
-      xl*)
-	# IBM XL C 8.0/Fortran 10.1 on PPC
+      xl* | bgxl* | bgf* | mpixl*)
+	# IBM XL C 8.0/Fortran 10.1, 11.1 on PPC and BlueGene
 	lt_prog_compiler_wl='-Wl,'
 	lt_prog_compiler_pic='-qpic'
 	lt_prog_compiler_static='-qstaticlink'
 	;;
       *)
 	case `$CC -V 2>&1 | sed 5q` in
+	*Sun\ Ceres\ Fortran* | *Sun*Fortran*\ [1-7].* | *Sun*Fortran*\ 8.[0-3]*)
+	  # Sun Fortran 8.3 passes all unrecognized flags to the linker
+	  lt_prog_compiler_pic='-KPIC'
+	  lt_prog_compiler_static='-Bstatic'
+	  lt_prog_compiler_wl=''
+	  ;;
+	*Sun\ F* | *Sun*Fortran*)
+	  lt_prog_compiler_pic='-KPIC'
+	  lt_prog_compiler_static='-Bstatic'
+	  lt_prog_compiler_wl='-Qoption ld '
+	  ;;
 	*Sun\ C*)
 	  # Sun C 5.9
 	  lt_prog_compiler_pic='-KPIC'
 	  lt_prog_compiler_static='-Bstatic'
 	  lt_prog_compiler_wl='-Wl,'
 	  ;;
-	*Sun\ F*)
-	  # Sun Fortran 8.3 passes all unrecognized flags to the linker
-	  lt_prog_compiler_pic='-KPIC'
+        *Intel*\ [CF]*Compiler*)
+	  lt_prog_compiler_wl='-Wl,'
+	  lt_prog_compiler_pic='-fPIC'
+	  lt_prog_compiler_static='-static'
+	  ;;
+	*Portland\ Group*)
+	  lt_prog_compiler_wl='-Wl,'
+	  lt_prog_compiler_pic='-fpic'
 	  lt_prog_compiler_static='-Bstatic'
-	  lt_prog_compiler_wl=''
 	  ;;
 	esac
 	;;
@@ -8605,7 +8701,7 @@
       lt_prog_compiler_pic='-KPIC'
       lt_prog_compiler_static='-Bstatic'
       case $cc_basename in
-      f77* | f90* | f95*)
+      f77* | f90* | f95* | sunf77* | sunf90* | sunf95*)
 	lt_prog_compiler_wl='-Qoption ld ';;
       *)
 	lt_prog_compiler_wl='-Wl,';;
@@ -8662,13 +8758,17 @@
     lt_prog_compiler_pic="$lt_prog_compiler_pic -DPIC"
     ;;
 esac
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_prog_compiler_pic" >&5
-$as_echo "$lt_prog_compiler_pic" >&6; }
-
-
-
-
-
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $compiler option to produce PIC" >&5
+$as_echo_n "checking for $compiler option to produce PIC... " >&6; }
+if ${lt_cv_prog_compiler_pic+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_prog_compiler_pic=$lt_prog_compiler_pic
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_prog_compiler_pic" >&5
+$as_echo "$lt_cv_prog_compiler_pic" >&6; }
+lt_prog_compiler_pic=$lt_cv_prog_compiler_pic
 
 #
 # Check to make sure the PIC flag actually works.
@@ -8676,7 +8776,7 @@
 if test -n "$lt_prog_compiler_pic"; then
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler PIC flag $lt_prog_compiler_pic works" >&5
 $as_echo_n "checking if $compiler PIC flag $lt_prog_compiler_pic works... " >&6; }
-if test "${lt_cv_prog_compiler_pic_works+set}" = set; then :
+if ${lt_cv_prog_compiler_pic_works+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_pic_works=no
@@ -8692,15 +8792,15 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [^ ]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:8695: $lt_compile\"" >&5)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&5)
    (eval "$lt_compile" 2>conftest.err)
    ac_status=$?
    cat conftest.err >&5
-   echo "$as_me:8699: \$? = $ac_status" >&5
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
    if (exit $ac_status) && test -s "$ac_outfile"; then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings other than the usual output.
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' >conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' >conftest.exp
      $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
      if test ! -s conftest.er2 || diff conftest.exp conftest.er2 >/dev/null; then
        lt_cv_prog_compiler_pic_works=yes
@@ -8729,13 +8829,18 @@
 
 
 
+
+
+
+
+
 #
 # Check to make sure the static flag actually works.
 #
 wl=$lt_prog_compiler_wl eval lt_tmp_static_flag=\"$lt_prog_compiler_static\"
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler static flag $lt_tmp_static_flag works" >&5
 $as_echo_n "checking if $compiler static flag $lt_tmp_static_flag works... " >&6; }
-if test "${lt_cv_prog_compiler_static_works+set}" = set; then :
+if ${lt_cv_prog_compiler_static_works+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_static_works=no
@@ -8748,7 +8853,7 @@
      if test -s conftest.err; then
        # Append any errors to the config.log.
        cat conftest.err 1>&5
-       $ECHO "X$_lt_linker_boilerplate" | $Xsed -e '/^$/d' > conftest.exp
+       $ECHO "$_lt_linker_boilerplate" | $SED '/^$/d' > conftest.exp
        $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
        if diff conftest.exp conftest.er2 >/dev/null; then
          lt_cv_prog_compiler_static_works=yes
@@ -8778,7 +8883,7 @@
 
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler supports -c -o file.$ac_objext" >&5
 $as_echo_n "checking if $compiler supports -c -o file.$ac_objext... " >&6; }
-if test "${lt_cv_prog_compiler_c_o+set}" = set; then :
+if ${lt_cv_prog_compiler_c_o+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_c_o=no
@@ -8797,16 +8902,16 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [^ ]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:8800: $lt_compile\"" >&5)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&5)
    (eval "$lt_compile" 2>out/conftest.err)
    ac_status=$?
    cat out/conftest.err >&5
-   echo "$as_me:8804: \$? = $ac_status" >&5
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
    if (exit $ac_status) && test -s out/conftest2.$ac_objext
    then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' > out/conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' > out/conftest.exp
      $SED '/^$/d; /^ *+/d' out/conftest.err >out/conftest.er2
      if test ! -s out/conftest.er2 || diff out/conftest.exp out/conftest.er2 >/dev/null; then
        lt_cv_prog_compiler_c_o=yes
@@ -8833,7 +8938,7 @@
 
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler supports -c -o file.$ac_objext" >&5
 $as_echo_n "checking if $compiler supports -c -o file.$ac_objext... " >&6; }
-if test "${lt_cv_prog_compiler_c_o+set}" = set; then :
+if ${lt_cv_prog_compiler_c_o+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_c_o=no
@@ -8852,16 +8957,16 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [^ ]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:8855: $lt_compile\"" >&5)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&5)
    (eval "$lt_compile" 2>out/conftest.err)
    ac_status=$?
    cat out/conftest.err >&5
-   echo "$as_me:8859: \$? = $ac_status" >&5
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
    if (exit $ac_status) && test -s out/conftest2.$ac_objext
    then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' > out/conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' > out/conftest.exp
      $SED '/^$/d; /^ *+/d' out/conftest.err >out/conftest.er2
      if test ! -s out/conftest.er2 || diff out/conftest.exp out/conftest.er2 >/dev/null; then
        lt_cv_prog_compiler_c_o=yes
@@ -8927,7 +9032,6 @@
   hardcode_direct=no
   hardcode_direct_absolute=no
   hardcode_libdir_flag_spec=
-  hardcode_libdir_flag_spec_ld=
   hardcode_libdir_separator=
   hardcode_minus_L=no
   hardcode_shlibpath_var=unsupported
@@ -8971,13 +9075,39 @@
   openbsd*)
     with_gnu_ld=no
     ;;
-  linux* | k*bsd*-gnu)
+  linux* | k*bsd*-gnu | gnu*)
     link_all_deplibs=no
     ;;
   esac
 
   ld_shlibs=yes
+
+  # On some targets, GNU ld is compatible enough with the native linker
+  # that we're better off using the native interface for both.
+  lt_use_gnu_ld_interface=no
   if test "$with_gnu_ld" = yes; then
+    case $host_os in
+      aix*)
+	# The AIX port of GNU ld has always aspired to compatibility
+	# with the native linker.  However, as the warning in the GNU ld
+	# block says, versions before 2.19.5* couldn't really create working
+	# shared libraries, regardless of the interface used.
+	case `$LD -v 2>&1` in
+	  *\ \(GNU\ Binutils\)\ 2.19.5*) ;;
+	  *\ \(GNU\ Binutils\)\ 2.[2-9]*) ;;
+	  *\ \(GNU\ Binutils\)\ [3-9]*) ;;
+	  *)
+	    lt_use_gnu_ld_interface=yes
+	    ;;
+	esac
+	;;
+      *)
+	lt_use_gnu_ld_interface=yes
+	;;
+    esac
+  fi
+
+  if test "$lt_use_gnu_ld_interface" = yes; then
     # If archive_cmds runs LD, not CC, wlarc should be empty
     wlarc='${wl}'
 
@@ -8995,6 +9125,7 @@
     fi
     supports_anon_versioning=no
     case `$LD -v 2>&1` in
+      *GNU\ gold*) supports_anon_versioning=yes ;;
       *\ [01].* | *\ 2.[0-9].* | *\ 2.10.*) ;; # catch versions < 2.11
       *\ 2.11.93.0.2\ *) supports_anon_versioning=yes ;; # RH7.3 ...
       *\ 2.11.92.0.12\ *) supports_anon_versioning=yes ;; # Mandrake 8.2 ...
@@ -9010,11 +9141,12 @@
 	ld_shlibs=no
 	cat <<_LT_EOF 1>&2
 
-*** Warning: the GNU linker, at least up to release 2.9.1, is reported
+*** Warning: the GNU linker, at least up to release 2.19, is reported
 *** to be unable to reliably create shared libraries on AIX.
 *** Therefore, libtool is disabling shared libraries support.  If you
-*** really care for shared libraries, you may want to modify your PATH
-*** so that a non-GNU linker is found, and then restart.
+*** really care for shared libraries, you may want to install binutils
+*** 2.20 or above, or modify your PATH so that a non-GNU linker is found.
+*** You will then need to restart the configuration process.
 
 _LT_EOF
       fi
@@ -9050,10 +9182,12 @@
       # _LT_TAGVAR(hardcode_libdir_flag_spec, ) is actually meaningless,
       # as there is no search path for DLLs.
       hardcode_libdir_flag_spec='-L$libdir'
+      export_dynamic_flag_spec='${wl}--export-all-symbols'
       allow_undefined_flag=unsupported
       always_export_symbols=no
       enable_shared_with_static_runtimes=yes
-      export_symbols_cmds='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[BCDGRS][ ]/s/.*[ ]\([^ ]*\)/\1 DATA/'\'' | $SED -e '\''/^[AITW][ ]/s/.*[ ]//'\'' | sort | uniq > $export_symbols'
+      export_symbols_cmds='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[BCDGRS][ ]/s/.*[ ]\([^ ]*\)/\1 DATA/;s/^.*[ ]__nm__\([^ ]*\)[ ][^ ]*/\1 DATA/;/^I[ ]/d;/^[AITW][ ]/s/.* //'\'' | sort | uniq > $export_symbols'
+      exclude_expsyms='[_]+GLOBAL_OFFSET_TABLE_|[_]+GLOBAL__[FID]_.*|[_]+head_[A-Za-z0-9_]+_dll|[A-Za-z0-9_]+_dll_iname'
 
       if $LD --help 2>&1 | $GREP 'auto-import' > /dev/null; then
         archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
@@ -9071,6 +9205,11 @@
       fi
       ;;
 
+    haiku*)
+      archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+      link_all_deplibs=yes
+      ;;
+
     interix[3-9]*)
       hardcode_direct=no
       hardcode_shlibpath_var=no
@@ -9086,7 +9225,7 @@
       archive_expsym_cmds='sed "s,^,_," $export_symbols >$output_objdir/$soname.expsym~$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-h,$soname ${wl}--retain-symbols-file,$output_objdir/$soname.expsym ${wl}--image-base,`expr ${RANDOM-$$} % 4096 / 2 \* 262144 + 1342177280` -o $lib'
       ;;
 
-    gnu* | linux* | tpf* | k*bsd*-gnu)
+    gnu* | linux* | tpf* | k*bsd*-gnu | kopensolaris*-gnu)
       tmp_diet=no
       if test "$host_os" = linux-dietlibc; then
 	case $cc_basename in
@@ -9096,15 +9235,16 @@
       if $LD --help 2>&1 | $EGREP ': supported targets:.* elf' > /dev/null \
 	 && test "$tmp_diet" = no
       then
-	tmp_addflag=
+	tmp_addflag=' $pic_flag'
 	tmp_sharedflag='-shared'
 	case $cc_basename,$host_cpu in
         pgcc*)				# Portland Group C compiler
-	  whole_archive_flag_spec='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	  whole_archive_flag_spec='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	  tmp_addflag=' $pic_flag'
 	  ;;
-	pgf77* | pgf90* | pgf95*)	# Portland Group f77 and f90 compilers
-	  whole_archive_flag_spec='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	pgf77* | pgf90* | pgf95* | pgfortran*)
+					# Portland Group f77 and f90 compilers
+	  whole_archive_flag_spec='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	  tmp_addflag=' $pic_flag -Mnomain' ;;
 	ecc*,ia64* | icc*,ia64*)	# Intel C compiler on ia64
 	  tmp_addflag=' -i_dynamic' ;;
@@ -9115,13 +9255,17 @@
 	lf95*)				# Lahey Fortran 8.1
 	  whole_archive_flag_spec=
 	  tmp_sharedflag='--shared' ;;
-	xl[cC]*)			# IBM XL C 8.0 on PPC (deal with xlf below)
+	xl[cC]* | bgxl[cC]* | mpixl[cC]*) # IBM XL C 8.0 on PPC (deal with xlf below)
 	  tmp_sharedflag='-qmkshrobj'
 	  tmp_addflag= ;;
+	nvcc*)	# Cuda Compiler Driver 2.2
+	  whole_archive_flag_spec='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
+	  compiler_needs_object=yes
+	  ;;
 	esac
 	case `$CC -V 2>&1 | sed 5q` in
 	*Sun\ C*)			# Sun C 5.9
-	  whole_archive_flag_spec='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	  whole_archive_flag_spec='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	  compiler_needs_object=yes
 	  tmp_sharedflag='-G' ;;
 	*Sun\ F*)			# Sun Fortran 8.3
@@ -9137,17 +9281,16 @@
         fi
 
 	case $cc_basename in
-	xlf*)
+	xlf* | bgf* | bgxlf* | mpixlf*)
 	  # IBM XL Fortran 10.1 on PPC cannot create shared libs itself
 	  whole_archive_flag_spec='--whole-archive$convenience --no-whole-archive'
-	  hardcode_libdir_flag_spec=
-	  hardcode_libdir_flag_spec_ld='-rpath $libdir'
-	  archive_cmds='$LD -shared $libobjs $deplibs $compiler_flags -soname $soname -o $lib'
+	  hardcode_libdir_flag_spec='${wl}-rpath ${wl}$libdir'
+	  archive_cmds='$LD -shared $libobjs $deplibs $linker_flags -soname $soname -o $lib'
 	  if test "x$supports_anon_versioning" = xyes; then
 	    archive_expsym_cmds='echo "{ global:" > $output_objdir/$libname.ver~
 	      cat $export_symbols | sed -e "s/\(.*\)/\1;/" >> $output_objdir/$libname.ver~
 	      echo "local: *; };" >> $output_objdir/$libname.ver~
-	      $LD -shared $libobjs $deplibs $compiler_flags -soname $soname -version-script $output_objdir/$libname.ver -o $lib'
+	      $LD -shared $libobjs $deplibs $linker_flags -soname $soname -version-script $output_objdir/$libname.ver -o $lib'
 	  fi
 	  ;;
 	esac
@@ -9161,8 +9304,8 @@
 	archive_cmds='$LD -Bshareable $libobjs $deplibs $linker_flags -o $lib'
 	wlarc=
       else
-	archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
-	archive_expsym_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+	archive_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+	archive_expsym_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
       fi
       ;;
 
@@ -9180,8 +9323,8 @@
 
 _LT_EOF
       elif $LD --help 2>&1 | $GREP ': supported targets:.* elf' > /dev/null; then
-	archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
-	archive_expsym_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+	archive_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+	archive_expsym_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
       else
 	ld_shlibs=no
       fi
@@ -9227,8 +9370,8 @@
 
     *)
       if $LD --help 2>&1 | $GREP ': supported targets:.* elf' > /dev/null; then
-	archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
-	archive_expsym_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+	archive_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+	archive_expsym_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
       else
 	ld_shlibs=no
       fi
@@ -9268,8 +9411,10 @@
       else
 	# If we're using GNU nm, then we don't want the "-C" option.
 	# -C means demangle to AIX nm, but means don't demangle with GNU nm
+	# Also, AIX nm treats weak defined symbols like other global
+	# defined symbols, whereas GNU nm marks them as "W".
 	if $NM -V 2>&1 | $GREP 'GNU' > /dev/null; then
-	  export_symbols_cmds='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && (substr(\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
+	  export_symbols_cmds='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B") || (\$ 2 == "W")) && (substr(\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
 	else
 	  export_symbols_cmds='$NM -BCpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && (substr(\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
 	fi
@@ -9357,7 +9502,13 @@
 	allow_undefined_flag='-berok'
         # Determine the default libpath from the value encoded in an
         # empty executable.
-        cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+        if test "${lt_cv_aix_libpath+set}" = set; then
+  aix_libpath=$lt_cv_aix_libpath
+else
+  if ${lt_cv_aix_libpath_+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -9370,25 +9521,32 @@
 _ACEOF
 if ac_fn_c_try_link "$LINENO"; then :
 
-lt_aix_libpath_sed='
-    /Import File Strings/,/^$/ {
-	/^0/ {
-	    s/^0  *\(.*\)$/\1/
-	    p
-	}
-    }'
-aix_libpath=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-# Check for a 64-bit object if we didn't find anything.
-if test -z "$aix_libpath"; then
-  aix_libpath=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-fi
+  lt_aix_libpath_sed='
+      /Import File Strings/,/^$/ {
+	  /^0/ {
+	      s/^0  *\([^ ]*\) *$/\1/
+	      p
+	  }
+      }'
+  lt_cv_aix_libpath_=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  # Check for a 64-bit object if we didn't find anything.
+  if test -z "$lt_cv_aix_libpath_"; then
+    lt_cv_aix_libpath_=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  fi
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-if test -z "$aix_libpath"; then aix_libpath="/usr/lib:/lib"; fi
+  if test -z "$lt_cv_aix_libpath_"; then
+    lt_cv_aix_libpath_="/usr/lib:/lib"
+  fi
+
+fi
+
+  aix_libpath=$lt_cv_aix_libpath_
+fi
 
         hardcode_libdir_flag_spec='${wl}-blibpath:$libdir:'"$aix_libpath"
-        archive_expsym_cmds='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then $ECHO "X${wl}${allow_undefined_flag}" | $Xsed; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
+        archive_expsym_cmds='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then func_echo_all "${wl}${allow_undefined_flag}"; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
       else
 	if test "$host_cpu" = ia64; then
 	  hardcode_libdir_flag_spec='${wl}-R $libdir:/usr/lib:/lib'
@@ -9397,7 +9555,13 @@
 	else
 	 # Determine the default libpath from the value encoded in an
 	 # empty executable.
-	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+	 if test "${lt_cv_aix_libpath+set}" = set; then
+  aix_libpath=$lt_cv_aix_libpath
+else
+  if ${lt_cv_aix_libpath_+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -9410,30 +9574,42 @@
 _ACEOF
 if ac_fn_c_try_link "$LINENO"; then :
 
-lt_aix_libpath_sed='
-    /Import File Strings/,/^$/ {
-	/^0/ {
-	    s/^0  *\(.*\)$/\1/
-	    p
-	}
-    }'
-aix_libpath=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-# Check for a 64-bit object if we didn't find anything.
-if test -z "$aix_libpath"; then
-  aix_libpath=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-fi
+  lt_aix_libpath_sed='
+      /Import File Strings/,/^$/ {
+	  /^0/ {
+	      s/^0  *\([^ ]*\) *$/\1/
+	      p
+	  }
+      }'
+  lt_cv_aix_libpath_=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  # Check for a 64-bit object if we didn't find anything.
+  if test -z "$lt_cv_aix_libpath_"; then
+    lt_cv_aix_libpath_=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  fi
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-if test -z "$aix_libpath"; then aix_libpath="/usr/lib:/lib"; fi
+  if test -z "$lt_cv_aix_libpath_"; then
+    lt_cv_aix_libpath_="/usr/lib:/lib"
+  fi
+
+fi
+
+  aix_libpath=$lt_cv_aix_libpath_
+fi
 
 	 hardcode_libdir_flag_spec='${wl}-blibpath:$libdir:'"$aix_libpath"
 	  # Warning - without using the other run time loading flags,
 	  # -berok will link without error, but may produce a broken library.
 	  no_undefined_flag=' ${wl}-bernotok'
 	  allow_undefined_flag=' ${wl}-berok'
-	  # Exported symbols can be pulled into shared objects from archives
-	  whole_archive_flag_spec='$convenience'
+	  if test "$with_gnu_ld" = yes; then
+	    # We only use this code for GNU lds that support --whole-archive.
+	    whole_archive_flag_spec='${wl}--whole-archive$convenience ${wl}--no-whole-archive'
+	  else
+	    # Exported symbols can be pulled into shared objects from archives
+	    whole_archive_flag_spec='$convenience'
+	  fi
 	  archive_cmds_need_lc=yes
 	  # This is similar to how AIX traditionally builds its shared libraries.
 	  archive_expsym_cmds="\$CC $shared_flag"' -o $output_objdir/$soname $libobjs $deplibs ${wl}-bnoentry $compiler_flags ${wl}-bE:$export_symbols${allow_undefined_flag}~$AR $AR_FLAGS $output_objdir/$libname$release.a $output_objdir/$soname'
@@ -9465,20 +9641,64 @@
       # Microsoft Visual C++.
       # hardcode_libdir_flag_spec is actually meaningless, as there is
       # no search path for DLLs.
-      hardcode_libdir_flag_spec=' '
-      allow_undefined_flag=unsupported
-      # Tell ltmain to make .lib files, not .a files.
-      libext=lib
-      # Tell ltmain to make .dll files, not .so files.
-      shrext_cmds=".dll"
-      # FIXME: Setting linknames here is a bad hack.
-      archive_cmds='$CC -o $lib $libobjs $compiler_flags `$ECHO "X$deplibs" | $Xsed -e '\''s/ -lc$//'\''` -link -dll~linknames='
-      # The linker will automatically build a .lib file if we build a DLL.
-      old_archive_from_new_cmds='true'
-      # FIXME: Should let the user specify the lib program.
-      old_archive_cmds='lib -OUT:$oldlib$oldobjs$old_deplibs'
-      fix_srcfile_path='`cygpath -w "$srcfile"`'
-      enable_shared_with_static_runtimes=yes
+      case $cc_basename in
+      cl*)
+	# Native MSVC
+	hardcode_libdir_flag_spec=' '
+	allow_undefined_flag=unsupported
+	always_export_symbols=yes
+	file_list_spec='@'
+	# Tell ltmain to make .lib files, not .a files.
+	libext=lib
+	# Tell ltmain to make .dll files, not .so files.
+	shrext_cmds=".dll"
+	# FIXME: Setting linknames here is a bad hack.
+	archive_cmds='$CC -o $output_objdir/$soname $libobjs $compiler_flags $deplibs -Wl,-dll~linknames='
+	archive_expsym_cmds='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
+	    sed -n -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' -e '1\\\!p' < $export_symbols > $output_objdir/$soname.exp;
+	  else
+	    sed -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' < $export_symbols > $output_objdir/$soname.exp;
+	  fi~
+	  $CC -o $tool_output_objdir$soname $libobjs $compiler_flags $deplibs "@$tool_output_objdir$soname.exp" -Wl,-DLL,-IMPLIB:"$tool_output_objdir$libname.dll.lib"~
+	  linknames='
+	# The linker will not automatically build a static lib if we build a DLL.
+	# _LT_TAGVAR(old_archive_from_new_cmds, )='true'
+	enable_shared_with_static_runtimes=yes
+	exclude_expsyms='_NULL_IMPORT_DESCRIPTOR|_IMPORT_DESCRIPTOR_.*'
+	export_symbols_cmds='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[BCDGRS][ ]/s/.*[ ]\([^ ]*\)/\1,DATA/'\'' | $SED -e '\''/^[AITW][ ]/s/.*[ ]//'\'' | sort | uniq > $export_symbols'
+	# Don't use ranlib
+	old_postinstall_cmds='chmod 644 $oldlib'
+	postlink_cmds='lt_outputfile="@OUTPUT@"~
+	  lt_tool_outputfile="@TOOL_OUTPUT@"~
+	  case $lt_outputfile in
+	    *.exe|*.EXE) ;;
+	    *)
+	      lt_outputfile="$lt_outputfile.exe"
+	      lt_tool_outputfile="$lt_tool_outputfile.exe"
+	      ;;
+	  esac~
+	  if test "$MANIFEST_TOOL" != ":" && test -f "$lt_outputfile.manifest"; then
+	    $MANIFEST_TOOL -manifest "$lt_tool_outputfile.manifest" -outputresource:"$lt_tool_outputfile" || exit 1;
+	    $RM "$lt_outputfile.manifest";
+	  fi'
+	;;
+      *)
+	# Assume MSVC wrapper
+	hardcode_libdir_flag_spec=' '
+	allow_undefined_flag=unsupported
+	# Tell ltmain to make .lib files, not .a files.
+	libext=lib
+	# Tell ltmain to make .dll files, not .so files.
+	shrext_cmds=".dll"
+	# FIXME: Setting linknames here is a bad hack.
+	archive_cmds='$CC -o $lib $libobjs $compiler_flags `func_echo_all "$deplibs" | $SED '\''s/ -lc$//'\''` -link -dll~linknames='
+	# The linker will automatically build a .lib file if we build a DLL.
+	old_archive_from_new_cmds='true'
+	# FIXME: Should let the user specify the lib program.
+	old_archive_cmds='lib -OUT:$oldlib$oldobjs$old_deplibs'
+	enable_shared_with_static_runtimes=yes
+	;;
+      esac
       ;;
 
     darwin* | rhapsody*)
@@ -9488,7 +9708,12 @@
   hardcode_direct=no
   hardcode_automatic=yes
   hardcode_shlibpath_var=unsupported
-  whole_archive_flag_spec=''
+  if test "$lt_cv_ld_force_load" = "yes"; then
+    whole_archive_flag_spec='`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience ${wl}-force_load,$conv\"; done; func_echo_all \"$new_convenience\"`'
+
+  else
+    whole_archive_flag_spec=''
+  fi
   link_all_deplibs=yes
   allow_undefined_flag="$_lt_dar_allow_undefined"
   case $cc_basename in
@@ -9496,7 +9721,7 @@
      *) _lt_dar_can_shared=$GCC ;;
   esac
   if test "$_lt_dar_can_shared" = "yes"; then
-    output_verbose_link_cmd=echo
+    output_verbose_link_cmd=func_echo_all
     archive_cmds="\$CC -dynamiclib \$allow_undefined_flag -o \$lib \$libobjs \$deplibs \$compiler_flags -install_name \$rpath/\$soname \$verstring $_lt_dar_single_mod${_lt_dsymutil}"
     module_cmds="\$CC \$allow_undefined_flag -o \$lib -bundle \$libobjs \$deplibs \$compiler_flags${_lt_dsymutil}"
     archive_expsym_cmds="sed 's,^,_,' < \$export_symbols > \$output_objdir/\${libname}-symbols.expsym~\$CC -dynamiclib \$allow_undefined_flag -o \$lib \$libobjs \$deplibs \$compiler_flags -install_name \$rpath/\$soname \$verstring ${_lt_dar_single_mod}${_lt_dar_export_syms}${_lt_dsymutil}"
@@ -9514,10 +9739,6 @@
       hardcode_shlibpath_var=no
       ;;
 
-    freebsd1*)
-      ld_shlibs=no
-      ;;
-
     # FreeBSD 2.2.[012] allows us to include c++rt0.o to get C++ constructor
     # support.  Future versions do this automatically, but an explicit c++rt0.o
     # does not break anything, and helps significantly (at the cost of a little
@@ -9530,7 +9751,7 @@
       ;;
 
     # Unfortunately, older versions of FreeBSD 2 do not have this feature.
-    freebsd2*)
+    freebsd2.*)
       archive_cmds='$LD -Bshareable -o $lib $libobjs $deplibs $linker_flags'
       hardcode_direct=yes
       hardcode_minus_L=yes
@@ -9539,7 +9760,7 @@
 
     # FreeBSD 3 and greater uses gcc -shared to do shared libraries.
     freebsd* | dragonfly*)
-      archive_cmds='$CC -shared -o $lib $libobjs $deplibs $compiler_flags'
+      archive_cmds='$CC -shared $pic_flag -o $lib $libobjs $deplibs $compiler_flags'
       hardcode_libdir_flag_spec='-R$libdir'
       hardcode_direct=yes
       hardcode_shlibpath_var=no
@@ -9547,7 +9768,7 @@
 
     hpux9*)
       if test "$GCC" = yes; then
-	archive_cmds='$RM $output_objdir/$soname~$CC -shared -fPIC ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $libobjs $deplibs $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
+	archive_cmds='$RM $output_objdir/$soname~$CC -shared $pic_flag ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $libobjs $deplibs $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
       else
 	archive_cmds='$RM $output_objdir/$soname~$LD -b +b $install_libdir -o $output_objdir/$soname $libobjs $deplibs $linker_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
       fi
@@ -9562,14 +9783,13 @@
       ;;
 
     hpux10*)
-      if test "$GCC" = yes -a "$with_gnu_ld" = no; then
-	archive_cmds='$CC -shared -fPIC ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
+      if test "$GCC" = yes && test "$with_gnu_ld" = no; then
+	archive_cmds='$CC -shared $pic_flag ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
       else
 	archive_cmds='$LD -b +h $soname +b $install_libdir -o $lib $libobjs $deplibs $linker_flags'
       fi
       if test "$with_gnu_ld" = no; then
 	hardcode_libdir_flag_spec='${wl}+b ${wl}$libdir'
-	hardcode_libdir_flag_spec_ld='+b $libdir'
 	hardcode_libdir_separator=:
 	hardcode_direct=yes
 	hardcode_direct_absolute=yes
@@ -9581,16 +9801,16 @@
       ;;
 
     hpux11*)
-      if test "$GCC" = yes -a "$with_gnu_ld" = no; then
+      if test "$GCC" = yes && test "$with_gnu_ld" = no; then
 	case $host_cpu in
 	hppa*64*)
 	  archive_cmds='$CC -shared ${wl}+h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	ia64*)
-	  archive_cmds='$CC -shared -fPIC ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $libobjs $deplibs $compiler_flags'
+	  archive_cmds='$CC -shared $pic_flag ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	*)
-	  archive_cmds='$CC -shared -fPIC ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
+	  archive_cmds='$CC -shared $pic_flag ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	esac
       else
@@ -9602,7 +9822,46 @@
 	  archive_cmds='$CC -b ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $libobjs $deplibs $compiler_flags'
 	  ;;
 	*)
-	  archive_cmds='$CC -b ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
+
+	  # Older versions of the 11.00 compiler do not understand -b yet
+	  # (HP92453-01 A.11.01.20 doesn't, HP92453-01 B.11.X.35175-35176.GP does)
+	  { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $CC understands -b" >&5
+$as_echo_n "checking if $CC understands -b... " >&6; }
+if ${lt_cv_prog_compiler__b+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_prog_compiler__b=no
+   save_LDFLAGS="$LDFLAGS"
+   LDFLAGS="$LDFLAGS -b"
+   echo "$lt_simple_link_test_code" > conftest.$ac_ext
+   if (eval $ac_link 2>conftest.err) && test -s conftest$ac_exeext; then
+     # The linker can only warn and ignore the option if not recognized
+     # So say no if there are warnings
+     if test -s conftest.err; then
+       # Append any errors to the config.log.
+       cat conftest.err 1>&5
+       $ECHO "$_lt_linker_boilerplate" | $SED '/^$/d' > conftest.exp
+       $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
+       if diff conftest.exp conftest.er2 >/dev/null; then
+         lt_cv_prog_compiler__b=yes
+       fi
+     else
+       lt_cv_prog_compiler__b=yes
+     fi
+   fi
+   $RM -r conftest*
+   LDFLAGS="$save_LDFLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_prog_compiler__b" >&5
+$as_echo "$lt_cv_prog_compiler__b" >&6; }
+
+if test x"$lt_cv_prog_compiler__b" = xyes; then
+    archive_cmds='$CC -b ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $libobjs $deplibs $compiler_flags'
+else
+    archive_cmds='$LD -b +h $soname +b $install_libdir -o $lib $libobjs $deplibs $linker_flags'
+fi
+
 	  ;;
 	esac
       fi
@@ -9630,26 +9889,39 @@
 
     irix5* | irix6* | nonstopux*)
       if test "$GCC" = yes; then
-	archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	archive_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 	# Try to use the -exported_symbol ld option, if it does not
 	# work, assume that -exports_file does not work either and
 	# implicitly export all symbols.
-        save_LDFLAGS="$LDFLAGS"
-        LDFLAGS="$LDFLAGS -shared ${wl}-exported_symbol ${wl}foo ${wl}-update_registry ${wl}/dev/null"
-        cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+	# This should be the same for all languages, so no per-tag cache variable.
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether the $host_os linker accepts -exported_symbol" >&5
+$as_echo_n "checking whether the $host_os linker accepts -exported_symbol... " >&6; }
+if ${lt_cv_irix_exported_symbol+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  save_LDFLAGS="$LDFLAGS"
+	   LDFLAGS="$LDFLAGS -shared ${wl}-exported_symbol ${wl}foo ${wl}-update_registry ${wl}/dev/null"
+	   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-int foo(void) {}
+int foo (void) { return 0; }
 _ACEOF
 if ac_fn_c_try_link "$LINENO"; then :
-  archive_expsym_cmds='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations ${wl}-exports_file ${wl}$export_symbols -o $lib'
-
+  lt_cv_irix_exported_symbol=yes
+else
+  lt_cv_irix_exported_symbol=no
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-        LDFLAGS="$save_LDFLAGS"
+           LDFLAGS="$save_LDFLAGS"
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_irix_exported_symbol" >&5
+$as_echo "$lt_cv_irix_exported_symbol" >&6; }
+	if test "$lt_cv_irix_exported_symbol" = yes; then
+          archive_expsym_cmds='$CC -shared $pic_flag $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations ${wl}-exports_file ${wl}$export_symbols -o $lib'
+	fi
       else
-	archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
-	archive_expsym_cmds='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -exports_file $export_symbols -o $lib'
+	archive_cmds='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
+	archive_expsym_cmds='$CC -shared $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -exports_file $export_symbols -o $lib'
       fi
       archive_cmds_need_lc='no'
       hardcode_libdir_flag_spec='${wl}-rpath ${wl}$libdir'
@@ -9711,17 +9983,17 @@
       hardcode_libdir_flag_spec='-L$libdir'
       hardcode_minus_L=yes
       allow_undefined_flag=unsupported
-      archive_cmds='$ECHO "LIBRARY $libname INITINSTANCE" > $output_objdir/$libname.def~$ECHO "DESCRIPTION \"$libname\"" >> $output_objdir/$libname.def~$ECHO DATA >> $output_objdir/$libname.def~$ECHO " SINGLE NONSHARED" >> $output_objdir/$libname.def~$ECHO EXPORTS >> $output_objdir/$libname.def~emxexp $libobjs >> $output_objdir/$libname.def~$CC -Zdll -Zcrtdll -o $lib $libobjs $deplibs $compiler_flags $output_objdir/$libname.def'
+      archive_cmds='$ECHO "LIBRARY $libname INITINSTANCE" > $output_objdir/$libname.def~$ECHO "DESCRIPTION \"$libname\"" >> $output_objdir/$libname.def~echo DATA >> $output_objdir/$libname.def~echo " SINGLE NONSHARED" >> $output_objdir/$libname.def~echo EXPORTS >> $output_objdir/$libname.def~emxexp $libobjs >> $output_objdir/$libname.def~$CC -Zdll -Zcrtdll -o $lib $libobjs $deplibs $compiler_flags $output_objdir/$libname.def'
       old_archive_from_new_cmds='emximp -o $output_objdir/$libname.a $output_objdir/$libname.def'
       ;;
 
     osf3*)
       if test "$GCC" = yes; then
 	allow_undefined_flag=' ${wl}-expect_unresolved ${wl}\*'
-	archive_cmds='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	archive_cmds='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
       else
 	allow_undefined_flag=' -expect_unresolved \*'
-	archive_cmds='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	archive_cmds='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
       fi
       archive_cmds_need_lc='no'
       hardcode_libdir_flag_spec='${wl}-rpath ${wl}$libdir'
@@ -9731,13 +10003,13 @@
     osf4* | osf5*)	# as osf3* with the addition of -msym flag
       if test "$GCC" = yes; then
 	allow_undefined_flag=' ${wl}-expect_unresolved ${wl}\*'
-	archive_cmds='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	archive_cmds='$CC -shared${allow_undefined_flag} $pic_flag $libobjs $deplibs $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 	hardcode_libdir_flag_spec='${wl}-rpath ${wl}$libdir'
       else
 	allow_undefined_flag=' -expect_unresolved \*'
-	archive_cmds='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -msym -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	archive_cmds='$CC -shared${allow_undefined_flag} $libobjs $deplibs $compiler_flags -msym -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 	archive_expsym_cmds='for i in `cat $export_symbols`; do printf "%s %s\\n" -exported_symbol "\$i" >> $lib.exp; done; printf "%s\\n" "-hidden">> $lib.exp~
-	$CC -shared${allow_undefined_flag} ${wl}-input ${wl}$lib.exp $compiler_flags $libobjs $deplibs -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib~$RM $lib.exp'
+	$CC -shared${allow_undefined_flag} ${wl}-input ${wl}$lib.exp $compiler_flags $libobjs $deplibs -soname $soname `test -n "$verstring" && $ECHO "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib~$RM $lib.exp'
 
 	# Both c and cxx compiler support -rpath directly
 	hardcode_libdir_flag_spec='-rpath $libdir'
@@ -9750,9 +10022,9 @@
       no_undefined_flag=' -z defs'
       if test "$GCC" = yes; then
 	wlarc='${wl}'
-	archive_cmds='$CC -shared ${wl}-z ${wl}text ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags'
+	archive_cmds='$CC -shared $pic_flag ${wl}-z ${wl}text ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags'
 	archive_expsym_cmds='echo "{ global:" > $lib.exp~cat $export_symbols | $SED -e "s/\(.*\)/\1;/" >> $lib.exp~echo "local: *; };" >> $lib.exp~
-	  $CC -shared ${wl}-z ${wl}text ${wl}-M ${wl}$lib.exp ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags~$RM $lib.exp'
+	  $CC -shared $pic_flag ${wl}-z ${wl}text ${wl}-M ${wl}$lib.exp ${wl}-h ${wl}$soname -o $lib $libobjs $deplibs $compiler_flags~$RM $lib.exp'
       else
 	case `$CC -V 2>&1` in
 	*"Compilers 5.0"*)
@@ -9940,44 +10212,50 @@
       # to ld, don't add -lc before -lgcc.
       { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether -lc should be explicitly linked in" >&5
 $as_echo_n "checking whether -lc should be explicitly linked in... " >&6; }
-      $RM conftest*
-      echo "$lt_simple_compile_test_code" > conftest.$ac_ext
+if ${lt_cv_archive_cmds_need_lc+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  $RM conftest*
+	echo "$lt_simple_compile_test_code" > conftest.$ac_ext
 
-      if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_compile\""; } >&5
+	if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_compile\""; } >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; } 2>conftest.err; then
-        soname=conftest
-        lib=conftest
-        libobjs=conftest.$ac_objext
-        deplibs=
-        wl=$lt_prog_compiler_wl
-	pic_flag=$lt_prog_compiler_pic
-        compiler_flags=-v
-        linker_flags=-v
-        verstring=
-        output_objdir=.
-        libname=conftest
-        lt_save_allow_undefined_flag=$allow_undefined_flag
-        allow_undefined_flag=
-        if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$archive_cmds 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1\""; } >&5
+	  soname=conftest
+	  lib=conftest
+	  libobjs=conftest.$ac_objext
+	  deplibs=
+	  wl=$lt_prog_compiler_wl
+	  pic_flag=$lt_prog_compiler_pic
+	  compiler_flags=-v
+	  linker_flags=-v
+	  verstring=
+	  output_objdir=.
+	  libname=conftest
+	  lt_save_allow_undefined_flag=$allow_undefined_flag
+	  allow_undefined_flag=
+	  if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$archive_cmds 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1\""; } >&5
   (eval $archive_cmds 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1) 2>&5
   ac_status=$?
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }
-        then
-	  archive_cmds_need_lc=no
-        else
-	  archive_cmds_need_lc=yes
-        fi
-        allow_undefined_flag=$lt_save_allow_undefined_flag
-      else
-        cat conftest.err 1>&5
-      fi
-      $RM conftest*
-      { $as_echo "$as_me:${as_lineno-$LINENO}: result: $archive_cmds_need_lc" >&5
-$as_echo "$archive_cmds_need_lc" >&6; }
+	  then
+	    lt_cv_archive_cmds_need_lc=no
+	  else
+	    lt_cv_archive_cmds_need_lc=yes
+	  fi
+	  allow_undefined_flag=$lt_save_allow_undefined_flag
+	else
+	  cat conftest.err 1>&5
+	fi
+	$RM conftest*
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_archive_cmds_need_lc" >&5
+$as_echo "$lt_cv_archive_cmds_need_lc" >&6; }
+      archive_cmds_need_lc=$lt_cv_archive_cmds_need_lc
       ;;
     esac
   fi
@@ -10135,11 +10413,6 @@
 
 
 
-
-
-
-
-
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking dynamic linker characteristics" >&5
 $as_echo_n "checking dynamic linker characteristics... " >&6; }
 
@@ -10148,16 +10421,23 @@
     darwin*) lt_awk_arg="/^libraries:/,/LR/" ;;
     *) lt_awk_arg="/^libraries:/" ;;
   esac
-  lt_search_path_spec=`$CC -print-search-dirs | awk $lt_awk_arg | $SED -e "s/^libraries://" -e "s,=/,/,g"`
-  if $ECHO "$lt_search_path_spec" | $GREP ';' >/dev/null ; then
+  case $host_os in
+    mingw* | cegcc*) lt_sed_strip_eq="s,=\([A-Za-z]:\),\1,g" ;;
+    *) lt_sed_strip_eq="s,=/,/,g" ;;
+  esac
+  lt_search_path_spec=`$CC -print-search-dirs | awk $lt_awk_arg | $SED -e "s/^libraries://" -e $lt_sed_strip_eq`
+  case $lt_search_path_spec in
+  *\;*)
     # if the path contains ";" then we assume it to be the separator
     # otherwise default to the standard path separator (i.e. ":") - it is
     # assumed that no part of a normal pathname contains ";" but that should
     # okay in the real world where ";" in dirpaths is itself problematic.
-    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED -e 's/;/ /g'`
-  else
-    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED  -e "s/$PATH_SEPARATOR/ /g"`
-  fi
+    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED 's/;/ /g'`
+    ;;
+  *)
+    lt_search_path_spec=`$ECHO "$lt_search_path_spec" | $SED "s/$PATH_SEPARATOR/ /g"`
+    ;;
+  esac
   # Ok, now we have the path, separated by spaces, we can step through it
   # and add multilib dir if necessary.
   lt_tmp_lt_search_path_spec=
@@ -10170,7 +10450,7 @@
 	lt_tmp_lt_search_path_spec="$lt_tmp_lt_search_path_spec $lt_sys_path"
     fi
   done
-  lt_search_path_spec=`$ECHO $lt_tmp_lt_search_path_spec | awk '
+  lt_search_path_spec=`$ECHO "$lt_tmp_lt_search_path_spec" | awk '
 BEGIN {RS=" "; FS="/|\n";} {
   lt_foo="";
   lt_count=0;
@@ -10190,7 +10470,13 @@
   if (lt_foo != "") { lt_freq[lt_foo]++; }
   if (lt_freq[lt_foo] == 1) { print lt_foo; }
 }'`
-  sys_lib_search_path_spec=`$ECHO $lt_search_path_spec`
+  # AWK program above erroneously prepends '/' to C:/dos/paths
+  # for these hosts.
+  case $host_os in
+    mingw* | cegcc*) lt_search_path_spec=`$ECHO "$lt_search_path_spec" |\
+      $SED 's,/\([A-Za-z]:\),\1,g'` ;;
+  esac
+  sys_lib_search_path_spec=`$ECHO "$lt_search_path_spec" | $lt_NL2SP`
 else
   sys_lib_search_path_spec="/lib /usr/lib /usr/local/lib"
 fi
@@ -10216,7 +10502,7 @@
 
 case $host_os in
 aix3*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix $libname.a'
   shlibpath_var=LIBPATH
 
@@ -10225,7 +10511,7 @@
   ;;
 
 aix[4-9]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   hardcode_into_libs=yes
@@ -10278,7 +10564,7 @@
   m68k)
     library_names_spec='$libname.ixlibrary $libname.a'
     # Create ${libname}_ixlibrary.a entries in /sys/libs.
-    finish_eval='for lib in `ls $libdir/*.ixlibrary 2>/dev/null`; do libname=`$ECHO "X$lib" | $Xsed -e '\''s%^.*/\([^/]*\)\.ixlibrary$%\1%'\''`; test $RM /sys/libs/${libname}_ixlibrary.a; $show "cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a"; cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a || exit 1; done'
+    finish_eval='for lib in `ls $libdir/*.ixlibrary 2>/dev/null`; do libname=`func_echo_all "$lib" | $SED '\''s%^.*/\([^/]*\)\.ixlibrary$%\1%'\''`; test $RM /sys/libs/${libname}_ixlibrary.a; $show "cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a"; cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a || exit 1; done'
     ;;
   esac
   ;;
@@ -10290,7 +10576,7 @@
   ;;
 
 bsdi[45]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
@@ -10309,8 +10595,9 @@
   need_version=no
   need_lib_prefix=no
 
-  case $GCC,$host_os in
-  yes,cygwin* | yes,mingw* | yes,pw32* | yes,cegcc*)
+  case $GCC,$cc_basename in
+  yes,*)
+    # gcc
     library_names_spec='$libname.dll.a'
     # DLL is installed to $(libdir)/../bin by postinstall_cmds
     postinstall_cmds='base_file=`basename \${file}`~
@@ -10331,36 +10618,83 @@
     cygwin*)
       # Cygwin DLLs use 'cyg' prefix rather than 'lib'
       soname_spec='`echo ${libname} | sed -e 's/^lib/cyg/'``echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
-      sys_lib_search_path_spec="/usr/lib /lib/w32api /lib /usr/local/lib"
+
+      sys_lib_search_path_spec="$sys_lib_search_path_spec /usr/lib/w32api"
       ;;
     mingw* | cegcc*)
       # MinGW DLLs use traditional 'lib' prefix
       soname_spec='${libname}`echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
-      sys_lib_search_path_spec=`$CC -print-search-dirs | $GREP "^libraries:" | $SED -e "s/^libraries://" -e "s,=/,/,g"`
-      if $ECHO "$sys_lib_search_path_spec" | $GREP ';[c-zC-Z]:/' >/dev/null; then
-        # It is most probably a Windows format PATH printed by
-        # mingw gcc, but we are running on Cygwin. Gcc prints its search
-        # path with ; separators, and with drive letters. We can handle the
-        # drive letters (cygwin fileutils understands them), so leave them,
-        # especially as we might pass files found there to a mingw objdump,
-        # which wouldn't understand a cygwinified path. Ahh.
-        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e 's/;/ /g'`
-      else
-        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED  -e "s/$PATH_SEPARATOR/ /g"`
-      fi
       ;;
     pw32*)
       # pw32 DLLs use 'pw' prefix rather than 'lib'
       library_names_spec='`echo ${libname} | sed -e 's/^lib/pw/'``echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
       ;;
     esac
+    dynamic_linker='Win32 ld.exe'
+    ;;
+
+  *,cl*)
+    # Native MSVC
+    libname_spec='$name'
+    soname_spec='${libname}`echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
+    library_names_spec='${libname}.dll.lib'
+
+    case $build_os in
+    mingw*)
+      sys_lib_search_path_spec=
+      lt_save_ifs=$IFS
+      IFS=';'
+      for lt_path in $LIB
+      do
+        IFS=$lt_save_ifs
+        # Let DOS variable expansion print the short 8.3 style file name.
+        lt_path=`cd "$lt_path" 2>/dev/null && cmd //C "for %i in (".") do @echo %~si"`
+        sys_lib_search_path_spec="$sys_lib_search_path_spec $lt_path"
+      done
+      IFS=$lt_save_ifs
+      # Convert to MSYS style.
+      sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | sed -e 's|\\\\|/|g' -e 's| \\([a-zA-Z]\\):| /\\1|g' -e 's|^ ||'`
+      ;;
+    cygwin*)
+      # Convert to unix form, then to dos form, then back to unix form
+      # but this time dos style (no spaces!) so that the unix form looks
+      # like /cygdrive/c/PROGRA~1:/cygdr...
+      sys_lib_search_path_spec=`cygpath --path --unix "$LIB"`
+      sys_lib_search_path_spec=`cygpath --path --dos "$sys_lib_search_path_spec" 2>/dev/null`
+      sys_lib_search_path_spec=`cygpath --path --unix "$sys_lib_search_path_spec" | $SED -e "s/$PATH_SEPARATOR/ /g"`
+      ;;
+    *)
+      sys_lib_search_path_spec="$LIB"
+      if $ECHO "$sys_lib_search_path_spec" | $GREP ';[c-zC-Z]:/' >/dev/null; then
+        # It is most probably a Windows format PATH.
+        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e 's/;/ /g'`
+      else
+        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e "s/$PATH_SEPARATOR/ /g"`
+      fi
+      # FIXME: find the short name or the path components, as spaces are
+      # common. (e.g. "Program Files" -> "PROGRA~1")
+      ;;
+    esac
+
+    # DLL is installed to $(libdir)/../bin by postinstall_cmds
+    postinstall_cmds='base_file=`basename \${file}`~
+      dlpath=`$SHELL 2>&1 -c '\''. $dir/'\''\${base_file}'\''i; echo \$dlname'\''`~
+      dldir=$destdir/`dirname \$dlpath`~
+      test -d \$dldir || mkdir -p \$dldir~
+      $install_prog $dir/$dlname \$dldir/$dlname'
+    postuninstall_cmds='dldll=`$SHELL 2>&1 -c '\''. $file; echo \$dlname'\''`~
+      dlpath=$dir/\$dldll~
+       $RM \$dlpath'
+    shlibpath_overrides_runpath=yes
+    dynamic_linker='Win32 link.exe'
     ;;
 
   *)
+    # Assume MSVC wrapper
     library_names_spec='${libname}`echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext} $libname.lib'
+    dynamic_linker='Win32 ld.exe'
     ;;
   esac
-  dynamic_linker='Win32 ld.exe'
   # FIXME: first we should search . and the directory the executable is in
   shlibpath_var=PATH
   ;;
@@ -10381,7 +10715,7 @@
   ;;
 
 dgux*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname$shared_ext'
@@ -10389,10 +10723,6 @@
   shlibpath_var=LD_LIBRARY_PATH
   ;;
 
-freebsd1*)
-  dynamic_linker=no
-  ;;
-
 freebsd* | dragonfly*)
   # DragonFly does not have aout.  When/if they implement a new
   # versioning mechanism, adjust this.
@@ -10400,7 +10730,7 @@
     objformat=`/usr/bin/objformat`
   else
     case $host_os in
-    freebsd[123]*) objformat=aout ;;
+    freebsd[23].*) objformat=aout ;;
     *) objformat=elf ;;
     esac
   fi
@@ -10418,7 +10748,7 @@
   esac
   shlibpath_var=LD_LIBRARY_PATH
   case $host_os in
-  freebsd2*)
+  freebsd2.*)
     shlibpath_overrides_runpath=yes
     ;;
   freebsd3.[01]* | freebsdelf3.[01]*)
@@ -10437,13 +10767,16 @@
   esac
   ;;
 
-gnu*)
-  version_type=linux
+haiku*)
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
+  dynamic_linker="$host_os runtime_loader"
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}${major} ${libname}${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
-  shlibpath_var=LD_LIBRARY_PATH
+  shlibpath_var=LIBRARY_PATH
+  shlibpath_overrides_runpath=yes
+  sys_lib_dlsearch_path_spec='/boot/home/config/lib /boot/common/lib /boot/system/lib'
   hardcode_into_libs=yes
   ;;
 
@@ -10489,12 +10822,14 @@
     soname_spec='${libname}${release}${shared_ext}$major'
     ;;
   esac
-  # HP-UX runs *really* slowly unless shared libraries are mode 555.
+  # HP-UX runs *really* slowly unless shared libraries are mode 555, ...
   postinstall_cmds='chmod 555 $lib'
+  # or fails outright, so override atomically:
+  install_override_mode=555
   ;;
 
 interix[3-9]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major ${libname}${shared_ext}'
@@ -10510,7 +10845,7 @@
     nonstopux*) version_type=nonstopux ;;
     *)
 	if test "$lt_cv_prog_gnu_ld" = yes; then
-		version_type=linux
+		version_type=linux # correct to gnu/linux during the next big refactor
 	else
 		version_type=irix
 	fi ;;
@@ -10547,9 +10882,9 @@
   dynamic_linker=no
   ;;
 
-# This must be Linux ELF.
-linux* | k*bsd*-gnu)
-  version_type=linux
+# This must be glibc/ELF.
+linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -10557,12 +10892,17 @@
   finish_cmds='PATH="\$PATH:/sbin" ldconfig -n $libdir'
   shlibpath_var=LD_LIBRARY_PATH
   shlibpath_overrides_runpath=no
+
   # Some binutils ld are patched to set DT_RUNPATH
-  save_LDFLAGS=$LDFLAGS
-  save_libdir=$libdir
-  eval "libdir=/foo; wl=\"$lt_prog_compiler_wl\"; \
-       LDFLAGS=\"\$LDFLAGS $hardcode_libdir_flag_spec\""
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+  if ${lt_cv_shlibpath_overrides_runpath+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_shlibpath_overrides_runpath=no
+    save_LDFLAGS=$LDFLAGS
+    save_libdir=$libdir
+    eval "libdir=/foo; wl=\"$lt_prog_compiler_wl\"; \
+	 LDFLAGS=\"\$LDFLAGS $hardcode_libdir_flag_spec\""
+    cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -10575,13 +10915,17 @@
 _ACEOF
 if ac_fn_c_try_link "$LINENO"; then :
   if  ($OBJDUMP -p conftest$ac_exeext) 2>/dev/null | grep "RUNPATH.*$libdir" >/dev/null; then :
-  shlibpath_overrides_runpath=yes
+  lt_cv_shlibpath_overrides_runpath=yes
 fi
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-  LDFLAGS=$save_LDFLAGS
-  libdir=$save_libdir
+    LDFLAGS=$save_LDFLAGS
+    libdir=$save_libdir
+
+fi
+
+  shlibpath_overrides_runpath=$lt_cv_shlibpath_overrides_runpath
 
   # This implies no fast_install, which is unacceptable.
   # Some rework will be needed to allow for fast_install
@@ -10590,7 +10934,7 @@
 
   # Append ld.so.conf contents to the search path
   if test -f /etc/ld.so.conf; then
-    lt_ld_extra=`awk '/^include / { system(sprintf("cd /etc; cat %s 2>/dev/null", \$2)); skip = 1; } { if (!skip) print \$0; skip = 0; }' < /etc/ld.so.conf | $SED -e 's/#.*//;/^[	 ]*hwcap[	 ]/d;s/[:,	]/ /g;s/=[^=]*$//;s/=[^= ]* / /g;/^$/d' | tr '\n' ' '`
+    lt_ld_extra=`awk '/^include / { system(sprintf("cd /etc; cat %s 2>/dev/null", \$2)); skip = 1; } { if (!skip) print \$0; skip = 0; }' < /etc/ld.so.conf | $SED -e 's/#.*//;/^[	 ]*hwcap[	 ]/d;s/[:,	]/ /g;s/=[^=]*$//;s/=[^= ]* / /g;s/"//g;/^$/d' | tr '\n' ' '`
     sys_lib_dlsearch_path_spec="/lib /usr/lib $lt_ld_extra"
   fi
 
@@ -10634,7 +10978,7 @@
   ;;
 
 newsos6)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   shlibpath_var=LD_LIBRARY_PATH
   shlibpath_overrides_runpath=yes
@@ -10703,7 +11047,7 @@
   ;;
 
 solaris*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -10728,7 +11072,7 @@
   ;;
 
 sysv4 | sysv4.3*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
   shlibpath_var=LD_LIBRARY_PATH
@@ -10752,7 +11096,7 @@
 
 sysv4*MP*)
   if test -d /usr/nec ;then
-    version_type=linux
+    version_type=linux # correct to gnu/linux during the next big refactor
     library_names_spec='$libname${shared_ext}.$versuffix $libname${shared_ext}.$major $libname${shared_ext}'
     soname_spec='$libname${shared_ext}.$major'
     shlibpath_var=LD_LIBRARY_PATH
@@ -10783,7 +11127,7 @@
 
 tpf*)
   # TPF is a cross-target only.  Preferred cross-host = GNU/Linux.
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -10793,7 +11137,7 @@
   ;;
 
 uts4*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
   shlibpath_var=LD_LIBRARY_PATH
@@ -10905,6 +11249,11 @@
 
 
 
+
+
+
+
+
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking how to hardcode library paths into programs" >&5
 $as_echo_n "checking how to hardcode library paths into programs... " >&6; }
 hardcode_action=
@@ -10977,7 +11326,7 @@
   # if libdl is installed we need to link against it
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for dlopen in -ldl" >&5
 $as_echo_n "checking for dlopen in -ldl... " >&6; }
-if test "${ac_cv_lib_dl_dlopen+set}" = set; then :
+if ${ac_cv_lib_dl_dlopen+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -11011,7 +11360,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dl_dlopen" >&5
 $as_echo "$ac_cv_lib_dl_dlopen" >&6; }
-if test "x$ac_cv_lib_dl_dlopen" = x""yes; then :
+if test "x$ac_cv_lib_dl_dlopen" = xyes; then :
   lt_cv_dlopen="dlopen" lt_cv_dlopen_libs="-ldl"
 else
 
@@ -11025,12 +11374,12 @@
 
   *)
     ac_fn_c_check_func "$LINENO" "shl_load" "ac_cv_func_shl_load"
-if test "x$ac_cv_func_shl_load" = x""yes; then :
+if test "x$ac_cv_func_shl_load" = xyes; then :
   lt_cv_dlopen="shl_load"
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for shl_load in -ldld" >&5
 $as_echo_n "checking for shl_load in -ldld... " >&6; }
-if test "${ac_cv_lib_dld_shl_load+set}" = set; then :
+if ${ac_cv_lib_dld_shl_load+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -11064,16 +11413,16 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dld_shl_load" >&5
 $as_echo "$ac_cv_lib_dld_shl_load" >&6; }
-if test "x$ac_cv_lib_dld_shl_load" = x""yes; then :
+if test "x$ac_cv_lib_dld_shl_load" = xyes; then :
   lt_cv_dlopen="shl_load" lt_cv_dlopen_libs="-ldld"
 else
   ac_fn_c_check_func "$LINENO" "dlopen" "ac_cv_func_dlopen"
-if test "x$ac_cv_func_dlopen" = x""yes; then :
+if test "x$ac_cv_func_dlopen" = xyes; then :
   lt_cv_dlopen="dlopen"
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for dlopen in -ldl" >&5
 $as_echo_n "checking for dlopen in -ldl... " >&6; }
-if test "${ac_cv_lib_dl_dlopen+set}" = set; then :
+if ${ac_cv_lib_dl_dlopen+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -11107,12 +11456,12 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dl_dlopen" >&5
 $as_echo "$ac_cv_lib_dl_dlopen" >&6; }
-if test "x$ac_cv_lib_dl_dlopen" = x""yes; then :
+if test "x$ac_cv_lib_dl_dlopen" = xyes; then :
   lt_cv_dlopen="dlopen" lt_cv_dlopen_libs="-ldl"
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for dlopen in -lsvld" >&5
 $as_echo_n "checking for dlopen in -lsvld... " >&6; }
-if test "${ac_cv_lib_svld_dlopen+set}" = set; then :
+if ${ac_cv_lib_svld_dlopen+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -11146,12 +11495,12 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_svld_dlopen" >&5
 $as_echo "$ac_cv_lib_svld_dlopen" >&6; }
-if test "x$ac_cv_lib_svld_dlopen" = x""yes; then :
+if test "x$ac_cv_lib_svld_dlopen" = xyes; then :
   lt_cv_dlopen="dlopen" lt_cv_dlopen_libs="-lsvld"
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for dld_link in -ldld" >&5
 $as_echo_n "checking for dld_link in -ldld... " >&6; }
-if test "${ac_cv_lib_dld_dld_link+set}" = set; then :
+if ${ac_cv_lib_dld_dld_link+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -11185,7 +11534,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dld_dld_link" >&5
 $as_echo "$ac_cv_lib_dld_dld_link" >&6; }
-if test "x$ac_cv_lib_dld_dld_link" = x""yes; then :
+if test "x$ac_cv_lib_dld_dld_link" = xyes; then :
   lt_cv_dlopen="dld_link" lt_cv_dlopen_libs="-ldld"
 fi
 
@@ -11226,7 +11575,7 @@
 
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether a program can dlopen itself" >&5
 $as_echo_n "checking whether a program can dlopen itself... " >&6; }
-if test "${lt_cv_dlopen_self+set}" = set; then :
+if ${lt_cv_dlopen_self+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   	  if test "$cross_compiling" = yes; then :
@@ -11235,7 +11584,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11238 "configure"
+#line $LINENO "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -11276,7 +11625,13 @@
 #  endif
 #endif
 
-void fnord() { int i=42;}
+/* When -fvisbility=hidden is used, assume the code has been annotated
+   correspondingly for the symbols needed.  */
+#if defined(__GNUC__) && (((__GNUC__ == 3) && (__GNUC_MINOR__ >= 3)) || (__GNUC__ > 3))
+int fnord () __attribute__((visibility("default")));
+#endif
+
+int fnord () { return 42; }
 int main ()
 {
   void *self = dlopen (0, LT_DLGLOBAL|LT_DLLAZY_OR_NOW);
@@ -11285,7 +11640,11 @@
   if (self)
     {
       if (dlsym (self,"fnord"))       status = $lt_dlno_uscore;
-      else if (dlsym( self,"_fnord")) status = $lt_dlneed_uscore;
+      else
+        {
+	  if (dlsym( self,"_fnord"))  status = $lt_dlneed_uscore;
+          else puts (dlerror ());
+	}
       /* dlclose (self); */
     }
   else
@@ -11322,7 +11681,7 @@
       wl=$lt_prog_compiler_wl eval LDFLAGS=\"\$LDFLAGS $lt_prog_compiler_static\"
       { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether a statically linked program can dlopen itself" >&5
 $as_echo_n "checking whether a statically linked program can dlopen itself... " >&6; }
-if test "${lt_cv_dlopen_self_static+set}" = set; then :
+if ${lt_cv_dlopen_self_static+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   	  if test "$cross_compiling" = yes; then :
@@ -11331,7 +11690,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11334 "configure"
+#line $LINENO "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -11372,7 +11731,13 @@
 #  endif
 #endif
 
-void fnord() { int i=42;}
+/* When -fvisbility=hidden is used, assume the code has been annotated
+   correspondingly for the symbols needed.  */
+#if defined(__GNUC__) && (((__GNUC__ == 3) && (__GNUC_MINOR__ >= 3)) || (__GNUC__ > 3))
+int fnord () __attribute__((visibility("default")));
+#endif
+
+int fnord () { return 42; }
 int main ()
 {
   void *self = dlopen (0, LT_DLGLOBAL|LT_DLLAZY_OR_NOW);
@@ -11381,7 +11746,11 @@
   if (self)
     {
       if (dlsym (self,"fnord"))       status = $lt_dlno_uscore;
-      else if (dlsym( self,"_fnord")) status = $lt_dlneed_uscore;
+      else
+        {
+	  if (dlsym( self,"_fnord"))  status = $lt_dlneed_uscore;
+          else puts (dlerror ());
+	}
       /* dlclose (self); */
     }
   else
@@ -11538,6 +11907,145 @@
 
 CC="$lt_save_CC"
 
+      if test -n "$CXX" && ( test "X$CXX" != "Xno" &&
+    ( (test "X$CXX" = "Xg++" && `g++ -v >/dev/null 2>&1` ) ||
+    (test "X$CXX" != "Xg++"))) ; then
+  ac_ext=cpp
+ac_cpp='$CXXCPP $CPPFLAGS'
+ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to run the C++ preprocessor" >&5
+$as_echo_n "checking how to run the C++ preprocessor... " >&6; }
+if test -z "$CXXCPP"; then
+  if ${ac_cv_prog_CXXCPP+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+      # Double quotes because CXXCPP needs to be expanded
+    for CXXCPP in "$CXX -E" "/lib/cpp"
+    do
+      ac_preproc_ok=false
+for ac_cxx_preproc_warn_flag in '' yes
+do
+  # Use a header file that comes with gcc, so configuring glibc
+  # with a fresh cross-compiler works.
+  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
+  # <limits.h> exists even on freestanding compilers.
+  # On the NeXT, cc -E runs the code through the compiler's parser,
+  # not just through cpp. "Syntax error" is here to catch this case.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#ifdef __STDC__
+# include <limits.h>
+#else
+# include <assert.h>
+#endif
+		     Syntax error
+_ACEOF
+if ac_fn_cxx_try_cpp "$LINENO"; then :
+
+else
+  # Broken: fails on valid input.
+continue
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+  # OK, works on sane cases.  Now check whether nonexistent headers
+  # can be detected and how.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <ac_nonexistent.h>
+_ACEOF
+if ac_fn_cxx_try_cpp "$LINENO"; then :
+  # Broken: success on invalid input.
+continue
+else
+  # Passes both tests.
+ac_preproc_ok=:
+break
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+done
+# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
+rm -f conftest.i conftest.err conftest.$ac_ext
+if $ac_preproc_ok; then :
+  break
+fi
+
+    done
+    ac_cv_prog_CXXCPP=$CXXCPP
+
+fi
+  CXXCPP=$ac_cv_prog_CXXCPP
+else
+  ac_cv_prog_CXXCPP=$CXXCPP
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $CXXCPP" >&5
+$as_echo "$CXXCPP" >&6; }
+ac_preproc_ok=false
+for ac_cxx_preproc_warn_flag in '' yes
+do
+  # Use a header file that comes with gcc, so configuring glibc
+  # with a fresh cross-compiler works.
+  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
+  # <limits.h> exists even on freestanding compilers.
+  # On the NeXT, cc -E runs the code through the compiler's parser,
+  # not just through cpp. "Syntax error" is here to catch this case.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#ifdef __STDC__
+# include <limits.h>
+#else
+# include <assert.h>
+#endif
+		     Syntax error
+_ACEOF
+if ac_fn_cxx_try_cpp "$LINENO"; then :
+
+else
+  # Broken: fails on valid input.
+continue
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+  # OK, works on sane cases.  Now check whether nonexistent headers
+  # can be detected and how.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <ac_nonexistent.h>
+_ACEOF
+if ac_fn_cxx_try_cpp "$LINENO"; then :
+  # Broken: success on invalid input.
+continue
+else
+  # Passes both tests.
+ac_preproc_ok=:
+break
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+done
+# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
+rm -f conftest.i conftest.err conftest.$ac_ext
+if $ac_preproc_ok; then :
+
+else
+  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "C++ preprocessor \"$CXXCPP\" fails sanity check
+See \`config.log' for more details" "$LINENO" 5; }
+fi
+
+ac_ext=c
+ac_cpp='$CPP $CPPFLAGS'
+ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+else
+  _lt_caught_CXX_error=yes
+fi
 
 ac_ext=cpp
 ac_cpp='$CXXCPP $CPPFLAGS'
@@ -11554,7 +12062,6 @@
 hardcode_direct_CXX=no
 hardcode_direct_absolute_CXX=no
 hardcode_libdir_flag_spec_CXX=
-hardcode_libdir_flag_spec_ld_CXX=
 hardcode_libdir_separator_CXX=
 hardcode_minus_L_CXX=no
 hardcode_shlibpath_var_CXX=unsupported
@@ -11564,6 +12071,8 @@
 module_expsym_cmds_CXX=
 link_all_deplibs_CXX=unknown
 old_archive_cmds_CXX=$old_archive_cmds
+reload_flag_CXX=$reload_flag
+reload_cmds_CXX=$reload_cmds
 no_undefined_flag_CXX=
 whole_archive_flag_spec_CXX=
 enable_shared_with_static_runtimes_CXX=no
@@ -11619,6 +12128,7 @@
 
   # Allow CC to be a program name with arguments.
   lt_save_CC=$CC
+  lt_save_CFLAGS=$CFLAGS
   lt_save_LD=$LD
   lt_save_GCC=$GCC
   GCC=$GXX
@@ -11636,6 +12146,7 @@
   fi
   test -z "${LDCXX+set}" || LD=$LDCXX
   CC=${CXX-"c++"}
+  CFLAGS=$CXXFLAGS
   compiler=$CC
   compiler_CXX=$CC
   for cc_temp in $compiler""; do
@@ -11646,7 +12157,7 @@
     *) break;;
   esac
 done
-cc_basename=`$ECHO "X$cc_temp" | $Xsed -e 's%.*/%%' -e "s%^$host_alias-%%"`
+cc_basename=`$ECHO "$cc_temp" | $SED "s%.*/%%; s%^$host_alias-%%"`
 
 
   if test -n "$compiler"; then
@@ -11709,7 +12220,7 @@
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for non-GNU ld" >&5
 $as_echo_n "checking for non-GNU ld... " >&6; }
 fi
-if test "${lt_cv_path_LD+set}" = set; then :
+if ${lt_cv_path_LD+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -z "$LD"; then
@@ -11746,10 +12257,10 @@
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
 $as_echo "no" >&6; }
 fi
-test -z "$LD" && as_fn_error "no acceptable ld found in \$PATH" "$LINENO" 5
+test -z "$LD" && as_fn_error $? "no acceptable ld found in \$PATH" "$LINENO" 5
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking if the linker ($LD) is GNU ld" >&5
 $as_echo_n "checking if the linker ($LD) is GNU ld... " >&6; }
-if test "${lt_cv_prog_gnu_ld+set}" = set; then :
+if ${lt_cv_prog_gnu_ld+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   # I'd rather use --version here, but apparently some GNU lds only accept -v.
@@ -11775,8 +12286,8 @@
       # Check if GNU C++ uses GNU ld as the underlying linker, since the
       # archiving commands below assume that GNU ld is being used.
       if test "$with_gnu_ld" = yes; then
-        archive_cmds_CXX='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname -o $lib'
-        archive_expsym_cmds_CXX='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
+        archive_cmds_CXX='$CC $pic_flag -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname -o $lib'
+        archive_expsym_cmds_CXX='$CC $pic_flag -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $wl$soname ${wl}-retain-symbols-file $wl$export_symbols -o $lib'
 
         hardcode_libdir_flag_spec_CXX='${wl}-rpath ${wl}$libdir'
         export_dynamic_flag_spec_CXX='${wl}--export-dynamic'
@@ -11808,7 +12319,7 @@
       # Commands to make compiler produce verbose output that lists
       # what "hidden" libraries, object files and flags are used when
       # linking a shared library.
-      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 
     else
       GXX=no
@@ -11918,7 +12429,13 @@
           allow_undefined_flag_CXX='-berok'
           # Determine the default libpath from the value encoded in an empty
           # executable.
-          cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+          if test "${lt_cv_aix_libpath+set}" = set; then
+  aix_libpath=$lt_cv_aix_libpath
+else
+  if ${lt_cv_aix_libpath__CXX+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -11931,26 +12448,33 @@
 _ACEOF
 if ac_fn_cxx_try_link "$LINENO"; then :
 
-lt_aix_libpath_sed='
-    /Import File Strings/,/^$/ {
-	/^0/ {
-	    s/^0  *\(.*\)$/\1/
-	    p
-	}
-    }'
-aix_libpath=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-# Check for a 64-bit object if we didn't find anything.
-if test -z "$aix_libpath"; then
-  aix_libpath=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-fi
+  lt_aix_libpath_sed='
+      /Import File Strings/,/^$/ {
+	  /^0/ {
+	      s/^0  *\([^ ]*\) *$/\1/
+	      p
+	  }
+      }'
+  lt_cv_aix_libpath__CXX=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  # Check for a 64-bit object if we didn't find anything.
+  if test -z "$lt_cv_aix_libpath__CXX"; then
+    lt_cv_aix_libpath__CXX=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  fi
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-if test -z "$aix_libpath"; then aix_libpath="/usr/lib:/lib"; fi
+  if test -z "$lt_cv_aix_libpath__CXX"; then
+    lt_cv_aix_libpath__CXX="/usr/lib:/lib"
+  fi
+
+fi
+
+  aix_libpath=$lt_cv_aix_libpath__CXX
+fi
 
           hardcode_libdir_flag_spec_CXX='${wl}-blibpath:$libdir:'"$aix_libpath"
 
-          archive_expsym_cmds_CXX='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then $ECHO "X${wl}${allow_undefined_flag}" | $Xsed; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
+          archive_expsym_cmds_CXX='$CC -o $output_objdir/$soname $libobjs $deplibs '"\${wl}$no_entry_flag"' $compiler_flags `if test "x${allow_undefined_flag}" != "x"; then func_echo_all "${wl}${allow_undefined_flag}"; else :; fi` '"\${wl}$exp_sym_flag:\$export_symbols $shared_flag"
         else
           if test "$host_cpu" = ia64; then
 	    hardcode_libdir_flag_spec_CXX='${wl}-R $libdir:/usr/lib:/lib'
@@ -11959,7 +12483,13 @@
           else
 	    # Determine the default libpath from the value encoded in an
 	    # empty executable.
-	    cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+	    if test "${lt_cv_aix_libpath+set}" = set; then
+  aix_libpath=$lt_cv_aix_libpath
+else
+  if ${lt_cv_aix_libpath__CXX+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -11972,30 +12502,42 @@
 _ACEOF
 if ac_fn_cxx_try_link "$LINENO"; then :
 
-lt_aix_libpath_sed='
-    /Import File Strings/,/^$/ {
-	/^0/ {
-	    s/^0  *\(.*\)$/\1/
-	    p
-	}
-    }'
-aix_libpath=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-# Check for a 64-bit object if we didn't find anything.
-if test -z "$aix_libpath"; then
-  aix_libpath=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
-fi
+  lt_aix_libpath_sed='
+      /Import File Strings/,/^$/ {
+	  /^0/ {
+	      s/^0  *\([^ ]*\) *$/\1/
+	      p
+	  }
+      }'
+  lt_cv_aix_libpath__CXX=`dump -H conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  # Check for a 64-bit object if we didn't find anything.
+  if test -z "$lt_cv_aix_libpath__CXX"; then
+    lt_cv_aix_libpath__CXX=`dump -HX64 conftest$ac_exeext 2>/dev/null | $SED -n -e "$lt_aix_libpath_sed"`
+  fi
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-if test -z "$aix_libpath"; then aix_libpath="/usr/lib:/lib"; fi
+  if test -z "$lt_cv_aix_libpath__CXX"; then
+    lt_cv_aix_libpath__CXX="/usr/lib:/lib"
+  fi
+
+fi
+
+  aix_libpath=$lt_cv_aix_libpath__CXX
+fi
 
 	    hardcode_libdir_flag_spec_CXX='${wl}-blibpath:$libdir:'"$aix_libpath"
 	    # Warning - without using the other run time loading flags,
 	    # -berok will link without error, but may produce a broken library.
 	    no_undefined_flag_CXX=' ${wl}-bernotok'
 	    allow_undefined_flag_CXX=' ${wl}-berok'
-	    # Exported symbols can be pulled into shared objects from archives
-	    whole_archive_flag_spec_CXX='$convenience'
+	    if test "$with_gnu_ld" = yes; then
+	      # We only use this code for GNU lds that support --whole-archive.
+	      whole_archive_flag_spec_CXX='${wl}--whole-archive$convenience ${wl}--no-whole-archive'
+	    else
+	      # Exported symbols can be pulled into shared objects from archives
+	      whole_archive_flag_spec_CXX='$convenience'
+	    fi
 	    archive_cmds_need_lc_CXX=yes
 	    # This is similar to how AIX traditionally builds its shared
 	    # libraries.
@@ -12025,28 +12567,75 @@
         ;;
 
       cygwin* | mingw* | pw32* | cegcc*)
-        # _LT_TAGVAR(hardcode_libdir_flag_spec, CXX) is actually meaningless,
-        # as there is no search path for DLLs.
-        hardcode_libdir_flag_spec_CXX='-L$libdir'
-        allow_undefined_flag_CXX=unsupported
-        always_export_symbols_CXX=no
-        enable_shared_with_static_runtimes_CXX=yes
+	case $GXX,$cc_basename in
+	,cl* | no,cl*)
+	  # Native MSVC
+	  # hardcode_libdir_flag_spec is actually meaningless, as there is
+	  # no search path for DLLs.
+	  hardcode_libdir_flag_spec_CXX=' '
+	  allow_undefined_flag_CXX=unsupported
+	  always_export_symbols_CXX=yes
+	  file_list_spec_CXX='@'
+	  # Tell ltmain to make .lib files, not .a files.
+	  libext=lib
+	  # Tell ltmain to make .dll files, not .so files.
+	  shrext_cmds=".dll"
+	  # FIXME: Setting linknames here is a bad hack.
+	  archive_cmds_CXX='$CC -o $output_objdir/$soname $libobjs $compiler_flags $deplibs -Wl,-dll~linknames='
+	  archive_expsym_cmds_CXX='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
+	      $SED -n -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' -e '1\\\!p' < $export_symbols > $output_objdir/$soname.exp;
+	    else
+	      $SED -e 's/\\\\\\\(.*\\\\\\\)/-link\\\ -EXPORT:\\\\\\\1/' < $export_symbols > $output_objdir/$soname.exp;
+	    fi~
+	    $CC -o $tool_output_objdir$soname $libobjs $compiler_flags $deplibs "@$tool_output_objdir$soname.exp" -Wl,-DLL,-IMPLIB:"$tool_output_objdir$libname.dll.lib"~
+	    linknames='
+	  # The linker will not automatically build a static lib if we build a DLL.
+	  # _LT_TAGVAR(old_archive_from_new_cmds, CXX)='true'
+	  enable_shared_with_static_runtimes_CXX=yes
+	  # Don't use ranlib
+	  old_postinstall_cmds_CXX='chmod 644 $oldlib'
+	  postlink_cmds_CXX='lt_outputfile="@OUTPUT@"~
+	    lt_tool_outputfile="@TOOL_OUTPUT@"~
+	    case $lt_outputfile in
+	      *.exe|*.EXE) ;;
+	      *)
+		lt_outputfile="$lt_outputfile.exe"
+		lt_tool_outputfile="$lt_tool_outputfile.exe"
+		;;
+	    esac~
+	    func_to_tool_file "$lt_outputfile"~
+	    if test "$MANIFEST_TOOL" != ":" && test -f "$lt_outputfile.manifest"; then
+	      $MANIFEST_TOOL -manifest "$lt_tool_outputfile.manifest" -outputresource:"$lt_tool_outputfile" || exit 1;
+	      $RM "$lt_outputfile.manifest";
+	    fi'
+	  ;;
+	*)
+	  # g++
+	  # _LT_TAGVAR(hardcode_libdir_flag_spec, CXX) is actually meaningless,
+	  # as there is no search path for DLLs.
+	  hardcode_libdir_flag_spec_CXX='-L$libdir'
+	  export_dynamic_flag_spec_CXX='${wl}--export-all-symbols'
+	  allow_undefined_flag_CXX=unsupported
+	  always_export_symbols_CXX=no
+	  enable_shared_with_static_runtimes_CXX=yes
 
-        if $LD --help 2>&1 | $GREP 'auto-import' > /dev/null; then
-          archive_cmds_CXX='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
-          # If the export-symbols file already is a .def file (1st line
-          # is EXPORTS), use it as is; otherwise, prepend...
-          archive_expsym_cmds_CXX='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
-	    cp $export_symbols $output_objdir/$soname.def;
-          else
-	    echo EXPORTS > $output_objdir/$soname.def;
-	    cat $export_symbols >> $output_objdir/$soname.def;
-          fi~
-          $CC -shared -nostdlib $output_objdir/$soname.def $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
-        else
-          ld_shlibs_CXX=no
-        fi
-        ;;
+	  if $LD --help 2>&1 | $GREP 'auto-import' > /dev/null; then
+	    archive_cmds_CXX='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
+	    # If the export-symbols file already is a .def file (1st line
+	    # is EXPORTS), use it as is; otherwise, prepend...
+	    archive_expsym_cmds_CXX='if test "x`$SED 1q $export_symbols`" = xEXPORTS; then
+	      cp $export_symbols $output_objdir/$soname.def;
+	    else
+	      echo EXPORTS > $output_objdir/$soname.def;
+	      cat $export_symbols >> $output_objdir/$soname.def;
+	    fi~
+	    $CC -shared -nostdlib $output_objdir/$soname.def $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -o $output_objdir/$soname ${wl}--enable-auto-image-base -Xlinker --out-implib -Xlinker $lib'
+	  else
+	    ld_shlibs_CXX=no
+	  fi
+	  ;;
+	esac
+	;;
       darwin* | rhapsody*)
 
 
@@ -12054,7 +12643,12 @@
   hardcode_direct_CXX=no
   hardcode_automatic_CXX=yes
   hardcode_shlibpath_var_CXX=unsupported
-  whole_archive_flag_spec_CXX=''
+  if test "$lt_cv_ld_force_load" = "yes"; then
+    whole_archive_flag_spec_CXX='`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience ${wl}-force_load,$conv\"; done; func_echo_all \"$new_convenience\"`'
+
+  else
+    whole_archive_flag_spec_CXX=''
+  fi
   link_all_deplibs_CXX=yes
   allow_undefined_flag_CXX="$_lt_dar_allow_undefined"
   case $cc_basename in
@@ -12062,7 +12656,7 @@
      *) _lt_dar_can_shared=$GCC ;;
   esac
   if test "$_lt_dar_can_shared" = "yes"; then
-    output_verbose_link_cmd=echo
+    output_verbose_link_cmd=func_echo_all
     archive_cmds_CXX="\$CC -dynamiclib \$allow_undefined_flag -o \$lib \$libobjs \$deplibs \$compiler_flags -install_name \$rpath/\$soname \$verstring $_lt_dar_single_mod${_lt_dsymutil}"
     module_cmds_CXX="\$CC \$allow_undefined_flag -o \$lib -bundle \$libobjs \$deplibs \$compiler_flags${_lt_dsymutil}"
     archive_expsym_cmds_CXX="sed 's,^,_,' < \$export_symbols > \$output_objdir/\${libname}-symbols.expsym~\$CC -dynamiclib \$allow_undefined_flag -o \$lib \$libobjs \$deplibs \$compiler_flags -install_name \$rpath/\$soname \$verstring ${_lt_dar_single_mod}${_lt_dar_export_syms}${_lt_dsymutil}"
@@ -12096,7 +12690,7 @@
         esac
         ;;
 
-      freebsd[12]*)
+      freebsd2.*)
         # C++ shared libraries reported to be fairly broken before
 	# switch to ELF
         ld_shlibs_CXX=no
@@ -12112,7 +12706,9 @@
         ld_shlibs_CXX=yes
         ;;
 
-      gnu*)
+      haiku*)
+        archive_cmds_CXX='$CC -shared $libobjs $deplibs $compiler_flags ${wl}-soname $wl$soname -o $lib'
+        link_all_deplibs_CXX=yes
         ;;
 
       hpux9*)
@@ -12139,11 +12735,11 @@
             # explicitly linking system object files so we need to strip them
             # from the output so that they don't get included in the library
             # dependencies.
-            output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $EGREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+            output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $EGREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
             ;;
           *)
             if test "$GXX" = yes; then
-              archive_cmds_CXX='$RM $output_objdir/$soname~$CC -shared -nostdlib -fPIC ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
+              archive_cmds_CXX='$RM $output_objdir/$soname~$CC -shared -nostdlib $pic_flag ${wl}+b ${wl}$install_libdir -o $output_objdir/$soname $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~test $output_objdir/$soname = $lib || mv $output_objdir/$soname $lib'
             else
               # FIXME: insert proper C++ library support
               ld_shlibs_CXX=no
@@ -12204,7 +12800,7 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $GREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`($CC -b $CFLAGS -v conftest.$objext 2>&1) | $GREP "\-L"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
 	    ;;
           *)
 	    if test "$GXX" = yes; then
@@ -12214,10 +12810,10 @@
 	            archive_cmds_CXX='$CC -shared -nostdlib -fPIC ${wl}+h ${wl}$soname -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	            ;;
 	          ia64*)
-	            archive_cmds_CXX='$CC -shared -nostdlib -fPIC ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
+	            archive_cmds_CXX='$CC -shared -nostdlib $pic_flag ${wl}+h ${wl}$soname ${wl}+nodefaultrpath -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	            ;;
 	          *)
-	            archive_cmds_CXX='$CC -shared -nostdlib -fPIC ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
+	            archive_cmds_CXX='$CC -shared -nostdlib $pic_flag ${wl}+h ${wl}$soname ${wl}+b ${wl}$install_libdir -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	            ;;
 	        esac
 	      fi
@@ -12247,7 +12843,7 @@
         case $cc_basename in
           CC*)
 	    # SGI C++
-	    archive_cmds_CXX='$CC -shared -all -multigot $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	    archive_cmds_CXX='$CC -shared -all -multigot $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 
 	    # Archives containing C++ object files must be created using
 	    # "CC -ar", where "CC" is the IRIX C++ compiler.  This is
@@ -12258,9 +12854,9 @@
           *)
 	    if test "$GXX" = yes; then
 	      if test "$with_gnu_ld" = no; then
-	        archive_cmds_CXX='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	        archive_cmds_CXX='$CC -shared $pic_flag -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 	      else
-	        archive_cmds_CXX='$CC -shared -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` -o $lib'
+	        archive_cmds_CXX='$CC -shared $pic_flag -nostdlib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` -o $lib'
 	      fi
 	    fi
 	    link_all_deplibs_CXX=yes
@@ -12271,7 +12867,7 @@
         inherit_rpath_CXX=yes
         ;;
 
-      linux* | k*bsd*-gnu)
+      linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
         case $cc_basename in
           KCC*)
 	    # Kuck and Associates, Inc. (KAI) C++ Compiler
@@ -12289,7 +12885,7 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`$CC $CFLAGS -v conftest.$objext -o libconftest$shared_ext 2>&1 | $GREP "ld"`; rm -f libconftest$shared_ext; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`$CC $CFLAGS -v conftest.$objext -o libconftest$shared_ext 2>&1 | $GREP "ld"`; rm -f libconftest$shared_ext; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
 
 	    hardcode_libdir_flag_spec_CXX='${wl}-rpath,$libdir'
 	    export_dynamic_flag_spec_CXX='${wl}--export-dynamic'
@@ -12326,26 +12922,26 @@
           pgCC* | pgcpp*)
             # Portland Group C++ compiler
 	    case `$CC -V` in
-	    *pgCC\ [1-5]* | *pgcpp\ [1-5]*)
+	    *pgCC\ [1-5].* | *pgcpp\ [1-5].*)
 	      prelink_cmds_CXX='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $objs $libobjs $compile_deplibs~
-		compile_command="$compile_command `find $tpldir -name \*.o | $NL2SP`"'
+		compile_command="$compile_command `find $tpldir -name \*.o | sort | $NL2SP`"'
 	      old_archive_cmds_CXX='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $oldobjs$old_deplibs~
-		$AR $AR_FLAGS $oldlib$oldobjs$old_deplibs `find $tpldir -name \*.o | $NL2SP`~
+		$AR $AR_FLAGS $oldlib$oldobjs$old_deplibs `find $tpldir -name \*.o | sort | $NL2SP`~
 		$RANLIB $oldlib'
 	      archive_cmds_CXX='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $predep_objects $libobjs $deplibs $convenience $postdep_objects~
-		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname -o $lib'
+		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | sort | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname -o $lib'
 	      archive_expsym_cmds_CXX='tpldir=Template.dir~
 		rm -rf $tpldir~
 		$CC --prelink_objects --instantiation_dir $tpldir $predep_objects $libobjs $deplibs $convenience $postdep_objects~
-		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname ${wl}-retain-symbols-file ${wl}$export_symbols -o $lib'
+		$CC -shared $pic_flag $predep_objects $libobjs $deplibs `find $tpldir -name \*.o | sort | $NL2SP` $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname ${wl}-retain-symbols-file ${wl}$export_symbols -o $lib'
 	      ;;
-	    *) # Version 6 will use weak symbols
+	    *) # Version 6 and above use weak symbols
 	      archive_cmds_CXX='$CC -shared $pic_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname -o $lib'
 	      archive_expsym_cmds_CXX='$CC -shared $pic_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname ${wl}-retain-symbols-file ${wl}$export_symbols -o $lib'
 	      ;;
@@ -12353,7 +12949,7 @@
 
 	    hardcode_libdir_flag_spec_CXX='${wl}--rpath ${wl}$libdir'
 	    export_dynamic_flag_spec_CXX='${wl}--export-dynamic'
-	    whole_archive_flag_spec_CXX='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	    whole_archive_flag_spec_CXX='${wl}--whole-archive`for conv in $convenience\"\"; do test  -n \"$conv\" && new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
             ;;
 	  cxx*)
 	    # Compaq C++
@@ -12372,9 +12968,9 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld"`; templist=`$ECHO "X$templist" | $Xsed -e "s/\(^.*ld.*\)\( .*ld .*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld"`; templist=`func_echo_all "$templist" | $SED "s/\(^.*ld.*\)\( .*ld .*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "X$list" | $Xsed'
 	    ;;
-	  xl*)
+	  xl* | mpixl* | bgxl*)
 	    # IBM XL 8.0 on PPC, with GNU ld
 	    hardcode_libdir_flag_spec_CXX='${wl}-rpath ${wl}$libdir'
 	    export_dynamic_flag_spec_CXX='${wl}--export-dynamic'
@@ -12394,13 +12990,13 @@
 	      archive_cmds_CXX='$CC -G${allow_undefined_flag} -h$soname -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags'
 	      archive_expsym_cmds_CXX='$CC -G${allow_undefined_flag} -h$soname -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-retain-symbols-file ${wl}$export_symbols'
 	      hardcode_libdir_flag_spec_CXX='-R$libdir'
-	      whole_archive_flag_spec_CXX='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; $ECHO \"$new_convenience\"` ${wl}--no-whole-archive'
+	      whole_archive_flag_spec_CXX='${wl}--whole-archive`new_convenience=; for conv in $convenience\"\"; do test -z \"$conv\" || new_convenience=\"$new_convenience,$conv\"; done; func_echo_all \"$new_convenience\"` ${wl}--no-whole-archive'
 	      compiler_needs_object_CXX=yes
 
 	      # Not sure whether something based on
 	      # $CC $CFLAGS -v conftest.$objext -o libconftest$shared_ext 2>&1
 	      # would be better.
-	      output_verbose_link_cmd='echo'
+	      output_verbose_link_cmd='func_echo_all'
 
 	      # Archives containing C++ object files must be created using
 	      # "CC -xar", where "CC" is the Sun C++ compiler.  This is
@@ -12469,7 +13065,7 @@
 	    export_dynamic_flag_spec_CXX='${wl}-E'
 	    whole_archive_flag_spec_CXX="$wlarc"'--whole-archive$convenience '"$wlarc"'--no-whole-archive'
 	  fi
-	  output_verbose_link_cmd=echo
+	  output_verbose_link_cmd=func_echo_all
 	else
 	  ld_shlibs_CXX=no
 	fi
@@ -12504,15 +13100,15 @@
 	    case $host in
 	      osf3*)
 	        allow_undefined_flag_CXX=' ${wl}-expect_unresolved ${wl}\*'
-	        archive_cmds_CXX='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $soname `test -n "$verstring" && $ECHO "X${wl}-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	        archive_cmds_CXX='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname $soname `test -n "$verstring" && func_echo_all "${wl}-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 	        hardcode_libdir_flag_spec_CXX='${wl}-rpath ${wl}$libdir'
 		;;
 	      *)
 	        allow_undefined_flag_CXX=' -expect_unresolved \*'
-	        archive_cmds_CXX='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib'
+	        archive_cmds_CXX='$CC -shared${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname `test -n "$verstring" && func_echo_all "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib'
 	        archive_expsym_cmds_CXX='for i in `cat $export_symbols`; do printf "%s %s\\n" -exported_symbol "\$i" >> $lib.exp; done~
 	          echo "-hidden">> $lib.exp~
-	          $CC -shared$allow_undefined_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname ${wl}-input ${wl}$lib.exp  `test -n "$verstring" && $ECHO "X-set_version $verstring" | $Xsed` -update_registry ${output_objdir}/so_locations -o $lib~
+	          $CC -shared$allow_undefined_flag $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags -msym -soname $soname ${wl}-input ${wl}$lib.exp  `test -n "$verstring" && $ECHO "-set_version $verstring"` -update_registry ${output_objdir}/so_locations -o $lib~
 	          $RM $lib.exp'
 	        hardcode_libdir_flag_spec_CXX='-rpath $libdir'
 		;;
@@ -12528,17 +13124,17 @@
 	    # explicitly linking system object files so we need to strip them
 	    # from the output so that they don't get included in the library
 	    # dependencies.
-	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld" | $GREP -v "ld:"`; templist=`$ECHO "X$templist" | $Xsed -e "s/\(^.*ld.*\)\( .*ld.*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; $ECHO "X$list" | $Xsed'
+	    output_verbose_link_cmd='templist=`$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "ld" | $GREP -v "ld:"`; templist=`func_echo_all "$templist" | $SED "s/\(^.*ld.*\)\( .*ld.*$\)/\1/"`; list=""; for z in $templist; do case $z in conftest.$objext) list="$list $z";; *.$objext);; *) list="$list $z";;esac; done; func_echo_all "$list"'
 	    ;;
 	  *)
 	    if test "$GXX" = yes && test "$with_gnu_ld" = no; then
 	      allow_undefined_flag_CXX=' ${wl}-expect_unresolved ${wl}\*'
 	      case $host in
 	        osf3*)
-	          archive_cmds_CXX='$CC -shared -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "X${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	          archive_cmds_CXX='$CC -shared -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 		  ;;
 	        *)
-	          archive_cmds_CXX='$CC -shared -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && $ECHO "${wl}-set_version ${wl}$verstring" | $Xsed` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
+	          archive_cmds_CXX='$CC -shared $pic_flag -nostdlib ${allow_undefined_flag} $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-msym ${wl}-soname ${wl}$soname `test -n "$verstring" && func_echo_all "${wl}-set_version ${wl}$verstring"` ${wl}-update_registry ${wl}${output_objdir}/so_locations -o $lib'
 		  ;;
 	      esac
 
@@ -12548,7 +13144,7 @@
 	      # Commands to make compiler produce verbose output that lists
 	      # what "hidden" libraries, object files and flags are used when
 	      # linking a shared library.
-	      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+	      output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 
 	    else
 	      # FIXME: insert proper C++ library support
@@ -12584,7 +13180,7 @@
 
       solaris*)
         case $cc_basename in
-          CC*)
+          CC* | sunCC*)
 	    # Sun C++ 4.2, 5.x and Centerline C++
             archive_cmds_need_lc_CXX=yes
 	    no_undefined_flag_CXX=' -zdefs'
@@ -12605,7 +13201,7 @@
 	    esac
 	    link_all_deplibs_CXX=yes
 
-	    output_verbose_link_cmd='echo'
+	    output_verbose_link_cmd='func_echo_all'
 
 	    # Archives containing C++ object files must be created using
 	    # "CC -xar", where "CC" is the Sun C++ compiler.  This is
@@ -12625,14 +13221,14 @@
 	    if test "$GXX" = yes && test "$with_gnu_ld" = no; then
 	      no_undefined_flag_CXX=' ${wl}-z ${wl}defs'
 	      if $CC --version | $GREP -v '^2\.7' > /dev/null; then
-	        archive_cmds_CXX='$CC -shared -nostdlib $LDFLAGS $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-h $wl$soname -o $lib'
+	        archive_cmds_CXX='$CC -shared $pic_flag -nostdlib $LDFLAGS $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags ${wl}-h $wl$soname -o $lib'
 	        archive_expsym_cmds_CXX='echo "{ global:" > $lib.exp~cat $export_symbols | $SED -e "s/\(.*\)/\1;/" >> $lib.exp~echo "local: *; };" >> $lib.exp~
-		  $CC -shared -nostdlib ${wl}-M $wl$lib.exp -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~$RM $lib.exp'
+		  $CC -shared $pic_flag -nostdlib ${wl}-M $wl$lib.exp -o $lib $predep_objects $libobjs $deplibs $postdep_objects $compiler_flags~$RM $lib.exp'
 
 	        # Commands to make compiler produce verbose output that lists
 	        # what "hidden" libraries, object files and flags are used when
 	        # linking a shared library.
-	        output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+	        output_verbose_link_cmd='$CC -shared $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 	      else
 	        # g++ 2.7 appears to require `-G' NOT `-shared' on this
 	        # platform.
@@ -12643,7 +13239,7 @@
 	        # Commands to make compiler produce verbose output that lists
 	        # what "hidden" libraries, object files and flags are used when
 	        # linking a shared library.
-	        output_verbose_link_cmd='$CC -G $CFLAGS -v conftest.$objext 2>&1 | $GREP "\-L"'
+	        output_verbose_link_cmd='$CC -G $CFLAGS -v conftest.$objext 2>&1 | $GREP -v "^Configured with:" | $GREP "\-L"'
 	      fi
 
 	      hardcode_libdir_flag_spec_CXX='${wl}-R $wl$libdir'
@@ -12697,6 +13293,10 @@
           CC*)
 	    archive_cmds_CXX='$CC -G ${wl}-h,$soname -o $lib $libobjs $deplibs $compiler_flags'
 	    archive_expsym_cmds_CXX='$CC -G ${wl}-Bexport:$export_symbols ${wl}-h,$soname -o $lib $libobjs $deplibs $compiler_flags'
+	    old_archive_cmds_CXX='$CC -Tprelink_objects $oldobjs~
+	      '"$old_archive_cmds_CXX"
+	    reload_cmds_CXX='$CC -Tprelink_objects $reload_objs~
+	      '"$reload_cmds_CXX"
 	    ;;
 	  *)
 	    archive_cmds_CXX='$CC -shared ${wl}-h,$soname -o $lib $libobjs $deplibs $compiler_flags'
@@ -12758,6 +13358,14 @@
 };
 _LT_EOF
 
+
+_lt_libdeps_save_CFLAGS=$CFLAGS
+case "$CC $CFLAGS " in #(
+*\ -flto*\ *) CFLAGS="$CFLAGS -fno-lto" ;;
+*\ -fwhopr*\ *) CFLAGS="$CFLAGS -fno-whopr" ;;
+*\ -fuse-linker-plugin*\ *) CFLAGS="$CFLAGS -fno-use-linker-plugin" ;;
+esac
+
 if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_compile\""; } >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
@@ -12771,7 +13379,7 @@
   pre_test_object_deps_done=no
 
   for p in `eval "$output_verbose_link_cmd"`; do
-    case $p in
+    case ${prev}${p} in
 
     -L* | -R* | -l*)
        # Some compilers place space between "-{L,R}" and the path.
@@ -12780,13 +13388,22 @@
           test $p = "-R"; then
 	 prev=$p
 	 continue
-       else
-	 prev=
        fi
 
+       # Expand the sysroot to ease extracting the directories later.
+       if test -z "$prev"; then
+         case $p in
+         -L*) func_stripname_cnf '-L' '' "$p"; prev=-L; p=$func_stripname_result ;;
+         -R*) func_stripname_cnf '-R' '' "$p"; prev=-R; p=$func_stripname_result ;;
+         -l*) func_stripname_cnf '-l' '' "$p"; prev=-l; p=$func_stripname_result ;;
+         esac
+       fi
+       case $p in
+       =*) func_stripname_cnf '=' '' "$p"; p=$lt_sysroot$func_stripname_result ;;
+       esac
        if test "$pre_test_object_deps_done" = no; then
-	 case $p in
-	 -L* | -R*)
+	 case ${prev} in
+	 -L | -R)
 	   # Internal compiler library paths should come after those
 	   # provided the user.  The postdeps already come after the
 	   # user supplied libs so there is no need to process them.
@@ -12806,8 +13423,10 @@
 	   postdeps_CXX="${postdeps_CXX} ${prev}${p}"
 	 fi
        fi
+       prev=
        ;;
 
+    *.lto.$objext) ;; # Ignore GCC LTO objects
     *.$objext)
        # This assumes that the test object file only shows up
        # once in the compiler output.
@@ -12843,6 +13462,7 @@
 fi
 
 $RM -f confest.$objext
+CFLAGS=$_lt_libdeps_save_CFLAGS
 
 # PORTME: override above test on systems where it is broken
 case $host_os in
@@ -12878,7 +13498,7 @@
 
 solaris*)
   case $cc_basename in
-  CC*)
+  CC* | sunCC*)
     # The more standards-conforming stlport4 library is
     # incompatible with the Cstd library. Avoid specifying
     # it if it's in CXXFLAGS. Ignore libCrun as
@@ -12943,8 +13563,6 @@
 lt_prog_compiler_pic_CXX=
 lt_prog_compiler_static_CXX=
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $compiler option to produce PIC" >&5
-$as_echo_n "checking for $compiler option to produce PIC... " >&6; }
 
   # C++ specific cases for pic, static, wl, etc.
   if test "$GXX" = yes; then
@@ -12994,6 +13612,11 @@
       # DJGPP does not support shared libraries at all
       lt_prog_compiler_pic_CXX=
       ;;
+    haiku*)
+      # PIC is the default for Haiku.
+      # The "-static" flag exists, but is broken.
+      lt_prog_compiler_static_CXX=
+      ;;
     interix[3-9]*)
       # Interix 3.x gcc -fpic/-fPIC options generate broken code.
       # Instead, we relocate shared libraries at runtime.
@@ -13043,6 +13666,11 @@
 	  ;;
 	esac
 	;;
+      mingw* | cygwin* | os2* | pw32* | cegcc*)
+	# This hack is so that the source file can tell whether it is being
+	# built for inclusion in a dll (and should export symbols for example).
+	lt_prog_compiler_pic_CXX='-DDLL_EXPORT'
+	;;
       dgux*)
 	case $cc_basename in
 	  ec++*)
@@ -13099,7 +13727,7 @@
 	    ;;
 	esac
 	;;
-      linux* | k*bsd*-gnu)
+      linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
 	case $cc_basename in
 	  KCC*)
 	    # KAI C++ Compiler
@@ -13132,8 +13760,8 @@
 	    lt_prog_compiler_pic_CXX=
 	    lt_prog_compiler_static_CXX='-non_shared'
 	    ;;
-	  xlc* | xlC*)
-	    # IBM XL 8.0 on PPC
+	  xlc* | xlC* | bgxl[cC]* | mpixl[cC]*)
+	    # IBM XL 8.0, 9.0 on PPC and BlueGene
 	    lt_prog_compiler_wl_CXX='-Wl,'
 	    lt_prog_compiler_pic_CXX='-qpic'
 	    lt_prog_compiler_static_CXX='-qstaticlink'
@@ -13195,7 +13823,7 @@
 	;;
       solaris*)
 	case $cc_basename in
-	  CC*)
+	  CC* | sunCC*)
 	    # Sun C++ 4.2, 5.x and Centerline C++
 	    lt_prog_compiler_pic_CXX='-KPIC'
 	    lt_prog_compiler_static_CXX='-Bstatic'
@@ -13260,10 +13888,17 @@
     lt_prog_compiler_pic_CXX="$lt_prog_compiler_pic_CXX -DPIC"
     ;;
 esac
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_prog_compiler_pic_CXX" >&5
-$as_echo "$lt_prog_compiler_pic_CXX" >&6; }
-
-
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $compiler option to produce PIC" >&5
+$as_echo_n "checking for $compiler option to produce PIC... " >&6; }
+if ${lt_cv_prog_compiler_pic_CXX+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_prog_compiler_pic_CXX=$lt_prog_compiler_pic_CXX
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_prog_compiler_pic_CXX" >&5
+$as_echo "$lt_cv_prog_compiler_pic_CXX" >&6; }
+lt_prog_compiler_pic_CXX=$lt_cv_prog_compiler_pic_CXX
 
 #
 # Check to make sure the PIC flag actually works.
@@ -13271,7 +13906,7 @@
 if test -n "$lt_prog_compiler_pic_CXX"; then
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler PIC flag $lt_prog_compiler_pic_CXX works" >&5
 $as_echo_n "checking if $compiler PIC flag $lt_prog_compiler_pic_CXX works... " >&6; }
-if test "${lt_cv_prog_compiler_pic_works_CXX+set}" = set; then :
+if ${lt_cv_prog_compiler_pic_works_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_pic_works_CXX=no
@@ -13287,15 +13922,15 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [^ ]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:13290: $lt_compile\"" >&5)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&5)
    (eval "$lt_compile" 2>conftest.err)
    ac_status=$?
    cat conftest.err >&5
-   echo "$as_me:13294: \$? = $ac_status" >&5
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
    if (exit $ac_status) && test -s "$ac_outfile"; then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings other than the usual output.
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' >conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' >conftest.exp
      $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
      if test ! -s conftest.er2 || diff conftest.exp conftest.er2 >/dev/null; then
        lt_cv_prog_compiler_pic_works_CXX=yes
@@ -13321,13 +13956,15 @@
 
 
 
+
+
 #
 # Check to make sure the static flag actually works.
 #
 wl=$lt_prog_compiler_wl_CXX eval lt_tmp_static_flag=\"$lt_prog_compiler_static_CXX\"
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler static flag $lt_tmp_static_flag works" >&5
 $as_echo_n "checking if $compiler static flag $lt_tmp_static_flag works... " >&6; }
-if test "${lt_cv_prog_compiler_static_works_CXX+set}" = set; then :
+if ${lt_cv_prog_compiler_static_works_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_static_works_CXX=no
@@ -13340,7 +13977,7 @@
      if test -s conftest.err; then
        # Append any errors to the config.log.
        cat conftest.err 1>&5
-       $ECHO "X$_lt_linker_boilerplate" | $Xsed -e '/^$/d' > conftest.exp
+       $ECHO "$_lt_linker_boilerplate" | $SED '/^$/d' > conftest.exp
        $SED '/^$/d; /^ *+/d' conftest.err >conftest.er2
        if diff conftest.exp conftest.er2 >/dev/null; then
          lt_cv_prog_compiler_static_works_CXX=yes
@@ -13367,7 +14004,7 @@
 
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler supports -c -o file.$ac_objext" >&5
 $as_echo_n "checking if $compiler supports -c -o file.$ac_objext... " >&6; }
-if test "${lt_cv_prog_compiler_c_o_CXX+set}" = set; then :
+if ${lt_cv_prog_compiler_c_o_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_c_o_CXX=no
@@ -13386,16 +14023,16 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [^ ]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:13389: $lt_compile\"" >&5)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&5)
    (eval "$lt_compile" 2>out/conftest.err)
    ac_status=$?
    cat out/conftest.err >&5
-   echo "$as_me:13393: \$? = $ac_status" >&5
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
    if (exit $ac_status) && test -s out/conftest2.$ac_objext
    then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' > out/conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' > out/conftest.exp
      $SED '/^$/d; /^ *+/d' out/conftest.err >out/conftest.er2
      if test ! -s out/conftest.er2 || diff out/conftest.exp out/conftest.er2 >/dev/null; then
        lt_cv_prog_compiler_c_o_CXX=yes
@@ -13419,7 +14056,7 @@
 
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking if $compiler supports -c -o file.$ac_objext" >&5
 $as_echo_n "checking if $compiler supports -c -o file.$ac_objext... " >&6; }
-if test "${lt_cv_prog_compiler_c_o_CXX+set}" = set; then :
+if ${lt_cv_prog_compiler_c_o_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   lt_cv_prog_compiler_c_o_CXX=no
@@ -13438,16 +14075,16 @@
    -e 's:.*FLAGS}\{0,1\} :&$lt_compiler_flag :; t' \
    -e 's: [^ ]*conftest\.: $lt_compiler_flag&:; t' \
    -e 's:$: $lt_compiler_flag:'`
-   (eval echo "\"\$as_me:13441: $lt_compile\"" >&5)
+   (eval echo "\"\$as_me:$LINENO: $lt_compile\"" >&5)
    (eval "$lt_compile" 2>out/conftest.err)
    ac_status=$?
    cat out/conftest.err >&5
-   echo "$as_me:13445: \$? = $ac_status" >&5
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
    if (exit $ac_status) && test -s out/conftest2.$ac_objext
    then
      # The compiler can only warn and ignore the option if not recognized
      # So say no if there are warnings
-     $ECHO "X$_lt_compiler_boilerplate" | $Xsed -e '/^$/d' > out/conftest.exp
+     $ECHO "$_lt_compiler_boilerplate" | $SED '/^$/d' > out/conftest.exp
      $SED '/^$/d; /^ *+/d' out/conftest.err >out/conftest.er2
      if test ! -s out/conftest.er2 || diff out/conftest.exp out/conftest.er2 >/dev/null; then
        lt_cv_prog_compiler_c_o_CXX=yes
@@ -13498,30 +14135,40 @@
 $as_echo_n "checking whether the $compiler linker ($LD) supports shared libraries... " >&6; }
 
   export_symbols_cmds_CXX='$NM $libobjs $convenience | $global_symbol_pipe | $SED '\''s/.* //'\'' | sort | uniq > $export_symbols'
+  exclude_expsyms_CXX='_GLOBAL_OFFSET_TABLE_|_GLOBAL__F[ID]_.*'
   case $host_os in
   aix[4-9]*)
     # If we're using GNU nm, then we don't want the "-C" option.
     # -C means demangle to AIX nm, but means don't demangle with GNU nm
+    # Also, AIX nm treats weak defined symbols like other global defined
+    # symbols, whereas GNU nm marks them as "W".
     if $NM -V 2>&1 | $GREP 'GNU' > /dev/null; then
-      export_symbols_cmds_CXX='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && (substr(\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
+      export_symbols_cmds_CXX='$NM -Bpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B") || (\$ 2 == "W")) && (substr(\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
     else
       export_symbols_cmds_CXX='$NM -BCpg $libobjs $convenience | awk '\''{ if (((\$ 2 == "T") || (\$ 2 == "D") || (\$ 2 == "B")) && (substr(\$ 3,1,1) != ".")) { print \$ 3 } }'\'' | sort -u > $export_symbols'
     fi
     ;;
   pw32*)
     export_symbols_cmds_CXX="$ltdll_cmds"
-  ;;
+    ;;
   cygwin* | mingw* | cegcc*)
-    export_symbols_cmds_CXX='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[BCDGRS][ ]/s/.*[ ]\([^ ]*\)/\1 DATA/;/^.*[ ]__nm__/s/^.*[ ]__nm__\([^ ]*\)[ ][^ ]*/\1 DATA/;/^I[ ]/d;/^[AITW][ ]/s/.* //'\'' | sort | uniq > $export_symbols'
-  ;;
-  linux* | k*bsd*-gnu)
+    case $cc_basename in
+    cl*)
+      exclude_expsyms_CXX='_NULL_IMPORT_DESCRIPTOR|_IMPORT_DESCRIPTOR_.*'
+      ;;
+    *)
+      export_symbols_cmds_CXX='$NM $libobjs $convenience | $global_symbol_pipe | $SED -e '\''/^[BCDGRS][ ]/s/.*[ ]\([^ ]*\)/\1 DATA/;s/^.*[ ]__nm__\([^ ]*\)[ ][^ ]*/\1 DATA/;/^I[ ]/d;/^[AITW][ ]/s/.* //'\'' | sort | uniq > $export_symbols'
+      exclude_expsyms_CXX='[_]+GLOBAL_OFFSET_TABLE_|[_]+GLOBAL__[FID]_.*|[_]+head_[A-Za-z0-9_]+_dll|[A-Za-z0-9_]+_dll_iname'
+      ;;
+    esac
+    ;;
+  linux* | k*bsd*-gnu | gnu*)
     link_all_deplibs_CXX=no
-  ;;
+    ;;
   *)
     export_symbols_cmds_CXX='$NM $libobjs $convenience | $global_symbol_pipe | $SED '\''s/.* //'\'' | sort | uniq > $export_symbols'
-  ;;
+    ;;
   esac
-  exclude_expsyms_CXX='_GLOBAL_OFFSET_TABLE_|_GLOBAL__F[ID]_.*'
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ld_shlibs_CXX" >&5
 $as_echo "$ld_shlibs_CXX" >&6; }
@@ -13553,44 +14200,50 @@
       # to ld, don't add -lc before -lgcc.
       { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether -lc should be explicitly linked in" >&5
 $as_echo_n "checking whether -lc should be explicitly linked in... " >&6; }
-      $RM conftest*
-      echo "$lt_simple_compile_test_code" > conftest.$ac_ext
+if ${lt_cv_archive_cmds_need_lc_CXX+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  $RM conftest*
+	echo "$lt_simple_compile_test_code" > conftest.$ac_ext
 
-      if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_compile\""; } >&5
+	if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$ac_compile\""; } >&5
   (eval $ac_compile) 2>&5
   ac_status=$?
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; } 2>conftest.err; then
-        soname=conftest
-        lib=conftest
-        libobjs=conftest.$ac_objext
-        deplibs=
-        wl=$lt_prog_compiler_wl_CXX
-	pic_flag=$lt_prog_compiler_pic_CXX
-        compiler_flags=-v
-        linker_flags=-v
-        verstring=
-        output_objdir=.
-        libname=conftest
-        lt_save_allow_undefined_flag=$allow_undefined_flag_CXX
-        allow_undefined_flag_CXX=
-        if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$archive_cmds_CXX 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1\""; } >&5
+	  soname=conftest
+	  lib=conftest
+	  libobjs=conftest.$ac_objext
+	  deplibs=
+	  wl=$lt_prog_compiler_wl_CXX
+	  pic_flag=$lt_prog_compiler_pic_CXX
+	  compiler_flags=-v
+	  linker_flags=-v
+	  verstring=
+	  output_objdir=.
+	  libname=conftest
+	  lt_save_allow_undefined_flag=$allow_undefined_flag_CXX
+	  allow_undefined_flag_CXX=
+	  if { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$archive_cmds_CXX 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1\""; } >&5
   (eval $archive_cmds_CXX 2\>\&1 \| $GREP \" -lc \" \>/dev/null 2\>\&1) 2>&5
   ac_status=$?
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }
-        then
-	  archive_cmds_need_lc_CXX=no
-        else
-	  archive_cmds_need_lc_CXX=yes
-        fi
-        allow_undefined_flag_CXX=$lt_save_allow_undefined_flag
-      else
-        cat conftest.err 1>&5
-      fi
-      $RM conftest*
-      { $as_echo "$as_me:${as_lineno-$LINENO}: result: $archive_cmds_need_lc_CXX" >&5
-$as_echo "$archive_cmds_need_lc_CXX" >&6; }
+	  then
+	    lt_cv_archive_cmds_need_lc_CXX=no
+	  else
+	    lt_cv_archive_cmds_need_lc_CXX=yes
+	  fi
+	  allow_undefined_flag_CXX=$lt_save_allow_undefined_flag
+	else
+	  cat conftest.err 1>&5
+	fi
+	$RM conftest*
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $lt_cv_archive_cmds_need_lc_CXX" >&5
+$as_echo "$lt_cv_archive_cmds_need_lc_CXX" >&6; }
+      archive_cmds_need_lc_CXX=$lt_cv_archive_cmds_need_lc_CXX
       ;;
     esac
   fi
@@ -13658,8 +14311,6 @@
 
 
 
-
-
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking dynamic linker characteristics" >&5
 $as_echo_n "checking dynamic linker characteristics... " >&6; }
 
@@ -13685,7 +14336,7 @@
 
 case $host_os in
 aix3*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix $libname.a'
   shlibpath_var=LIBPATH
 
@@ -13694,7 +14345,7 @@
   ;;
 
 aix[4-9]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   hardcode_into_libs=yes
@@ -13747,7 +14398,7 @@
   m68k)
     library_names_spec='$libname.ixlibrary $libname.a'
     # Create ${libname}_ixlibrary.a entries in /sys/libs.
-    finish_eval='for lib in `ls $libdir/*.ixlibrary 2>/dev/null`; do libname=`$ECHO "X$lib" | $Xsed -e '\''s%^.*/\([^/]*\)\.ixlibrary$%\1%'\''`; test $RM /sys/libs/${libname}_ixlibrary.a; $show "cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a"; cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a || exit 1; done'
+    finish_eval='for lib in `ls $libdir/*.ixlibrary 2>/dev/null`; do libname=`func_echo_all "$lib" | $SED '\''s%^.*/\([^/]*\)\.ixlibrary$%\1%'\''`; test $RM /sys/libs/${libname}_ixlibrary.a; $show "cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a"; cd /sys/libs && $LN_S $lib ${libname}_ixlibrary.a || exit 1; done'
     ;;
   esac
   ;;
@@ -13759,7 +14410,7 @@
   ;;
 
 bsdi[45]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
@@ -13778,8 +14429,9 @@
   need_version=no
   need_lib_prefix=no
 
-  case $GCC,$host_os in
-  yes,cygwin* | yes,mingw* | yes,pw32* | yes,cegcc*)
+  case $GCC,$cc_basename in
+  yes,*)
+    # gcc
     library_names_spec='$libname.dll.a'
     # DLL is installed to $(libdir)/../bin by postinstall_cmds
     postinstall_cmds='base_file=`basename \${file}`~
@@ -13800,36 +14452,82 @@
     cygwin*)
       # Cygwin DLLs use 'cyg' prefix rather than 'lib'
       soname_spec='`echo ${libname} | sed -e 's/^lib/cyg/'``echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
-      sys_lib_search_path_spec="/usr/lib /lib/w32api /lib /usr/local/lib"
+
       ;;
     mingw* | cegcc*)
       # MinGW DLLs use traditional 'lib' prefix
       soname_spec='${libname}`echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
-      sys_lib_search_path_spec=`$CC -print-search-dirs | $GREP "^libraries:" | $SED -e "s/^libraries://" -e "s,=/,/,g"`
-      if $ECHO "$sys_lib_search_path_spec" | $GREP ';[c-zC-Z]:/' >/dev/null; then
-        # It is most probably a Windows format PATH printed by
-        # mingw gcc, but we are running on Cygwin. Gcc prints its search
-        # path with ; separators, and with drive letters. We can handle the
-        # drive letters (cygwin fileutils understands them), so leave them,
-        # especially as we might pass files found there to a mingw objdump,
-        # which wouldn't understand a cygwinified path. Ahh.
-        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e 's/;/ /g'`
-      else
-        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED  -e "s/$PATH_SEPARATOR/ /g"`
-      fi
       ;;
     pw32*)
       # pw32 DLLs use 'pw' prefix rather than 'lib'
       library_names_spec='`echo ${libname} | sed -e 's/^lib/pw/'``echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
       ;;
     esac
+    dynamic_linker='Win32 ld.exe'
+    ;;
+
+  *,cl*)
+    # Native MSVC
+    libname_spec='$name'
+    soname_spec='${libname}`echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext}'
+    library_names_spec='${libname}.dll.lib'
+
+    case $build_os in
+    mingw*)
+      sys_lib_search_path_spec=
+      lt_save_ifs=$IFS
+      IFS=';'
+      for lt_path in $LIB
+      do
+        IFS=$lt_save_ifs
+        # Let DOS variable expansion print the short 8.3 style file name.
+        lt_path=`cd "$lt_path" 2>/dev/null && cmd //C "for %i in (".") do @echo %~si"`
+        sys_lib_search_path_spec="$sys_lib_search_path_spec $lt_path"
+      done
+      IFS=$lt_save_ifs
+      # Convert to MSYS style.
+      sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | sed -e 's|\\\\|/|g' -e 's| \\([a-zA-Z]\\):| /\\1|g' -e 's|^ ||'`
+      ;;
+    cygwin*)
+      # Convert to unix form, then to dos form, then back to unix form
+      # but this time dos style (no spaces!) so that the unix form looks
+      # like /cygdrive/c/PROGRA~1:/cygdr...
+      sys_lib_search_path_spec=`cygpath --path --unix "$LIB"`
+      sys_lib_search_path_spec=`cygpath --path --dos "$sys_lib_search_path_spec" 2>/dev/null`
+      sys_lib_search_path_spec=`cygpath --path --unix "$sys_lib_search_path_spec" | $SED -e "s/$PATH_SEPARATOR/ /g"`
+      ;;
+    *)
+      sys_lib_search_path_spec="$LIB"
+      if $ECHO "$sys_lib_search_path_spec" | $GREP ';[c-zC-Z]:/' >/dev/null; then
+        # It is most probably a Windows format PATH.
+        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e 's/;/ /g'`
+      else
+        sys_lib_search_path_spec=`$ECHO "$sys_lib_search_path_spec" | $SED -e "s/$PATH_SEPARATOR/ /g"`
+      fi
+      # FIXME: find the short name or the path components, as spaces are
+      # common. (e.g. "Program Files" -> "PROGRA~1")
+      ;;
+    esac
+
+    # DLL is installed to $(libdir)/../bin by postinstall_cmds
+    postinstall_cmds='base_file=`basename \${file}`~
+      dlpath=`$SHELL 2>&1 -c '\''. $dir/'\''\${base_file}'\''i; echo \$dlname'\''`~
+      dldir=$destdir/`dirname \$dlpath`~
+      test -d \$dldir || mkdir -p \$dldir~
+      $install_prog $dir/$dlname \$dldir/$dlname'
+    postuninstall_cmds='dldll=`$SHELL 2>&1 -c '\''. $file; echo \$dlname'\''`~
+      dlpath=$dir/\$dldll~
+       $RM \$dlpath'
+    shlibpath_overrides_runpath=yes
+    dynamic_linker='Win32 link.exe'
     ;;
 
   *)
+    # Assume MSVC wrapper
     library_names_spec='${libname}`echo ${release} | $SED -e 's/[.]/-/g'`${versuffix}${shared_ext} $libname.lib'
+    dynamic_linker='Win32 ld.exe'
     ;;
   esac
-  dynamic_linker='Win32 ld.exe'
   # FIXME: first we should search . and the directory the executable is in
   shlibpath_var=PATH
   ;;
@@ -13849,7 +14547,7 @@
   ;;
 
 dgux*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname$shared_ext'
@@ -13857,10 +14555,6 @@
   shlibpath_var=LD_LIBRARY_PATH
   ;;
 
-freebsd1*)
-  dynamic_linker=no
-  ;;
-
 freebsd* | dragonfly*)
   # DragonFly does not have aout.  When/if they implement a new
   # versioning mechanism, adjust this.
@@ -13868,7 +14562,7 @@
     objformat=`/usr/bin/objformat`
   else
     case $host_os in
-    freebsd[123]*) objformat=aout ;;
+    freebsd[23].*) objformat=aout ;;
     *) objformat=elf ;;
     esac
   fi
@@ -13886,7 +14580,7 @@
   esac
   shlibpath_var=LD_LIBRARY_PATH
   case $host_os in
-  freebsd2*)
+  freebsd2.*)
     shlibpath_overrides_runpath=yes
     ;;
   freebsd3.[01]* | freebsdelf3.[01]*)
@@ -13905,13 +14599,16 @@
   esac
   ;;
 
-gnu*)
-  version_type=linux
+haiku*)
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
+  dynamic_linker="$host_os runtime_loader"
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}${major} ${libname}${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
-  shlibpath_var=LD_LIBRARY_PATH
+  shlibpath_var=LIBRARY_PATH
+  shlibpath_overrides_runpath=yes
+  sys_lib_dlsearch_path_spec='/boot/home/config/lib /boot/common/lib /boot/system/lib'
   hardcode_into_libs=yes
   ;;
 
@@ -13957,12 +14654,14 @@
     soname_spec='${libname}${release}${shared_ext}$major'
     ;;
   esac
-  # HP-UX runs *really* slowly unless shared libraries are mode 555.
+  # HP-UX runs *really* slowly unless shared libraries are mode 555, ...
   postinstall_cmds='chmod 555 $lib'
+  # or fails outright, so override atomically:
+  install_override_mode=555
   ;;
 
 interix[3-9]*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major ${libname}${shared_ext}'
@@ -13978,7 +14677,7 @@
     nonstopux*) version_type=nonstopux ;;
     *)
 	if test "$lt_cv_prog_gnu_ld" = yes; then
-		version_type=linux
+		version_type=linux # correct to gnu/linux during the next big refactor
 	else
 		version_type=irix
 	fi ;;
@@ -14015,9 +14714,9 @@
   dynamic_linker=no
   ;;
 
-# This must be Linux ELF.
-linux* | k*bsd*-gnu)
-  version_type=linux
+# This must be glibc/ELF.
+linux* | k*bsd*-gnu | kopensolaris*-gnu | gnu*)
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -14025,12 +14724,17 @@
   finish_cmds='PATH="\$PATH:/sbin" ldconfig -n $libdir'
   shlibpath_var=LD_LIBRARY_PATH
   shlibpath_overrides_runpath=no
+
   # Some binutils ld are patched to set DT_RUNPATH
-  save_LDFLAGS=$LDFLAGS
-  save_libdir=$libdir
-  eval "libdir=/foo; wl=\"$lt_prog_compiler_wl_CXX\"; \
-       LDFLAGS=\"\$LDFLAGS $hardcode_libdir_flag_spec_CXX\""
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+  if ${lt_cv_shlibpath_overrides_runpath+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  lt_cv_shlibpath_overrides_runpath=no
+    save_LDFLAGS=$LDFLAGS
+    save_libdir=$libdir
+    eval "libdir=/foo; wl=\"$lt_prog_compiler_wl_CXX\"; \
+	 LDFLAGS=\"\$LDFLAGS $hardcode_libdir_flag_spec_CXX\""
+    cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -14043,13 +14747,17 @@
 _ACEOF
 if ac_fn_cxx_try_link "$LINENO"; then :
   if  ($OBJDUMP -p conftest$ac_exeext) 2>/dev/null | grep "RUNPATH.*$libdir" >/dev/null; then :
-  shlibpath_overrides_runpath=yes
+  lt_cv_shlibpath_overrides_runpath=yes
 fi
 fi
 rm -f core conftest.err conftest.$ac_objext \
     conftest$ac_exeext conftest.$ac_ext
-  LDFLAGS=$save_LDFLAGS
-  libdir=$save_libdir
+    LDFLAGS=$save_LDFLAGS
+    libdir=$save_libdir
+
+fi
+
+  shlibpath_overrides_runpath=$lt_cv_shlibpath_overrides_runpath
 
   # This implies no fast_install, which is unacceptable.
   # Some rework will be needed to allow for fast_install
@@ -14058,7 +14766,7 @@
 
   # Append ld.so.conf contents to the search path
   if test -f /etc/ld.so.conf; then
-    lt_ld_extra=`awk '/^include / { system(sprintf("cd /etc; cat %s 2>/dev/null", \$2)); skip = 1; } { if (!skip) print \$0; skip = 0; }' < /etc/ld.so.conf | $SED -e 's/#.*//;/^[	 ]*hwcap[	 ]/d;s/[:,	]/ /g;s/=[^=]*$//;s/=[^= ]* / /g;/^$/d' | tr '\n' ' '`
+    lt_ld_extra=`awk '/^include / { system(sprintf("cd /etc; cat %s 2>/dev/null", \$2)); skip = 1; } { if (!skip) print \$0; skip = 0; }' < /etc/ld.so.conf | $SED -e 's/#.*//;/^[	 ]*hwcap[	 ]/d;s/[:,	]/ /g;s/=[^=]*$//;s/=[^= ]* / /g;s/"//g;/^$/d' | tr '\n' ' '`
     sys_lib_dlsearch_path_spec="/lib /usr/lib $lt_ld_extra"
   fi
 
@@ -14102,7 +14810,7 @@
   ;;
 
 newsos6)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   shlibpath_var=LD_LIBRARY_PATH
   shlibpath_overrides_runpath=yes
@@ -14171,7 +14879,7 @@
   ;;
 
 solaris*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -14196,7 +14904,7 @@
   ;;
 
 sysv4 | sysv4.3*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
   shlibpath_var=LD_LIBRARY_PATH
@@ -14220,7 +14928,7 @@
 
 sysv4*MP*)
   if test -d /usr/nec ;then
-    version_type=linux
+    version_type=linux # correct to gnu/linux during the next big refactor
     library_names_spec='$libname${shared_ext}.$versuffix $libname${shared_ext}.$major $libname${shared_ext}'
     soname_spec='$libname${shared_ext}.$major'
     shlibpath_var=LD_LIBRARY_PATH
@@ -14251,7 +14959,7 @@
 
 tpf*)
   # TPF is a cross-target only.  Preferred cross-host = GNU/Linux.
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   need_lib_prefix=no
   need_version=no
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
@@ -14261,7 +14969,7 @@
   ;;
 
 uts4*)
-  version_type=linux
+  version_type=linux # correct to gnu/linux during the next big refactor
   library_names_spec='${libname}${release}${shared_ext}$versuffix ${libname}${release}${shared_ext}$major $libname${shared_ext}'
   soname_spec='${libname}${release}${shared_ext}$major'
   shlibpath_var=LD_LIBRARY_PATH
@@ -14322,6 +15030,8 @@
 
 
 
+
+
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking how to hardcode library paths into programs" >&5
 $as_echo_n "checking how to hardcode library paths into programs... " >&6; }
 hardcode_action_CXX=
@@ -14369,6 +15079,7 @@
   fi # test -n "$compiler"
 
   CC=$lt_save_CC
+  CFLAGS=$lt_save_CFLAGS
   LDCXX=$LD
   LD=$lt_save_LD
   GCC=$lt_save_GCC
@@ -14397,6 +15108,8 @@
 
 
 
+
+
         ac_config_commands="$ac_config_commands libtool"
 
 
@@ -14430,6 +15143,34 @@
     LDFLAGS="-L$libpath $LDFLAGS"
 done
 
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether GCC atomic builtins are available" >&5
+$as_echo_n "checking whether GCC atomic builtins are available... " >&6; }
+echo 'int main(int argc, char* argv) { int i; __sync_add_and_fetch(&i, 1); __sync_sub_and_fetch(&i, 1); return 0; } ' > check_atomicbuiltins.c
+if test -z "`${CC} check_atomicbuiltins.c -o check_atomicbuiltins 2>&1`" ; then
+	HAVE_GCC_ATOMIC_BUILTINS=yes
+
+$as_echo "#define HAVE_GCC_ATOMIC_BUILTINS 1" >>confdefs.h
+
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+$as_echo "yes" >&6; }
+	if test $cross_compiling == "yes"; then
+		# Some platforms don't seem to be fully happy for libraries using GCC atomic builtins
+		#  unless -lgcc and -lgcc_s are explicitly included.
+		# (Errors like
+		# ld: hidden symbol `__sync_add_and_fetch_4' in .../libgcc.a(linux-atomic.o) is referenced by DSO
+		# ld: final link failed: Nonrepresentable section on output)
+		LDFLAGS="$LDFLAGS -lgcc -lgcc_s"
+	fi
+else
+	HAVE_GCC_ATOMIC_BUILTINS=no
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+rm -f check_atomicbuiltins*
+HAVE_GCC_ATOMIC_BUILTINS=$HAVE_GCC_ATOMIC_BUILTINS
+
+
+
 
 
 # Check whether --with-libidn was given.
@@ -14445,10 +15186,10 @@
     CPPFLAGS="${CPPFLAGS} -I$libidn/include"
   fi
   ac_fn_c_check_header_mongrel "$LINENO" "idna.h" "ac_cv_header_idna_h" "$ac_includes_default"
-if test "x$ac_cv_header_idna_h" = x""yes; then :
+if test "x$ac_cv_header_idna_h" = xyes; then :
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for stringprep_check_version in -lidn" >&5
 $as_echo_n "checking for stringprep_check_version in -lidn... " >&6; }
-if test "${ac_cv_lib_idn_stringprep_check_version+set}" = set; then :
+if ${ac_cv_lib_idn_stringprep_check_version+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -14482,7 +15223,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_idn_stringprep_check_version" >&5
 $as_echo "$ac_cv_lib_idn_stringprep_check_version" >&6; }
-if test "x$ac_cv_lib_idn_stringprep_check_version" = x""yes; then :
+if test "x$ac_cv_lib_idn_stringprep_check_version" = xyes; then :
   libidn=yes LIBS="${LIBS} -lidn"
 else
   libidn=no
@@ -14558,10 +15299,10 @@
       CPPFLAGS="${CPPFLAGS} `pkg-config gnutls --cflags`"
     fi
     ac_fn_c_check_header_mongrel "$LINENO" "gnutls/gnutls.h" "ac_cv_header_gnutls_gnutls_h" "$ac_includes_default"
-if test "x$ac_cv_header_gnutls_gnutls_h" = x""yes; then :
+if test "x$ac_cv_header_gnutls_gnutls_h" = xyes; then :
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for gnutls_check_version in -lgnutls" >&5
 $as_echo_n "checking for gnutls_check_version in -lgnutls... " >&6; }
-if test "${ac_cv_lib_gnutls_gnutls_check_version+set}" = set; then :
+if ${ac_cv_lib_gnutls_gnutls_check_version+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -14595,8 +15336,8 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gnutls_gnutls_check_version" >&5
 $as_echo "$ac_cv_lib_gnutls_gnutls_check_version" >&6; }
-if test "x$ac_cv_lib_gnutls_gnutls_check_version" = x""yes; then :
-  gnutls=yes LIBS="${LIBS} `pkg-config gnutls --libs`"
+if test "x$ac_cv_lib_gnutls_gnutls_check_version" = xyes; then :
+  gnutls=yes LIBS="${LIBS} `pkg-config gnutls --libs` -lgcrypt"
 else
   gnutls=no
 fi
@@ -14612,6 +15353,53 @@
 $as_echo "#define HAVE_GNUTLS 1" >>confdefs.h
 
     ssl=yes
+    { $as_echo "$as_me:${as_lineno-$LINENO}: checking for gnutls_session_channel_binding in -lgnutls" >&5
+$as_echo_n "checking for gnutls_session_channel_binding in -lgnutls... " >&6; }
+if ${ac_cv_lib_gnutls_gnutls_session_channel_binding+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  ac_check_lib_save_LIBS=$LIBS
+LIBS="-lgnutls  $LIBS"
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+/* Override any GCC internal prototype to avoid an error.
+   Use char because int might match the return type of a GCC
+   builtin and then its argument prototype would still apply.  */
+#ifdef __cplusplus
+extern "C"
+#endif
+char gnutls_session_channel_binding ();
+int
+main ()
+{
+return gnutls_session_channel_binding ();
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  ac_cv_lib_gnutls_gnutls_session_channel_binding=yes
+else
+  ac_cv_lib_gnutls_gnutls_session_channel_binding=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+LIBS=$ac_check_lib_save_LIBS
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_gnutls_gnutls_session_channel_binding" >&5
+$as_echo "$ac_cv_lib_gnutls_gnutls_session_channel_binding" >&6; }
+if test "x$ac_cv_lib_gnutls_gnutls_session_channel_binding" = xyes; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
+$as_echo "yes" >&6; }
+
+$as_echo "#define HAVE_GNUTLS_SESSION_CHANNEL_BINDING 1" >>confdefs.h
+
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
   else
     { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: GnuTLS not found" >&5
 $as_echo "$as_me: WARNING: GnuTLS not found" >&2;}
@@ -14639,10 +15427,10 @@
     LIBS_TMP=${LIBS}
     LIBS="${LIBS} -lssl -lcrypto"
     ac_fn_c_check_header_mongrel "$LINENO" "openssl/ssl.h" "ac_cv_header_openssl_ssl_h" "$ac_includes_default"
-if test "x$ac_cv_header_openssl_ssl_h" = x""yes; then :
+if test "x$ac_cv_header_openssl_ssl_h" = xyes; then :
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for SSL_library_init in -lssl" >&5
 $as_echo_n "checking for SSL_library_init in -lssl... " >&6; }
-if test "${ac_cv_lib_ssl_SSL_library_init+set}" = set; then :
+if ${ac_cv_lib_ssl_SSL_library_init+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -14676,7 +15464,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_ssl_SSL_library_init" >&5
 $as_echo "$ac_cv_lib_ssl_SSL_library_init" >&6; }
-if test "x$ac_cv_lib_ssl_SSL_library_init" = x""yes; then :
+if test "x$ac_cv_lib_ssl_SSL_library_init" = xyes; then :
   openssl=yes
 else
   openssl=no
@@ -14716,10 +15504,10 @@
     CPPFLAGS="${CPPFLAGS} -I$zlib/include"
   fi
   ac_fn_c_check_header_mongrel "$LINENO" "zlib.h" "ac_cv_header_zlib_h" "$ac_includes_default"
-if test "x$ac_cv_header_zlib_h" = x""yes; then :
+if test "x$ac_cv_header_zlib_h" = xyes; then :
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for zlibVersion in -lz" >&5
 $as_echo_n "checking for zlibVersion in -lz... " >&6; }
-if test "${ac_cv_lib_z_zlibVersion+set}" = set; then :
+if ${ac_cv_lib_z_zlibVersion+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -14753,7 +15541,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_z_zlibVersion" >&5
 $as_echo "$ac_cv_lib_z_zlibVersion" >&6; }
-if test "x$ac_cv_lib_z_zlibVersion" = x""yes; then :
+if test "x$ac_cv_lib_z_zlibVersion" = xyes; then :
   zlib=yes LIBS="${LIBS} -lz"
 else
   zlib=no
@@ -14903,7 +15691,7 @@
 set dummy pthread-config; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_acx_pthread_config+set}" = set; then :
+if ${ac_cv_prog_acx_pthread_config+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$acx_pthread_config"; then
@@ -14915,7 +15703,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_acx_pthread_config="yes"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -15059,7 +15847,7 @@
 set dummy $ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_PTHREAD_CC+set}" = set; then :
+if ${ac_cv_prog_PTHREAD_CC+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$PTHREAD_CC"; then
@@ -15071,7 +15859,7 @@
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_PTHREAD_CC="$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -15131,7 +15919,7 @@
 for ac_func in res_querydomain
 do :
   ac_fn_c_check_func "$LINENO" "res_querydomain" "ac_cv_func_res_querydomain"
-if test "x$ac_cv_func_res_querydomain" = x""yes; then :
+if test "x$ac_cv_func_res_querydomain" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_RES_QUERYDOMAIN 1
 _ACEOF
@@ -15144,7 +15932,7 @@
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for res_querydomain in -lresolv" >&5
 $as_echo_n "checking for res_querydomain in -lresolv... " >&6; }
-if test "${ac_cv_lib_resolv_res_querydomain+set}" = set; then :
+if ${ac_cv_lib_resolv_res_querydomain+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -15178,7 +15966,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_resolv_res_querydomain" >&5
 $as_echo "$ac_cv_lib_resolv_res_querydomain" >&6; }
-if test "x$ac_cv_lib_resolv_res_querydomain" = x""yes; then :
+if test "x$ac_cv_lib_resolv_res_querydomain" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_LIBRESOLV 1
 _ACEOF
@@ -15194,7 +15982,7 @@
   else
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for res_querydomain in -lbind" >&5
 $as_echo_n "checking for res_querydomain in -lbind... " >&6; }
-if test "${ac_cv_lib_bind_res_querydomain+set}" = set; then :
+if ${ac_cv_lib_bind_res_querydomain+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -15228,7 +16016,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_bind_res_querydomain" >&5
 $as_echo "$ac_cv_lib_bind_res_querydomain" >&6; }
-if test "x$ac_cv_lib_bind_res_querydomain" = x""yes; then :
+if test "x$ac_cv_lib_bind_res_querydomain" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_LIBBIND 1
 _ACEOF
@@ -15277,7 +16065,7 @@
 for ac_func in dn_skipname
 do :
   ac_fn_c_check_func "$LINENO" "dn_skipname" "ac_cv_func_dn_skipname"
-if test "x$ac_cv_func_dn_skipname" = x""yes; then :
+if test "x$ac_cv_func_dn_skipname" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_DN_SKIPNAME 1
 _ACEOF
@@ -15290,7 +16078,7 @@
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for dn_skipname in -lresolv" >&5
 $as_echo_n "checking for dn_skipname in -lresolv... " >&6; }
-if test "${ac_cv_lib_resolv_dn_skipname+set}" = set; then :
+if ${ac_cv_lib_resolv_dn_skipname+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -15324,7 +16112,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_resolv_dn_skipname" >&5
 $as_echo "$ac_cv_lib_resolv_dn_skipname" >&6; }
-if test "x$ac_cv_lib_resolv_dn_skipname" = x""yes; then :
+if test "x$ac_cv_lib_resolv_dn_skipname" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_LIBRESOLV 1
 _ACEOF
@@ -15340,7 +16128,7 @@
   else
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for dn_skipname in -lbind" >&5
 $as_echo_n "checking for dn_skipname in -lbind... " >&6; }
-if test "${ac_cv_lib_bind_dn_skipname+set}" = set; then :
+if ${ac_cv_lib_bind_dn_skipname+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -15374,7 +16162,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_bind_dn_skipname" >&5
 $as_echo "$ac_cv_lib_bind_dn_skipname" >&6; }
-if test "x$ac_cv_lib_bind_dn_skipname" = x""yes; then :
+if test "x$ac_cv_lib_bind_dn_skipname" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_LIBBIND 1
 _ACEOF
@@ -15424,7 +16212,7 @@
 for ac_func in res_query
 do :
   ac_fn_c_check_func "$LINENO" "res_query" "ac_cv_func_res_query"
-if test "x$ac_cv_func_res_query" = x""yes; then :
+if test "x$ac_cv_func_res_query" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_RES_QUERY 1
 _ACEOF
@@ -15437,7 +16225,7 @@
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for res_query in -lresolv" >&5
 $as_echo_n "checking for res_query in -lresolv... " >&6; }
-if test "${ac_cv_lib_resolv_res_query+set}" = set; then :
+if ${ac_cv_lib_resolv_res_query+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -15471,7 +16259,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_resolv_res_query" >&5
 $as_echo "$ac_cv_lib_resolv_res_query" >&6; }
-if test "x$ac_cv_lib_resolv_res_query" = x""yes; then :
+if test "x$ac_cv_lib_resolv_res_query" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_LIBRESOLV 1
 _ACEOF
@@ -15487,7 +16275,7 @@
   else
     { $as_echo "$as_me:${as_lineno-$LINENO}: checking for res_query in -lbind" >&5
 $as_echo_n "checking for res_query in -lbind... " >&6; }
-if test "${ac_cv_lib_bind_res_query+set}" = set; then :
+if ${ac_cv_lib_bind_res_query+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -15521,7 +16309,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_bind_res_query" >&5
 $as_echo "$ac_cv_lib_bind_res_query" >&6; }
-if test "x$ac_cv_lib_bind_res_query" = x""yes; then :
+if test "x$ac_cv_lib_bind_res_query" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_LIBBIND 1
 _ACEOF
@@ -15545,7 +16333,7 @@
 int
 main ()
 {
-res_query(0,0)
+res_query(0,0,0,0,0)
   ;
   return 0;
 }
@@ -15602,7 +16390,7 @@
     for ac_func in getaddrinfo
 do :
   ac_fn_c_check_func "$LINENO" "getaddrinfo" "ac_cv_func_getaddrinfo"
-if test "x$ac_cv_func_getaddrinfo" = x""yes; then :
+if test "x$ac_cv_func_getaddrinfo" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_GETADDRINFO 1
 _ACEOF
@@ -15620,7 +16408,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for ANSI C header files" >&5
 $as_echo_n "checking for ANSI C header files... " >&6; }
-if test "${ac_cv_header_stdc+set}" = set; then :
+if ${ac_cv_header_stdc+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -15734,8 +16522,7 @@
 do :
   as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
 ac_fn_c_check_header_mongrel "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default"
-eval as_val=\$$as_ac_Header
-   if test "x$as_val" = x""yes; then :
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
   cat >>confdefs.h <<_ACEOF
 #define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
 _ACEOF
@@ -15747,7 +16534,7 @@
 for ac_func in setsockopt
 do :
   ac_fn_c_check_func "$LINENO" "setsockopt" "ac_cv_func_setsockopt"
-if test "x$ac_cv_func_setsockopt" = x""yes; then :
+if test "x$ac_cv_func_setsockopt" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_SETSOCKOPT 1
 _ACEOF
@@ -15755,7 +16542,7 @@
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: checking for setsockopt in -lsocket" >&5
 $as_echo_n "checking for setsockopt in -lsocket... " >&6; }
-if test "${ac_cv_lib_socket_setsockopt+set}" = set; then :
+if ${ac_cv_lib_socket_setsockopt+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_check_lib_save_LIBS=$LIBS
@@ -15789,7 +16576,7 @@
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_socket_setsockopt" >&5
 $as_echo "$ac_cv_lib_socket_setsockopt" >&6; }
-if test "x$ac_cv_lib_socket_setsockopt" = x""yes; then :
+if test "x$ac_cv_lib_socket_setsockopt" = xyes; then :
   cat >>confdefs.h <<_ACEOF
 #define HAVE_LIBSOCKET 1
 _ACEOF
@@ -15804,7 +16591,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for an ANSI C-conforming const" >&5
 $as_echo_n "checking for an ANSI C-conforming const... " >&6; }
-if test "${ac_cv_c_const+set}" = set; then :
+if ${ac_cv_c_const+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -15813,11 +16600,11 @@
 int
 main ()
 {
-/* FIXME: Include the comments suggested by Paul. */
+
 #ifndef __cplusplus
-  /* Ultrix mips cc rejects this.  */
+  /* Ultrix mips cc rejects this sort of thing.  */
   typedef int charset[2];
-  const charset cs;
+  const charset cs = { 0, 0 };
   /* SunOS 4.1.1 cc rejects this.  */
   char const *const *pcpcc;
   char **ppc;
@@ -15834,8 +16621,9 @@
   ++pcpcc;
   ppc = (char**) pcpcc;
   pcpcc = (char const *const *) ppc;
-  { /* SCO 3.2v4 cc rejects this.  */
-    char *t;
+  { /* SCO 3.2v4 cc rejects this sort of thing.  */
+    char tx;
+    char *t = &tx;
     char const *s = 0 ? (char *) 0 : (char const *) 0;
 
     *t++ = 0;
@@ -15851,10 +16639,10 @@
     iptr p = 0;
     ++p;
   }
-  { /* AIX XL C 1.02.0.0 rejects this saying
+  { /* AIX XL C 1.02.0.0 rejects this sort of thing, saying
        "k.c", line 2.27: 1506-025 (S) Operand must be a modifiable lvalue. */
-    struct s { int j; const int *ap[3]; };
-    struct s *b; b->j = 5;
+    struct s { int j; const int *ap[3]; } bx;
+    struct s *b = &bx; b->j = 5;
   }
   { /* ULTRIX-32 V3.1 (Rev 9) vcc rejects this */
     const int foo = 10;
@@ -15884,7 +16672,7 @@
 
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for inline" >&5
 $as_echo_n "checking for inline... " >&6; }
-if test "${ac_cv_c_inline+set}" = set; then :
+if ${ac_cv_c_inline+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_cv_c_inline=no
@@ -15925,6 +16713,75 @@
 esac
 
 
+# Check whether --enable-mdns was given.
+if test "${enable_mdns+set}" = set; then :
+  enableval=$enable_mdns; enable_mdns=yes
+else
+  enable_mdns=no
+fi
+
+if test "$enable_mdns" = yes; then
+
+$as_echo "#define HAVE_MDNS /**/" >>confdefs.h
+
+  ac_fn_c_check_header_mongrel "$LINENO" "dns_sd.h" "ac_cv_header_dns_sd_h" "$ac_includes_default"
+if test "x$ac_cv_header_dns_sd_h" = xyes; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for DNSServiceCreateConnection in -ldns_sd" >&5
+$as_echo_n "checking for DNSServiceCreateConnection in -ldns_sd... " >&6; }
+if ${ac_cv_lib_dns_sd_DNSServiceCreateConnection+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  ac_check_lib_save_LIBS=$LIBS
+LIBS="-ldns_sd  $LIBS"
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+/* Override any GCC internal prototype to avoid an error.
+   Use char because int might match the return type of a GCC
+   builtin and then its argument prototype would still apply.  */
+#ifdef __cplusplus
+extern "C"
+#endif
+char DNSServiceCreateConnection ();
+int
+main ()
+{
+return DNSServiceCreateConnection ();
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  ac_cv_lib_dns_sd_DNSServiceCreateConnection=yes
+else
+  ac_cv_lib_dns_sd_DNSServiceCreateConnection=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+LIBS=$ac_check_lib_save_LIBS
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dns_sd_DNSServiceCreateConnection" >&5
+$as_echo "$ac_cv_lib_dns_sd_DNSServiceCreateConnection" >&6; }
+if test "x$ac_cv_lib_dns_sd_DNSServiceCreateConnection" = xyes; then :
+  LIBS="${LIBS} -ldns_sd"
+else
+  enable_mdns=no
+fi
+
+else
+  enable_mdns=no
+fi
+
+
+else
+  MAYBE_LIB_mdns=
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking if mDNS support should be built" >&5
+$as_echo_n "checking if mDNS support should be built... " >&6; }
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $enable_mdns" >&5
+$as_echo "$enable_mdns" >&6; }
+
 want_tests=yes
 
 # Check whether --with-tests was given.
@@ -15970,7 +16827,7 @@
 
 
 
-ac_config_files="$ac_config_files Makefile gloox.pc gloox-config src/Makefile src/examples/Makefile src/tests/Makefile src/tests/adhoc/Makefile src/tests/adhoccommand/Makefile src/tests/adhoccommandnote/Makefile src/tests/amprule/Makefile src/tests/amp/Makefile src/tests/base64/Makefile src/tests/capabilities/Makefile src/tests/chatstatefilter/Makefile src/tests/client/Makefile src/tests/clientbase/Makefile src/tests/connectionbosh/Makefile src/tests/dataform/Makefile src/tests/dataformfield/Makefile src/tests/dataformitem/Makefile src/tests/dataformreported/Makefile src/tests/delayeddelivery/Makefile src/tests/discoinfo/Makefile src/tests/discoitems/Makefile src/tests/disco/Makefile src/tests/error/Makefile src/tests/featureneg/Makefile src/tests/flexofflineoffline/Makefile src/tests/flexoffline/Makefile src/tests/gpgencrypted/Makefile src/tests/gpgsigned/Makefile src/tests/inbandbytestreamibb/Makefile src/tests/inbandbytestream/Makefile src/tests/iq/Makefile src/tests/jid/Makefile src/tests/lastactivityquery/Makefile src/tests/lastactivity/Makefile src/tests/md5/Makefile src/tests/message/Makefile src/tests/messageeventfilter/Makefile src/tests/mucroommuc/Makefile src/tests/mucroommucadmin/Makefile src/tests/mucroommucowner/Makefile src/tests/mucroommucuser/Makefile src/tests/nickname/Makefile src/tests/nonsaslauthquery/Makefile src/tests/nonsaslauth/Makefile src/tests/oob/Makefile src/tests/parser/Makefile src/tests/prep/Makefile src/tests/presence/Makefile src/tests/privacymanagerquery/Makefile src/tests/privacymanager/Makefile src/tests/privatexml/Makefile src/tests/pubsubmanagerpubsub/Makefile src/tests/pubsubmanager/Makefile src/tests/pubsubevent/Makefile src/tests/receipt/Makefile src/tests/registrationquery/Makefile src/tests/registration/Makefile src/tests/rostermanagerquery/Makefile src/tests/rostermanager/Makefile src/tests/searchquery/Makefile src/tests/search/Makefile src/tests/sha/Makefile src/tests/shim/Makefile src/tests/simanager/Makefile src/tests/simanagersi/Makefile src/tests/stanzaextensionfactory/Makefile src/tests/subscription/Makefile src/tests/tag/Makefile src/tests/tlsgnutls/Makefile src/tests/uniquemucroomunique/Makefile src/tests/util/Makefile src/tests/vcard/Makefile src/tests/vcardupdate/Makefile src/tests/xpath/Makefile src/tests/zlib/Makefile"
+ac_config_files="$ac_config_files Makefile gloox.pc gloox-config src/Makefile src/examples/Makefile src/tests/Makefile src/tests/adhoc/Makefile src/tests/adhoccommand/Makefile src/tests/adhoccommandnote/Makefile src/tests/amprule/Makefile src/tests/amp/Makefile src/tests/base64/Makefile src/tests/capabilities/Makefile src/tests/carbons/Makefile src/tests/chatstatefilter/Makefile src/tests/client/Makefile src/tests/clientbase/Makefile src/tests/connectionbosh/Makefile src/tests/dataform/Makefile src/tests/dataformfield/Makefile src/tests/dataformitem/Makefile src/tests/dataformreported/Makefile src/tests/delayeddelivery/Makefile src/tests/discoinfo/Makefile src/tests/discoitems/Makefile src/tests/disco/Makefile src/tests/error/Makefile src/tests/featureneg/Makefile src/tests/flexofflineoffline/Makefile src/tests/flexoffline/Makefile src/tests/forward/Makefile src/tests/gpgencrypted/Makefile src/tests/gpgsigned/Makefile src/tests/inbandbytestreamibb/Makefile src/tests/inbandbytestream/Makefile src/tests/iq/Makefile src/tests/jid/Makefile src/tests/jinglecontent/Makefile src/tests/jingleiceudp/Makefile src/tests/jinglesession/Makefile src/tests/jinglesessionjingle/Makefile src/tests/jinglesessionmanager/Makefile src/tests/lastactivityquery/Makefile src/tests/lastactivity/Makefile src/tests/md5/Makefile src/tests/message/Makefile src/tests/messageeventfilter/Makefile src/tests/mucroommuc/Makefile src/tests/mucroommucadmin/Makefile src/tests/mucroommucowner/Makefile src/tests/mucroommucuser/Makefile src/tests/nickname/Makefile src/tests/nonsaslauthquery/Makefile src/tests/nonsaslauth/Makefile src/tests/oob/Makefile src/tests/parser/Makefile src/tests/prep/Makefile src/tests/presence/Makefile src/tests/privacymanagerquery/Makefile src/tests/privacymanager/Makefile src/tests/privatexml/Makefile src/tests/pubsubmanagerpubsub/Makefile src/tests/pubsubmanager/Makefile src/tests/pubsubevent/Makefile src/tests/receipt/Makefile src/tests/registrationquery/Makefile src/tests/registration/Makefile src/tests/rostermanagerquery/Makefile src/tests/rostermanager/Makefile src/tests/searchquery/Makefile src/tests/search/Makefile src/tests/sha/Makefile src/tests/shim/Makefile src/tests/simanager/Makefile src/tests/simanagersi/Makefile src/tests/stanzaextensionfactory/Makefile src/tests/subscription/Makefile src/tests/tag/Makefile src/tests/tlsgnutls/Makefile src/tests/uniquemucroomunique/Makefile src/tests/util/Makefile src/tests/vcard/Makefile src/tests/vcardupdate/Makefile src/tests/xpath/Makefile src/tests/zlib/Makefile"
 
 cat >confcache <<\_ACEOF
 # This file is a shell script that caches the results of configure
@@ -16036,10 +16893,21 @@
      :end' >>confcache
 if diff "$cache_file" confcache >/dev/null 2>&1; then :; else
   if test -w "$cache_file"; then
-    test "x$cache_file" != "x/dev/null" &&
+    if test "x$cache_file" != "x/dev/null"; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: updating cache $cache_file" >&5
 $as_echo "$as_me: updating cache $cache_file" >&6;}
-    cat confcache >$cache_file
+      if test ! -f "$cache_file" || test -h "$cache_file"; then
+	cat confcache >"$cache_file"
+      else
+        case $cache_file in #(
+        */* | ?:*)
+	  mv -f confcache "$cache_file"$$ &&
+	  mv -f "$cache_file"$$ "$cache_file" ;; #(
+        *)
+	  mv -f confcache "$cache_file" ;;
+	esac
+      fi
+    fi
   else
     { $as_echo "$as_me:${as_lineno-$LINENO}: not updating unwritable cache $cache_file" >&5
 $as_echo "$as_me: not updating unwritable cache $cache_file" >&6;}
@@ -16055,6 +16923,7 @@
 
 ac_libobjs=
 ac_ltlibobjs=
+U=
 for ac_i in : $LIBOBJS; do test "x$ac_i" = x: && continue
   # 1. Remove the extension, and $U if already installed.
   ac_script='s/\$U\././;s/\.o$//;s/\.obj$//'
@@ -16078,23 +16947,19 @@
 fi
 
 if test -z "${AMDEP_TRUE}" && test -z "${AMDEP_FALSE}"; then
-  as_fn_error "conditional \"AMDEP\" was never defined.
+  as_fn_error $? "conditional \"AMDEP\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
 fi
 if test -z "${am__fastdepCC_TRUE}" && test -z "${am__fastdepCC_FALSE}"; then
-  as_fn_error "conditional \"am__fastdepCC\" was never defined.
-Usually this means the macro was only invoked conditionally." "$LINENO" 5
-fi
-if test -z "${am__fastdepCXX_TRUE}" && test -z "${am__fastdepCXX_FALSE}"; then
-  as_fn_error "conditional \"am__fastdepCXX\" was never defined.
-Usually this means the macro was only invoked conditionally." "$LINENO" 5
-fi
-if test -z "${am__fastdepCXX_TRUE}" && test -z "${am__fastdepCXX_FALSE}"; then
-  as_fn_error "conditional \"am__fastdepCXX\" was never defined.
+  as_fn_error $? "conditional \"am__fastdepCC\" was never defined.
+Usually this means the macro was only invoked conditionally." "$LINENO" 5
+fi
+if test -z "${am__fastdepCXX_TRUE}" && test -z "${am__fastdepCXX_FALSE}"; then
+  as_fn_error $? "conditional \"am__fastdepCXX\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
 fi
 
-: ${CONFIG_STATUS=./config.status}
+: "${CONFIG_STATUS=./config.status}"
 ac_write_fail=0
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
@@ -16195,6 +17060,7 @@
 IFS=" ""	$as_nl"
 
 # Find who we are.  Look in the path if we contain no directory separator.
+as_myself=
 case $0 in #((
   *[\\/]* ) as_myself=$0 ;;
   *) as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
@@ -16240,19 +17106,19 @@
 (unset CDPATH) >/dev/null 2>&1 && unset CDPATH
 
 
-# as_fn_error ERROR [LINENO LOG_FD]
-# ---------------------------------
+# as_fn_error STATUS ERROR [LINENO LOG_FD]
+# ----------------------------------------
 # Output "`basename $0`: error: ERROR" to stderr. If LINENO and LOG_FD are
 # provided, also output the error to LOG_FD, referencing LINENO. Then exit the
-# script with status $?, using 1 if that was 0.
+# script with STATUS, using 1 if that was 0.
 as_fn_error ()
 {
-  as_status=$?; test $as_status -eq 0 && as_status=1
-  if test "$3"; then
-    as_lineno=${as_lineno-"$2"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-    $as_echo "$as_me:${as_lineno-$LINENO}: error: $1" >&$3
+  as_status=$1; test $as_status -eq 0 && as_status=1
+  if test "$4"; then
+    as_lineno=${as_lineno-"$3"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
+    $as_echo "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
   fi
-  $as_echo "$as_me: error: $1" >&2
+  $as_echo "$as_me: error: $2" >&2
   as_fn_exit $as_status
 } # as_fn_error
 
@@ -16390,16 +17256,16 @@
     # ... but there are two gotchas:
     # 1) On MSYS, both `ln -s file dir' and `ln file dir' fail.
     # 2) DJGPP < 2.04 has no symlinks; `ln -s' creates a wrapper executable.
-    # In both cases, we have to default to `cp -p'.
+    # In both cases, we have to default to `cp -pR'.
     ln -s conf$$.file conf$$.dir 2>/dev/null && test ! -f conf$$.exe ||
-      as_ln_s='cp -p'
+      as_ln_s='cp -pR'
   elif ln conf$$.file conf$$ 2>/dev/null; then
     as_ln_s=ln
   else
-    as_ln_s='cp -p'
+    as_ln_s='cp -pR'
   fi
 else
-  as_ln_s='cp -p'
+  as_ln_s='cp -pR'
 fi
 rm -f conf$$ conf$$.exe conf$$.dir/conf$$.file conf$$.file
 rmdir conf$$.dir 2>/dev/null
@@ -16448,7 +17314,7 @@
       test -d "$as_dir" && break
     done
     test -z "$as_dirs" || eval "mkdir $as_dirs"
-  } || test -d "$as_dir" || as_fn_error "cannot create directory $as_dir"
+  } || test -d "$as_dir" || as_fn_error $? "cannot create directory $as_dir"
 
 
 } # as_fn_mkdir_p
@@ -16459,28 +17325,16 @@
   as_mkdir_p=false
 fi
 
-if test -x / >/dev/null 2>&1; then
-  as_test_x='test -x'
-else
-  if ls -dL / >/dev/null 2>&1; then
-    as_ls_L_option=L
-  else
-    as_ls_L_option=
-  fi
-  as_test_x='
-    eval sh -c '\''
-      if test -d "$1"; then
-	test -d "$1/.";
-      else
-	case $1 in #(
-	-*)set "./$1";;
-	esac;
-	case `ls -ld'$as_ls_L_option' "$1" 2>/dev/null` in #((
-	???[sx]*):;;*)false;;esac;fi
-    '\'' sh
-  '
-fi
-as_executable_p=$as_test_x
+
+# as_fn_executable_p FILE
+# -----------------------
+# Test if FILE is an executable regular file.
+as_fn_executable_p ()
+{
+  test -f "$1" && test -x "$1"
+} # as_fn_executable_p
+as_test_x='test -x'
+as_executable_p=as_fn_executable_p
 
 # Sed expression to map a string onto a valid CPP name.
 as_tr_cpp="eval sed 'y%*$as_cr_letters%P$as_cr_LETTERS%;s%[^_$as_cr_alnum]%_%g'"
@@ -16501,8 +17355,8 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by gloox $as_me 1.0, which was
-generated by GNU Autoconf 2.64.  Invocation command line was
+This file was extended by gloox $as_me 1.0.9, which was
+generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
   CONFIG_HEADERS  = $CONFIG_HEADERS
@@ -16542,6 +17396,7 @@
 
   -h, --help       print this help, then exit
   -V, --version    print version number and configuration settings, then exit
+      --config     print configuration, then exit
   -q, --quiet, --silent
                    do not print progress messages
   -d, --debug      don't remove temporary files
@@ -16564,12 +17419,13 @@
 
 _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
+ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-gloox config.status 1.0
-configured by $0, generated by GNU Autoconf 2.64,
-  with options \\"`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`\\"
+gloox config.status 1.0.9
+configured by $0, generated by GNU Autoconf 2.69,
+  with options \\"\$ac_cs_config\\"
 
-Copyright (C) 2009 Free Software Foundation, Inc.
+Copyright (C) 2012 Free Software Foundation, Inc.
 This config.status script is free software; the Free Software Foundation
 gives unlimited permission to copy, distribute and modify it."
 
@@ -16587,11 +17443,16 @@
 while test $# != 0
 do
   case $1 in
-  --*=*)
+  --*=?*)
     ac_option=`expr "X$1" : 'X\([^=]*\)='`
     ac_optarg=`expr "X$1" : 'X[^=]*=\(.*\)'`
     ac_shift=:
     ;;
+  --*=)
+    ac_option=`expr "X$1" : 'X\([^=]*\)='`
+    ac_optarg=
+    ac_shift=:
+    ;;
   *)
     ac_option=$1
     ac_optarg=$2
@@ -16605,12 +17466,15 @@
     ac_cs_recheck=: ;;
   --version | --versio | --versi | --vers | --ver | --ve | --v | -V )
     $as_echo "$ac_cs_version"; exit ;;
+  --config | --confi | --conf | --con | --co | --c )
+    $as_echo "$ac_cs_config"; exit ;;
   --debug | --debu | --deb | --de | --d | -d )
     debug=: ;;
   --file | --fil | --fi | --f )
     $ac_shift
     case $ac_optarg in
     *\'*) ac_optarg=`$as_echo "$ac_optarg" | sed "s/'/'\\\\\\\\''/g"` ;;
+    '') as_fn_error $? "missing file argument" ;;
     esac
     as_fn_append CONFIG_FILES " '$ac_optarg'"
     ac_need_defaults=false;;
@@ -16623,7 +17487,7 @@
     ac_need_defaults=false;;
   --he | --h)
     # Conflict between --help and --header
-    as_fn_error "ambiguous option: \`$1'
+    as_fn_error $? "ambiguous option: \`$1'
 Try \`$0 --help' for more information.";;
   --help | --hel | -h )
     $as_echo "$ac_cs_usage"; exit ;;
@@ -16632,7 +17496,7 @@
     ac_cs_silent=: ;;
 
   # This is an error.
-  -*) as_fn_error "unrecognized option: \`$1'
+  -*) as_fn_error $? "unrecognized option: \`$1'
 Try \`$0 --help' for more information." ;;
 
   *) as_fn_append ac_config_targets " $1"
@@ -16652,7 +17516,7 @@
 _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 if \$ac_cs_recheck; then
-  set X '$SHELL' '$0' $ac_configure_args \$ac_configure_extra_args --no-create --no-recursion
+  set X $SHELL '$0' $ac_configure_args \$ac_configure_extra_args --no-create --no-recursion
   shift
   \$as_echo "running CONFIG_SHELL=$SHELL \$*" >&6
   CONFIG_SHELL='$SHELL'
@@ -16686,184 +17550,208 @@
 sed_quote_subst='$sed_quote_subst'
 double_quote_subst='$double_quote_subst'
 delay_variable_subst='$delay_variable_subst'
-macro_version='`$ECHO "X$macro_version" | $Xsed -e "$delay_single_quote_subst"`'
-macro_revision='`$ECHO "X$macro_revision" | $Xsed -e "$delay_single_quote_subst"`'
-enable_shared='`$ECHO "X$enable_shared" | $Xsed -e "$delay_single_quote_subst"`'
-enable_static='`$ECHO "X$enable_static" | $Xsed -e "$delay_single_quote_subst"`'
-pic_mode='`$ECHO "X$pic_mode" | $Xsed -e "$delay_single_quote_subst"`'
-enable_fast_install='`$ECHO "X$enable_fast_install" | $Xsed -e "$delay_single_quote_subst"`'
-host_alias='`$ECHO "X$host_alias" | $Xsed -e "$delay_single_quote_subst"`'
-host='`$ECHO "X$host" | $Xsed -e "$delay_single_quote_subst"`'
-host_os='`$ECHO "X$host_os" | $Xsed -e "$delay_single_quote_subst"`'
-build_alias='`$ECHO "X$build_alias" | $Xsed -e "$delay_single_quote_subst"`'
-build='`$ECHO "X$build" | $Xsed -e "$delay_single_quote_subst"`'
-build_os='`$ECHO "X$build_os" | $Xsed -e "$delay_single_quote_subst"`'
-SED='`$ECHO "X$SED" | $Xsed -e "$delay_single_quote_subst"`'
-Xsed='`$ECHO "X$Xsed" | $Xsed -e "$delay_single_quote_subst"`'
-GREP='`$ECHO "X$GREP" | $Xsed -e "$delay_single_quote_subst"`'
-EGREP='`$ECHO "X$EGREP" | $Xsed -e "$delay_single_quote_subst"`'
-FGREP='`$ECHO "X$FGREP" | $Xsed -e "$delay_single_quote_subst"`'
-LD='`$ECHO "X$LD" | $Xsed -e "$delay_single_quote_subst"`'
-NM='`$ECHO "X$NM" | $Xsed -e "$delay_single_quote_subst"`'
-LN_S='`$ECHO "X$LN_S" | $Xsed -e "$delay_single_quote_subst"`'
-max_cmd_len='`$ECHO "X$max_cmd_len" | $Xsed -e "$delay_single_quote_subst"`'
-ac_objext='`$ECHO "X$ac_objext" | $Xsed -e "$delay_single_quote_subst"`'
-exeext='`$ECHO "X$exeext" | $Xsed -e "$delay_single_quote_subst"`'
-lt_unset='`$ECHO "X$lt_unset" | $Xsed -e "$delay_single_quote_subst"`'
-lt_SP2NL='`$ECHO "X$lt_SP2NL" | $Xsed -e "$delay_single_quote_subst"`'
-lt_NL2SP='`$ECHO "X$lt_NL2SP" | $Xsed -e "$delay_single_quote_subst"`'
-reload_flag='`$ECHO "X$reload_flag" | $Xsed -e "$delay_single_quote_subst"`'
-reload_cmds='`$ECHO "X$reload_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-OBJDUMP='`$ECHO "X$OBJDUMP" | $Xsed -e "$delay_single_quote_subst"`'
-deplibs_check_method='`$ECHO "X$deplibs_check_method" | $Xsed -e "$delay_single_quote_subst"`'
-file_magic_cmd='`$ECHO "X$file_magic_cmd" | $Xsed -e "$delay_single_quote_subst"`'
-AR='`$ECHO "X$AR" | $Xsed -e "$delay_single_quote_subst"`'
-AR_FLAGS='`$ECHO "X$AR_FLAGS" | $Xsed -e "$delay_single_quote_subst"`'
-STRIP='`$ECHO "X$STRIP" | $Xsed -e "$delay_single_quote_subst"`'
-RANLIB='`$ECHO "X$RANLIB" | $Xsed -e "$delay_single_quote_subst"`'
-old_postinstall_cmds='`$ECHO "X$old_postinstall_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-old_postuninstall_cmds='`$ECHO "X$old_postuninstall_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-old_archive_cmds='`$ECHO "X$old_archive_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-CC='`$ECHO "X$CC" | $Xsed -e "$delay_single_quote_subst"`'
-CFLAGS='`$ECHO "X$CFLAGS" | $Xsed -e "$delay_single_quote_subst"`'
-compiler='`$ECHO "X$compiler" | $Xsed -e "$delay_single_quote_subst"`'
-GCC='`$ECHO "X$GCC" | $Xsed -e "$delay_single_quote_subst"`'
-lt_cv_sys_global_symbol_pipe='`$ECHO "X$lt_cv_sys_global_symbol_pipe" | $Xsed -e "$delay_single_quote_subst"`'
-lt_cv_sys_global_symbol_to_cdecl='`$ECHO "X$lt_cv_sys_global_symbol_to_cdecl" | $Xsed -e "$delay_single_quote_subst"`'
-lt_cv_sys_global_symbol_to_c_name_address='`$ECHO "X$lt_cv_sys_global_symbol_to_c_name_address" | $Xsed -e "$delay_single_quote_subst"`'
-lt_cv_sys_global_symbol_to_c_name_address_lib_prefix='`$ECHO "X$lt_cv_sys_global_symbol_to_c_name_address_lib_prefix" | $Xsed -e "$delay_single_quote_subst"`'
-objdir='`$ECHO "X$objdir" | $Xsed -e "$delay_single_quote_subst"`'
-SHELL='`$ECHO "X$SHELL" | $Xsed -e "$delay_single_quote_subst"`'
-ECHO='`$ECHO "X$ECHO" | $Xsed -e "$delay_single_quote_subst"`'
-MAGIC_CMD='`$ECHO "X$MAGIC_CMD" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_no_builtin_flag='`$ECHO "X$lt_prog_compiler_no_builtin_flag" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_wl='`$ECHO "X$lt_prog_compiler_wl" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_pic='`$ECHO "X$lt_prog_compiler_pic" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_static='`$ECHO "X$lt_prog_compiler_static" | $Xsed -e "$delay_single_quote_subst"`'
-lt_cv_prog_compiler_c_o='`$ECHO "X$lt_cv_prog_compiler_c_o" | $Xsed -e "$delay_single_quote_subst"`'
-need_locks='`$ECHO "X$need_locks" | $Xsed -e "$delay_single_quote_subst"`'
-DSYMUTIL='`$ECHO "X$DSYMUTIL" | $Xsed -e "$delay_single_quote_subst"`'
-NMEDIT='`$ECHO "X$NMEDIT" | $Xsed -e "$delay_single_quote_subst"`'
-LIPO='`$ECHO "X$LIPO" | $Xsed -e "$delay_single_quote_subst"`'
-OTOOL='`$ECHO "X$OTOOL" | $Xsed -e "$delay_single_quote_subst"`'
-OTOOL64='`$ECHO "X$OTOOL64" | $Xsed -e "$delay_single_quote_subst"`'
-libext='`$ECHO "X$libext" | $Xsed -e "$delay_single_quote_subst"`'
-shrext_cmds='`$ECHO "X$shrext_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-extract_expsyms_cmds='`$ECHO "X$extract_expsyms_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-archive_cmds_need_lc='`$ECHO "X$archive_cmds_need_lc" | $Xsed -e "$delay_single_quote_subst"`'
-enable_shared_with_static_runtimes='`$ECHO "X$enable_shared_with_static_runtimes" | $Xsed -e "$delay_single_quote_subst"`'
-export_dynamic_flag_spec='`$ECHO "X$export_dynamic_flag_spec" | $Xsed -e "$delay_single_quote_subst"`'
-whole_archive_flag_spec='`$ECHO "X$whole_archive_flag_spec" | $Xsed -e "$delay_single_quote_subst"`'
-compiler_needs_object='`$ECHO "X$compiler_needs_object" | $Xsed -e "$delay_single_quote_subst"`'
-old_archive_from_new_cmds='`$ECHO "X$old_archive_from_new_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-old_archive_from_expsyms_cmds='`$ECHO "X$old_archive_from_expsyms_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-archive_cmds='`$ECHO "X$archive_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-archive_expsym_cmds='`$ECHO "X$archive_expsym_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-module_cmds='`$ECHO "X$module_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-module_expsym_cmds='`$ECHO "X$module_expsym_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-with_gnu_ld='`$ECHO "X$with_gnu_ld" | $Xsed -e "$delay_single_quote_subst"`'
-allow_undefined_flag='`$ECHO "X$allow_undefined_flag" | $Xsed -e "$delay_single_quote_subst"`'
-no_undefined_flag='`$ECHO "X$no_undefined_flag" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_libdir_flag_spec='`$ECHO "X$hardcode_libdir_flag_spec" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_libdir_flag_spec_ld='`$ECHO "X$hardcode_libdir_flag_spec_ld" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_libdir_separator='`$ECHO "X$hardcode_libdir_separator" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_direct='`$ECHO "X$hardcode_direct" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_direct_absolute='`$ECHO "X$hardcode_direct_absolute" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_minus_L='`$ECHO "X$hardcode_minus_L" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_shlibpath_var='`$ECHO "X$hardcode_shlibpath_var" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_automatic='`$ECHO "X$hardcode_automatic" | $Xsed -e "$delay_single_quote_subst"`'
-inherit_rpath='`$ECHO "X$inherit_rpath" | $Xsed -e "$delay_single_quote_subst"`'
-link_all_deplibs='`$ECHO "X$link_all_deplibs" | $Xsed -e "$delay_single_quote_subst"`'
-fix_srcfile_path='`$ECHO "X$fix_srcfile_path" | $Xsed -e "$delay_single_quote_subst"`'
-always_export_symbols='`$ECHO "X$always_export_symbols" | $Xsed -e "$delay_single_quote_subst"`'
-export_symbols_cmds='`$ECHO "X$export_symbols_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-exclude_expsyms='`$ECHO "X$exclude_expsyms" | $Xsed -e "$delay_single_quote_subst"`'
-include_expsyms='`$ECHO "X$include_expsyms" | $Xsed -e "$delay_single_quote_subst"`'
-prelink_cmds='`$ECHO "X$prelink_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-file_list_spec='`$ECHO "X$file_list_spec" | $Xsed -e "$delay_single_quote_subst"`'
-variables_saved_for_relink='`$ECHO "X$variables_saved_for_relink" | $Xsed -e "$delay_single_quote_subst"`'
-need_lib_prefix='`$ECHO "X$need_lib_prefix" | $Xsed -e "$delay_single_quote_subst"`'
-need_version='`$ECHO "X$need_version" | $Xsed -e "$delay_single_quote_subst"`'
-version_type='`$ECHO "X$version_type" | $Xsed -e "$delay_single_quote_subst"`'
-runpath_var='`$ECHO "X$runpath_var" | $Xsed -e "$delay_single_quote_subst"`'
-shlibpath_var='`$ECHO "X$shlibpath_var" | $Xsed -e "$delay_single_quote_subst"`'
-shlibpath_overrides_runpath='`$ECHO "X$shlibpath_overrides_runpath" | $Xsed -e "$delay_single_quote_subst"`'
-libname_spec='`$ECHO "X$libname_spec" | $Xsed -e "$delay_single_quote_subst"`'
-library_names_spec='`$ECHO "X$library_names_spec" | $Xsed -e "$delay_single_quote_subst"`'
-soname_spec='`$ECHO "X$soname_spec" | $Xsed -e "$delay_single_quote_subst"`'
-postinstall_cmds='`$ECHO "X$postinstall_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-postuninstall_cmds='`$ECHO "X$postuninstall_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-finish_cmds='`$ECHO "X$finish_cmds" | $Xsed -e "$delay_single_quote_subst"`'
-finish_eval='`$ECHO "X$finish_eval" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_into_libs='`$ECHO "X$hardcode_into_libs" | $Xsed -e "$delay_single_quote_subst"`'
-sys_lib_search_path_spec='`$ECHO "X$sys_lib_search_path_spec" | $Xsed -e "$delay_single_quote_subst"`'
-sys_lib_dlsearch_path_spec='`$ECHO "X$sys_lib_dlsearch_path_spec" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_action='`$ECHO "X$hardcode_action" | $Xsed -e "$delay_single_quote_subst"`'
-enable_dlopen='`$ECHO "X$enable_dlopen" | $Xsed -e "$delay_single_quote_subst"`'
-enable_dlopen_self='`$ECHO "X$enable_dlopen_self" | $Xsed -e "$delay_single_quote_subst"`'
-enable_dlopen_self_static='`$ECHO "X$enable_dlopen_self_static" | $Xsed -e "$delay_single_quote_subst"`'
-old_striplib='`$ECHO "X$old_striplib" | $Xsed -e "$delay_single_quote_subst"`'
-striplib='`$ECHO "X$striplib" | $Xsed -e "$delay_single_quote_subst"`'
-compiler_lib_search_dirs='`$ECHO "X$compiler_lib_search_dirs" | $Xsed -e "$delay_single_quote_subst"`'
-predep_objects='`$ECHO "X$predep_objects" | $Xsed -e "$delay_single_quote_subst"`'
-postdep_objects='`$ECHO "X$postdep_objects" | $Xsed -e "$delay_single_quote_subst"`'
-predeps='`$ECHO "X$predeps" | $Xsed -e "$delay_single_quote_subst"`'
-postdeps='`$ECHO "X$postdeps" | $Xsed -e "$delay_single_quote_subst"`'
-compiler_lib_search_path='`$ECHO "X$compiler_lib_search_path" | $Xsed -e "$delay_single_quote_subst"`'
-LD_CXX='`$ECHO "X$LD_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-old_archive_cmds_CXX='`$ECHO "X$old_archive_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-compiler_CXX='`$ECHO "X$compiler_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-GCC_CXX='`$ECHO "X$GCC_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_no_builtin_flag_CXX='`$ECHO "X$lt_prog_compiler_no_builtin_flag_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_wl_CXX='`$ECHO "X$lt_prog_compiler_wl_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_pic_CXX='`$ECHO "X$lt_prog_compiler_pic_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-lt_prog_compiler_static_CXX='`$ECHO "X$lt_prog_compiler_static_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-lt_cv_prog_compiler_c_o_CXX='`$ECHO "X$lt_cv_prog_compiler_c_o_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-archive_cmds_need_lc_CXX='`$ECHO "X$archive_cmds_need_lc_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-enable_shared_with_static_runtimes_CXX='`$ECHO "X$enable_shared_with_static_runtimes_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-export_dynamic_flag_spec_CXX='`$ECHO "X$export_dynamic_flag_spec_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-whole_archive_flag_spec_CXX='`$ECHO "X$whole_archive_flag_spec_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-compiler_needs_object_CXX='`$ECHO "X$compiler_needs_object_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-old_archive_from_new_cmds_CXX='`$ECHO "X$old_archive_from_new_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-old_archive_from_expsyms_cmds_CXX='`$ECHO "X$old_archive_from_expsyms_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-archive_cmds_CXX='`$ECHO "X$archive_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-archive_expsym_cmds_CXX='`$ECHO "X$archive_expsym_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-module_cmds_CXX='`$ECHO "X$module_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-module_expsym_cmds_CXX='`$ECHO "X$module_expsym_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-with_gnu_ld_CXX='`$ECHO "X$with_gnu_ld_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-allow_undefined_flag_CXX='`$ECHO "X$allow_undefined_flag_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-no_undefined_flag_CXX='`$ECHO "X$no_undefined_flag_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_libdir_flag_spec_CXX='`$ECHO "X$hardcode_libdir_flag_spec_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_libdir_flag_spec_ld_CXX='`$ECHO "X$hardcode_libdir_flag_spec_ld_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_libdir_separator_CXX='`$ECHO "X$hardcode_libdir_separator_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_direct_CXX='`$ECHO "X$hardcode_direct_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_direct_absolute_CXX='`$ECHO "X$hardcode_direct_absolute_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_minus_L_CXX='`$ECHO "X$hardcode_minus_L_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_shlibpath_var_CXX='`$ECHO "X$hardcode_shlibpath_var_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_automatic_CXX='`$ECHO "X$hardcode_automatic_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-inherit_rpath_CXX='`$ECHO "X$inherit_rpath_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-link_all_deplibs_CXX='`$ECHO "X$link_all_deplibs_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-fix_srcfile_path_CXX='`$ECHO "X$fix_srcfile_path_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-always_export_symbols_CXX='`$ECHO "X$always_export_symbols_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-export_symbols_cmds_CXX='`$ECHO "X$export_symbols_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-exclude_expsyms_CXX='`$ECHO "X$exclude_expsyms_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-include_expsyms_CXX='`$ECHO "X$include_expsyms_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-prelink_cmds_CXX='`$ECHO "X$prelink_cmds_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-file_list_spec_CXX='`$ECHO "X$file_list_spec_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-hardcode_action_CXX='`$ECHO "X$hardcode_action_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-compiler_lib_search_dirs_CXX='`$ECHO "X$compiler_lib_search_dirs_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-predep_objects_CXX='`$ECHO "X$predep_objects_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-postdep_objects_CXX='`$ECHO "X$postdep_objects_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-predeps_CXX='`$ECHO "X$predeps_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-postdeps_CXX='`$ECHO "X$postdeps_CXX" | $Xsed -e "$delay_single_quote_subst"`'
-compiler_lib_search_path_CXX='`$ECHO "X$compiler_lib_search_path_CXX" | $Xsed -e "$delay_single_quote_subst"`'
+macro_version='`$ECHO "$macro_version" | $SED "$delay_single_quote_subst"`'
+macro_revision='`$ECHO "$macro_revision" | $SED "$delay_single_quote_subst"`'
+enable_shared='`$ECHO "$enable_shared" | $SED "$delay_single_quote_subst"`'
+enable_static='`$ECHO "$enable_static" | $SED "$delay_single_quote_subst"`'
+pic_mode='`$ECHO "$pic_mode" | $SED "$delay_single_quote_subst"`'
+enable_fast_install='`$ECHO "$enable_fast_install" | $SED "$delay_single_quote_subst"`'
+SHELL='`$ECHO "$SHELL" | $SED "$delay_single_quote_subst"`'
+ECHO='`$ECHO "$ECHO" | $SED "$delay_single_quote_subst"`'
+PATH_SEPARATOR='`$ECHO "$PATH_SEPARATOR" | $SED "$delay_single_quote_subst"`'
+host_alias='`$ECHO "$host_alias" | $SED "$delay_single_quote_subst"`'
+host='`$ECHO "$host" | $SED "$delay_single_quote_subst"`'
+host_os='`$ECHO "$host_os" | $SED "$delay_single_quote_subst"`'
+build_alias='`$ECHO "$build_alias" | $SED "$delay_single_quote_subst"`'
+build='`$ECHO "$build" | $SED "$delay_single_quote_subst"`'
+build_os='`$ECHO "$build_os" | $SED "$delay_single_quote_subst"`'
+SED='`$ECHO "$SED" | $SED "$delay_single_quote_subst"`'
+Xsed='`$ECHO "$Xsed" | $SED "$delay_single_quote_subst"`'
+GREP='`$ECHO "$GREP" | $SED "$delay_single_quote_subst"`'
+EGREP='`$ECHO "$EGREP" | $SED "$delay_single_quote_subst"`'
+FGREP='`$ECHO "$FGREP" | $SED "$delay_single_quote_subst"`'
+LD='`$ECHO "$LD" | $SED "$delay_single_quote_subst"`'
+NM='`$ECHO "$NM" | $SED "$delay_single_quote_subst"`'
+LN_S='`$ECHO "$LN_S" | $SED "$delay_single_quote_subst"`'
+max_cmd_len='`$ECHO "$max_cmd_len" | $SED "$delay_single_quote_subst"`'
+ac_objext='`$ECHO "$ac_objext" | $SED "$delay_single_quote_subst"`'
+exeext='`$ECHO "$exeext" | $SED "$delay_single_quote_subst"`'
+lt_unset='`$ECHO "$lt_unset" | $SED "$delay_single_quote_subst"`'
+lt_SP2NL='`$ECHO "$lt_SP2NL" | $SED "$delay_single_quote_subst"`'
+lt_NL2SP='`$ECHO "$lt_NL2SP" | $SED "$delay_single_quote_subst"`'
+lt_cv_to_host_file_cmd='`$ECHO "$lt_cv_to_host_file_cmd" | $SED "$delay_single_quote_subst"`'
+lt_cv_to_tool_file_cmd='`$ECHO "$lt_cv_to_tool_file_cmd" | $SED "$delay_single_quote_subst"`'
+reload_flag='`$ECHO "$reload_flag" | $SED "$delay_single_quote_subst"`'
+reload_cmds='`$ECHO "$reload_cmds" | $SED "$delay_single_quote_subst"`'
+OBJDUMP='`$ECHO "$OBJDUMP" | $SED "$delay_single_quote_subst"`'
+deplibs_check_method='`$ECHO "$deplibs_check_method" | $SED "$delay_single_quote_subst"`'
+file_magic_cmd='`$ECHO "$file_magic_cmd" | $SED "$delay_single_quote_subst"`'
+file_magic_glob='`$ECHO "$file_magic_glob" | $SED "$delay_single_quote_subst"`'
+want_nocaseglob='`$ECHO "$want_nocaseglob" | $SED "$delay_single_quote_subst"`'
+DLLTOOL='`$ECHO "$DLLTOOL" | $SED "$delay_single_quote_subst"`'
+sharedlib_from_linklib_cmd='`$ECHO "$sharedlib_from_linklib_cmd" | $SED "$delay_single_quote_subst"`'
+AR='`$ECHO "$AR" | $SED "$delay_single_quote_subst"`'
+AR_FLAGS='`$ECHO "$AR_FLAGS" | $SED "$delay_single_quote_subst"`'
+archiver_list_spec='`$ECHO "$archiver_list_spec" | $SED "$delay_single_quote_subst"`'
+STRIP='`$ECHO "$STRIP" | $SED "$delay_single_quote_subst"`'
+RANLIB='`$ECHO "$RANLIB" | $SED "$delay_single_quote_subst"`'
+old_postinstall_cmds='`$ECHO "$old_postinstall_cmds" | $SED "$delay_single_quote_subst"`'
+old_postuninstall_cmds='`$ECHO "$old_postuninstall_cmds" | $SED "$delay_single_quote_subst"`'
+old_archive_cmds='`$ECHO "$old_archive_cmds" | $SED "$delay_single_quote_subst"`'
+lock_old_archive_extraction='`$ECHO "$lock_old_archive_extraction" | $SED "$delay_single_quote_subst"`'
+CC='`$ECHO "$CC" | $SED "$delay_single_quote_subst"`'
+CFLAGS='`$ECHO "$CFLAGS" | $SED "$delay_single_quote_subst"`'
+compiler='`$ECHO "$compiler" | $SED "$delay_single_quote_subst"`'
+GCC='`$ECHO "$GCC" | $SED "$delay_single_quote_subst"`'
+lt_cv_sys_global_symbol_pipe='`$ECHO "$lt_cv_sys_global_symbol_pipe" | $SED "$delay_single_quote_subst"`'
+lt_cv_sys_global_symbol_to_cdecl='`$ECHO "$lt_cv_sys_global_symbol_to_cdecl" | $SED "$delay_single_quote_subst"`'
+lt_cv_sys_global_symbol_to_c_name_address='`$ECHO "$lt_cv_sys_global_symbol_to_c_name_address" | $SED "$delay_single_quote_subst"`'
+lt_cv_sys_global_symbol_to_c_name_address_lib_prefix='`$ECHO "$lt_cv_sys_global_symbol_to_c_name_address_lib_prefix" | $SED "$delay_single_quote_subst"`'
+nm_file_list_spec='`$ECHO "$nm_file_list_spec" | $SED "$delay_single_quote_subst"`'
+lt_sysroot='`$ECHO "$lt_sysroot" | $SED "$delay_single_quote_subst"`'
+objdir='`$ECHO "$objdir" | $SED "$delay_single_quote_subst"`'
+MAGIC_CMD='`$ECHO "$MAGIC_CMD" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_no_builtin_flag='`$ECHO "$lt_prog_compiler_no_builtin_flag" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_pic='`$ECHO "$lt_prog_compiler_pic" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_wl='`$ECHO "$lt_prog_compiler_wl" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_static='`$ECHO "$lt_prog_compiler_static" | $SED "$delay_single_quote_subst"`'
+lt_cv_prog_compiler_c_o='`$ECHO "$lt_cv_prog_compiler_c_o" | $SED "$delay_single_quote_subst"`'
+need_locks='`$ECHO "$need_locks" | $SED "$delay_single_quote_subst"`'
+MANIFEST_TOOL='`$ECHO "$MANIFEST_TOOL" | $SED "$delay_single_quote_subst"`'
+DSYMUTIL='`$ECHO "$DSYMUTIL" | $SED "$delay_single_quote_subst"`'
+NMEDIT='`$ECHO "$NMEDIT" | $SED "$delay_single_quote_subst"`'
+LIPO='`$ECHO "$LIPO" | $SED "$delay_single_quote_subst"`'
+OTOOL='`$ECHO "$OTOOL" | $SED "$delay_single_quote_subst"`'
+OTOOL64='`$ECHO "$OTOOL64" | $SED "$delay_single_quote_subst"`'
+libext='`$ECHO "$libext" | $SED "$delay_single_quote_subst"`'
+shrext_cmds='`$ECHO "$shrext_cmds" | $SED "$delay_single_quote_subst"`'
+extract_expsyms_cmds='`$ECHO "$extract_expsyms_cmds" | $SED "$delay_single_quote_subst"`'
+archive_cmds_need_lc='`$ECHO "$archive_cmds_need_lc" | $SED "$delay_single_quote_subst"`'
+enable_shared_with_static_runtimes='`$ECHO "$enable_shared_with_static_runtimes" | $SED "$delay_single_quote_subst"`'
+export_dynamic_flag_spec='`$ECHO "$export_dynamic_flag_spec" | $SED "$delay_single_quote_subst"`'
+whole_archive_flag_spec='`$ECHO "$whole_archive_flag_spec" | $SED "$delay_single_quote_subst"`'
+compiler_needs_object='`$ECHO "$compiler_needs_object" | $SED "$delay_single_quote_subst"`'
+old_archive_from_new_cmds='`$ECHO "$old_archive_from_new_cmds" | $SED "$delay_single_quote_subst"`'
+old_archive_from_expsyms_cmds='`$ECHO "$old_archive_from_expsyms_cmds" | $SED "$delay_single_quote_subst"`'
+archive_cmds='`$ECHO "$archive_cmds" | $SED "$delay_single_quote_subst"`'
+archive_expsym_cmds='`$ECHO "$archive_expsym_cmds" | $SED "$delay_single_quote_subst"`'
+module_cmds='`$ECHO "$module_cmds" | $SED "$delay_single_quote_subst"`'
+module_expsym_cmds='`$ECHO "$module_expsym_cmds" | $SED "$delay_single_quote_subst"`'
+with_gnu_ld='`$ECHO "$with_gnu_ld" | $SED "$delay_single_quote_subst"`'
+allow_undefined_flag='`$ECHO "$allow_undefined_flag" | $SED "$delay_single_quote_subst"`'
+no_undefined_flag='`$ECHO "$no_undefined_flag" | $SED "$delay_single_quote_subst"`'
+hardcode_libdir_flag_spec='`$ECHO "$hardcode_libdir_flag_spec" | $SED "$delay_single_quote_subst"`'
+hardcode_libdir_separator='`$ECHO "$hardcode_libdir_separator" | $SED "$delay_single_quote_subst"`'
+hardcode_direct='`$ECHO "$hardcode_direct" | $SED "$delay_single_quote_subst"`'
+hardcode_direct_absolute='`$ECHO "$hardcode_direct_absolute" | $SED "$delay_single_quote_subst"`'
+hardcode_minus_L='`$ECHO "$hardcode_minus_L" | $SED "$delay_single_quote_subst"`'
+hardcode_shlibpath_var='`$ECHO "$hardcode_shlibpath_var" | $SED "$delay_single_quote_subst"`'
+hardcode_automatic='`$ECHO "$hardcode_automatic" | $SED "$delay_single_quote_subst"`'
+inherit_rpath='`$ECHO "$inherit_rpath" | $SED "$delay_single_quote_subst"`'
+link_all_deplibs='`$ECHO "$link_all_deplibs" | $SED "$delay_single_quote_subst"`'
+always_export_symbols='`$ECHO "$always_export_symbols" | $SED "$delay_single_quote_subst"`'
+export_symbols_cmds='`$ECHO "$export_symbols_cmds" | $SED "$delay_single_quote_subst"`'
+exclude_expsyms='`$ECHO "$exclude_expsyms" | $SED "$delay_single_quote_subst"`'
+include_expsyms='`$ECHO "$include_expsyms" | $SED "$delay_single_quote_subst"`'
+prelink_cmds='`$ECHO "$prelink_cmds" | $SED "$delay_single_quote_subst"`'
+postlink_cmds='`$ECHO "$postlink_cmds" | $SED "$delay_single_quote_subst"`'
+file_list_spec='`$ECHO "$file_list_spec" | $SED "$delay_single_quote_subst"`'
+variables_saved_for_relink='`$ECHO "$variables_saved_for_relink" | $SED "$delay_single_quote_subst"`'
+need_lib_prefix='`$ECHO "$need_lib_prefix" | $SED "$delay_single_quote_subst"`'
+need_version='`$ECHO "$need_version" | $SED "$delay_single_quote_subst"`'
+version_type='`$ECHO "$version_type" | $SED "$delay_single_quote_subst"`'
+runpath_var='`$ECHO "$runpath_var" | $SED "$delay_single_quote_subst"`'
+shlibpath_var='`$ECHO "$shlibpath_var" | $SED "$delay_single_quote_subst"`'
+shlibpath_overrides_runpath='`$ECHO "$shlibpath_overrides_runpath" | $SED "$delay_single_quote_subst"`'
+libname_spec='`$ECHO "$libname_spec" | $SED "$delay_single_quote_subst"`'
+library_names_spec='`$ECHO "$library_names_spec" | $SED "$delay_single_quote_subst"`'
+soname_spec='`$ECHO "$soname_spec" | $SED "$delay_single_quote_subst"`'
+install_override_mode='`$ECHO "$install_override_mode" | $SED "$delay_single_quote_subst"`'
+postinstall_cmds='`$ECHO "$postinstall_cmds" | $SED "$delay_single_quote_subst"`'
+postuninstall_cmds='`$ECHO "$postuninstall_cmds" | $SED "$delay_single_quote_subst"`'
+finish_cmds='`$ECHO "$finish_cmds" | $SED "$delay_single_quote_subst"`'
+finish_eval='`$ECHO "$finish_eval" | $SED "$delay_single_quote_subst"`'
+hardcode_into_libs='`$ECHO "$hardcode_into_libs" | $SED "$delay_single_quote_subst"`'
+sys_lib_search_path_spec='`$ECHO "$sys_lib_search_path_spec" | $SED "$delay_single_quote_subst"`'
+sys_lib_dlsearch_path_spec='`$ECHO "$sys_lib_dlsearch_path_spec" | $SED "$delay_single_quote_subst"`'
+hardcode_action='`$ECHO "$hardcode_action" | $SED "$delay_single_quote_subst"`'
+enable_dlopen='`$ECHO "$enable_dlopen" | $SED "$delay_single_quote_subst"`'
+enable_dlopen_self='`$ECHO "$enable_dlopen_self" | $SED "$delay_single_quote_subst"`'
+enable_dlopen_self_static='`$ECHO "$enable_dlopen_self_static" | $SED "$delay_single_quote_subst"`'
+old_striplib='`$ECHO "$old_striplib" | $SED "$delay_single_quote_subst"`'
+striplib='`$ECHO "$striplib" | $SED "$delay_single_quote_subst"`'
+compiler_lib_search_dirs='`$ECHO "$compiler_lib_search_dirs" | $SED "$delay_single_quote_subst"`'
+predep_objects='`$ECHO "$predep_objects" | $SED "$delay_single_quote_subst"`'
+postdep_objects='`$ECHO "$postdep_objects" | $SED "$delay_single_quote_subst"`'
+predeps='`$ECHO "$predeps" | $SED "$delay_single_quote_subst"`'
+postdeps='`$ECHO "$postdeps" | $SED "$delay_single_quote_subst"`'
+compiler_lib_search_path='`$ECHO "$compiler_lib_search_path" | $SED "$delay_single_quote_subst"`'
+LD_CXX='`$ECHO "$LD_CXX" | $SED "$delay_single_quote_subst"`'
+reload_flag_CXX='`$ECHO "$reload_flag_CXX" | $SED "$delay_single_quote_subst"`'
+reload_cmds_CXX='`$ECHO "$reload_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+old_archive_cmds_CXX='`$ECHO "$old_archive_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+compiler_CXX='`$ECHO "$compiler_CXX" | $SED "$delay_single_quote_subst"`'
+GCC_CXX='`$ECHO "$GCC_CXX" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_no_builtin_flag_CXX='`$ECHO "$lt_prog_compiler_no_builtin_flag_CXX" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_pic_CXX='`$ECHO "$lt_prog_compiler_pic_CXX" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_wl_CXX='`$ECHO "$lt_prog_compiler_wl_CXX" | $SED "$delay_single_quote_subst"`'
+lt_prog_compiler_static_CXX='`$ECHO "$lt_prog_compiler_static_CXX" | $SED "$delay_single_quote_subst"`'
+lt_cv_prog_compiler_c_o_CXX='`$ECHO "$lt_cv_prog_compiler_c_o_CXX" | $SED "$delay_single_quote_subst"`'
+archive_cmds_need_lc_CXX='`$ECHO "$archive_cmds_need_lc_CXX" | $SED "$delay_single_quote_subst"`'
+enable_shared_with_static_runtimes_CXX='`$ECHO "$enable_shared_with_static_runtimes_CXX" | $SED "$delay_single_quote_subst"`'
+export_dynamic_flag_spec_CXX='`$ECHO "$export_dynamic_flag_spec_CXX" | $SED "$delay_single_quote_subst"`'
+whole_archive_flag_spec_CXX='`$ECHO "$whole_archive_flag_spec_CXX" | $SED "$delay_single_quote_subst"`'
+compiler_needs_object_CXX='`$ECHO "$compiler_needs_object_CXX" | $SED "$delay_single_quote_subst"`'
+old_archive_from_new_cmds_CXX='`$ECHO "$old_archive_from_new_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+old_archive_from_expsyms_cmds_CXX='`$ECHO "$old_archive_from_expsyms_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+archive_cmds_CXX='`$ECHO "$archive_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+archive_expsym_cmds_CXX='`$ECHO "$archive_expsym_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+module_cmds_CXX='`$ECHO "$module_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+module_expsym_cmds_CXX='`$ECHO "$module_expsym_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+with_gnu_ld_CXX='`$ECHO "$with_gnu_ld_CXX" | $SED "$delay_single_quote_subst"`'
+allow_undefined_flag_CXX='`$ECHO "$allow_undefined_flag_CXX" | $SED "$delay_single_quote_subst"`'
+no_undefined_flag_CXX='`$ECHO "$no_undefined_flag_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_libdir_flag_spec_CXX='`$ECHO "$hardcode_libdir_flag_spec_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_libdir_separator_CXX='`$ECHO "$hardcode_libdir_separator_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_direct_CXX='`$ECHO "$hardcode_direct_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_direct_absolute_CXX='`$ECHO "$hardcode_direct_absolute_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_minus_L_CXX='`$ECHO "$hardcode_minus_L_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_shlibpath_var_CXX='`$ECHO "$hardcode_shlibpath_var_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_automatic_CXX='`$ECHO "$hardcode_automatic_CXX" | $SED "$delay_single_quote_subst"`'
+inherit_rpath_CXX='`$ECHO "$inherit_rpath_CXX" | $SED "$delay_single_quote_subst"`'
+link_all_deplibs_CXX='`$ECHO "$link_all_deplibs_CXX" | $SED "$delay_single_quote_subst"`'
+always_export_symbols_CXX='`$ECHO "$always_export_symbols_CXX" | $SED "$delay_single_quote_subst"`'
+export_symbols_cmds_CXX='`$ECHO "$export_symbols_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+exclude_expsyms_CXX='`$ECHO "$exclude_expsyms_CXX" | $SED "$delay_single_quote_subst"`'
+include_expsyms_CXX='`$ECHO "$include_expsyms_CXX" | $SED "$delay_single_quote_subst"`'
+prelink_cmds_CXX='`$ECHO "$prelink_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+postlink_cmds_CXX='`$ECHO "$postlink_cmds_CXX" | $SED "$delay_single_quote_subst"`'
+file_list_spec_CXX='`$ECHO "$file_list_spec_CXX" | $SED "$delay_single_quote_subst"`'
+hardcode_action_CXX='`$ECHO "$hardcode_action_CXX" | $SED "$delay_single_quote_subst"`'
+compiler_lib_search_dirs_CXX='`$ECHO "$compiler_lib_search_dirs_CXX" | $SED "$delay_single_quote_subst"`'
+predep_objects_CXX='`$ECHO "$predep_objects_CXX" | $SED "$delay_single_quote_subst"`'
+postdep_objects_CXX='`$ECHO "$postdep_objects_CXX" | $SED "$delay_single_quote_subst"`'
+predeps_CXX='`$ECHO "$predeps_CXX" | $SED "$delay_single_quote_subst"`'
+postdeps_CXX='`$ECHO "$postdeps_CXX" | $SED "$delay_single_quote_subst"`'
+compiler_lib_search_path_CXX='`$ECHO "$compiler_lib_search_path_CXX" | $SED "$delay_single_quote_subst"`'
 
 LTCC='$LTCC'
 LTCFLAGS='$LTCFLAGS'
 compiler='$compiler_DEFAULT'
 
+# A function that is used when there is no print builtin or printf.
+func_fallback_echo ()
+{
+  eval 'cat <<_LTECHO_EOF
+\$1
+_LTECHO_EOF'
+}
+
 # Quote evaled strings.
-for var in SED \
+for var in SHELL \
+ECHO \
+PATH_SEPARATOR \
+SED \
 GREP \
 EGREP \
 FGREP \
@@ -16876,8 +17764,13 @@
 OBJDUMP \
 deplibs_check_method \
 file_magic_cmd \
+file_magic_glob \
+want_nocaseglob \
+DLLTOOL \
+sharedlib_from_linklib_cmd \
 AR \
 AR_FLAGS \
+archiver_list_spec \
 STRIP \
 RANLIB \
 CC \
@@ -16887,14 +17780,14 @@
 lt_cv_sys_global_symbol_to_cdecl \
 lt_cv_sys_global_symbol_to_c_name_address \
 lt_cv_sys_global_symbol_to_c_name_address_lib_prefix \
-SHELL \
-ECHO \
+nm_file_list_spec \
 lt_prog_compiler_no_builtin_flag \
+lt_prog_compiler_pic \
 lt_prog_compiler_wl \
-lt_prog_compiler_pic \
 lt_prog_compiler_static \
 lt_cv_prog_compiler_c_o \
 need_locks \
+MANIFEST_TOOL \
 DSYMUTIL \
 NMEDIT \
 LIPO \
@@ -16908,9 +17801,7 @@
 allow_undefined_flag \
 no_undefined_flag \
 hardcode_libdir_flag_spec \
-hardcode_libdir_flag_spec_ld \
 hardcode_libdir_separator \
-fix_srcfile_path \
 exclude_expsyms \
 include_expsyms \
 file_list_spec \
@@ -16918,6 +17809,7 @@
 libname_spec \
 library_names_spec \
 soname_spec \
+install_override_mode \
 finish_eval \
 old_striplib \
 striplib \
@@ -16928,10 +17820,11 @@
 postdeps \
 compiler_lib_search_path \
 LD_CXX \
+reload_flag_CXX \
 compiler_CXX \
 lt_prog_compiler_no_builtin_flag_CXX \
+lt_prog_compiler_pic_CXX \
 lt_prog_compiler_wl_CXX \
-lt_prog_compiler_pic_CXX \
 lt_prog_compiler_static_CXX \
 lt_cv_prog_compiler_c_o_CXX \
 export_dynamic_flag_spec_CXX \
@@ -16941,9 +17834,7 @@
 allow_undefined_flag_CXX \
 no_undefined_flag_CXX \
 hardcode_libdir_flag_spec_CXX \
-hardcode_libdir_flag_spec_ld_CXX \
 hardcode_libdir_separator_CXX \
-fix_srcfile_path_CXX \
 exclude_expsyms_CXX \
 include_expsyms_CXX \
 file_list_spec_CXX \
@@ -16953,9 +17844,9 @@
 predeps_CXX \
 postdeps_CXX \
 compiler_lib_search_path_CXX; do
-    case \`eval \\\\\$ECHO "X\\\\\$\$var"\` in
+    case \`eval \\\\\$ECHO \\\\""\\\\\$\$var"\\\\"\` in
     *[\\\\\\\`\\"\\\$]*)
-      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"X\\\$\$var\\" | \\\$Xsed -e \\"\\\$sed_quote_subst\\"\\\`\\\\\\""
+      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"\\\$\$var\\" | \\\$SED \\"\\\$sed_quote_subst\\"\\\`\\\\\\""
       ;;
     *)
       eval "lt_\$var=\\\\\\"\\\$\$var\\\\\\""
@@ -16977,11 +17868,13 @@
 module_expsym_cmds \
 export_symbols_cmds \
 prelink_cmds \
+postlink_cmds \
 postinstall_cmds \
 postuninstall_cmds \
 finish_cmds \
 sys_lib_search_path_spec \
 sys_lib_dlsearch_path_spec \
+reload_cmds_CXX \
 old_archive_cmds_CXX \
 old_archive_from_new_cmds_CXX \
 old_archive_from_expsyms_cmds_CXX \
@@ -16990,10 +17883,11 @@
 module_cmds_CXX \
 module_expsym_cmds_CXX \
 export_symbols_cmds_CXX \
-prelink_cmds_CXX; do
-    case \`eval \\\\\$ECHO "X\\\\\$\$var"\` in
+prelink_cmds_CXX \
+postlink_cmds_CXX; do
+    case \`eval \\\\\$ECHO \\\\""\\\\\$\$var"\\\\"\` in
     *[\\\\\\\`\\"\\\$]*)
-      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"X\\\$\$var\\" | \\\$Xsed -e \\"\\\$double_quote_subst\\" -e \\"\\\$sed_quote_subst\\" -e \\"\\\$delay_variable_subst\\"\\\`\\\\\\""
+      eval "lt_\$var=\\\\\\"\\\`\\\$ECHO \\"\\\$\$var\\" | \\\$SED -e \\"\\\$double_quote_subst\\" -e \\"\\\$sed_quote_subst\\" -e \\"\\\$delay_variable_subst\\"\\\`\\\\\\""
       ;;
     *)
       eval "lt_\$var=\\\\\\"\\\$\$var\\\\\\""
@@ -17001,12 +17895,6 @@
     esac
 done
 
-# Fix-up fallback echo if it was mangled by the above quoting rules.
-case \$lt_ECHO in
-*'\\\$0 --fallback-echo"')  lt_ECHO=\`\$ECHO "X\$lt_ECHO" | \$Xsed -e 's/\\\\\\\\\\\\\\\$0 --fallback-echo"\$/\$0 --fallback-echo"/'\`
-  ;;
-esac
-
 ac_aux_dir='$ac_aux_dir'
 xsi_shell='$xsi_shell'
 lt_shell_append='$lt_shell_append'
@@ -17053,6 +17941,7 @@
     "src/tests/amp/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/amp/Makefile" ;;
     "src/tests/base64/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/base64/Makefile" ;;
     "src/tests/capabilities/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/capabilities/Makefile" ;;
+    "src/tests/carbons/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/carbons/Makefile" ;;
     "src/tests/chatstatefilter/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/chatstatefilter/Makefile" ;;
     "src/tests/client/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/client/Makefile" ;;
     "src/tests/clientbase/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/clientbase/Makefile" ;;
@@ -17069,12 +17958,18 @@
     "src/tests/featureneg/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/featureneg/Makefile" ;;
     "src/tests/flexofflineoffline/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/flexofflineoffline/Makefile" ;;
     "src/tests/flexoffline/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/flexoffline/Makefile" ;;
+    "src/tests/forward/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/forward/Makefile" ;;
     "src/tests/gpgencrypted/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/gpgencrypted/Makefile" ;;
     "src/tests/gpgsigned/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/gpgsigned/Makefile" ;;
     "src/tests/inbandbytestreamibb/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/inbandbytestreamibb/Makefile" ;;
     "src/tests/inbandbytestream/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/inbandbytestream/Makefile" ;;
     "src/tests/iq/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/iq/Makefile" ;;
     "src/tests/jid/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/jid/Makefile" ;;
+    "src/tests/jinglecontent/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/jinglecontent/Makefile" ;;
+    "src/tests/jingleiceudp/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/jingleiceudp/Makefile" ;;
+    "src/tests/jinglesession/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/jinglesession/Makefile" ;;
+    "src/tests/jinglesessionjingle/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/jinglesessionjingle/Makefile" ;;
+    "src/tests/jinglesessionmanager/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/jinglesessionmanager/Makefile" ;;
     "src/tests/lastactivityquery/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/lastactivityquery/Makefile" ;;
     "src/tests/lastactivity/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/lastactivity/Makefile" ;;
     "src/tests/md5/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/md5/Makefile" ;;
@@ -17119,7 +18014,7 @@
     "src/tests/xpath/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/xpath/Makefile" ;;
     "src/tests/zlib/Makefile") CONFIG_FILES="$CONFIG_FILES src/tests/zlib/Makefile" ;;
 
-  *) as_fn_error "invalid argument: \`$ac_config_target'" "$LINENO" 5;;
+  *) as_fn_error $? "invalid argument: \`$ac_config_target'" "$LINENO" 5;;
   esac
 done
 
@@ -17142,9 +18037,10 @@
 # after its creation but before its name has been assigned to `$tmp'.
 $debug ||
 {
-  tmp=
+  tmp= ac_tmp=
   trap 'exit_status=$?
-  { test -z "$tmp" || test ! -d "$tmp" || rm -fr "$tmp"; } && exit $exit_status
+  : "${ac_tmp:=$tmp}"
+  { test ! -d "$ac_tmp" || rm -fr "$ac_tmp"; } && exit $exit_status
 ' 0
   trap 'as_fn_exit 1' 1 2 13 15
 }
@@ -17152,12 +18048,13 @@
 
 {
   tmp=`(umask 077 && mktemp -d "./confXXXXXX") 2>/dev/null` &&
-  test -n "$tmp" && test -d "$tmp"
+  test -d "$tmp"
 }  ||
 {
   tmp=./conf$$-$RANDOM
   (umask 077 && mkdir "$tmp")
-} || as_fn_error "cannot create a temporary directory in ." "$LINENO" 5
+} || as_fn_error $? "cannot create a temporary directory in ." "$LINENO" 5
+ac_tmp=$tmp
 
 # Set up the scripts for CONFIG_FILES section.
 # No need to generate them if there are no CONFIG_FILES.
@@ -17174,12 +18071,12 @@
 fi
 ac_cs_awk_cr=`$AWK 'BEGIN { print "a\rb" }' </dev/null 2>/dev/null`
 if test "$ac_cs_awk_cr" = "a${ac_cr}b"; then
-  ac_cs_awk_cr='\r'
+  ac_cs_awk_cr='\\r'
 else
   ac_cs_awk_cr=$ac_cr
 fi
 
-echo 'BEGIN {' >"$tmp/subs1.awk" &&
+echo 'BEGIN {' >"$ac_tmp/subs1.awk" &&
 _ACEOF
 
 
@@ -17188,18 +18085,18 @@
   echo "$ac_subst_vars" | sed 's/.*/&!$&$ac_delim/' &&
   echo "_ACEOF"
 } >conf$$subs.sh ||
-  as_fn_error "could not make $CONFIG_STATUS" "$LINENO" 5
-ac_delim_num=`echo "$ac_subst_vars" | grep -c '$'`
+  as_fn_error $? "could not make $CONFIG_STATUS" "$LINENO" 5
+ac_delim_num=`echo "$ac_subst_vars" | grep -c '^'`
 ac_delim='%!_!# '
 for ac_last_try in false false false false false :; do
   . ./conf$$subs.sh ||
-    as_fn_error "could not make $CONFIG_STATUS" "$LINENO" 5
+    as_fn_error $? "could not make $CONFIG_STATUS" "$LINENO" 5
 
   ac_delim_n=`sed -n "s/.*$ac_delim\$/X/p" conf$$subs.awk | grep -c X`
   if test $ac_delim_n = $ac_delim_num; then
     break
   elif $ac_last_try; then
-    as_fn_error "could not make $CONFIG_STATUS" "$LINENO" 5
+    as_fn_error $? "could not make $CONFIG_STATUS" "$LINENO" 5
   else
     ac_delim="$ac_delim!$ac_delim _$ac_delim!! "
   fi
@@ -17207,7 +18104,7 @@
 rm -f conf$$subs.sh
 
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
-cat >>"\$tmp/subs1.awk" <<\\_ACAWK &&
+cat >>"\$ac_tmp/subs1.awk" <<\\_ACAWK &&
 _ACEOF
 sed -n '
 h
@@ -17221,7 +18118,7 @@
 t delim
 :nl
 h
-s/\(.\{148\}\).*/\1/
+s/\(.\{148\}\)..*/\1/
 t more1
 s/["\\]/\\&/g; s/^/"/; s/$/\\n"\\/
 p
@@ -17235,7 +18132,7 @@
 t nl
 :delim
 h
-s/\(.\{148\}\).*/\1/
+s/\(.\{148\}\)..*/\1/
 t more2
 s/["\\]/\\&/g; s/^/"/; s/$/"/
 p
@@ -17255,7 +18152,7 @@
 rm -f conf$$subs.awk
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 _ACAWK
-cat >>"\$tmp/subs1.awk" <<_ACAWK &&
+cat >>"\$ac_tmp/subs1.awk" <<_ACAWK &&
   for (key in S) S_is_set[key] = 1
   FS = ""
 
@@ -17287,21 +18184,29 @@
   sed "s/$ac_cr\$//; s/$ac_cr/$ac_cs_awk_cr/g"
 else
   cat
-fi < "$tmp/subs1.awk" > "$tmp/subs.awk" \
-  || as_fn_error "could not setup config files machinery" "$LINENO" 5
+fi < "$ac_tmp/subs1.awk" > "$ac_tmp/subs.awk" \
+  || as_fn_error $? "could not setup config files machinery" "$LINENO" 5
 _ACEOF
 
-# VPATH may cause trouble with some makes, so we remove $(srcdir),
-# ${srcdir} and @srcdir@ from VPATH if srcdir is ".", strip leading and
+# VPATH may cause trouble with some makes, so we remove sole $(srcdir),
+# ${srcdir} and @srcdir@ entries from VPATH if srcdir is ".", strip leading and
 # trailing colons and then remove the whole line if VPATH becomes empty
 # (actually we leave an empty line to preserve line numbers).
 if test "x$srcdir" = x.; then
-  ac_vpsub='/^[	 ]*VPATH[	 ]*=/{
-s/:*\$(srcdir):*/:/
-s/:*\${srcdir}:*/:/
-s/:*@srcdir@:*/:/
-s/^\([^=]*=[	 ]*\):*/\1/
+  ac_vpsub='/^[	 ]*VPATH[	 ]*=[	 ]*/{
+h
+s///
+s/^/:/
+s/[	 ]*$/:/
+s/:\$(srcdir):/:/g
+s/:\${srcdir}:/:/g
+s/:@srcdir@:/:/g
+s/^:*//
 s/:*$//
+x
+s/\(=[	 ]*\).*/\1/
+G
+s/\n//
 s/^[^=]*=[	 ]*$//
 }'
 fi
@@ -17313,7 +18218,7 @@
 # No need to generate them if there are no CONFIG_HEADERS.
 # This happens for instance with `./config.status Makefile'.
 if test -n "$CONFIG_HEADERS"; then
-cat >"$tmp/defines.awk" <<\_ACAWK ||
+cat >"$ac_tmp/defines.awk" <<\_ACAWK ||
 BEGIN {
 _ACEOF
 
@@ -17325,11 +18230,11 @@
 # handling of long lines.
 ac_delim='%!_!# '
 for ac_last_try in false false :; do
-  ac_t=`sed -n "/$ac_delim/p" confdefs.h`
-  if test -z "$ac_t"; then
+  ac_tt=`sed -n "/$ac_delim/p" confdefs.h`
+  if test -z "$ac_tt"; then
     break
   elif $ac_last_try; then
-    as_fn_error "could not make $CONFIG_HEADERS" "$LINENO" 5
+    as_fn_error $? "could not make $CONFIG_HEADERS" "$LINENO" 5
   else
     ac_delim="$ac_delim!$ac_delim _$ac_delim!! "
   fi
@@ -17414,7 +18319,7 @@
 _ACAWK
 _ACEOF
 cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
-  as_fn_error "could not setup config headers machinery" "$LINENO" 5
+  as_fn_error $? "could not setup config headers machinery" "$LINENO" 5
 fi # test -n "$CONFIG_HEADERS"
 
 
@@ -17427,7 +18332,7 @@
   esac
   case $ac_mode$ac_tag in
   :[FHL]*:*);;
-  :L* | :C*:*) as_fn_error "invalid tag \`$ac_tag'" "$LINENO" 5;;
+  :L* | :C*:*) as_fn_error $? "invalid tag \`$ac_tag'" "$LINENO" 5;;
   :[FH]-) ac_tag=-:-;;
   :[FH]*) ac_tag=$ac_tag:$ac_tag.in;;
   esac
@@ -17446,7 +18351,7 @@
     for ac_f
     do
       case $ac_f in
-      -) ac_f="$tmp/stdin";;
+      -) ac_f="$ac_tmp/stdin";;
       *) # Look for the file first in the build tree, then in the source tree
 	 # (if the path is not absolute).  The absolute path cannot be DOS-style,
 	 # because $ac_f cannot contain `:'.
@@ -17455,7 +18360,7 @@
 	   [\\/$]*) false;;
 	   *) test -f "$srcdir/$ac_f" && ac_f="$srcdir/$ac_f";;
 	   esac ||
-	   as_fn_error "cannot find input file: \`$ac_f'" "$LINENO" 5;;
+	   as_fn_error 1 "cannot find input file: \`$ac_f'" "$LINENO" 5;;
       esac
       case $ac_f in *\'*) ac_f=`$as_echo "$ac_f" | sed "s/'/'\\\\\\\\''/g"`;; esac
       as_fn_append ac_file_inputs " '$ac_f'"
@@ -17481,8 +18386,8 @@
     esac
 
     case $ac_tag in
-    *:-:* | *:-) cat >"$tmp/stdin" \
-      || as_fn_error "could not create $ac_file" "$LINENO" 5 ;;
+    *:-:* | *:-) cat >"$ac_tmp/stdin" \
+      || as_fn_error $? "could not create $ac_file" "$LINENO" 5 ;;
     esac
     ;;
   esac
@@ -17618,23 +18523,24 @@
 s&@MKDIR_P@&$ac_MKDIR_P&;t t
 $ac_datarootdir_hack
 "
-eval sed \"\$ac_sed_extra\" "$ac_file_inputs" | $AWK -f "$tmp/subs.awk" >$tmp/out \
-  || as_fn_error "could not create $ac_file" "$LINENO" 5
+eval sed \"\$ac_sed_extra\" "$ac_file_inputs" | $AWK -f "$ac_tmp/subs.awk" \
+  >$ac_tmp/out || as_fn_error $? "could not create $ac_file" "$LINENO" 5
 
 test -z "$ac_datarootdir_hack$ac_datarootdir_seen" &&
-  { ac_out=`sed -n '/\${datarootdir}/p' "$tmp/out"`; test -n "$ac_out"; } &&
-  { ac_out=`sed -n '/^[	 ]*datarootdir[	 ]*:*=/p' "$tmp/out"`; test -z "$ac_out"; } &&
+  { ac_out=`sed -n '/\${datarootdir}/p' "$ac_tmp/out"`; test -n "$ac_out"; } &&
+  { ac_out=`sed -n '/^[	 ]*datarootdir[	 ]*:*=/p' \
+      "$ac_tmp/out"`; test -z "$ac_out"; } &&
   { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $ac_file contains a reference to the variable \`datarootdir'
-which seems to be undefined.  Please make sure it is defined." >&5
+which seems to be undefined.  Please make sure it is defined" >&5
 $as_echo "$as_me: WARNING: $ac_file contains a reference to the variable \`datarootdir'
-which seems to be undefined.  Please make sure it is defined." >&2;}
+which seems to be undefined.  Please make sure it is defined" >&2;}
 
-  rm -f "$tmp/stdin"
+  rm -f "$ac_tmp/stdin"
   case $ac_file in
-  -) cat "$tmp/out" && rm -f "$tmp/out";;
-  *) rm -f "$ac_file" && mv "$tmp/out" "$ac_file";;
+  -) cat "$ac_tmp/out" && rm -f "$ac_tmp/out";;
+  *) rm -f "$ac_file" && mv "$ac_tmp/out" "$ac_file";;
   esac \
-  || as_fn_error "could not create $ac_file" "$LINENO" 5
+  || as_fn_error $? "could not create $ac_file" "$LINENO" 5
  ;;
   :H)
   #
@@ -17643,21 +18549,21 @@
   if test x"$ac_file" != x-; then
     {
       $as_echo "/* $configure_input  */" \
-      && eval '$AWK -f "$tmp/defines.awk"' "$ac_file_inputs"
-    } >"$tmp/config.h" \
-      || as_fn_error "could not create $ac_file" "$LINENO" 5
-    if diff "$ac_file" "$tmp/config.h" >/dev/null 2>&1; then
+      && eval '$AWK -f "$ac_tmp/defines.awk"' "$ac_file_inputs"
+    } >"$ac_tmp/config.h" \
+      || as_fn_error $? "could not create $ac_file" "$LINENO" 5
+    if diff "$ac_file" "$ac_tmp/config.h" >/dev/null 2>&1; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: $ac_file is unchanged" >&5
 $as_echo "$as_me: $ac_file is unchanged" >&6;}
     else
       rm -f "$ac_file"
-      mv "$tmp/config.h" "$ac_file" \
-	|| as_fn_error "could not create $ac_file" "$LINENO" 5
+      mv "$ac_tmp/config.h" "$ac_file" \
+	|| as_fn_error $? "could not create $ac_file" "$LINENO" 5
     fi
   else
     $as_echo "/* $configure_input  */" \
-      && eval '$AWK -f "$tmp/defines.awk"' "$ac_file_inputs" \
-      || as_fn_error "could not create -" "$LINENO" 5
+      && eval '$AWK -f "$ac_tmp/defines.awk"' "$ac_file_inputs" \
+      || as_fn_error $? "could not create -" "$LINENO" 5
   fi
 # Compute "$ac_file"'s index in $config_headers.
 _am_arg="$ac_file"
@@ -17818,7 +18724,8 @@
 # NOTE: Changes made to this file will be lost: look at ltmain.sh.
 #
 #   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005,
-#                 2006, 2007, 2008 Free Software Foundation, Inc.
+#                 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+#                 Foundation, Inc.
 #   Written by Gordon Matzigkeit, 1996
 #
 #   This file is part of GNU Libtool.
@@ -17866,6 +18773,15 @@
 # Whether or not to optimize for fast installation.
 fast_install=$enable_fast_install
 
+# Shell to use when invoking shell scripts.
+SHELL=$lt_SHELL
+
+# An echo program that protects backslashes.
+ECHO=$lt_ECHO
+
+# The PATH separator for the build system.
+PATH_SEPARATOR=$lt_PATH_SEPARATOR
+
 # The host system.
 host_alias=$host_alias
 host=$host
@@ -17915,9 +18831,11 @@
 # turn newlines into spaces.
 NL2SP=$lt_lt_NL2SP
 
-# How to create reloadable object files.
-reload_flag=$lt_reload_flag
-reload_cmds=$lt_reload_cmds
+# convert \$build file names to \$host format.
+to_host_file_cmd=$lt_cv_to_host_file_cmd
+
+# convert \$build files to toolchain format.
+to_tool_file_cmd=$lt_cv_to_tool_file_cmd
 
 # An object symbol dumper.
 OBJDUMP=$lt_OBJDUMP
@@ -17925,13 +18843,30 @@
 # Method to check whether dependent libraries are shared objects.
 deplibs_check_method=$lt_deplibs_check_method
 
-# Command to use when deplibs_check_method == "file_magic".
+# Command to use when deplibs_check_method = "file_magic".
 file_magic_cmd=$lt_file_magic_cmd
 
+# How to find potential files when deplibs_check_method = "file_magic".
+file_magic_glob=$lt_file_magic_glob
+
+# Find potential files using nocaseglob when deplibs_check_method = "file_magic".
+want_nocaseglob=$lt_want_nocaseglob
+
+# DLL creation program.
+DLLTOOL=$lt_DLLTOOL
+
+# Command to associate shared and link libraries.
+sharedlib_from_linklib_cmd=$lt_sharedlib_from_linklib_cmd
+
 # The archiver.
 AR=$lt_AR
+
+# Flags to create an archive.
 AR_FLAGS=$lt_AR_FLAGS
 
+# How to feed a file listing to the archiver.
+archiver_list_spec=$lt_archiver_list_spec
+
 # A symbol stripping program.
 STRIP=$lt_STRIP
 
@@ -17940,6 +18875,9 @@
 old_postinstall_cmds=$lt_old_postinstall_cmds
 old_postuninstall_cmds=$lt_old_postuninstall_cmds
 
+# Whether to use a lock for old archive extraction.
+lock_old_archive_extraction=$lock_old_archive_extraction
+
 # A C compiler.
 LTCC=$lt_CC
 
@@ -17958,21 +18896,24 @@
 # Transform the output of nm in a C name address pair when lib prefix is needed.
 global_symbol_to_c_name_address_lib_prefix=$lt_lt_cv_sys_global_symbol_to_c_name_address_lib_prefix
 
+# Specify filename containing input files for \$NM.
+nm_file_list_spec=$lt_nm_file_list_spec
+
+# The root where to search for dependent libraries,and in which our libraries should be installed.
+lt_sysroot=$lt_sysroot
+
 # The name of the directory that contains temporary libtool files.
 objdir=$objdir
 
-# Shell to use when invoking shell scripts.
-SHELL=$lt_SHELL
-
-# An echo program that does not interpret backslashes.
-ECHO=$lt_ECHO
-
 # Used to examine libraries when file_magic_cmd begins with "file".
 MAGIC_CMD=$MAGIC_CMD
 
 # Must we lock files when doing compilation?
 need_locks=$lt_need_locks
 
+# Manifest tool.
+MANIFEST_TOOL=$lt_MANIFEST_TOOL
+
 # Tool to manipulate archived DWARF debug symbol files on Mac OS X.
 DSYMUTIL=$lt_DSYMUTIL
 
@@ -18029,6 +18970,9 @@
 # The coded name of the library, if different from the real name.
 soname_spec=$lt_soname_spec
 
+# Permission mode override for installation of shared libraries.
+install_override_mode=$lt_install_override_mode
+
 # Command to use after installation of a shared archive.
 postinstall_cmds=$lt_postinstall_cmds
 
@@ -18068,6 +19012,10 @@
 # The linker used to build libraries.
 LD=$lt_LD
 
+# How to create reloadable object files.
+reload_flag=$lt_reload_flag
+reload_cmds=$lt_reload_cmds
+
 # Commands used to build an old-style archive.
 old_archive_cmds=$lt_old_archive_cmds
 
@@ -18080,12 +19028,12 @@
 # Compiler flag to turn off builtin functions.
 no_builtin_flag=$lt_lt_prog_compiler_no_builtin_flag
 
+# Additional compiler flags for building library objects.
+pic_flag=$lt_lt_prog_compiler_pic
+
 # How to pass a linker flag through the compiler.
 wl=$lt_lt_prog_compiler_wl
 
-# Additional compiler flags for building library objects.
-pic_flag=$lt_lt_prog_compiler_pic
-
 # Compiler flag to prevent dynamic linking.
 link_static_flag=$lt_lt_prog_compiler_static
 
@@ -18135,10 +19083,6 @@
 # This must work even if \$libdir does not exist
 hardcode_libdir_flag_spec=$lt_hardcode_libdir_flag_spec
 
-# If ld is used when linking, flag to hardcode \$libdir into a binary
-# during linking.  This must work even if \$libdir does not exist.
-hardcode_libdir_flag_spec_ld=$lt_hardcode_libdir_flag_spec_ld
-
 # Whether we need a single "-rpath" flag with a separated argument.
 hardcode_libdir_separator=$lt_hardcode_libdir_separator
 
@@ -18172,9 +19116,6 @@
 # Whether libtool must link a program against all its dependency libraries.
 link_all_deplibs=$link_all_deplibs
 
-# Fix the shell variable \$srcfile for the compiler.
-fix_srcfile_path=$lt_fix_srcfile_path
-
 # Set to "yes" if exported symbols are required.
 always_export_symbols=$always_export_symbols
 
@@ -18190,6 +19131,9 @@
 # Commands necessary for linking programs (against libraries) with templates.
 prelink_cmds=$lt_prelink_cmds
 
+# Commands necessary for finishing linking programs.
+postlink_cmds=$lt_postlink_cmds
+
 # Specify filename containing input files.
 file_list_spec=$lt_file_list_spec
 
@@ -18236,212 +19180,169 @@
   # if finds mixed CR/LF and LF-only lines.  Since sed operates in
   # text mode, it properly converts lines to CR/LF.  This bash problem
   # is reportedly fixed, but why not run on old versions too?
-  sed '/^# Generated shell functions inserted here/q' "$ltmain" >> "$cfgfile" \
-    || (rm -f "$cfgfile"; exit 1)
-
-  case $xsi_shell in
-  yes)
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_dirname file append nondir_replacement
-# Compute the dirname of FILE.  If nonempty, add APPEND to the result,
-# otherwise set result to NONDIR_REPLACEMENT.
-func_dirname ()
-{
-  case ${1} in
-    */*) func_dirname_result="${1%/*}${2}" ;;
-    *  ) func_dirname_result="${3}" ;;
-  esac
-}
-
-# func_basename file
-func_basename ()
-{
-  func_basename_result="${1##*/}"
-}
-
-# func_dirname_and_basename file append nondir_replacement
-# perform func_basename and func_dirname in a single function
-# call:
-#   dirname:  Compute the dirname of FILE.  If nonempty,
-#             add APPEND to the result, otherwise set result
-#             to NONDIR_REPLACEMENT.
-#             value returned in "$func_dirname_result"
-#   basename: Compute filename of FILE.
-#             value retuned in "$func_basename_result"
-# Implementation must be kept synchronized with func_dirname
-# and func_basename. For efficiency, we do not delegate to
-# those functions but instead duplicate the functionality here.
-func_dirname_and_basename ()
-{
-  case ${1} in
-    */*) func_dirname_result="${1%/*}${2}" ;;
-    *  ) func_dirname_result="${3}" ;;
-  esac
-  func_basename_result="${1##*/}"
-}
-
-# func_stripname prefix suffix name
-# strip PREFIX and SUFFIX off of NAME.
-# PREFIX and SUFFIX must not contain globbing or regex special
-# characters, hashes, percent signs, but SUFFIX may contain a leading
-# dot (in which case that matches only a dot).
-func_stripname ()
-{
-  # pdksh 5.2.14 does not do ${X%$Y} correctly if both X and Y are
-  # positional parameters, so assign one to ordinary parameter first.
-  func_stripname_result=${3}
-  func_stripname_result=${func_stripname_result#"${1}"}
-  func_stripname_result=${func_stripname_result%"${2}"}
-}
-
-# func_opt_split
-func_opt_split ()
-{
-  func_opt_split_opt=${1%%=*}
-  func_opt_split_arg=${1#*=}
-}
-
-# func_lo2o object
-func_lo2o ()
-{
-  case ${1} in
-    *.lo) func_lo2o_result=${1%.lo}.${objext} ;;
-    *)    func_lo2o_result=${1} ;;
-  esac
-}
-
-# func_xform libobj-or-source
-func_xform ()
-{
-  func_xform_result=${1%.*}.lo
-}
-
-# func_arith arithmetic-term...
-func_arith ()
-{
-  func_arith_result=$(( $* ))
-}
-
-# func_len string
-# STRING may not start with a hyphen.
-func_len ()
-{
-  func_len_result=${#1}
-}
-
-_LT_EOF
-    ;;
-  *) # Bourne compatible functions.
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_dirname file append nondir_replacement
-# Compute the dirname of FILE.  If nonempty, add APPEND to the result,
-# otherwise set result to NONDIR_REPLACEMENT.
-func_dirname ()
-{
-  # Extract subdirectory from the argument.
-  func_dirname_result=`$ECHO "X${1}" | $Xsed -e "$dirname"`
-  if test "X$func_dirname_result" = "X${1}"; then
-    func_dirname_result="${3}"
-  else
-    func_dirname_result="$func_dirname_result${2}"
-  fi
-}
-
-# func_basename file
-func_basename ()
-{
-  func_basename_result=`$ECHO "X${1}" | $Xsed -e "$basename"`
-}
-
-
-# func_stripname prefix suffix name
-# strip PREFIX and SUFFIX off of NAME.
-# PREFIX and SUFFIX must not contain globbing or regex special
-# characters, hashes, percent signs, but SUFFIX may contain a leading
-# dot (in which case that matches only a dot).
-# func_strip_suffix prefix name
-func_stripname ()
-{
-  case ${2} in
-    .*) func_stripname_result=`$ECHO "X${3}" \
-           | $Xsed -e "s%^${1}%%" -e "s%\\\\${2}\$%%"`;;
-    *)  func_stripname_result=`$ECHO "X${3}" \
-           | $Xsed -e "s%^${1}%%" -e "s%${2}\$%%"`;;
-  esac
-}
-
-# sed scripts:
-my_sed_long_opt='1s/^\(-[^=]*\)=.*/\1/;q'
-my_sed_long_arg='1s/^-[^=]*=//'
-
-# func_opt_split
-func_opt_split ()
-{
-  func_opt_split_opt=`$ECHO "X${1}" | $Xsed -e "$my_sed_long_opt"`
-  func_opt_split_arg=`$ECHO "X${1}" | $Xsed -e "$my_sed_long_arg"`
-}
-
-# func_lo2o object
-func_lo2o ()
-{
-  func_lo2o_result=`$ECHO "X${1}" | $Xsed -e "$lo2o"`
-}
-
-# func_xform libobj-or-source
-func_xform ()
-{
-  func_xform_result=`$ECHO "X${1}" | $Xsed -e 's/\.[^.]*$/.lo/'`
-}
-
-# func_arith arithmetic-term...
-func_arith ()
-{
-  func_arith_result=`expr "$@"`
-}
-
-# func_len string
-# STRING may not start with a hyphen.
-func_len ()
-{
-  func_len_result=`expr "$1" : ".*" 2>/dev/null || echo $max_cmd_len`
-}
-
-_LT_EOF
-esac
-
-case $lt_shell_append in
-  yes)
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_append var value
-# Append VALUE to the end of shell variable VAR.
-func_append ()
-{
-  eval "$1+=\$2"
-}
-_LT_EOF
-    ;;
-  *)
-    cat << \_LT_EOF >> "$cfgfile"
-
-# func_append var value
-# Append VALUE to the end of shell variable VAR.
-func_append ()
-{
-  eval "$1=\$$1\$2"
-}
-
-_LT_EOF
-    ;;
-  esac
-
-
-  sed -n '/^# Generated shell functions inserted here/,$p' "$ltmain" >> "$cfgfile" \
-    || (rm -f "$cfgfile"; exit 1)
-
-  mv -f "$cfgfile" "$ofile" ||
+  sed '$q' "$ltmain" >> "$cfgfile" \
+     || (rm -f "$cfgfile"; exit 1)
+
+  if test x"$xsi_shell" = xyes; then
+  sed -e '/^func_dirname ()$/,/^} # func_dirname /c\
+func_dirname ()\
+{\
+\    case ${1} in\
+\      */*) func_dirname_result="${1%/*}${2}" ;;\
+\      *  ) func_dirname_result="${3}" ;;\
+\    esac\
+} # Extended-shell func_dirname implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_basename ()$/,/^} # func_basename /c\
+func_basename ()\
+{\
+\    func_basename_result="${1##*/}"\
+} # Extended-shell func_basename implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_dirname_and_basename ()$/,/^} # func_dirname_and_basename /c\
+func_dirname_and_basename ()\
+{\
+\    case ${1} in\
+\      */*) func_dirname_result="${1%/*}${2}" ;;\
+\      *  ) func_dirname_result="${3}" ;;\
+\    esac\
+\    func_basename_result="${1##*/}"\
+} # Extended-shell func_dirname_and_basename implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_stripname ()$/,/^} # func_stripname /c\
+func_stripname ()\
+{\
+\    # pdksh 5.2.14 does not do ${X%$Y} correctly if both X and Y are\
+\    # positional parameters, so assign one to ordinary parameter first.\
+\    func_stripname_result=${3}\
+\    func_stripname_result=${func_stripname_result#"${1}"}\
+\    func_stripname_result=${func_stripname_result%"${2}"}\
+} # Extended-shell func_stripname implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_split_long_opt ()$/,/^} # func_split_long_opt /c\
+func_split_long_opt ()\
+{\
+\    func_split_long_opt_name=${1%%=*}\
+\    func_split_long_opt_arg=${1#*=}\
+} # Extended-shell func_split_long_opt implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_split_short_opt ()$/,/^} # func_split_short_opt /c\
+func_split_short_opt ()\
+{\
+\    func_split_short_opt_arg=${1#??}\
+\    func_split_short_opt_name=${1%"$func_split_short_opt_arg"}\
+} # Extended-shell func_split_short_opt implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_lo2o ()$/,/^} # func_lo2o /c\
+func_lo2o ()\
+{\
+\    case ${1} in\
+\      *.lo) func_lo2o_result=${1%.lo}.${objext} ;;\
+\      *)    func_lo2o_result=${1} ;;\
+\    esac\
+} # Extended-shell func_lo2o implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_xform ()$/,/^} # func_xform /c\
+func_xform ()\
+{\
+    func_xform_result=${1%.*}.lo\
+} # Extended-shell func_xform implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_arith ()$/,/^} # func_arith /c\
+func_arith ()\
+{\
+    func_arith_result=$(( $* ))\
+} # Extended-shell func_arith implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_len ()$/,/^} # func_len /c\
+func_len ()\
+{\
+    func_len_result=${#1}\
+} # Extended-shell func_len implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+fi
+
+if test x"$lt_shell_append" = xyes; then
+  sed -e '/^func_append ()$/,/^} # func_append /c\
+func_append ()\
+{\
+    eval "${1}+=\\${2}"\
+} # Extended-shell func_append implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  sed -e '/^func_append_quoted ()$/,/^} # func_append_quoted /c\
+func_append_quoted ()\
+{\
+\    func_quote_for_eval "${2}"\
+\    eval "${1}+=\\\\ \\$func_quote_for_eval_result"\
+} # Extended-shell func_append_quoted implementation' "$cfgfile" > $cfgfile.tmp \
+  && mv -f "$cfgfile.tmp" "$cfgfile" \
+    || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+test 0 -eq $? || _lt_function_replace_fail=:
+
+
+  # Save a `func_append' function call where possible by direct use of '+='
+  sed -e 's%func_append \([a-zA-Z_]\{1,\}\) "%\1+="%g' $cfgfile > $cfgfile.tmp \
+    && mv -f "$cfgfile.tmp" "$cfgfile" \
+      || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+  test 0 -eq $? || _lt_function_replace_fail=:
+else
+  # Save a `func_append' function call even when '+=' is not available
+  sed -e 's%func_append \([a-zA-Z_]\{1,\}\) "%\1="$\1%g' $cfgfile > $cfgfile.tmp \
+    && mv -f "$cfgfile.tmp" "$cfgfile" \
+      || (rm -f "$cfgfile" && cp "$cfgfile.tmp" "$cfgfile" && rm -f "$cfgfile.tmp")
+  test 0 -eq $? || _lt_function_replace_fail=:
+fi
+
+if test x"$_lt_function_replace_fail" = x":"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: Unable to substitute extended shell functions in $ofile" >&5
+$as_echo "$as_me: WARNING: Unable to substitute extended shell functions in $ofile" >&2;}
+fi
+
+
+   mv -f "$cfgfile" "$ofile" ||
     (rm -f "$ofile" && cp "$cfgfile" "$ofile" && rm -f "$cfgfile")
   chmod +x "$ofile"
 
@@ -18453,6 +19354,10 @@
 # The linker used to build libraries.
 LD=$lt_LD_CXX
 
+# How to create reloadable object files.
+reload_flag=$lt_reload_flag_CXX
+reload_cmds=$lt_reload_cmds_CXX
+
 # Commands used to build an old-style archive.
 old_archive_cmds=$lt_old_archive_cmds_CXX
 
@@ -18465,12 +19370,12 @@
 # Compiler flag to turn off builtin functions.
 no_builtin_flag=$lt_lt_prog_compiler_no_builtin_flag_CXX
 
+# Additional compiler flags for building library objects.
+pic_flag=$lt_lt_prog_compiler_pic_CXX
+
 # How to pass a linker flag through the compiler.
 wl=$lt_lt_prog_compiler_wl_CXX
 
-# Additional compiler flags for building library objects.
-pic_flag=$lt_lt_prog_compiler_pic_CXX
-
 # Compiler flag to prevent dynamic linking.
 link_static_flag=$lt_lt_prog_compiler_static_CXX
 
@@ -18520,10 +19425,6 @@
 # This must work even if \$libdir does not exist
 hardcode_libdir_flag_spec=$lt_hardcode_libdir_flag_spec_CXX
 
-# If ld is used when linking, flag to hardcode \$libdir into a binary
-# during linking.  This must work even if \$libdir does not exist.
-hardcode_libdir_flag_spec_ld=$lt_hardcode_libdir_flag_spec_ld_CXX
-
 # Whether we need a single "-rpath" flag with a separated argument.
 hardcode_libdir_separator=$lt_hardcode_libdir_separator_CXX
 
@@ -18557,9 +19458,6 @@
 # Whether libtool must link a program against all its dependency libraries.
 link_all_deplibs=$link_all_deplibs_CXX
 
-# Fix the shell variable \$srcfile for the compiler.
-fix_srcfile_path=$lt_fix_srcfile_path_CXX
-
 # Set to "yes" if exported symbols are required.
 always_export_symbols=$always_export_symbols_CXX
 
@@ -18575,6 +19473,9 @@
 # Commands necessary for linking programs (against libraries) with templates.
 prelink_cmds=$lt_prelink_cmds_CXX
 
+# Commands necessary for finishing linking programs.
+postlink_cmds=$lt_postlink_cmds_CXX
+
 # Specify filename containing input files.
 file_list_spec=$lt_file_list_spec_CXX
 
@@ -18609,7 +19510,7 @@
 ac_clean_files=$ac_clean_files_save
 
 test $ac_write_fail = 0 ||
-  as_fn_error "write failure creating $CONFIG_STATUS" "$LINENO" 5
+  as_fn_error $? "write failure creating $CONFIG_STATUS" "$LINENO" 5
 
 
 # configure is writing to config.log, and then calls config.status.
@@ -18630,7 +19531,7 @@
   exec 5>>config.log
   # Use ||, not &&, to avoid exiting from the if with $? = 1, which
   # would make configure fail if this is the last instruction.
-  $ac_cs_success || as_fn_exit $?
+  $ac_cs_success || as_fn_exit 1
 fi
 if test -n "$ac_unrecognized_opts" && test "$enable_option_checking" != no; then
   { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: unrecognized options: $ac_unrecognized_opts" >&5

=== modified file 'configure.ac'
--- configure.ac	2010-01-17 13:05:04 +0000
+++ configure.ac	2014-01-16 10:42:06 +0000
@@ -2,7 +2,7 @@
 dnl Process this file with autoconf to produce a configure script.
 
 AC_PREREQ(2.50)
-AC_INIT([gloox], [1.0], [js@camaya.net])
+AC_INIT([gloox], [1.0.9], [js@camaya.net])
 AC_CONFIG_SRCDIR(src/gloox.cpp)
 AM_INIT_AUTOMAKE(AC_PACKAGE_NAME, AC_PACKAGE_VERSION)
 
@@ -44,11 +44,34 @@
     LDFLAGS="-L$libpath $LDFLAGS"
 done
 
+dnl Check for GCC atomic builtins
+AC_MSG_CHECKING([whether GCC atomic builtins are available])
+echo 'int main(int argc, char* argv[]) { int i; __sync_add_and_fetch(&i, 1); __sync_sub_and_fetch(&i, 1); return 0; } ' > check_atomicbuiltins.c
+if test -z "`${CC} check_atomicbuiltins.c -o check_atomicbuiltins 2>&1`" ; then
+	HAVE_GCC_ATOMIC_BUILTINS=yes
+	AC_DEFINE(HAVE_GCC_ATOMIC_BUILTINS, 1, [Define to 1 if GCC atomic builtins are available])
+	AC_MSG_RESULT([yes])
+	if test $cross_compiling == "yes"; then
+		# Some platforms don't seem to be fully happy for libraries using GCC atomic builtins
+		#  unless -lgcc and -lgcc_s are explicitly included.
+		# (Errors like
+		# ld: hidden symbol `__sync_add_and_fetch_4' in .../libgcc.a(linux-atomic.o) is referenced by DSO
+		# ld: final link failed: Nonrepresentable section on output)
+		LDFLAGS="$LDFLAGS -lgcc -lgcc_s"
+	fi
+else
+	HAVE_GCC_ATOMIC_BUILTINS=no
+	AC_MSG_RESULT([no])
+fi
+rm -f check_atomicbuiltins*
+AC_SUBST(HAVE_GCC_ATOMIC_BUILTINS,$HAVE_GCC_ATOMIC_BUILTINS)
+
+
 dnl Checks for libraries.
 
 dnl Libidn
 AC_ARG_WITH(libidn, AC_HELP_STRING([--with-libidn=[DIR]],
-      [Support IDN (needs GNU Libidn)]),
+                                   [Support IDN (needs GNU Libidn)]),
       libidn=$withval, libidn=yes)
 if test "$libidn" != "no"; then
   if test "$libidn" != "yes"; then
@@ -102,7 +125,7 @@
 dnl GnuTLS
 if test "$ssl" = "no"; then
   AC_ARG_WITH(gnutls, AC_HELP_STRING([--with-gnutls=[DIR]],
-        [Support Stream Encryption (needs GnuTLS)]),
+                                     [Support Stream Encryption (needs GnuTLS)]),
         gnutls=$withval, gnutls=yes)
   if test "$gnutls" != "no"; then
     if test "$gnutls" != "yes"; then
@@ -111,12 +134,15 @@
     fi
     AC_CHECK_HEADER(gnutls/gnutls.h,
     AC_CHECK_LIB(gnutls, gnutls_check_version,
-            [gnutls=yes LIBS="${LIBS} `pkg-config gnutls --libs`"], gnutls=no),
+            [gnutls=yes LIBS="${LIBS} `pkg-config gnutls --libs` -lgcrypt"], gnutls=no),
             gnutls=no)
   fi
   if test "$gnutls" != "no" ; then
     AC_DEFINE(HAVE_GNUTLS, 1, [Define to 1 if you want TLS support (GnuTLS). Undefine HAVE_OPENSSL.])
     ssl=yes
+    AC_CHECK_LIB(gnutls, gnutls_session_channel_binding,
+            [AC_MSG_RESULT(yes)
+            AC_DEFINE(HAVE_GNUTLS_SESSION_CHANNEL_BINDING, 1, [Define to 1 if you have GnuTLS 2.12.0 or above.] )], [AC_MSG_RESULT(no)])
   else
     AC_MSG_WARN([GnuTLS not found])
   fi
@@ -127,7 +153,7 @@
 dnl OpenSSL
 if test "$ssl" = "no"; then
   AC_ARG_WITH(openssl, AC_HELP_STRING([--with-openssl=[DIR]],
-        [Support Stream Encryption (needs OpenSSL)]),
+                                      [Support Stream Encryption (needs OpenSSL)]),
         openssl=$withval, openssl=yes)
   if test "$openssl" != "no"; then
     if test "$openssl" != "yes"; then
@@ -152,7 +178,7 @@
 
 dnl Zlib
 AC_ARG_WITH(zlib, AC_HELP_STRING([--with-zlib=[DIR]],
-      [Support Stream Compression (needs Zlib)]),
+                                 [Support Stream Compression (needs Zlib)]),
       zlib=$withval, zlib=yes)
 if test "$zlib" != "no"; then
   if test "$zlib" != "yes"; then
@@ -253,7 +279,7 @@
       AC_MSG_CHECKING([for res_query in -lresolv (alternate version)])
       save_libs="$LIBS"
       LIBS="-lresolv $LIBS"
-      AC_LINK_IFELSE([AC_LANG_PROGRAM([[#include <resolv.h>]], [[res_query(0,0)]])],
+      AC_LINK_IFELSE([AC_LANG_PROGRAM([[#include <resolv.h>]], [[res_query(0,0,0,0,0)]])],
                      [AC_MSG_RESULT(yes)
                       AC_DEFINE(HAVE_RES_QUERY)
                       have_res_query=yes],
@@ -277,7 +303,8 @@
 dnl Debug
 debug="no"
 AC_ARG_ENABLE( debug,
-               [  --enable-debug          turn on debugging [default=no]],
+               [AC_HELP_STRING([--enable-debug],
+                               [turn on debugging [default=no]])],
                [debug="yes"] )
 if test "x$debug" = "xyes"; then
       CPPFLAGS="$CPPFLAGS -g3 -fno-inline -DDEBUG"
@@ -288,7 +315,8 @@
 dnl getaddrinfo
 getaddrinfo="no"
 AC_ARG_ENABLE( getaddrinfo,
-               [  --enable-getaddrinfo    use getaddrinfo for dns lookups [default=no]],
+               [AC_HELP_STRING([--enable-getaddrinfo],
+                               [use getaddrinfo for dns lookups [default=no]])],
                [getaddrinfo="yes"] )
 if test "x$getaddrinfo" = "xyes"; then
     AC_CHECK_FUNCS(getaddrinfo,,getaddrinfo="no")
@@ -305,6 +333,25 @@
 AC_C_CONST
 AC_C_INLINE
 
+dnl Want mdns support?
+AC_ARG_ENABLE([mdns],
+              [AC_HELP_STRING([--enable-mdns],
+                              [use mdns [default=no]])],
+              [enable_mdns=yes],
+              [enable_mdns=no])
+if test "$enable_mdns" = yes; then
+  AC_DEFINE([HAVE_MDNS], [], [enable mdns support])
+  AC_CHECK_HEADER(dns_sd.h,
+                  AC_CHECK_LIB(dns_sd, DNSServiceCreateConnection,
+                               [LIBS="${LIBS} -ldns_sd"], enable_mdns=no),
+                  enable_mdns=no)
+else
+  MAYBE_LIB_mdns=
+fi
+AC_SUBST(MAYBE_LIB_mdns)
+AC_MSG_CHECKING([if mDNS support should be built])
+AC_MSG_RESULT($enable_mdns)
+
 dnl build tests?
 want_tests=yes
 AC_ARG_WITH(tests, AC_HELP_STRING([--with-tests],
@@ -353,6 +400,7 @@
 src/tests/amp/Makefile
 src/tests/base64/Makefile
 src/tests/capabilities/Makefile
+src/tests/carbons/Makefile
 src/tests/chatstatefilter/Makefile
 src/tests/client/Makefile
 src/tests/clientbase/Makefile
@@ -369,12 +417,18 @@
 src/tests/featureneg/Makefile
 src/tests/flexofflineoffline/Makefile
 src/tests/flexoffline/Makefile
+src/tests/forward/Makefile
 src/tests/gpgencrypted/Makefile
 src/tests/gpgsigned/Makefile
 src/tests/inbandbytestreamibb/Makefile
 src/tests/inbandbytestream/Makefile
 src/tests/iq/Makefile
 src/tests/jid/Makefile
+src/tests/jinglecontent/Makefile
+src/tests/jingleiceudp/Makefile
+src/tests/jinglesession/Makefile
+src/tests/jinglesessionjingle/Makefile
+src/tests/jinglesessionmanager/Makefile
 src/tests/lastactivityquery/Makefile
 src/tests/lastactivity/Makefile
 src/tests/md5/Makefile

=== modified file 'debian/changelog'
--- debian/changelog	2014-01-16 09:35:12 +0000
+++ debian/changelog	2014-03-16 17:34:43 +0000
@@ -1,3 +1,26 @@
+gloox (1.0.9-3) unstable; urgency=medium
+
+  * Upload to unstable.
+
+ -- Vincent Cheng <vcheng@debian.org>  Sun, 16 Mar 2014 17:34:43 -0700
+
+gloox (1.0.9-2) experimental; urgency=medium
+
+  * Run dh-autoreconf instead of autotools-dev. (Closes: #726278, #735987)
+
+ -- Vincent Cheng <vcheng@debian.org>  Mon, 27 Jan 2014 22:16:13 -0800
+
+gloox (1.0.9-1) experimental; urgency=medium
+
+  * Upload to experimental.
+  * New upstream release. (Closes: #729074)
+    - SRV record lookup enabled. (Closes: #593150)
+    - Refresh patch.
+  * Update debian/copyright (GPLv2+ -> GPLv3+).
+  * Modify package name (libgloox8 -> libgloox11) to reflect SONAME bump.
+
+ -- Vincent Cheng <vcheng@debian.org>  Thu, 16 Jan 2014 10:42:06 -0800
+
 gloox (1.0-3) unstable; urgency=medium
 
   * Run tests, but ignore test failures for now.

=== modified file 'debian/control'
--- debian/control	2014-01-16 09:35:12 +0000
+++ debian/control	2014-01-27 22:16:13 +0000
@@ -3,8 +3,8 @@
 Priority: optional
 Maintainer: Vincent Cheng <vcheng@debian.org>
 Build-Depends:
- autotools-dev,
  debhelper (>= 9),
+ dh-autoreconf,
  doxygen,
  graphviz,
  gsfonts,
@@ -21,7 +21,7 @@
 Architecture: any
 Multi-Arch: same
 Depends:
- libgloox8 (= ${binary:Version}),
+ libgloox11 (= ${binary:Version}),
  libgnutls-dev,
  libidn11-dev,
  ${misc:Depends}
@@ -35,7 +35,7 @@
  .
  This package contains files needed for development with this library.
 
-Package: libgloox8
+Package: libgloox11
 Architecture: any
 Multi-Arch: same
 Pre-Depends: ${misc:Pre-Depends}

=== modified file 'debian/copyright'
--- debian/copyright	2014-01-16 01:11:18 +0000
+++ debian/copyright	2014-01-16 10:42:06 +0000
@@ -4,17 +4,17 @@
 
 Files: *
 Copyright: 2004-2013 Jakob Schröter <js@camaya.net>
-License: GPL-2.0+ with OpenSSL exception
+License: GPL-3.0+ with OpenSSL exception
 
 Files: debian/*
 Copyright: 2005-2010 Jose Carlos Garcia Sogo <jsogo@debian.org>
            2014 Vincent Cheng <vcheng@debian.org>
-License: GPL-2.0+ with OpenSSL exception
+License: GPL-3.0+ with OpenSSL exception
 
-License: GPL-2.0+ with OpenSSL exception
+License: GPL-3.0+ with OpenSSL exception
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 2 of the License, or
+ the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
  .
  In addition, as a special exception, the copyright holders give
@@ -35,4 +35,4 @@
  along with this program. If not, see <http://www.gnu.org/licenses/>.
  .
  On Debian systems, the complete text of the GNU General
- Public License version 2 can be found in "/usr/share/common-licenses/GPL-2".
+ Public License version 3 can be found in "/usr/share/common-licenses/GPL-3".

=== added file 'debian/libgloox11.install'
--- debian/libgloox11.install	1970-01-01 00:00:00 +0000
+++ debian/libgloox11.install	2014-01-16 10:42:06 +0000
@@ -0,0 +1,1 @@
+usr/lib/*/lib*.so.*

=== removed file 'debian/libgloox8.install'
--- debian/libgloox8.install	2014-01-16 01:11:18 +0000
+++ debian/libgloox8.install	1970-01-01 00:00:00 +0000
@@ -1,1 +0,0 @@
-usr/lib/*/lib*.so.*

=== modified file 'debian/patches/10-fix-gcc4.3.patch'
--- debian/patches/10-fix-gcc4.3.patch	2014-01-16 01:11:18 +0000
+++ debian/patches/10-fix-gcc4.3.patch	2014-01-16 10:42:06 +0000
@@ -39,9 +39,9 @@
  class ZlibTest : public CompressionDataHandler
 --- a/src/tlsgnutlsbase.cpp
 +++ b/src/tlsgnutlsbase.cpp
-@@ -20,6 +20,9 @@
- #include <stdlib.h>
+@@ -21,6 +21,9 @@
  #include <string.h>
+ #include <cstdio>
  
 +#include <cstdlib>
 +#include <cstring>

=== modified file 'debian/rules'
--- debian/rules	2014-01-16 09:35:12 +0000
+++ debian/rules	2014-01-27 22:16:13 +0000
@@ -1,7 +1,7 @@
 #!/usr/bin/make -f
 
 %:
-	dh $@ --with autotools_dev
+	dh $@ --with autoreconf
 
 override_dh_clean:
 	rm -rf api

=== modified file 'depcomp'
--- depcomp	2010-01-17 13:05:04 +0000
+++ depcomp	2014-01-16 10:42:06 +0000
@@ -1,10 +1,10 @@
 #! /bin/sh
 # depcomp - compile a program generating dependencies as side-effects
 
-scriptversion=2009-04-28.21; # UTC
+scriptversion=2012-03-27.16; # UTC
 
-# Copyright (C) 1999, 2000, 2003, 2004, 2005, 2006, 2007, 2009 Free
-# Software Foundation, Inc.
+# Copyright (C) 1999, 2000, 2003, 2004, 2005, 2006, 2007, 2009, 2010,
+# 2011, 2012 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 
 case $1 in
   '')
-     echo "$0: No command.  Try \`$0 --help' for more information." 1>&2
+     echo "$0: No command.  Try '$0 --help' for more information." 1>&2
      exit 1;
      ;;
   -h | --h*)
@@ -40,11 +40,11 @@
 
 Environment variables:
   depmode     Dependency tracking mode.
-  source      Source file read by `PROGRAMS ARGS'.
-  object      Object file output by `PROGRAMS ARGS'.
+  source      Source file read by 'PROGRAMS ARGS'.
+  object      Object file output by 'PROGRAMS ARGS'.
   DEPDIR      directory where to store dependencies.
   depfile     Dependency file to output.
-  tmpdepfile  Temporary file to use when outputing dependencies.
+  tmpdepfile  Temporary file to use when outputting dependencies.
   libtool     Whether libtool is used (yes/no).
 
 Report bugs to <bug-automake@gnu.org>.
@@ -57,6 +57,12 @@
     ;;
 esac
 
+# A tabulation character.
+tab='	'
+# A newline character.
+nl='
+'
+
 if test -z "$depmode" || test -z "$source" || test -z "$object"; then
   echo "depcomp: Variables source, object and depmode must be set" 1>&2
   exit 1
@@ -90,10 +96,24 @@
    # This is just like msvisualcpp but w/o cygpath translation.
    # Just convert the backslash-escaped backslashes to single forward
    # slashes to satisfy depend.m4
-   cygpath_u="sed s,\\\\\\\\,/,g"
+   cygpath_u='sed s,\\\\,/,g'
    depmode=msvisualcpp
 fi
 
+if test "$depmode" = msvc7msys; then
+   # This is just like msvc7 but w/o cygpath translation.
+   # Just convert the backslash-escaped backslashes to single forward
+   # slashes to satisfy depend.m4
+   cygpath_u='sed s,\\\\,/,g'
+   depmode=msvc7
+fi
+
+if test "$depmode" = xlc; then
+   # IBM C/C++ Compilers xlc/xlC can output gcc-like dependency informations.
+   gccflag=-qmakedep=gcc,-MF
+   depmode=gcc
+fi
+
 case "$depmode" in
 gcc3)
 ## gcc 3 implements dependency tracking that does exactly what
@@ -148,20 +168,21 @@
 ## The second -e expression handles DOS-style file names with drive letters.
   sed -e 's/^[^:]*: / /' \
       -e 's/^['$alpha']:\/[^:]*: / /' < "$tmpdepfile" >> "$depfile"
-## This next piece of magic avoids the `deleted header file' problem.
+## This next piece of magic avoids the "deleted header file" problem.
 ## The problem is that when a header file which appears in a .P file
 ## is deleted, the dependency causes make to die (because there is
 ## typically no way to rebuild the header).  We avoid this by adding
 ## dummy dependencies for each header file.  Too bad gcc doesn't do
 ## this for us directly.
-  tr ' ' '
-' < "$tmpdepfile" |
-## Some versions of gcc put a space before the `:'.  On the theory
+  tr ' ' "$nl" < "$tmpdepfile" |
+## Some versions of gcc put a space before the ':'.  On the theory
 ## that the space means something, we add a space to the output as
-## well.
+## well.  hp depmode also adds that space, but also prefixes the VPATH
+## to the object.  Take care to not repeat it in the output.
 ## Some versions of the HPUX 10.20 sed can't process this invocation
 ## correctly.  Breaking it into two sed invocations is a workaround.
-    sed -e 's/^\\$//' -e '/^$/d' -e '/:$/d' | sed -e 's/$/ :/' >> "$depfile"
+    sed -e 's/^\\$//' -e '/^$/d' -e "s|.*$object$||" -e '/:$/d' \
+      | sed -e 's/$/ :/' >> "$depfile"
   rm -f "$tmpdepfile"
   ;;
 
@@ -193,18 +214,15 @@
     # clever and replace this with sed code, as IRIX sed won't handle
     # lines with more than a fixed number of characters (4096 in
     # IRIX 6.2 sed, 8192 in IRIX 6.5).  We also remove comment lines;
-    # the IRIX cc adds comments like `#:fec' to the end of the
+    # the IRIX cc adds comments like '#:fec' to the end of the
     # dependency line.
-    tr ' ' '
-' < "$tmpdepfile" \
+    tr ' ' "$nl" < "$tmpdepfile" \
     | sed -e 's/^.*\.o://' -e 's/#.*$//' -e '/^$/ d' | \
-    tr '
-' ' ' >> "$depfile"
+    tr "$nl" ' ' >> "$depfile"
     echo >> "$depfile"
 
     # The second pass generates a dummy entry for each header file.
-    tr ' ' '
-' < "$tmpdepfile" \
+    tr ' ' "$nl" < "$tmpdepfile" \
    | sed -e 's/^.*\.o://' -e 's/#.*$//' -e '/^$/ d' -e 's/$/:/' \
    >> "$depfile"
   else
@@ -216,10 +234,17 @@
   rm -f "$tmpdepfile"
   ;;
 
+xlc)
+  # This case exists only to let depend.m4 do its work.  It works by
+  # looking at the text of this script.  This case will never be run,
+  # since it is checked for above.
+  exit 1
+  ;;
+
 aix)
   # The C for AIX Compiler uses -M and outputs the dependencies
   # in a .u file.  In older versions, this file always lives in the
-  # current directory.  Also, the AIX compiler puts `$object:' at the
+  # current directory.  Also, the AIX compiler puts '$object:' at the
   # start of each line; $object doesn't have directory information.
   # Version 6 uses the directory in both cases.
   dir=`echo "$object" | sed -e 's|/[^/]*$|/|'`
@@ -249,12 +274,11 @@
     test -f "$tmpdepfile" && break
   done
   if test -f "$tmpdepfile"; then
-    # Each line is of the form `foo.o: dependent.h'.
+    # Each line is of the form 'foo.o: dependent.h'.
     # Do two passes, one to just change these to
-    # `$object: dependent.h' and one to simply `dependent.h:'.
+    # '$object: dependent.h' and one to simply 'dependent.h:'.
     sed -e "s,^.*\.[a-z]*:,$object:," < "$tmpdepfile" > "$depfile"
-    # That's a tab and a space in the [].
-    sed -e 's,^.*\.[a-z]*:[	 ]*,,' -e 's,$,:,' < "$tmpdepfile" >> "$depfile"
+    sed -e 's,^.*\.[a-z]*:['"$tab"' ]*,,' -e 's,$,:,' < "$tmpdepfile" >> "$depfile"
   else
     # The sourcefile does not contain any dependencies, so just
     # store a dummy comment line, to avoid errors with the Makefile
@@ -265,23 +289,26 @@
   ;;
 
 icc)
-  # Intel's C compiler understands `-MD -MF file'.  However on
-  #    icc -MD -MF foo.d -c -o sub/foo.o sub/foo.c
+  # Intel's C compiler anf tcc (Tiny C Compiler) understand '-MD -MF file'.
+  # However on
+  #    $CC -MD -MF foo.d -c -o sub/foo.o sub/foo.c
   # ICC 7.0 will fill foo.d with something like
   #    foo.o: sub/foo.c
   #    foo.o: sub/foo.h
-  # which is wrong.  We want:
+  # which is wrong.  We want
   #    sub/foo.o: sub/foo.c
   #    sub/foo.o: sub/foo.h
   #    sub/foo.c:
   #    sub/foo.h:
   # ICC 7.1 will output
   #    foo.o: sub/foo.c sub/foo.h
-  # and will wrap long lines using \ :
+  # and will wrap long lines using '\':
   #    foo.o: sub/foo.c ... \
   #     sub/foo.h ... \
   #     ...
-
+  # tcc 0.9.26 (FIXME still under development at the moment of writing)
+  # will emit a similar output, but also prepend the continuation lines
+  # with horizontal tabulation characters.
   "$@" -MD -MF "$tmpdepfile"
   stat=$?
   if test $stat -eq 0; then :
@@ -290,15 +317,21 @@
     exit $stat
   fi
   rm -f "$depfile"
-  # Each line is of the form `foo.o: dependent.h',
-  # or `foo.o: dep1.h dep2.h \', or ` dep3.h dep4.h \'.
+  # Each line is of the form 'foo.o: dependent.h',
+  # or 'foo.o: dep1.h dep2.h \', or ' dep3.h dep4.h \'.
   # Do two passes, one to just change these to
-  # `$object: dependent.h' and one to simply `dependent.h:'.
-  sed "s,^[^:]*:,$object :," < "$tmpdepfile" > "$depfile"
-  # Some versions of the HPUX 10.20 sed can't process this invocation
-  # correctly.  Breaking it into two sed invocations is a workaround.
-  sed 's,^[^:]*: \(.*\)$,\1,;s/^\\$//;/^$/d;/:$/d' < "$tmpdepfile" |
-    sed -e 's/$/ :/' >> "$depfile"
+  # '$object: dependent.h' and one to simply 'dependent.h:'.
+  sed -e "s/^[ $tab][ $tab]*/  /" -e "s,^[^:]*:,$object :," \
+    < "$tmpdepfile" > "$depfile"
+  sed '
+    s/[ '"$tab"'][ '"$tab"']*/ /g
+    s/^ *//
+    s/ *\\*$//
+    s/^[^:]*: *//
+    /^$/d
+    /:$/d
+    s/$/ :/
+  ' < "$tmpdepfile" >> "$depfile"
   rm -f "$tmpdepfile"
   ;;
 
@@ -334,7 +367,7 @@
   done
   if test -f "$tmpdepfile"; then
     sed -e "s,^.*\.[a-z]*:,$object:," "$tmpdepfile" > "$depfile"
-    # Add `dependent.h:' lines.
+    # Add 'dependent.h:' lines.
     sed -ne '2,${
 	       s/^ *//
 	       s/ \\*$//
@@ -349,9 +382,9 @@
 
 tru64)
    # The Tru64 compiler uses -MD to generate dependencies as a side
-   # effect.  `cc -MD -o foo.o ...' puts the dependencies into `foo.o.d'.
+   # effect.  'cc -MD -o foo.o ...' puts the dependencies into 'foo.o.d'.
    # At least on Alpha/Redhat 6.1, Compaq CCC V6.2-504 seems to put
-   # dependencies in `foo.d' instead, so we check for that too.
+   # dependencies in 'foo.d' instead, so we check for that too.
    # Subdirectories are respected.
    dir=`echo "$object" | sed -e 's|/[^/]*$|/|'`
    test "x$dir" = "x$object" && dir=
@@ -397,14 +430,59 @@
    done
    if test -f "$tmpdepfile"; then
       sed -e "s,^.*\.[a-z]*:,$object:," < "$tmpdepfile" > "$depfile"
-      # That's a tab and a space in the [].
-      sed -e 's,^.*\.[a-z]*:[	 ]*,,' -e 's,$,:,' < "$tmpdepfile" >> "$depfile"
+      sed -e 's,^.*\.[a-z]*:['"$tab"' ]*,,' -e 's,$,:,' < "$tmpdepfile" >> "$depfile"
    else
       echo "#dummy" > "$depfile"
    fi
    rm -f "$tmpdepfile"
    ;;
 
+msvc7)
+  if test "$libtool" = yes; then
+    showIncludes=-Wc,-showIncludes
+  else
+    showIncludes=-showIncludes
+  fi
+  "$@" $showIncludes > "$tmpdepfile"
+  stat=$?
+  grep -v '^Note: including file: ' "$tmpdepfile"
+  if test "$stat" = 0; then :
+  else
+    rm -f "$tmpdepfile"
+    exit $stat
+  fi
+  rm -f "$depfile"
+  echo "$object : \\" > "$depfile"
+  # The first sed program below extracts the file names and escapes
+  # backslashes for cygpath.  The second sed program outputs the file
+  # name when reading, but also accumulates all include files in the
+  # hold buffer in order to output them again at the end.  This only
+  # works with sed implementations that can handle large buffers.
+  sed < "$tmpdepfile" -n '
+/^Note: including file:  *\(.*\)/ {
+  s//\1/
+  s/\\/\\\\/g
+  p
+}' | $cygpath_u | sort -u | sed -n '
+s/ /\\ /g
+s/\(.*\)/'"$tab"'\1 \\/p
+s/.\(.*\) \\/\1:/
+H
+$ {
+  s/.*/'"$tab"'/
+  G
+  p
+}' >> "$depfile"
+  rm -f "$tmpdepfile"
+  ;;
+
+msvc7msys)
+  # This case exists only to let depend.m4 do its work.  It works by
+  # looking at the text of this script.  This case will never be run,
+  # since it is checked for above.
+  exit 1
+  ;;
+
 #nosideeffect)
   # This comment above is used by automake to tell side-effect
   # dependency tracking mechanisms from slower ones.
@@ -422,7 +500,7 @@
     shift
   fi
 
-  # Remove `-o $object'.
+  # Remove '-o $object'.
   IFS=" "
   for arg
   do
@@ -442,15 +520,14 @@
   done
 
   test -z "$dashmflag" && dashmflag=-M
-  # Require at least two characters before searching for `:'
+  # Require at least two characters before searching for ':'
   # in the target name.  This is to cope with DOS-style filenames:
-  # a dependency such as `c:/foo/bar' could be seen as target `c' otherwise.
+  # a dependency such as 'c:/foo/bar' could be seen as target 'c' otherwise.
   "$@" $dashmflag |
-    sed 's:^[  ]*[^: ][^:][^:]*\:[    ]*:'"$object"'\: :' > "$tmpdepfile"
+    sed 's:^['"$tab"' ]*[^:'"$tab"' ][^:][^:]*\:['"$tab"' ]*:'"$object"'\: :' > "$tmpdepfile"
   rm -f "$depfile"
   cat < "$tmpdepfile" > "$depfile"
-  tr ' ' '
-' < "$tmpdepfile" | \
+  tr ' ' "$nl" < "$tmpdepfile" | \
 ## Some versions of the HPUX 10.20 sed can't process this invocation
 ## correctly.  Breaking it into two sed invocations is a workaround.
     sed -e 's/^\\$//' -e '/^$/d' -e '/:$/d' | sed -e 's/$/ :/' >> "$depfile"
@@ -503,9 +580,10 @@
   touch "$tmpdepfile"
   ${MAKEDEPEND-makedepend} -o"$obj_suffix" -f"$tmpdepfile" "$@"
   rm -f "$depfile"
-  cat < "$tmpdepfile" > "$depfile"
-  sed '1,2d' "$tmpdepfile" | tr ' ' '
-' | \
+  # makedepend may prepend the VPATH from the source file name to the object.
+  # No need to regex-escape $object, excess matching of '.' is harmless.
+  sed "s|^.*\($object *:\)|\1|" "$tmpdepfile" > "$depfile"
+  sed '1,2d' "$tmpdepfile" | tr ' ' "$nl" | \
 ## Some versions of the HPUX 10.20 sed can't process this invocation
 ## correctly.  Breaking it into two sed invocations is a workaround.
     sed -e 's/^\\$//' -e '/^$/d' -e '/:$/d' | sed -e 's/$/ :/' >> "$depfile"
@@ -525,7 +603,7 @@
     shift
   fi
 
-  # Remove `-o $object'.
+  # Remove '-o $object'.
   IFS=" "
   for arg
   do
@@ -594,8 +672,8 @@
   sed -n '/^#line [0-9][0-9]* "\([^"]*\)"/ s::\1:p' | $cygpath_u | sort -u > "$tmpdepfile"
   rm -f "$depfile"
   echo "$object : \\" > "$depfile"
-  sed < "$tmpdepfile" -n -e 's% %\\ %g' -e '/^\(.*\)$/ s::	\1 \\:p' >> "$depfile"
-  echo "	" >> "$depfile"
+  sed < "$tmpdepfile" -n -e 's% %\\ %g' -e '/^\(.*\)$/ s::'"$tab"'\1 \\:p' >> "$depfile"
+  echo "$tab" >> "$depfile"
   sed < "$tmpdepfile" -n -e 's% %\\ %g' -e '/^\(.*\)$/ s::\1\::p' >> "$depfile"
   rm -f "$tmpdepfile"
   ;;

=== modified file 'gloox.cbp'
--- gloox.cbp	2010-01-17 13:05:04 +0000
+++ gloox.cbp	2014-01-16 10:42:06 +0000
@@ -23,8 +23,6 @@
 		</Compiler>
 		<Linker>
 			<Add option="-s" />
-			<Add option="--no-export-all-symbols" />
-			<Add option="--add-stdcall-alias" />
 			<Add library="wsock32" />
 			<Add library="dnsapi" />
 			<Add library="gdi32" />
@@ -32,248 +30,269 @@
 			<Add library="secur32" />
 		</Linker>
 		<Unit filename="config.h.win" />
-		<Unit filename="src\adhoc.cpp" />
-		<Unit filename="src\adhoc.h" />
-		<Unit filename="src\adhoccommandprovider.h" />
-		<Unit filename="src\adhochandler.h" />
-		<Unit filename="src\amp.cpp" />
-		<Unit filename="src\amp.h" />
-		<Unit filename="src\annotations.cpp" />
-		<Unit filename="src\annotations.h" />
-		<Unit filename="src\annotationshandler.h" />
-		<Unit filename="src\attention.cpp" />
-		<Unit filename="src\attention.h" />
-		<Unit filename="src\base64.cpp" />
-		<Unit filename="src\base64.h" />
-		<Unit filename="src\bookmarkhandler.h" />
-		<Unit filename="src\bookmarkstorage.cpp" />
-		<Unit filename="src\bookmarkstorage.h" />
-		<Unit filename="src\bytestream.h" />
-		<Unit filename="src\bytestreamdatahandler.h" />
-		<Unit filename="src\bytestreamhandler.h" />
-		<Unit filename="src\capabilities.cpp" />
-		<Unit filename="src\capabilities.h" />
-		<Unit filename="src\chatstate.cpp" />
-		<Unit filename="src\chatstate.h" />
-		<Unit filename="src\chatstatefilter.cpp" />
-		<Unit filename="src\chatstatefilter.h" />
-		<Unit filename="src\chatstatehandler.h" />
-		<Unit filename="src\client.cpp" />
-		<Unit filename="src\client.h" />
-		<Unit filename="src\clientbase.cpp" />
-		<Unit filename="src\clientbase.h" />
-		<Unit filename="src\component.cpp" />
-		<Unit filename="src\component.h" />
-		<Unit filename="src\compressionbase.h" />
-		<Unit filename="src\compressiondatahandler.h" />
-		<Unit filename="src\compressionzlib.cpp" />
-		<Unit filename="src\compressionzlib.h" />
-		<Unit filename="src\connectionbase.h" />
-		<Unit filename="src\connectionbosh.cpp" />
-		<Unit filename="src\connectionbosh.h" />
-		<Unit filename="src\connectiondatahandler.h" />
-		<Unit filename="src\connectionhandler.h" />
-		<Unit filename="src\connectionhttpproxy.cpp" />
-		<Unit filename="src\connectionhttpproxy.h" />
-		<Unit filename="src\connectionlistener.h" />
-		<Unit filename="src\connectionsocks5proxy.cpp" />
-		<Unit filename="src\connectionsocks5proxy.h" />
-		<Unit filename="src\connectiontcpbase.cpp" />
-		<Unit filename="src\connectiontcpbase.h" />
-		<Unit filename="src\connectiontcpclient.cpp" />
-		<Unit filename="src\connectiontcpclient.h" />
-		<Unit filename="src\connectiontcpserver.cpp" />
-		<Unit filename="src\connectiontcpserver.h" />
-		<Unit filename="src\connectiontls.cpp" />
-		<Unit filename="src\connectiontls.h" />
-		<Unit filename="src\dataform.cpp" />
-		<Unit filename="src\dataform.h" />
-		<Unit filename="src\dataformfield.cpp" />
-		<Unit filename="src\dataformfield.h" />
-		<Unit filename="src\dataformfieldcontainer.cpp" />
-		<Unit filename="src\dataformfieldcontainer.h" />
-		<Unit filename="src\dataformitem.cpp" />
-		<Unit filename="src\dataformitem.h" />
-		<Unit filename="src\dataformreported.cpp" />
-		<Unit filename="src\dataformreported.h" />
-		<Unit filename="src\delayeddelivery.cpp" />
-		<Unit filename="src\delayeddelivery.h" />
-		<Unit filename="src\disco.cpp" />
-		<Unit filename="src\disco.h" />
-		<Unit filename="src\discohandler.h" />
-		<Unit filename="src\disconodehandler.h" />
-		<Unit filename="src\dns.cpp" />
-		<Unit filename="src\dns.h" />
-		<Unit filename="src\error.cpp" />
-		<Unit filename="src\error.h" />
-		<Unit filename="src\event.h" />
-		<Unit filename="src\eventdispatcher.cpp" />
-		<Unit filename="src\eventdispatcher.h" />
-		<Unit filename="src\eventhandler.h" />
-		<Unit filename="src\featureneg.cpp" />
-		<Unit filename="src\featureneg.h" />
-		<Unit filename="src\flexoff.cpp" />
-		<Unit filename="src\flexoff.h" />
-		<Unit filename="src\flexoffhandler.h" />
-		<Unit filename="src\gloox.cpp" />
-		<Unit filename="src\gloox.h" />
-		<Unit filename="src\gpgencrypted.cpp" />
-		<Unit filename="src\gpgencrypted.h" />
-		<Unit filename="src\gpgsigned.cpp" />
-		<Unit filename="src\gpgsigned.h" />
-		<Unit filename="src\inbandbytestream.cpp" />
-		<Unit filename="src\inbandbytestream.h" />
-		<Unit filename="src\instantmucroom.cpp" />
-		<Unit filename="src\instantmucroom.h" />
-		<Unit filename="src\iq.cpp" />
-		<Unit filename="src\iq.h" />
-		<Unit filename="src\iqhandler.h" />
-		<Unit filename="src\jid.cpp" />
-		<Unit filename="src\jid.h" />
-		<Unit filename="src\lastactivity.cpp" />
-		<Unit filename="src\lastactivity.h" />
-		<Unit filename="src\lastactivityhandler.h" />
-		<Unit filename="src\loghandler.h" />
-		<Unit filename="src\logsink.cpp" />
-		<Unit filename="src\logsink.h" />
-		<Unit filename="src\macros.h" />
-		<Unit filename="src\md5.cpp" />
-		<Unit filename="src\md5.h" />
-		<Unit filename="src\message.cpp" />
-		<Unit filename="src\message.h" />
-		<Unit filename="src\messageevent.cpp" />
-		<Unit filename="src\messageevent.h" />
-		<Unit filename="src\messageeventfilter.cpp" />
-		<Unit filename="src\messageeventfilter.h" />
-		<Unit filename="src\messageeventhandler.h" />
-		<Unit filename="src\messagefilter.cpp" />
-		<Unit filename="src\messagefilter.h" />
-		<Unit filename="src\messagehandler.h" />
-		<Unit filename="src\messagesession.cpp" />
-		<Unit filename="src\messagesession.h" />
-		<Unit filename="src\messagesessionhandler.h" />
-		<Unit filename="src\mucinvitationhandler.h" />
-		<Unit filename="src\mucmessagesession.cpp" />
-		<Unit filename="src\mucmessagesession.h" />
-		<Unit filename="src\mucroom.cpp" />
-		<Unit filename="src\mucroom.h" />
-		<Unit filename="src\mucroomconfighandler.h" />
-		<Unit filename="src\mucroomhandler.h" />
-		<Unit filename="src\mutex.cpp" />
-		<Unit filename="src\mutex.h" />
-		<Unit filename="src\mutexguard.h" />
-		<Unit filename="src\nickname.cpp" />
-		<Unit filename="src\nickname.h" />
-		<Unit filename="src\nonsaslauth.cpp" />
-		<Unit filename="src\nonsaslauth.h" />
-		<Unit filename="src\oob.cpp" />
-		<Unit filename="src\oob.h" />
-		<Unit filename="src\parser.cpp" />
-		<Unit filename="src\parser.h" />
-		<Unit filename="src\prep.cpp" />
-		<Unit filename="src\prep.h" />
-		<Unit filename="src\presence.cpp" />
-		<Unit filename="src\presence.h" />
-		<Unit filename="src\presencehandler.h" />
-		<Unit filename="src\privacyitem.cpp" />
-		<Unit filename="src\privacyitem.h" />
-		<Unit filename="src\privacylisthandler.h" />
-		<Unit filename="src\privacymanager.cpp" />
-		<Unit filename="src\privacymanager.h" />
-		<Unit filename="src\privatexml.cpp" />
-		<Unit filename="src\privatexml.h" />
-		<Unit filename="src\privatexmlhandler.h" />
-		<Unit filename="src\pubsub.h" />
-		<Unit filename="src\pubsubevent.cpp" />
-		<Unit filename="src\pubsubevent.h" />
-		<Unit filename="src\pubsubeventhandler.h" />
-		<Unit filename="src\pubsubitem.cpp" />
-		<Unit filename="src\pubsubitem.h" />
-		<Unit filename="src\pubsubmanager.cpp" />
-		<Unit filename="src\pubsubmanager.h" />
-		<Unit filename="src\pubsubresulthandler.h" />
-		<Unit filename="src\receipt.cpp" />
-		<Unit filename="src\receipt.h" />
-		<Unit filename="src\registration.cpp" />
-		<Unit filename="src\registration.h" />
-		<Unit filename="src\registrationhandler.h" />
-		<Unit filename="src\resource.h" />
-		<Unit filename="src\rosteritem.cpp" />
-		<Unit filename="src\rosteritem.h" />
-		<Unit filename="src\rosteritemdata.h" />
-		<Unit filename="src\rosterlistener.h" />
-		<Unit filename="src\rostermanager.cpp" />
-		<Unit filename="src\rostermanager.h" />
-		<Unit filename="src\search.cpp" />
-		<Unit filename="src\search.h" />
-		<Unit filename="src\searchhandler.h" />
-		<Unit filename="src\sha.cpp" />
-		<Unit filename="src\sha.h" />
-		<Unit filename="src\shim.cpp" />
-		<Unit filename="src\shim.h" />
-		<Unit filename="src\sihandler.h" />
-		<Unit filename="src\simanager.cpp" />
-		<Unit filename="src\simanager.h" />
-		<Unit filename="src\siprofileft.cpp" />
-		<Unit filename="src\siprofileft.h" />
-		<Unit filename="src\siprofilefthandler.h" />
-		<Unit filename="src\siprofilehandler.h" />
-		<Unit filename="src\socks5bytestream.cpp" />
-		<Unit filename="src\socks5bytestream.h" />
-		<Unit filename="src\socks5bytestreammanager.cpp" />
-		<Unit filename="src\socks5bytestreammanager.h" />
-		<Unit filename="src\socks5bytestreamserver.cpp" />
-		<Unit filename="src\socks5bytestreamserver.h" />
-		<Unit filename="src\softwareversion.cpp" />
-		<Unit filename="src\softwareversion.h" />
-		<Unit filename="src\stanza.cpp" />
-		<Unit filename="src\stanza.h" />
-		<Unit filename="src\stanzaextension.h" />
-		<Unit filename="src\stanzaextensionfactory.cpp" />
-		<Unit filename="src\stanzaextensionfactory.h" />
-		<Unit filename="src\statisticshandler.h" />
-		<Unit filename="src\subscription.cpp" />
-		<Unit filename="src\subscription.h" />
-		<Unit filename="src\subscriptionhandler.h" />
-		<Unit filename="src\tag.cpp" />
-		<Unit filename="src\tag.h" />
-		<Unit filename="src\taghandler.h" />
-		<Unit filename="src\tlsbase.h" />
-		<Unit filename="src\tlsdefault.cpp" />
-		<Unit filename="src\tlsdefault.h" />
-		<Unit filename="src\tlsgnutlsbase.cpp" />
-		<Unit filename="src\tlsgnutlsbase.h" />
-		<Unit filename="src\tlsgnutlsclient.cpp" />
-		<Unit filename="src\tlsgnutlsclient.h" />
-		<Unit filename="src\tlsgnutlsclientanon.cpp" />
-		<Unit filename="src\tlsgnutlsclientanon.h" />
-		<Unit filename="src\tlsgnutlsserveranon.cpp" />
-		<Unit filename="src\tlsgnutlsserveranon.h" />
-		<Unit filename="src\tlshandler.h" />
-		<Unit filename="src\tlsopensslbase.cpp" />
-		<Unit filename="src\tlsopensslbase.h" />
-		<Unit filename="src\tlsopensslclient.cpp" />
-		<Unit filename="src\tlsopensslclient.h" />
-		<Unit filename="src\tlsopensslserver.cpp" />
-		<Unit filename="src\tlsopensslserver.h" />
-		<Unit filename="src\tlsschannel.cpp" />
-		<Unit filename="src\tlsschannel.h" />
-		<Unit filename="src\uniquemucroom.cpp" />
-		<Unit filename="src\uniquemucroom.h" />
-		<Unit filename="src\util.cpp" />
-		<Unit filename="src\util.h" />
-		<Unit filename="src\vcard.cpp" />
-		<Unit filename="src\vcard.h" />
-		<Unit filename="src\vcardhandler.h" />
-		<Unit filename="src\vcardmanager.cpp" />
-		<Unit filename="src\vcardmanager.h" />
-		<Unit filename="src\vcardupdate.cpp" />
-		<Unit filename="src\vcardupdate.h" />
-		<Unit filename="src\version.rc">
+		<Unit filename="src/adhoc.cpp" />
+		<Unit filename="src/adhoc.h" />
+		<Unit filename="src/adhoccommandprovider.h" />
+		<Unit filename="src/adhochandler.h" />
+		<Unit filename="src/amp.cpp" />
+		<Unit filename="src/amp.h" />
+		<Unit filename="src/annotations.cpp" />
+		<Unit filename="src/annotations.h" />
+		<Unit filename="src/annotationshandler.h" />
+		<Unit filename="src/atomicrefcount.cpp" />
+		<Unit filename="src/atomicrefcount.h" />
+		<Unit filename="src/attention.cpp" />
+		<Unit filename="src/attention.h" />
+		<Unit filename="src/base64.cpp" />
+		<Unit filename="src/base64.h" />
+		<Unit filename="src/bookmarkhandler.h" />
+		<Unit filename="src/bookmarkstorage.cpp" />
+		<Unit filename="src/bookmarkstorage.h" />
+		<Unit filename="src/bytestream.h" />
+		<Unit filename="src/bytestreamdatahandler.h" />
+		<Unit filename="src/bytestreamhandler.h" />
+		<Unit filename="src/capabilities.cpp" />
+		<Unit filename="src/capabilities.h" />
+		<Unit filename="src/carbons.cpp" />
+		<Unit filename="src/carbons.h" />
+		<Unit filename="src/chatstate.cpp" />
+		<Unit filename="src/chatstate.h" />
+		<Unit filename="src/chatstatefilter.cpp" />
+		<Unit filename="src/chatstatefilter.h" />
+		<Unit filename="src/chatstatehandler.h" />
+		<Unit filename="src/client.cpp" />
+		<Unit filename="src/client.h" />
+		<Unit filename="src/clientbase.cpp" />
+		<Unit filename="src/clientbase.h" />
+		<Unit filename="src/component.cpp" />
+		<Unit filename="src/component.h" />
+		<Unit filename="src/compressionbase.h" />
+		<Unit filename="src/compressiondatahandler.h" />
+		<Unit filename="src/compressionzlib.cpp" />
+		<Unit filename="src/compressionzlib.h" />
+		<Unit filename="src/connectionbase.h" />
+		<Unit filename="src/connectionbosh.cpp" />
+		<Unit filename="src/connectionbosh.h" />
+		<Unit filename="src/connectiondatahandler.h" />
+		<Unit filename="src/connectionhandler.h" />
+		<Unit filename="src/connectionhttpproxy.cpp" />
+		<Unit filename="src/connectionhttpproxy.h" />
+		<Unit filename="src/connectionlistener.h" />
+		<Unit filename="src/connectionsocks5proxy.cpp" />
+		<Unit filename="src/connectionsocks5proxy.h" />
+		<Unit filename="src/connectiontcpbase.cpp" />
+		<Unit filename="src/connectiontcpbase.h" />
+		<Unit filename="src/connectiontcpclient.cpp" />
+		<Unit filename="src/connectiontcpclient.h" />
+		<Unit filename="src/connectiontcpserver.cpp" />
+		<Unit filename="src/connectiontcpserver.h" />
+		<Unit filename="src/connectiontls.cpp" />
+		<Unit filename="src/connectiontls.h" />
+		<Unit filename="src/dataform.cpp" />
+		<Unit filename="src/dataform.h" />
+		<Unit filename="src/dataformfield.cpp" />
+		<Unit filename="src/dataformfield.h" />
+		<Unit filename="src/dataformfieldcontainer.cpp" />
+		<Unit filename="src/dataformfieldcontainer.h" />
+		<Unit filename="src/dataformitem.cpp" />
+		<Unit filename="src/dataformitem.h" />
+		<Unit filename="src/dataformreported.cpp" />
+		<Unit filename="src/dataformreported.h" />
+		<Unit filename="src/delayeddelivery.cpp" />
+		<Unit filename="src/delayeddelivery.h" />
+		<Unit filename="src/disco.cpp" />
+		<Unit filename="src/disco.h" />
+		<Unit filename="src/discohandler.h" />
+		<Unit filename="src/disconodehandler.h" />
+		<Unit filename="src/dns.cpp" />
+		<Unit filename="src/dns.h" />
+		<Unit filename="src/error.cpp" />
+		<Unit filename="src/error.h" />
+		<Unit filename="src/event.h" />
+		<Unit filename="src/eventdispatcher.cpp" />
+		<Unit filename="src/eventdispatcher.h" />
+		<Unit filename="src/eventhandler.h" />
+		<Unit filename="src/featureneg.cpp" />
+		<Unit filename="src/featureneg.h" />
+		<Unit filename="src/flexoff.cpp" />
+		<Unit filename="src/flexoff.h" />
+		<Unit filename="src/flexoffhandler.h" />
+		<Unit filename="src/forward.cpp" />
+		<Unit filename="src/forward.h" />
+		<Unit filename="src/gloox.cpp" />
+		<Unit filename="src/gloox.h" />
+		<Unit filename="src/gpgencrypted.cpp" />
+		<Unit filename="src/gpgencrypted.h" />
+		<Unit filename="src/gpgsigned.cpp" />
+		<Unit filename="src/gpgsigned.h" />
+		<Unit filename="src/inbandbytestream.cpp" />
+		<Unit filename="src/inbandbytestream.h" />
+		<Unit filename="src/instantmucroom.cpp" />
+		<Unit filename="src/instantmucroom.h" />
+		<Unit filename="src/iq.cpp" />
+		<Unit filename="src/iq.h" />
+		<Unit filename="src/iqhandler.h" />
+		<Unit filename="src/jid.cpp" />
+		<Unit filename="src/jid.h" />
+		<Unit filename="src/jinglecontent.cpp" />
+		<Unit filename="src/jinglecontent.h" />
+		<Unit filename="src/jinglefiletransfer.cpp" />
+		<Unit filename="src/jinglefiletransfer.h" />
+		<Unit filename="src/jingleiceudp.cpp" />
+		<Unit filename="src/jingleiceudp.h" />
+		<Unit filename="src/jingleplugin.h" />
+		<Unit filename="src/jinglepluginfactory.cpp" />
+		<Unit filename="src/jinglepluginfactory.h" />
+		<Unit filename="src/jinglesession.cpp" />
+		<Unit filename="src/jinglesession.h" />
+		<Unit filename="src/jinglesessionhandler.h" />
+		<Unit filename="src/jinglesessionmanager.cpp" />
+		<Unit filename="src/jinglesessionmanager.h" />
+		<Unit filename="src/jinglesessiontransport.h" />
+		<Unit filename="src/lastactivity.cpp" />
+		<Unit filename="src/lastactivity.h" />
+		<Unit filename="src/lastactivityhandler.h" />
+		<Unit filename="src/loghandler.h" />
+		<Unit filename="src/logsink.cpp" />
+		<Unit filename="src/logsink.h" />
+		<Unit filename="src/macros.h" />
+		<Unit filename="src/md5.cpp" />
+		<Unit filename="src/md5.h" />
+		<Unit filename="src/message.cpp" />
+		<Unit filename="src/message.h" />
+		<Unit filename="src/messageevent.cpp" />
+		<Unit filename="src/messageevent.h" />
+		<Unit filename="src/messageeventfilter.cpp" />
+		<Unit filename="src/messageeventfilter.h" />
+		<Unit filename="src/messageeventhandler.h" />
+		<Unit filename="src/messagefilter.cpp" />
+		<Unit filename="src/messagefilter.h" />
+		<Unit filename="src/messagehandler.h" />
+		<Unit filename="src/messagesession.cpp" />
+		<Unit filename="src/messagesession.h" />
+		<Unit filename="src/messagesessionhandler.h" />
+		<Unit filename="src/mucinvitationhandler.h" />
+		<Unit filename="src/mucmessagesession.cpp" />
+		<Unit filename="src/mucmessagesession.h" />
+		<Unit filename="src/mucroom.cpp" />
+		<Unit filename="src/mucroom.h" />
+		<Unit filename="src/mucroomconfighandler.h" />
+		<Unit filename="src/mucroomhandler.h" />
+		<Unit filename="src/mutex.cpp" />
+		<Unit filename="src/mutex.h" />
+		<Unit filename="src/mutexguard.h" />
+		<Unit filename="src/nickname.cpp" />
+		<Unit filename="src/nickname.h" />
+		<Unit filename="src/nonsaslauth.cpp" />
+		<Unit filename="src/nonsaslauth.h" />
+		<Unit filename="src/oob.cpp" />
+		<Unit filename="src/oob.h" />
+		<Unit filename="src/parser.cpp" />
+		<Unit filename="src/parser.h" />
+		<Unit filename="src/prep.cpp" />
+		<Unit filename="src/prep.h" />
+		<Unit filename="src/presence.cpp" />
+		<Unit filename="src/presence.h" />
+		<Unit filename="src/presencehandler.h" />
+		<Unit filename="src/privacyitem.cpp" />
+		<Unit filename="src/privacyitem.h" />
+		<Unit filename="src/privacylisthandler.h" />
+		<Unit filename="src/privacymanager.cpp" />
+		<Unit filename="src/privacymanager.h" />
+		<Unit filename="src/privatexml.cpp" />
+		<Unit filename="src/privatexml.h" />
+		<Unit filename="src/privatexmlhandler.h" />
+		<Unit filename="src/pubsub.h" />
+		<Unit filename="src/pubsubevent.cpp" />
+		<Unit filename="src/pubsubevent.h" />
+		<Unit filename="src/pubsubeventhandler.h" />
+		<Unit filename="src/pubsubitem.cpp" />
+		<Unit filename="src/pubsubitem.h" />
+		<Unit filename="src/pubsubmanager.cpp" />
+		<Unit filename="src/pubsubmanager.h" />
+		<Unit filename="src/pubsubresulthandler.h" />
+		<Unit filename="src/receipt.cpp" />
+		<Unit filename="src/receipt.h" />
+		<Unit filename="src/registration.cpp" />
+		<Unit filename="src/registration.h" />
+		<Unit filename="src/registrationhandler.h" />
+		<Unit filename="src/resource.h" />
+		<Unit filename="src/rosteritem.cpp" />
+		<Unit filename="src/rosteritem.h" />
+		<Unit filename="src/rosteritemdata.h" />
+		<Unit filename="src/rosterlistener.h" />
+		<Unit filename="src/rostermanager.cpp" />
+		<Unit filename="src/rostermanager.h" />
+		<Unit filename="src/search.cpp" />
+		<Unit filename="src/search.h" />
+		<Unit filename="src/searchhandler.h" />
+		<Unit filename="src/sha.cpp" />
+		<Unit filename="src/sha.h" />
+		<Unit filename="src/shim.cpp" />
+		<Unit filename="src/shim.h" />
+		<Unit filename="src/sihandler.h" />
+		<Unit filename="src/simanager.cpp" />
+		<Unit filename="src/simanager.h" />
+		<Unit filename="src/siprofileft.cpp" />
+		<Unit filename="src/siprofileft.h" />
+		<Unit filename="src/siprofilefthandler.h" />
+		<Unit filename="src/siprofilehandler.h" />
+		<Unit filename="src/socks5bytestream.cpp" />
+		<Unit filename="src/socks5bytestream.h" />
+		<Unit filename="src/socks5bytestreammanager.cpp" />
+		<Unit filename="src/socks5bytestreammanager.h" />
+		<Unit filename="src/socks5bytestreamserver.cpp" />
+		<Unit filename="src/socks5bytestreamserver.h" />
+		<Unit filename="src/softwareversion.cpp" />
+		<Unit filename="src/softwareversion.h" />
+		<Unit filename="src/stanza.cpp" />
+		<Unit filename="src/stanza.h" />
+		<Unit filename="src/stanzaextension.h" />
+		<Unit filename="src/stanzaextensionfactory.cpp" />
+		<Unit filename="src/stanzaextensionfactory.h" />
+		<Unit filename="src/statisticshandler.h" />
+		<Unit filename="src/subscription.cpp" />
+		<Unit filename="src/subscription.h" />
+		<Unit filename="src/subscriptionhandler.h" />
+		<Unit filename="src/tag.cpp" />
+		<Unit filename="src/tag.h" />
+		<Unit filename="src/taghandler.h" />
+		<Unit filename="src/tlsbase.h" />
+		<Unit filename="src/tlsdefault.cpp" />
+		<Unit filename="src/tlsdefault.h" />
+		<Unit filename="src/tlsgnutlsbase.cpp" />
+		<Unit filename="src/tlsgnutlsbase.h" />
+		<Unit filename="src/tlsgnutlsclient.cpp" />
+		<Unit filename="src/tlsgnutlsclient.h" />
+		<Unit filename="src/tlsgnutlsclientanon.cpp" />
+		<Unit filename="src/tlsgnutlsclientanon.h" />
+		<Unit filename="src/tlsgnutlsserveranon.cpp" />
+		<Unit filename="src/tlsgnutlsserveranon.h" />
+		<Unit filename="src/tlshandler.h" />
+		<Unit filename="src/tlsopensslbase.cpp" />
+		<Unit filename="src/tlsopensslbase.h" />
+		<Unit filename="src/tlsopensslclient.cpp" />
+		<Unit filename="src/tlsopensslclient.h" />
+		<Unit filename="src/tlsopensslserver.cpp" />
+		<Unit filename="src/tlsopensslserver.h" />
+		<Unit filename="src/tlsschannel.cpp" />
+		<Unit filename="src/tlsschannel.h" />
+		<Unit filename="src/uniquemucroom.cpp" />
+		<Unit filename="src/uniquemucroom.h" />
+		<Unit filename="src/util.cpp" />
+		<Unit filename="src/util.h" />
+		<Unit filename="src/vcard.cpp" />
+		<Unit filename="src/vcard.h" />
+		<Unit filename="src/vcardhandler.h" />
+		<Unit filename="src/vcardmanager.cpp" />
+		<Unit filename="src/vcardmanager.h" />
+		<Unit filename="src/vcardupdate.cpp" />
+		<Unit filename="src/vcardupdate.h" />
+		<Unit filename="src/version.rc">
 			<Option compilerVar="WINDRES" />
 		</Unit>
-		<Unit filename="src\xhtmlim.cpp" />
-		<Unit filename="src\xhtmlim.h" />
+		<Unit filename="src/xhtmlim.cpp" />
+		<Unit filename="src/xhtmlim.h" />
 		<Extensions>
 			<code_completion />
 			<envvars />

=== modified file 'gloox.dsp'
--- gloox.dsp	2010-01-17 13:05:04 +0000
+++ gloox.dsp	2014-01-16 10:42:06 +0000
@@ -114,6 +114,10 @@
 # End Source File
 # Begin Source File
 
+SOURCE=.\src\carbons.cpp
+# End Source File
+# Begin Source File
+
 SOURCE=.\src\chatstate.cpp
 # End Source File
 # Begin Source File
@@ -218,6 +222,10 @@
 # End Source File
 # Begin Source File
 
+SOURCE=.\src\forward.cpp
+# End Source File
+# Begin Source File
+
 SOURCE=.\src\gpgencrypted.cpp
 # End Source File
 # Begin Source File
@@ -522,6 +530,10 @@
 # End Source File
 # Begin Source File
 
+SOURCE=.\src\carbons.h
+# End Source File
+# Begin Source File
+
 SOURCE=.\src\chatstate.h
 # End Source File
 # Begin Source File
@@ -670,6 +682,10 @@
 # End Source File
 # Begin Source File
 
+SOURCE=.\src\forward.h
+# End Source File
+# Begin Source File
+
 SOURCE=.\src\gloox.h
 # End Source File
 # Begin Source File

=== modified file 'gloox.mmp'
--- gloox.mmp	2010-01-17 13:05:04 +0000
+++ gloox.mmp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -23,6 +23,7 @@
 source        amp.cpp
 source        annotations.cpp
 source        attention.cpp
+source        atomicrefcount.cpp
 source        base64.cpp
 source        bookmarkstorage.cpp
 source        capabilities.cpp

=== modified file 'gloox.pc.in'
--- gloox.pc.in	2008-04-27 10:32:55 +0000
+++ gloox.pc.in	2014-01-16 10:42:06 +0000
@@ -6,5 +6,5 @@
 Name: gloox
 Description: A high-level XMPP/Jabber library for C++
 Version: @VERSION@
-Libs: -L${libdir} -lgloox
-Cflags: -I${includedir}
+Libs: -L${libdir} -lgloox @LIBS@
+Cflags: -I${includedir} @CPPFLAGS@

=== modified file 'gloox.vcproj'
--- gloox.vcproj	2010-01-17 13:05:04 +0000
+++ gloox.vcproj	2014-01-16 10:42:06 +0000
@@ -2,8 +2,8 @@
 <VisualStudioProject
 	ProjectType="Visual C++"
 	Version="9,00"
-	Name="gloox 1.0"
-	ProjectGUID="{4DDB9C8A-C4A7-4518-A470-0B88629D8B66}"
+	Name="gloox-1.0"
+	ProjectGUID="{36E32BC3-0645-4C90-8BF5-6495ACB7CF5F}"
 	RootNamespace="gloox10"
 	TargetFrameworkVersion="196613"
 	>
@@ -17,7 +17,7 @@
 	<Configurations>
 		<Configuration
 			Name="Debug|Win32"
-			OutputDirectory="$(SolutionDir)$(ConfigurationName)"
+			OutputDirectory="..\gloox-1.0\$(ConfigurationName)"
 			IntermediateDirectory="$(ConfigurationName)"
 			ConfigurationType="2"
 			CharacterSet="2"
@@ -87,7 +87,7 @@
 			Name="Release|Win32"
 			OutputDirectory="$(SolutionDir)$(ConfigurationName)"
 			IntermediateDirectory="$(ConfigurationName)"
-			ConfigurationType="1"
+			ConfigurationType="2"
 			CharacterSet="2"
 			WholeProgramOptimization="1"
 			>
@@ -110,6 +110,7 @@
 				Name="VCCLCompilerTool"
 				Optimization="2"
 				EnableIntrinsicFunctions="true"
+				PreprocessorDefinitions="DLL_EXPORT"
 				RuntimeLibrary="2"
 				EnableFunctionLevelLinking="true"
 				WarningLevel="3"
@@ -175,6 +176,10 @@
 				>
 			</File>
 			<File
+				RelativePath=".\src\atomicrefcount.cpp"
+				>
+			</File>
+			<File
 				RelativePath="src\attention.cpp"
 				>
 			</File>
@@ -191,6 +196,10 @@
 				>
 			</File>
 			<File
+				RelativePath="src\carbons.cpp"
+				>
+			</File>
+			<File
 				RelativePath="src\chatstate.cpp"
 				>
 			</File>
@@ -299,6 +308,10 @@
 				>
 			</File>
 			<File
+				RelativePath="src\forward.cpp"
+				>
+			</File>
+			<File
 				RelativePath="src\gloox.cpp"
 				>
 			</File>
@@ -327,6 +340,30 @@
 				>
 			</File>
 			<File
+				RelativePath=".\src\jinglecontent.cpp"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglefiletransfer.cpp"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jingleiceudp.cpp"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglepluginfactory.cpp"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglesession.cpp"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglesessionmanager.cpp"
+				>
+			</File>
+			<File
 				RelativePath="src\lastactivity.cpp"
 				>
 			</File>
@@ -503,10 +540,6 @@
 				>
 			</File>
 			<File
-				RelativePath="src\tlsgnutlsserver.cpp"
-				>
-			</File>
-			<File
 				RelativePath="src\tlsgnutlsserveranon.cpp"
 				>
 			</File>
@@ -581,6 +614,10 @@
 				>
 			</File>
 			<File
+				RelativePath=".\src\atomicrefcount.h"
+				>
+			</File>
+			<File
 				RelativePath="src\attention.h"
 				>
 			</File>
@@ -613,6 +650,10 @@
 				>
 			</File>
 			<File
+				RelativePath="src\carbons.h"
+				>
+			</File>
+			<File
 				RelativePath="src\chatstate.h"
 				>
 			</File>
@@ -769,6 +810,10 @@
 				>
 			</File>
 			<File
+				RelativePath="src\forward.h"
+				>
+			</File>
+			<File
 				RelativePath="src\gloox.h"
 				>
 			</File>
@@ -801,6 +846,42 @@
 				>
 			</File>
 			<File
+				RelativePath=".\src\jinglecontent.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglefiletransfer.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jingleiceudp.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jingleplugin.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglepluginfactory.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglesession.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglesessionhandler.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jinglesessionmanager.h"
+				>
+			</File>
+			<File
+				RelativePath=".\src\jingletransport.h"
+				>
+			</File>
+			<File
 				RelativePath="src\lastactivity.h"
 				>
 			</File>
@@ -1089,10 +1170,6 @@
 				>
 			</File>
 			<File
-				RelativePath="src\tlsgnutlsserver.h"
-				>
-			</File>
-			<File
 				RelativePath="src\tlsgnutlsserveranon.h"
 				>
 			</File>

=== modified file 'install-sh'
--- install-sh	2010-01-17 13:05:04 +0000
+++ install-sh	2014-01-16 10:42:06 +0000
@@ -1,7 +1,7 @@
 #!/bin/sh
 # install - install a program, script, or datafile
 
-scriptversion=2009-04-28.21; # UTC
+scriptversion=2011-01-19.21; # UTC
 
 # This originates from X11R5 (mit/util/scripts/install.sh), which was
 # later released in X11R6 (xc/config/util/install.sh) with the
@@ -156,6 +156,10 @@
     -s) stripcmd=$stripprog;;
 
     -t) dst_arg=$2
+	# Protect names problematic for `test' and other utilities.
+	case $dst_arg in
+	  -* | [=\(\)!]) dst_arg=./$dst_arg;;
+	esac
 	shift;;
 
     -T) no_target_directory=true;;
@@ -186,6 +190,10 @@
     fi
     shift # arg
     dst_arg=$arg
+    # Protect names problematic for `test' and other utilities.
+    case $dst_arg in
+      -* | [=\(\)!]) dst_arg=./$dst_arg;;
+    esac
   done
 fi
 
@@ -200,7 +208,11 @@
 fi
 
 if test -z "$dir_arg"; then
-  trap '(exit $?); exit' 1 2 13 15
+  do_exit='(exit $ret); exit $ret'
+  trap "ret=129; $do_exit" 1
+  trap "ret=130; $do_exit" 2
+  trap "ret=141; $do_exit" 13
+  trap "ret=143; $do_exit" 15
 
   # Set umask so as not to create temps with too-generous modes.
   # However, 'strip' requires both read and write access to temps.
@@ -228,9 +240,9 @@
 
 for src
 do
-  # Protect names starting with `-'.
+  # Protect names problematic for `test' and other utilities.
   case $src in
-    -*) src=./$src;;
+    -* | [=\(\)!]) src=./$src;;
   esac
 
   if test -n "$dir_arg"; then
@@ -252,12 +264,7 @@
       echo "$0: no destination specified." >&2
       exit 1
     fi
-
     dst=$dst_arg
-    # Protect names starting with `-'.
-    case $dst in
-      -*) dst=./$dst;;
-    esac
 
     # If destination is a directory, append the input filename; won't work
     # if double slashes aren't ignored.
@@ -385,7 +392,7 @@
 
       case $dstdir in
 	/*) prefix='/';;
-	-*) prefix='./';;
+	[-=\(\)!]*) prefix='./';;
 	*)  prefix='';;
       esac
 
@@ -403,7 +410,7 @@
 
       for d
       do
-	test -z "$d" && continue
+	test X"$d" = X && continue
 
 	prefix=$prefix$d
 	if test -d "$prefix"; then

=== modified file 'ltmain.sh' (properties changed: +x to -x)
--- ltmain.sh	2010-01-17 13:05:04 +0000
+++ ltmain.sh	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Generated from ltmain.m4sh.
 
-# ltmain.sh (GNU libtool) 2.2.6
+# libtool (GNU libtool) 2.4.2
 # Written by Gordon Matzigkeit <gord@gnu.ai.mit.edu>, 1996
 
-# Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005, 2006, 2007 2008 Free Software Foundation, Inc.
+# Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2003, 2004, 2005, 2006,
+# 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 # This is free software; see the source for copying conditions.  There is NO
 # warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
@@ -32,50 +32,57 @@
 #
 # Provide generalized library-building support services.
 #
-#     --config             show all configuration variables
-#     --debug              enable verbose shell tracing
-# -n, --dry-run            display commands without modifying any files
-#     --features           display basic configuration information and exit
-#     --mode=MODE          use operation mode MODE
-#     --preserve-dup-deps  don't remove duplicate dependency libraries
-#     --quiet, --silent    don't print informational messages
-#     --tag=TAG            use configuration variables from tag TAG
-# -v, --verbose            print informational messages (default)
-#     --version            print version information
-# -h, --help               print short or long help message
+#       --config             show all configuration variables
+#       --debug              enable verbose shell tracing
+#   -n, --dry-run            display commands without modifying any files
+#       --features           display basic configuration information and exit
+#       --mode=MODE          use operation mode MODE
+#       --preserve-dup-deps  don't remove duplicate dependency libraries
+#       --quiet, --silent    don't print informational messages
+#       --no-quiet, --no-silent
+#                            print informational messages (default)
+#       --no-warn            don't display warning messages
+#       --tag=TAG            use configuration variables from tag TAG
+#   -v, --verbose            print more informational messages than default
+#       --no-verbose         don't print the extra informational messages
+#       --version            print version information
+#   -h, --help, --help-all   print short, long, or detailed help message
 #
 # MODE must be one of the following:
 #
-#       clean              remove files from the build directory
-#       compile            compile a source file into a libtool object
-#       execute            automatically set library path, then run a program
-#       finish             complete the installation of libtool libraries
-#       install            install libraries or executables
-#       link               create a library or an executable
-#       uninstall          remove libraries from an installed directory
+#         clean              remove files from the build directory
+#         compile            compile a source file into a libtool object
+#         execute            automatically set library path, then run a program
+#         finish             complete the installation of libtool libraries
+#         install            install libraries or executables
+#         link               create a library or an executable
+#         uninstall          remove libraries from an installed directory
 #
-# MODE-ARGS vary depending on the MODE.
+# MODE-ARGS vary depending on the MODE.  When passed as first option,
+# `--mode=MODE' may be abbreviated as `MODE' or a unique abbreviation of that.
 # Try `$progname --help --mode=MODE' for a more detailed description of MODE.
 #
 # When reporting a bug, please describe a test case to reproduce it and
 # include the following information:
 #
-#       host-triplet:	$host
-#       shell:		$SHELL
-#       compiler:		$LTCC
-#       compiler flags:		$LTCFLAGS
-#       linker:		$LD (gnu? $with_gnu_ld)
-#       $progname:		(GNU libtool) 2.2.6 Debian-2.2.6a-4
-#       automake:		$automake_version
-#       autoconf:		$autoconf_version
+#         host-triplet:	$host
+#         shell:		$SHELL
+#         compiler:		$LTCC
+#         compiler flags:		$LTCFLAGS
+#         linker:		$LD (gnu? $with_gnu_ld)
+#         $progname:	(GNU libtool) 2.4.2 Debian-2.4.2-1.1
+#         automake:	$automake_version
+#         autoconf:	$autoconf_version
 #
 # Report bugs to <bug-libtool@gnu.org>.
+# GNU libtool home page: <http://www.gnu.org/software/libtool/>.
+# General help using GNU software: <http://www.gnu.org/gethelp/>.
 
-PROGRAM=ltmain.sh
+PROGRAM=libtool
 PACKAGE=libtool
-VERSION="2.2.6 Debian-2.2.6a-4"
+VERSION="2.4.2 Debian-2.4.2-1.1"
 TIMESTAMP=""
-package_revision=1.3012
+package_revision=1.3337
 
 # Be Bourne compatible
 if test -n "${ZSH_VERSION+set}" && (emulate sh) >/dev/null 2>&1; then
@@ -91,10 +98,15 @@
 BIN_SH=xpg4; export BIN_SH # for Tru64
 DUALCASE=1; export DUALCASE # for MKS sh
 
+# A function that is used when there is no print builtin or printf.
+func_fallback_echo ()
+{
+  eval 'cat <<_LTECHO_EOF
+$1
+_LTECHO_EOF'
+}
+
 # NLS nuisances: We save the old values to restore during execute mode.
-# Only set LANG and LC_ALL to C if already set.
-# These must not be set unconditionally because not all systems understand
-# e.g. LANG=C (notably SCO).
 lt_user_locale=
 lt_safe_locale=
 for lt_var in LANG LANGUAGE LC_ALL LC_CTYPE LC_COLLATE LC_MESSAGES
@@ -107,24 +119,28 @@
 	  lt_safe_locale=\"$lt_var=C; \$lt_safe_locale\"
 	fi"
 done
+LC_ALL=C
+LANGUAGE=C
+export LANGUAGE LC_ALL
 
 $lt_unset CDPATH
 
 
+# Work around backward compatibility issue on IRIX 6.5. On IRIX 6.4+, sh
+# is ksh but when the shell is invoked as "sh" and the current value of
+# the _XPG environment variable is not equal to 1 (one), the special
+# positional parameter $0, within a function call, is the name of the
+# function.
+progpath="$0"
 
 
 
 : ${CP="cp -f"}
-: ${ECHO="echo"}
-: ${EGREP="/bin/grep -E"}
-: ${FGREP="/bin/grep -F"}
-: ${GREP="/bin/grep"}
-: ${LN_S="ln -s"}
+test "${ECHO+set}" = set || ECHO=${as_echo-'printf %s\n'}
 : ${MAKE="make"}
 : ${MKDIR="mkdir"}
 : ${MV="mv -f"}
 : ${RM="rm -f"}
-: ${SED="/bin/sed"}
 : ${SHELL="${CONFIG_SHELL-/bin/sh}"}
 : ${Xsed="$SED -e 1s/^X//"}
 
@@ -144,6 +160,27 @@
 dirname="s,/[^/]*$,,"
 basename="s,^.*/,,"
 
+# func_dirname file append nondir_replacement
+# Compute the dirname of FILE.  If nonempty, add APPEND to the result,
+# otherwise set result to NONDIR_REPLACEMENT.
+func_dirname ()
+{
+    func_dirname_result=`$ECHO "${1}" | $SED "$dirname"`
+    if test "X$func_dirname_result" = "X${1}"; then
+      func_dirname_result="${3}"
+    else
+      func_dirname_result="$func_dirname_result${2}"
+    fi
+} # func_dirname may be replaced by extended shell implementation
+
+
+# func_basename file
+func_basename ()
+{
+    func_basename_result=`$ECHO "${1}" | $SED "$basename"`
+} # func_basename may be replaced by extended shell implementation
+
+
 # func_dirname_and_basename file append nondir_replacement
 # perform func_basename and func_dirname in a single function
 # call:
@@ -158,33 +195,183 @@
 # those functions but instead duplicate the functionality here.
 func_dirname_and_basename ()
 {
-  # Extract subdirectory from the argument.
-  func_dirname_result=`$ECHO "X${1}" | $Xsed -e "$dirname"`
-  if test "X$func_dirname_result" = "X${1}"; then
-    func_dirname_result="${3}"
-  else
-    func_dirname_result="$func_dirname_result${2}"
-  fi
-  func_basename_result=`$ECHO "X${1}" | $Xsed -e "$basename"`
-}
-
-# Generated shell functions inserted here.
-
-# Work around backward compatibility issue on IRIX 6.5. On IRIX 6.4+, sh
-# is ksh but when the shell is invoked as "sh" and the current value of
-# the _XPG environment variable is not equal to 1 (one), the special
-# positional parameter $0, within a function call, is the name of the
-# function.
-progpath="$0"
+    # Extract subdirectory from the argument.
+    func_dirname_result=`$ECHO "${1}" | $SED -e "$dirname"`
+    if test "X$func_dirname_result" = "X${1}"; then
+      func_dirname_result="${3}"
+    else
+      func_dirname_result="$func_dirname_result${2}"
+    fi
+    func_basename_result=`$ECHO "${1}" | $SED -e "$basename"`
+} # func_dirname_and_basename may be replaced by extended shell implementation
+
+
+# func_stripname prefix suffix name
+# strip PREFIX and SUFFIX off of NAME.
+# PREFIX and SUFFIX must not contain globbing or regex special
+# characters, hashes, percent signs, but SUFFIX may contain a leading
+# dot (in which case that matches only a dot).
+# func_strip_suffix prefix name
+func_stripname ()
+{
+    case ${2} in
+      .*) func_stripname_result=`$ECHO "${3}" | $SED "s%^${1}%%; s%\\\\${2}\$%%"`;;
+      *)  func_stripname_result=`$ECHO "${3}" | $SED "s%^${1}%%; s%${2}\$%%"`;;
+    esac
+} # func_stripname may be replaced by extended shell implementation
+
+
+# These SED scripts presuppose an absolute path with a trailing slash.
+pathcar='s,^/\([^/]*\).*$,\1,'
+pathcdr='s,^/[^/]*,,'
+removedotparts=':dotsl
+		s@/\./@/@g
+		t dotsl
+		s,/\.$,/,'
+collapseslashes='s@/\{1,\}@/@g'
+finalslash='s,/*$,/,'
+
+# func_normal_abspath PATH
+# Remove doubled-up and trailing slashes, "." path components,
+# and cancel out any ".." path components in PATH after making
+# it an absolute path.
+#             value returned in "$func_normal_abspath_result"
+func_normal_abspath ()
+{
+  # Start from root dir and reassemble the path.
+  func_normal_abspath_result=
+  func_normal_abspath_tpath=$1
+  func_normal_abspath_altnamespace=
+  case $func_normal_abspath_tpath in
+    "")
+      # Empty path, that just means $cwd.
+      func_stripname '' '/' "`pwd`"
+      func_normal_abspath_result=$func_stripname_result
+      return
+    ;;
+    # The next three entries are used to spot a run of precisely
+    # two leading slashes without using negated character classes;
+    # we take advantage of case's first-match behaviour.
+    ///*)
+      # Unusual form of absolute path, do nothing.
+    ;;
+    //*)
+      # Not necessarily an ordinary path; POSIX reserves leading '//'
+      # and for example Cygwin uses it to access remote file shares
+      # over CIFS/SMB, so we conserve a leading double slash if found.
+      func_normal_abspath_altnamespace=/
+    ;;
+    /*)
+      # Absolute path, do nothing.
+    ;;
+    *)
+      # Relative path, prepend $cwd.
+      func_normal_abspath_tpath=`pwd`/$func_normal_abspath_tpath
+    ;;
+  esac
+  # Cancel out all the simple stuff to save iterations.  We also want
+  # the path to end with a slash for ease of parsing, so make sure
+  # there is one (and only one) here.
+  func_normal_abspath_tpath=`$ECHO "$func_normal_abspath_tpath" | $SED \
+        -e "$removedotparts" -e "$collapseslashes" -e "$finalslash"`
+  while :; do
+    # Processed it all yet?
+    if test "$func_normal_abspath_tpath" = / ; then
+      # If we ascended to the root using ".." the result may be empty now.
+      if test -z "$func_normal_abspath_result" ; then
+        func_normal_abspath_result=/
+      fi
+      break
+    fi
+    func_normal_abspath_tcomponent=`$ECHO "$func_normal_abspath_tpath" | $SED \
+        -e "$pathcar"`
+    func_normal_abspath_tpath=`$ECHO "$func_normal_abspath_tpath" | $SED \
+        -e "$pathcdr"`
+    # Figure out what to do with it
+    case $func_normal_abspath_tcomponent in
+      "")
+        # Trailing empty path component, ignore it.
+      ;;
+      ..)
+        # Parent dir; strip last assembled component from result.
+        func_dirname "$func_normal_abspath_result"
+        func_normal_abspath_result=$func_dirname_result
+      ;;
+      *)
+        # Actual path component, append it.
+        func_normal_abspath_result=$func_normal_abspath_result/$func_normal_abspath_tcomponent
+      ;;
+    esac
+  done
+  # Restore leading double-slash if one was found on entry.
+  func_normal_abspath_result=$func_normal_abspath_altnamespace$func_normal_abspath_result
+}
+
+# func_relative_path SRCDIR DSTDIR
+# generates a relative path from SRCDIR to DSTDIR, with a trailing
+# slash if non-empty, suitable for immediately appending a filename
+# without needing to append a separator.
+#             value returned in "$func_relative_path_result"
+func_relative_path ()
+{
+  func_relative_path_result=
+  func_normal_abspath "$1"
+  func_relative_path_tlibdir=$func_normal_abspath_result
+  func_normal_abspath "$2"
+  func_relative_path_tbindir=$func_normal_abspath_result
+
+  # Ascend the tree starting from libdir
+  while :; do
+    # check if we have found a prefix of bindir
+    case $func_relative_path_tbindir in
+      $func_relative_path_tlibdir)
+        # found an exact match
+        func_relative_path_tcancelled=
+        break
+        ;;
+      $func_relative_path_tlibdir*)
+        # found a matching prefix
+        func_stripname "$func_relative_path_tlibdir" '' "$func_relative_path_tbindir"
+        func_relative_path_tcancelled=$func_stripname_result
+        if test -z "$func_relative_path_result"; then
+          func_relative_path_result=.
+        fi
+        break
+        ;;
+      *)
+        func_dirname $func_relative_path_tlibdir
+        func_relative_path_tlibdir=${func_dirname_result}
+        if test "x$func_relative_path_tlibdir" = x ; then
+          # Have to descend all the way to the root!
+          func_relative_path_result=../$func_relative_path_result
+          func_relative_path_tcancelled=$func_relative_path_tbindir
+          break
+        fi
+        func_relative_path_result=../$func_relative_path_result
+        ;;
+    esac
+  done
+
+  # Now calculate path; take care to avoid doubling-up slashes.
+  func_stripname '' '/' "$func_relative_path_result"
+  func_relative_path_result=$func_stripname_result
+  func_stripname '/' '/' "$func_relative_path_tcancelled"
+  if test "x$func_stripname_result" != x ; then
+    func_relative_path_result=${func_relative_path_result}/${func_stripname_result}
+  fi
+
+  # Normalisation. If bindir is libdir, return empty string,
+  # else relative path ending with a slash; either way, target
+  # file name can be directly appended.
+  if test ! -z "$func_relative_path_result"; then
+    func_stripname './' '' "$func_relative_path_result/"
+    func_relative_path_result=$func_stripname_result
+  fi
+}
 
 # The name of this program:
-# In the unlikely event $progname began with a '-', it would play havoc with
-# func_echo (imagine progname=-n), so we prepend ./ in that case:
 func_dirname_and_basename "$progpath"
 progname=$func_basename_result
-case $progname in
-  -*) progname=./$progname ;;
-esac
 
 # Make sure we have an absolute path for reexecution:
 case $progpath in
@@ -196,7 +383,7 @@
      ;;
   *)
      save_IFS="$IFS"
-     IFS=:
+     IFS=${PATH_SEPARATOR-:}
      for progdir in $PATH; do
        IFS="$save_IFS"
        test -x "$progdir/$progname" && break
@@ -215,6 +402,15 @@
 # Same as above, but do not quote variable references.
 double_quote_subst='s/\(["`\\]\)/\\\1/g'
 
+# Sed substitution that turns a string into a regex matching for the
+# string literally.
+sed_make_literal_regex='s,[].[^$\\*\/],\\&,g'
+
+# Sed substitution that converts a w32 file name or path
+# which contains forward slashes, into one that contains
+# (escaped) backslashes.  A very naive implementation.
+lt_sed_naive_backslashify='s|\\\\*|\\|g;s|/|\\|g;s|\\|\\\\|g'
+
 # Re-`\' parameter expansions in output of double_quote_subst that were
 # `\'-ed in input to the same.  If an odd number of `\' preceded a '$'
 # in input to double_quote_subst, that '$' was protected from expansion.
@@ -243,7 +439,7 @@
 # name if it has been set yet.
 func_echo ()
 {
-    $ECHO "$progname${mode+: }$mode: $*"
+    $ECHO "$progname: ${opt_mode+$opt_mode: }$*"
 }
 
 # func_verbose arg...
@@ -258,18 +454,25 @@
     :
 }
 
+# func_echo_all arg...
+# Invoke $ECHO with all args, space-separated.
+func_echo_all ()
+{
+    $ECHO "$*"
+}
+
 # func_error arg...
 # Echo program name prefixed message to standard error.
 func_error ()
 {
-    $ECHO "$progname${mode+: }$mode: "${1+"$@"} 1>&2
+    $ECHO "$progname: ${opt_mode+$opt_mode: }"${1+"$@"} 1>&2
 }
 
 # func_warning arg...
 # Echo program name prefixed warning message to standard error.
 func_warning ()
 {
-    $opt_warning && $ECHO "$progname${mode+: }$mode: warning: "${1+"$@"} 1>&2
+    $opt_warning && $ECHO "$progname: ${opt_mode+$opt_mode: }warning: "${1+"$@"} 1>&2
 
     # bash bug again:
     :
@@ -326,9 +529,9 @@
         case $my_directory_path in */*) ;; *) break ;; esac
 
         # ...otherwise throw away the child directory and loop
-        my_directory_path=`$ECHO "X$my_directory_path" | $Xsed -e "$dirname"`
+        my_directory_path=`$ECHO "$my_directory_path" | $SED -e "$dirname"`
       done
-      my_dir_list=`$ECHO "X$my_dir_list" | $Xsed -e 's,:*$,,'`
+      my_dir_list=`$ECHO "$my_dir_list" | $SED 's,:*$,,'`
 
       save_mkdir_p_IFS="$IFS"; IFS=':'
       for my_dir in $my_dir_list; do
@@ -378,7 +581,7 @@
         func_fatal_error "cannot create temporary directory \`$my_tmpdir'"
     fi
 
-    $ECHO "X$my_tmpdir" | $Xsed
+    $ECHO "$my_tmpdir"
 }
 
 
@@ -392,7 +595,7 @@
 {
     case $1 in
       *[\\\`\"\$]*)
-	func_quote_for_eval_unquoted_result=`$ECHO "X$1" | $Xsed -e "$sed_quote_subst"` ;;
+	func_quote_for_eval_unquoted_result=`$ECHO "$1" | $SED "$sed_quote_subst"` ;;
       *)
         func_quote_for_eval_unquoted_result="$1" ;;
     esac
@@ -419,7 +622,7 @@
 {
     case $1 in
       *[\\\`\"]*)
-	my_arg=`$ECHO "X$1" | $Xsed \
+	my_arg=`$ECHO "$1" | $SED \
 	    -e "$double_quote_subst" -e "$sed_double_backslash"` ;;
       *)
         my_arg="$1" ;;
@@ -488,15 +691,39 @@
     fi
 }
 
-
-
+# func_tr_sh
+# Turn $1 into a string suitable for a shell variable name.
+# Result is stored in $func_tr_sh_result.  All characters
+# not in the set a-zA-Z0-9_ are replaced with '_'. Further,
+# if $1 begins with a digit, a '_' is prepended as well.
+func_tr_sh ()
+{
+  case $1 in
+  [0-9]* | *[!a-zA-Z0-9_]*)
+    func_tr_sh_result=`$ECHO "$1" | $SED 's/^\([0-9]\)/_\1/; s/[^a-zA-Z0-9_]/_/g'`
+    ;;
+  * )
+    func_tr_sh_result=$1
+    ;;
+  esac
+}
 
 
 # func_version
 # Echo version message to standard output and exit.
 func_version ()
 {
-    $SED -n '/^# '$PROGRAM' (GNU /,/# warranty; / {
+    $opt_debug
+
+    $SED -n '/(C)/!b go
+	:more
+	/\./!{
+	  N
+	  s/\n# / /
+	  b more
+	}
+	:go
+	/^# '$PROGRAM' (GNU /,/# warranty; / {
         s/^# //
 	s/^# *$//
         s/\((C)\)[ 0-9,-]*\( [1-9][0-9]*\)/\1\2/
@@ -509,22 +736,28 @@
 # Echo short help message to standard output and exit.
 func_usage ()
 {
-    $SED -n '/^# Usage:/,/# -h/ {
+    $opt_debug
+
+    $SED -n '/^# Usage:/,/^#  *.*--help/ {
         s/^# //
 	s/^# *$//
 	s/\$progname/'$progname'/
 	p
     }' < "$progpath"
-    $ECHO
+    echo
     $ECHO "run \`$progname --help | more' for full usage"
     exit $?
 }
 
-# func_help
-# Echo long help message to standard output and exit.
+# func_help [NOEXIT]
+# Echo long help message to standard output and exit,
+# unless 'noexit' is passed as argument.
 func_help ()
 {
+    $opt_debug
+
     $SED -n '/^# Usage:/,/# Report bugs to/ {
+	:print
         s/^# //
 	s/^# *$//
 	s*\$progname*'$progname'*
@@ -534,11 +767,18 @@
 	s*\$LTCFLAGS*'"$LTCFLAGS"'*
 	s*\$LD*'"$LD"'*
 	s/\$with_gnu_ld/'"$with_gnu_ld"'/
-	s/\$automake_version/'"`(automake --version) 2>/dev/null |$SED 1q`"'/
-	s/\$autoconf_version/'"`(autoconf --version) 2>/dev/null |$SED 1q`"'/
+	s/\$automake_version/'"`(${AUTOMAKE-automake} --version) 2>/dev/null |$SED 1q`"'/
+	s/\$autoconf_version/'"`(${AUTOCONF-autoconf} --version) 2>/dev/null |$SED 1q`"'/
 	p
-     }' < "$progpath"
-    exit $?
+	d
+     }
+     /^# .* home page:/b print
+     /^# General help using/b print
+     ' < "$progpath"
+    ret=$?
+    if test -z "$1"; then
+      exit $ret
+    fi
 }
 
 # func_missing_arg argname
@@ -546,63 +786,106 @@
 # exit_cmd.
 func_missing_arg ()
 {
-    func_error "missing argument for $1"
+    $opt_debug
+
+    func_error "missing argument for $1."
     exit_cmd=exit
 }
 
+
+# func_split_short_opt shortopt
+# Set func_split_short_opt_name and func_split_short_opt_arg shell
+# variables after splitting SHORTOPT after the 2nd character.
+func_split_short_opt ()
+{
+    my_sed_short_opt='1s/^\(..\).*$/\1/;q'
+    my_sed_short_rest='1s/^..\(.*\)$/\1/;q'
+
+    func_split_short_opt_name=`$ECHO "$1" | $SED "$my_sed_short_opt"`
+    func_split_short_opt_arg=`$ECHO "$1" | $SED "$my_sed_short_rest"`
+} # func_split_short_opt may be replaced by extended shell implementation
+
+
+# func_split_long_opt longopt
+# Set func_split_long_opt_name and func_split_long_opt_arg shell
+# variables after splitting LONGOPT at the `=' sign.
+func_split_long_opt ()
+{
+    my_sed_long_opt='1s/^\(--[^=]*\)=.*/\1/;q'
+    my_sed_long_arg='1s/^--[^=]*=//'
+
+    func_split_long_opt_name=`$ECHO "$1" | $SED "$my_sed_long_opt"`
+    func_split_long_opt_arg=`$ECHO "$1" | $SED "$my_sed_long_arg"`
+} # func_split_long_opt may be replaced by extended shell implementation
+
 exit_cmd=:
 
 
 
 
 
-# Check that we have a working $ECHO.
-if test "X$1" = X--no-reexec; then
-  # Discard the --no-reexec flag, and continue.
-  shift
-elif test "X$1" = X--fallback-echo; then
-  # Avoid inline document here, it may be left over
-  :
-elif test "X`{ $ECHO '\t'; } 2>/dev/null`" = 'X\t'; then
-  # Yippee, $ECHO works!
-  :
-else
-  # Restart under the correct shell, and then maybe $ECHO will work.
-  exec $SHELL "$progpath" --no-reexec ${1+"$@"}
-fi
-
-if test "X$1" = X--fallback-echo; then
-  # used as fallback echo
-  shift
-  cat <<EOF
-$*
-EOF
-  exit $EXIT_SUCCESS
-fi
-
 magic="%%%MAGIC variable%%%"
 magic_exe="%%%MAGIC EXE variable%%%"
 
 # Global variables.
-# $mode is unset
 nonopt=
-execute_dlfiles=
 preserve_args=
 lo2o="s/\\.lo\$/.${objext}/"
 o2lo="s/\\.${objext}\$/.lo/"
 extracted_archives=
 extracted_serial=0
 
-opt_dry_run=false
-opt_duplicate_deps=false
-opt_silent=false
-opt_debug=:
-
 # If this variable is set in any of the actions, the command in it
 # will be execed at the end.  This prevents here-documents from being
 # left over by shells.
 exec_cmd=
 
+# func_append var value
+# Append VALUE to the end of shell variable VAR.
+func_append ()
+{
+    eval "${1}=\$${1}\${2}"
+} # func_append may be replaced by extended shell implementation
+
+# func_append_quoted var value
+# Quote VALUE and append to the end of shell variable VAR, separated
+# by a space.
+func_append_quoted ()
+{
+    func_quote_for_eval "${2}"
+    eval "${1}=\$${1}\\ \$func_quote_for_eval_result"
+} # func_append_quoted may be replaced by extended shell implementation
+
+
+# func_arith arithmetic-term...
+func_arith ()
+{
+    func_arith_result=`expr "${@}"`
+} # func_arith may be replaced by extended shell implementation
+
+
+# func_len string
+# STRING may not start with a hyphen.
+func_len ()
+{
+    func_len_result=`expr "${1}" : ".*" 2>/dev/null || echo $max_cmd_len`
+} # func_len may be replaced by extended shell implementation
+
+
+# func_lo2o object
+func_lo2o ()
+{
+    func_lo2o_result=`$ECHO "${1}" | $SED "$lo2o"`
+} # func_lo2o may be replaced by extended shell implementation
+
+
+# func_xform libobj-or-source
+func_xform ()
+{
+    func_xform_result=`$ECHO "${1}" | $SED 's/\.[^.]*$/.lo/'`
+} # func_xform may be replaced by extended shell implementation
+
+
 # func_fatal_configuration arg...
 # Echo program name prefixed message to standard error, followed by
 # a configuration failure hint, and exit.
@@ -636,16 +919,16 @@
 # Display the features supported by this script.
 func_features ()
 {
-    $ECHO "host: $host"
+    echo "host: $host"
     if test "$build_libtool_libs" = yes; then
-      $ECHO "enable shared libraries"
+      echo "enable shared libraries"
     else
-      $ECHO "disable shared libraries"
+      echo "disable shared libraries"
     fi
     if test "$build_old_libs" = yes; then
-      $ECHO "enable static libraries"
+      echo "enable static libraries"
     else
-      $ECHO "disable static libraries"
+      echo "disable static libraries"
     fi
 
     exit $?
@@ -692,133 +975,6 @@
   esac
 }
 
-# Parse options once, thoroughly.  This comes as soon as possible in
-# the script to make things like `libtool --version' happen quickly.
-{
-
-  # Shorthand for --mode=foo, only valid as the first argument
-  case $1 in
-  clean|clea|cle|cl)
-    shift; set dummy --mode clean ${1+"$@"}; shift
-    ;;
-  compile|compil|compi|comp|com|co|c)
-    shift; set dummy --mode compile ${1+"$@"}; shift
-    ;;
-  execute|execut|execu|exec|exe|ex|e)
-    shift; set dummy --mode execute ${1+"$@"}; shift
-    ;;
-  finish|finis|fini|fin|fi|f)
-    shift; set dummy --mode finish ${1+"$@"}; shift
-    ;;
-  install|instal|insta|inst|ins|in|i)
-    shift; set dummy --mode install ${1+"$@"}; shift
-    ;;
-  link|lin|li|l)
-    shift; set dummy --mode link ${1+"$@"}; shift
-    ;;
-  uninstall|uninstal|uninsta|uninst|unins|unin|uni|un|u)
-    shift; set dummy --mode uninstall ${1+"$@"}; shift
-    ;;
-  esac
-
-  # Parse non-mode specific arguments:
-  while test "$#" -gt 0; do
-    opt="$1"
-    shift
-
-    case $opt in
-      --config)		func_config					;;
-
-      --debug)		preserve_args="$preserve_args $opt"
-			func_echo "enabling shell trace mode"
-			opt_debug='set -x'
-			$opt_debug
-			;;
-
-      -dlopen)		test "$#" -eq 0 && func_missing_arg "$opt" && break
-			execute_dlfiles="$execute_dlfiles $1"
-			shift
-			;;
-
-      --dry-run | -n)	opt_dry_run=:					;;
-      --features)       func_features					;;
-      --finish)		mode="finish"					;;
-
-      --mode)		test "$#" -eq 0 && func_missing_arg "$opt" && break
-			case $1 in
-			  # Valid mode arguments:
-			  clean)	;;
-			  compile)	;;
-			  execute)	;;
-			  finish)	;;
-			  install)	;;
-			  link)		;;
-			  relink)	;;
-			  uninstall)	;;
-
-			  # Catch anything else as an error
-			  *) func_error "invalid argument for $opt"
-			     exit_cmd=exit
-			     break
-			     ;;
-		        esac
-
-			mode="$1"
-			shift
-			;;
-
-      --preserve-dup-deps)
-			opt_duplicate_deps=:				;;
-
-      --quiet|--silent)	preserve_args="$preserve_args $opt"
-			opt_silent=:
-			;;
-
-      --verbose| -v)	preserve_args="$preserve_args $opt"
-			opt_silent=false
-			;;
-
-      --tag)		test "$#" -eq 0 && func_missing_arg "$opt" && break
-			preserve_args="$preserve_args $opt $1"
-			func_enable_tag "$1"	# tagname is set here
-			shift
-			;;
-
-      # Separate optargs to long options:
-      -dlopen=*|--mode=*|--tag=*)
-			func_opt_split "$opt"
-			set dummy "$func_opt_split_opt" "$func_opt_split_arg" ${1+"$@"}
-			shift
-			;;
-
-      -\?|-h)		func_usage					;;
-      --help)		opt_help=:					;;
-      --version)	func_version					;;
-
-      -*)		func_fatal_help "unrecognized option \`$opt'"	;;
-
-      *)		nonopt="$opt"
-			break
-			;;
-    esac
-  done
-
-
-  case $host in
-    *cygwin* | *mingw* | *pw32* | *cegcc*)
-      # don't eliminate duplications in $postdeps and $predeps
-      opt_duplicate_compiler_generated_deps=:
-      ;;
-    *)
-      opt_duplicate_compiler_generated_deps=$opt_duplicate_deps
-      ;;
-  esac
-
-  # Having warned about all mis-specified options, bail out if
-  # anything was wrong.
-  $exit_cmd $EXIT_FAILURE
-}
-
 # func_check_version_match
 # Ensure that we are using m4 macros, and libtool script from the same
 # release of libtool.
@@ -855,38 +1011,219 @@
 }
 
 
+# Shorthand for --mode=foo, only valid as the first argument
+case $1 in
+clean|clea|cle|cl)
+  shift; set dummy --mode clean ${1+"$@"}; shift
+  ;;
+compile|compil|compi|comp|com|co|c)
+  shift; set dummy --mode compile ${1+"$@"}; shift
+  ;;
+execute|execut|execu|exec|exe|ex|e)
+  shift; set dummy --mode execute ${1+"$@"}; shift
+  ;;
+finish|finis|fini|fin|fi|f)
+  shift; set dummy --mode finish ${1+"$@"}; shift
+  ;;
+install|instal|insta|inst|ins|in|i)
+  shift; set dummy --mode install ${1+"$@"}; shift
+  ;;
+link|lin|li|l)
+  shift; set dummy --mode link ${1+"$@"}; shift
+  ;;
+uninstall|uninstal|uninsta|uninst|unins|unin|uni|un|u)
+  shift; set dummy --mode uninstall ${1+"$@"}; shift
+  ;;
+esac
+
+
+
+# Option defaults:
+opt_debug=:
+opt_dry_run=false
+opt_config=false
+opt_preserve_dup_deps=false
+opt_features=false
+opt_finish=false
+opt_help=false
+opt_help_all=false
+opt_silent=:
+opt_warning=:
+opt_verbose=:
+opt_silent=false
+opt_verbose=false
+
+
+# Parse options once, thoroughly.  This comes as soon as possible in the
+# script to make things like `--version' happen as quickly as we can.
+{
+  # this just eases exit handling
+  while test $# -gt 0; do
+    opt="$1"
+    shift
+    case $opt in
+      --debug|-x)	opt_debug='set -x'
+			func_echo "enabling shell trace mode"
+			$opt_debug
+			;;
+      --dry-run|--dryrun|-n)
+			opt_dry_run=:
+			;;
+      --config)
+			opt_config=:
+func_config
+			;;
+      --dlopen|-dlopen)
+			optarg="$1"
+			opt_dlopen="${opt_dlopen+$opt_dlopen
+}$optarg"
+			shift
+			;;
+      --preserve-dup-deps)
+			opt_preserve_dup_deps=:
+			;;
+      --features)
+			opt_features=:
+func_features
+			;;
+      --finish)
+			opt_finish=:
+set dummy --mode finish ${1+"$@"}; shift
+			;;
+      --help)
+			opt_help=:
+			;;
+      --help-all)
+			opt_help_all=:
+opt_help=': help-all'
+			;;
+      --mode)
+			test $# = 0 && func_missing_arg $opt && break
+			optarg="$1"
+			opt_mode="$optarg"
+case $optarg in
+  # Valid mode arguments:
+  clean|compile|execute|finish|install|link|relink|uninstall) ;;
+
+  # Catch anything else as an error
+  *) func_error "invalid argument for $opt"
+     exit_cmd=exit
+     break
+     ;;
+esac
+			shift
+			;;
+      --no-silent|--no-quiet)
+			opt_silent=false
+func_append preserve_args " $opt"
+			;;
+      --no-warning|--no-warn)
+			opt_warning=false
+func_append preserve_args " $opt"
+			;;
+      --no-verbose)
+			opt_verbose=false
+func_append preserve_args " $opt"
+			;;
+      --silent|--quiet)
+			opt_silent=:
+func_append preserve_args " $opt"
+        opt_verbose=false
+			;;
+      --verbose|-v)
+			opt_verbose=:
+func_append preserve_args " $opt"
+opt_silent=false
+			;;
+      --tag)
+			test $# = 0 && func_missing_arg $opt && break
+			optarg="$1"
+			opt_tag="$optarg"
+func_append preserve_args " $opt $optarg"
+func_enable_tag "$optarg"
+			shift
+			;;
+
+      -\?|-h)		func_usage				;;
+      --help)		func_help				;;
+      --version)	func_version				;;
+
+      # Separate optargs to long options:
+      --*=*)
+			func_split_long_opt "$opt"
+			set dummy "$func_split_long_opt_name" "$func_split_long_opt_arg" ${1+"$@"}
+			shift
+			;;
+
+      # Separate non-argument short options:
+      -\?*|-h*|-n*|-v*)
+			func_split_short_opt "$opt"
+			set dummy "$func_split_short_opt_name" "-$func_split_short_opt_arg" ${1+"$@"}
+			shift
+			;;
+
+      --)		break					;;
+      -*)		func_fatal_help "unrecognized option \`$opt'" ;;
+      *)		set dummy "$opt" ${1+"$@"};	shift; break  ;;
+    esac
+  done
+
+  # Validate options:
+
+  # save first non-option argument
+  if test "$#" -gt 0; then
+    nonopt="$opt"
+    shift
+  fi
+
+  # preserve --debug
+  test "$opt_debug" = : || func_append preserve_args " --debug"
+
+  case $host in
+    *cygwin* | *mingw* | *pw32* | *cegcc*)
+      # don't eliminate duplications in $postdeps and $predeps
+      opt_duplicate_compiler_generated_deps=:
+      ;;
+    *)
+      opt_duplicate_compiler_generated_deps=$opt_preserve_dup_deps
+      ;;
+  esac
+
+  $opt_help || {
+    # Sanity checks first:
+    func_check_version_match
+
+    if test "$build_libtool_libs" != yes && test "$build_old_libs" != yes; then
+      func_fatal_configuration "not configured to build any kind of library"
+    fi
+
+    # Darwin sucks
+    eval std_shrext=\"$shrext_cmds\"
+
+    # Only execute mode is allowed to have -dlopen flags.
+    if test -n "$opt_dlopen" && test "$opt_mode" != execute; then
+      func_error "unrecognized option \`-dlopen'"
+      $ECHO "$help" 1>&2
+      exit $EXIT_FAILURE
+    fi
+
+    # Change the help message to a mode-specific one.
+    generic_help="$help"
+    help="Try \`$progname --help --mode=$opt_mode' for more information."
+  }
+
+
+  # Bail if the options were screwed
+  $exit_cmd $EXIT_FAILURE
+}
+
+
+
+
 ## ----------- ##
 ##    Main.    ##
 ## ----------- ##
 
-$opt_help || {
-  # Sanity checks first:
-  func_check_version_match
-
-  if test "$build_libtool_libs" != yes && test "$build_old_libs" != yes; then
-    func_fatal_configuration "not configured to build any kind of library"
-  fi
-
-  test -z "$mode" && func_fatal_error "error: you must specify a MODE."
-
-
-  # Darwin sucks
-  eval std_shrext=\"$shrext_cmds\"
-
-
-  # Only execute mode is allowed to have -dlopen flags.
-  if test -n "$execute_dlfiles" && test "$mode" != execute; then
-    func_error "unrecognized option \`-dlopen'"
-    $ECHO "$help" 1>&2
-    exit $EXIT_FAILURE
-  fi
-
-  # Change the help message to a mode-specific one.
-  generic_help="$help"
-  help="Try \`$progname --help --mode=$mode' for more information."
-}
-
-
 # func_lalib_p file
 # True iff FILE is a libtool `.la' library or `.lo' object file.
 # This function is only a basic sanity check; it will hardly flush out
@@ -950,12 +1287,9 @@
 # temporary ltwrapper_script.
 func_ltwrapper_scriptname ()
 {
-    func_ltwrapper_scriptname_result=""
-    if func_ltwrapper_executable_p "$1"; then
-	func_dirname_and_basename "$1" "" "."
-	func_stripname '' '.exe' "$func_basename_result"
-	func_ltwrapper_scriptname_result="$func_dirname_result/$objdir/${func_stripname_result}_ltshwrapper"
-    fi
+    func_dirname_and_basename "$1" "" "."
+    func_stripname '' '.exe' "$func_basename_result"
+    func_ltwrapper_scriptname_result="$func_dirname_result/$objdir/${func_stripname_result}_ltshwrapper"
 }
 
 # func_ltwrapper_p file
@@ -1001,6 +1335,37 @@
 }
 
 
+# func_resolve_sysroot PATH
+# Replace a leading = in PATH with a sysroot.  Store the result into
+# func_resolve_sysroot_result
+func_resolve_sysroot ()
+{
+  func_resolve_sysroot_result=$1
+  case $func_resolve_sysroot_result in
+  =*)
+    func_stripname '=' '' "$func_resolve_sysroot_result"
+    func_resolve_sysroot_result=$lt_sysroot$func_stripname_result
+    ;;
+  esac
+}
+
+# func_replace_sysroot PATH
+# If PATH begins with the sysroot, replace it with = and
+# store the result into func_replace_sysroot_result.
+func_replace_sysroot ()
+{
+  case "$lt_sysroot:$1" in
+  ?*:"$lt_sysroot"*)
+    func_stripname "$lt_sysroot" '' "$1"
+    func_replace_sysroot_result="=$func_stripname_result"
+    ;;
+  *)
+    # Including no sysroot.
+    func_replace_sysroot_result=$1
+    ;;
+  esac
+}
+
 # func_infer_tag arg
 # Infer tagged configuration to use if any are available and
 # if one wasn't chosen via the "--tag" command line option.
@@ -1013,13 +1378,15 @@
     if test -n "$available_tags" && test -z "$tagname"; then
       CC_quoted=
       for arg in $CC; do
-        func_quote_for_eval "$arg"
-	CC_quoted="$CC_quoted $func_quote_for_eval_result"
+	func_append_quoted CC_quoted "$arg"
       done
+      CC_expanded=`func_echo_all $CC`
+      CC_quoted_expanded=`func_echo_all $CC_quoted`
       case $@ in
       # Blanks in the command may have been stripped by the calling shell,
       # but not from the CC environment variable when configure was run.
-      " $CC "* | "$CC "* | " `$ECHO $CC` "* | "`$ECHO $CC` "* | " $CC_quoted"* | "$CC_quoted "* | " `$ECHO $CC_quoted` "* | "`$ECHO $CC_quoted` "*) ;;
+      " $CC "* | "$CC "* | " $CC_expanded "* | "$CC_expanded "* | \
+      " $CC_quoted"* | "$CC_quoted "* | " $CC_quoted_expanded "* | "$CC_quoted_expanded "*) ;;
       # Blanks at the start of $base_compile will cause this to fail
       # if we don't check for them as well.
       *)
@@ -1030,11 +1397,13 @@
 	    CC_quoted=
 	    for arg in $CC; do
 	      # Double-quote args containing other shell metacharacters.
-	      func_quote_for_eval "$arg"
-	      CC_quoted="$CC_quoted $func_quote_for_eval_result"
+	      func_append_quoted CC_quoted "$arg"
 	    done
+	    CC_expanded=`func_echo_all $CC`
+	    CC_quoted_expanded=`func_echo_all $CC_quoted`
 	    case "$@ " in
-	      " $CC "* | "$CC "* | " `$ECHO $CC` "* | "`$ECHO $CC` "* | " $CC_quoted"* | "$CC_quoted "* | " `$ECHO $CC_quoted` "* | "`$ECHO $CC_quoted` "*)
+	    " $CC "* | "$CC "* | " $CC_expanded "* | "$CC_expanded "* | \
+	    " $CC_quoted"* | "$CC_quoted "* | " $CC_quoted_expanded "* | "$CC_quoted_expanded "*)
 	      # The compiler in the base compile command matches
 	      # the one in the tagged configuration.
 	      # Assume this is the tagged configuration we want.
@@ -1097,6 +1466,486 @@
     }
 }
 
+
+##################################################
+# FILE NAME AND PATH CONVERSION HELPER FUNCTIONS #
+##################################################
+
+# func_convert_core_file_wine_to_w32 ARG
+# Helper function used by file name conversion functions when $build is *nix,
+# and $host is mingw, cygwin, or some other w32 environment. Relies on a
+# correctly configured wine environment available, with the winepath program
+# in $build's $PATH.
+#
+# ARG is the $build file name to be converted to w32 format.
+# Result is available in $func_convert_core_file_wine_to_w32_result, and will
+# be empty on error (or when ARG is empty)
+func_convert_core_file_wine_to_w32 ()
+{
+  $opt_debug
+  func_convert_core_file_wine_to_w32_result="$1"
+  if test -n "$1"; then
+    # Unfortunately, winepath does not exit with a non-zero error code, so we
+    # are forced to check the contents of stdout. On the other hand, if the
+    # command is not found, the shell will set an exit code of 127 and print
+    # *an error message* to stdout. So we must check for both error code of
+    # zero AND non-empty stdout, which explains the odd construction:
+    func_convert_core_file_wine_to_w32_tmp=`winepath -w "$1" 2>/dev/null`
+    if test "$?" -eq 0 && test -n "${func_convert_core_file_wine_to_w32_tmp}"; then
+      func_convert_core_file_wine_to_w32_result=`$ECHO "$func_convert_core_file_wine_to_w32_tmp" |
+        $SED -e "$lt_sed_naive_backslashify"`
+    else
+      func_convert_core_file_wine_to_w32_result=
+    fi
+  fi
+}
+# end: func_convert_core_file_wine_to_w32
+
+
+# func_convert_core_path_wine_to_w32 ARG
+# Helper function used by path conversion functions when $build is *nix, and
+# $host is mingw, cygwin, or some other w32 environment. Relies on a correctly
+# configured wine environment available, with the winepath program in $build's
+# $PATH. Assumes ARG has no leading or trailing path separator characters.
+#
+# ARG is path to be converted from $build format to win32.
+# Result is available in $func_convert_core_path_wine_to_w32_result.
+# Unconvertible file (directory) names in ARG are skipped; if no directory names
+# are convertible, then the result may be empty.
+func_convert_core_path_wine_to_w32 ()
+{
+  $opt_debug
+  # unfortunately, winepath doesn't convert paths, only file names
+  func_convert_core_path_wine_to_w32_result=""
+  if test -n "$1"; then
+    oldIFS=$IFS
+    IFS=:
+    for func_convert_core_path_wine_to_w32_f in $1; do
+      IFS=$oldIFS
+      func_convert_core_file_wine_to_w32 "$func_convert_core_path_wine_to_w32_f"
+      if test -n "$func_convert_core_file_wine_to_w32_result" ; then
+        if test -z "$func_convert_core_path_wine_to_w32_result"; then
+          func_convert_core_path_wine_to_w32_result="$func_convert_core_file_wine_to_w32_result"
+        else
+          func_append func_convert_core_path_wine_to_w32_result ";$func_convert_core_file_wine_to_w32_result"
+        fi
+      fi
+    done
+    IFS=$oldIFS
+  fi
+}
+# end: func_convert_core_path_wine_to_w32
+
+
+# func_cygpath ARGS...
+# Wrapper around calling the cygpath program via LT_CYGPATH. This is used when
+# when (1) $build is *nix and Cygwin is hosted via a wine environment; or (2)
+# $build is MSYS and $host is Cygwin, or (3) $build is Cygwin. In case (1) or
+# (2), returns the Cygwin file name or path in func_cygpath_result (input
+# file name or path is assumed to be in w32 format, as previously converted
+# from $build's *nix or MSYS format). In case (3), returns the w32 file name
+# or path in func_cygpath_result (input file name or path is assumed to be in
+# Cygwin format). Returns an empty string on error.
+#
+# ARGS are passed to cygpath, with the last one being the file name or path to
+# be converted.
+#
+# Specify the absolute *nix (or w32) name to cygpath in the LT_CYGPATH
+# environment variable; do not put it in $PATH.
+func_cygpath ()
+{
+  $opt_debug
+  if test -n "$LT_CYGPATH" && test -f "$LT_CYGPATH"; then
+    func_cygpath_result=`$LT_CYGPATH "$@" 2>/dev/null`
+    if test "$?" -ne 0; then
+      # on failure, ensure result is empty
+      func_cygpath_result=
+    fi
+  else
+    func_cygpath_result=
+    func_error "LT_CYGPATH is empty or specifies non-existent file: \`$LT_CYGPATH'"
+  fi
+}
+#end: func_cygpath
+
+
+# func_convert_core_msys_to_w32 ARG
+# Convert file name or path ARG from MSYS format to w32 format.  Return
+# result in func_convert_core_msys_to_w32_result.
+func_convert_core_msys_to_w32 ()
+{
+  $opt_debug
+  # awkward: cmd appends spaces to result
+  func_convert_core_msys_to_w32_result=`( cmd //c echo "$1" ) 2>/dev/null |
+    $SED -e 's/[ ]*$//' -e "$lt_sed_naive_backslashify"`
+}
+#end: func_convert_core_msys_to_w32
+
+
+# func_convert_file_check ARG1 ARG2
+# Verify that ARG1 (a file name in $build format) was converted to $host
+# format in ARG2. Otherwise, emit an error message, but continue (resetting
+# func_to_host_file_result to ARG1).
+func_convert_file_check ()
+{
+  $opt_debug
+  if test -z "$2" && test -n "$1" ; then
+    func_error "Could not determine host file name corresponding to"
+    func_error "  \`$1'"
+    func_error "Continuing, but uninstalled executables may not work."
+    # Fallback:
+    func_to_host_file_result="$1"
+  fi
+}
+# end func_convert_file_check
+
+
+# func_convert_path_check FROM_PATHSEP TO_PATHSEP FROM_PATH TO_PATH
+# Verify that FROM_PATH (a path in $build format) was converted to $host
+# format in TO_PATH. Otherwise, emit an error message, but continue, resetting
+# func_to_host_file_result to a simplistic fallback value (see below).
+func_convert_path_check ()
+{
+  $opt_debug
+  if test -z "$4" && test -n "$3"; then
+    func_error "Could not determine the host path corresponding to"
+    func_error "  \`$3'"
+    func_error "Continuing, but uninstalled executables may not work."
+    # Fallback.  This is a deliberately simplistic "conversion" and
+    # should not be "improved".  See libtool.info.
+    if test "x$1" != "x$2"; then
+      lt_replace_pathsep_chars="s|$1|$2|g"
+      func_to_host_path_result=`echo "$3" |
+        $SED -e "$lt_replace_pathsep_chars"`
+    else
+      func_to_host_path_result="$3"
+    fi
+  fi
+}
+# end func_convert_path_check
+
+
+# func_convert_path_front_back_pathsep FRONTPAT BACKPAT REPL ORIG
+# Modifies func_to_host_path_result by prepending REPL if ORIG matches FRONTPAT
+# and appending REPL if ORIG matches BACKPAT.
+func_convert_path_front_back_pathsep ()
+{
+  $opt_debug
+  case $4 in
+  $1 ) func_to_host_path_result="$3$func_to_host_path_result"
+    ;;
+  esac
+  case $4 in
+  $2 ) func_append func_to_host_path_result "$3"
+    ;;
+  esac
+}
+# end func_convert_path_front_back_pathsep
+
+
+##################################################
+# $build to $host FILE NAME CONVERSION FUNCTIONS #
+##################################################
+# invoked via `$to_host_file_cmd ARG'
+#
+# In each case, ARG is the path to be converted from $build to $host format.
+# Result will be available in $func_to_host_file_result.
+
+
+# func_to_host_file ARG
+# Converts the file name ARG from $build format to $host format. Return result
+# in func_to_host_file_result.
+func_to_host_file ()
+{
+  $opt_debug
+  $to_host_file_cmd "$1"
+}
+# end func_to_host_file
+
+
+# func_to_tool_file ARG LAZY
+# converts the file name ARG from $build format to toolchain format. Return
+# result in func_to_tool_file_result.  If the conversion in use is listed
+# in (the comma separated) LAZY, no conversion takes place.
+func_to_tool_file ()
+{
+  $opt_debug
+  case ,$2, in
+    *,"$to_tool_file_cmd",*)
+      func_to_tool_file_result=$1
+      ;;
+    *)
+      $to_tool_file_cmd "$1"
+      func_to_tool_file_result=$func_to_host_file_result
+      ;;
+  esac
+}
+# end func_to_tool_file
+
+
+# func_convert_file_noop ARG
+# Copy ARG to func_to_host_file_result.
+func_convert_file_noop ()
+{
+  func_to_host_file_result="$1"
+}
+# end func_convert_file_noop
+
+
+# func_convert_file_msys_to_w32 ARG
+# Convert file name ARG from (mingw) MSYS to (mingw) w32 format; automatic
+# conversion to w32 is not available inside the cwrapper.  Returns result in
+# func_to_host_file_result.
+func_convert_file_msys_to_w32 ()
+{
+  $opt_debug
+  func_to_host_file_result="$1"
+  if test -n "$1"; then
+    func_convert_core_msys_to_w32 "$1"
+    func_to_host_file_result="$func_convert_core_msys_to_w32_result"
+  fi
+  func_convert_file_check "$1" "$func_to_host_file_result"
+}
+# end func_convert_file_msys_to_w32
+
+
+# func_convert_file_cygwin_to_w32 ARG
+# Convert file name ARG from Cygwin to w32 format.  Returns result in
+# func_to_host_file_result.
+func_convert_file_cygwin_to_w32 ()
+{
+  $opt_debug
+  func_to_host_file_result="$1"
+  if test -n "$1"; then
+    # because $build is cygwin, we call "the" cygpath in $PATH; no need to use
+    # LT_CYGPATH in this case.
+    func_to_host_file_result=`cygpath -m "$1"`
+  fi
+  func_convert_file_check "$1" "$func_to_host_file_result"
+}
+# end func_convert_file_cygwin_to_w32
+
+
+# func_convert_file_nix_to_w32 ARG
+# Convert file name ARG from *nix to w32 format.  Requires a wine environment
+# and a working winepath. Returns result in func_to_host_file_result.
+func_convert_file_nix_to_w32 ()
+{
+  $opt_debug
+  func_to_host_file_result="$1"
+  if test -n "$1"; then
+    func_convert_core_file_wine_to_w32 "$1"
+    func_to_host_file_result="$func_convert_core_file_wine_to_w32_result"
+  fi
+  func_convert_file_check "$1" "$func_to_host_file_result"
+}
+# end func_convert_file_nix_to_w32
+
+
+# func_convert_file_msys_to_cygwin ARG
+# Convert file name ARG from MSYS to Cygwin format.  Requires LT_CYGPATH set.
+# Returns result in func_to_host_file_result.
+func_convert_file_msys_to_cygwin ()
+{
+  $opt_debug
+  func_to_host_file_result="$1"
+  if test -n "$1"; then
+    func_convert_core_msys_to_w32 "$1"
+    func_cygpath -u "$func_convert_core_msys_to_w32_result"
+    func_to_host_file_result="$func_cygpath_result"
+  fi
+  func_convert_file_check "$1" "$func_to_host_file_result"
+}
+# end func_convert_file_msys_to_cygwin
+
+
+# func_convert_file_nix_to_cygwin ARG
+# Convert file name ARG from *nix to Cygwin format.  Requires Cygwin installed
+# in a wine environment, working winepath, and LT_CYGPATH set.  Returns result
+# in func_to_host_file_result.
+func_convert_file_nix_to_cygwin ()
+{
+  $opt_debug
+  func_to_host_file_result="$1"
+  if test -n "$1"; then
+    # convert from *nix to w32, then use cygpath to convert from w32 to cygwin.
+    func_convert_core_file_wine_to_w32 "$1"
+    func_cygpath -u "$func_convert_core_file_wine_to_w32_result"
+    func_to_host_file_result="$func_cygpath_result"
+  fi
+  func_convert_file_check "$1" "$func_to_host_file_result"
+}
+# end func_convert_file_nix_to_cygwin
+
+
+#############################################
+# $build to $host PATH CONVERSION FUNCTIONS #
+#############################################
+# invoked via `$to_host_path_cmd ARG'
+#
+# In each case, ARG is the path to be converted from $build to $host format.
+# The result will be available in $func_to_host_path_result.
+#
+# Path separators are also converted from $build format to $host format.  If
+# ARG begins or ends with a path separator character, it is preserved (but
+# converted to $host format) on output.
+#
+# All path conversion functions are named using the following convention:
+#   file name conversion function    : func_convert_file_X_to_Y ()
+#   path conversion function         : func_convert_path_X_to_Y ()
+# where, for any given $build/$host combination the 'X_to_Y' value is the
+# same.  If conversion functions are added for new $build/$host combinations,
+# the two new functions must follow this pattern, or func_init_to_host_path_cmd
+# will break.
+
+
+# func_init_to_host_path_cmd
+# Ensures that function "pointer" variable $to_host_path_cmd is set to the
+# appropriate value, based on the value of $to_host_file_cmd.
+to_host_path_cmd=
+func_init_to_host_path_cmd ()
+{
+  $opt_debug
+  if test -z "$to_host_path_cmd"; then
+    func_stripname 'func_convert_file_' '' "$to_host_file_cmd"
+    to_host_path_cmd="func_convert_path_${func_stripname_result}"
+  fi
+}
+
+
+# func_to_host_path ARG
+# Converts the path ARG from $build format to $host format. Return result
+# in func_to_host_path_result.
+func_to_host_path ()
+{
+  $opt_debug
+  func_init_to_host_path_cmd
+  $to_host_path_cmd "$1"
+}
+# end func_to_host_path
+
+
+# func_convert_path_noop ARG
+# Copy ARG to func_to_host_path_result.
+func_convert_path_noop ()
+{
+  func_to_host_path_result="$1"
+}
+# end func_convert_path_noop
+
+
+# func_convert_path_msys_to_w32 ARG
+# Convert path ARG from (mingw) MSYS to (mingw) w32 format; automatic
+# conversion to w32 is not available inside the cwrapper.  Returns result in
+# func_to_host_path_result.
+func_convert_path_msys_to_w32 ()
+{
+  $opt_debug
+  func_to_host_path_result="$1"
+  if test -n "$1"; then
+    # Remove leading and trailing path separator characters from ARG.  MSYS
+    # behavior is inconsistent here; cygpath turns them into '.;' and ';.';
+    # and winepath ignores them completely.
+    func_stripname : : "$1"
+    func_to_host_path_tmp1=$func_stripname_result
+    func_convert_core_msys_to_w32 "$func_to_host_path_tmp1"
+    func_to_host_path_result="$func_convert_core_msys_to_w32_result"
+    func_convert_path_check : ";" \
+      "$func_to_host_path_tmp1" "$func_to_host_path_result"
+    func_convert_path_front_back_pathsep ":*" "*:" ";" "$1"
+  fi
+}
+# end func_convert_path_msys_to_w32
+
+
+# func_convert_path_cygwin_to_w32 ARG
+# Convert path ARG from Cygwin to w32 format.  Returns result in
+# func_to_host_file_result.
+func_convert_path_cygwin_to_w32 ()
+{
+  $opt_debug
+  func_to_host_path_result="$1"
+  if test -n "$1"; then
+    # See func_convert_path_msys_to_w32:
+    func_stripname : : "$1"
+    func_to_host_path_tmp1=$func_stripname_result
+    func_to_host_path_result=`cygpath -m -p "$func_to_host_path_tmp1"`
+    func_convert_path_check : ";" \
+      "$func_to_host_path_tmp1" "$func_to_host_path_result"
+    func_convert_path_front_back_pathsep ":*" "*:" ";" "$1"
+  fi
+}
+# end func_convert_path_cygwin_to_w32
+
+
+# func_convert_path_nix_to_w32 ARG
+# Convert path ARG from *nix to w32 format.  Requires a wine environment and
+# a working winepath.  Returns result in func_to_host_file_result.
+func_convert_path_nix_to_w32 ()
+{
+  $opt_debug
+  func_to_host_path_result="$1"
+  if test -n "$1"; then
+    # See func_convert_path_msys_to_w32:
+    func_stripname : : "$1"
+    func_to_host_path_tmp1=$func_stripname_result
+    func_convert_core_path_wine_to_w32 "$func_to_host_path_tmp1"
+    func_to_host_path_result="$func_convert_core_path_wine_to_w32_result"
+    func_convert_path_check : ";" \
+      "$func_to_host_path_tmp1" "$func_to_host_path_result"
+    func_convert_path_front_back_pathsep ":*" "*:" ";" "$1"
+  fi
+}
+# end func_convert_path_nix_to_w32
+
+
+# func_convert_path_msys_to_cygwin ARG
+# Convert path ARG from MSYS to Cygwin format.  Requires LT_CYGPATH set.
+# Returns result in func_to_host_file_result.
+func_convert_path_msys_to_cygwin ()
+{
+  $opt_debug
+  func_to_host_path_result="$1"
+  if test -n "$1"; then
+    # See func_convert_path_msys_to_w32:
+    func_stripname : : "$1"
+    func_to_host_path_tmp1=$func_stripname_result
+    func_convert_core_msys_to_w32 "$func_to_host_path_tmp1"
+    func_cygpath -u -p "$func_convert_core_msys_to_w32_result"
+    func_to_host_path_result="$func_cygpath_result"
+    func_convert_path_check : : \
+      "$func_to_host_path_tmp1" "$func_to_host_path_result"
+    func_convert_path_front_back_pathsep ":*" "*:" : "$1"
+  fi
+}
+# end func_convert_path_msys_to_cygwin
+
+
+# func_convert_path_nix_to_cygwin ARG
+# Convert path ARG from *nix to Cygwin format.  Requires Cygwin installed in a
+# a wine environment, working winepath, and LT_CYGPATH set.  Returns result in
+# func_to_host_file_result.
+func_convert_path_nix_to_cygwin ()
+{
+  $opt_debug
+  func_to_host_path_result="$1"
+  if test -n "$1"; then
+    # Remove leading and trailing path separator characters from
+    # ARG. msys behavior is inconsistent here, cygpath turns them
+    # into '.;' and ';.', and winepath ignores them completely.
+    func_stripname : : "$1"
+    func_to_host_path_tmp1=$func_stripname_result
+    func_convert_core_path_wine_to_w32 "$func_to_host_path_tmp1"
+    func_cygpath -u -p "$func_convert_core_path_wine_to_w32_result"
+    func_to_host_path_result="$func_cygpath_result"
+    func_convert_path_check : : \
+      "$func_to_host_path_tmp1" "$func_to_host_path_result"
+    func_convert_path_front_back_pathsep ":*" "*:" : "$1"
+  fi
+}
+# end func_convert_path_nix_to_cygwin
+
+
 # func_mode_compile arg...
 func_mode_compile ()
 {
@@ -1137,12 +1986,12 @@
 	  ;;
 
 	-pie | -fpie | -fPIE)
-          pie_flag="$pie_flag $arg"
+          func_append pie_flag " $arg"
 	  continue
 	  ;;
 
 	-shared | -static | -prefer-pic | -prefer-non-pic)
-	  later="$later $arg"
+	  func_append later " $arg"
 	  continue
 	  ;;
 
@@ -1163,15 +2012,14 @@
 	  save_ifs="$IFS"; IFS=','
 	  for arg in $args; do
 	    IFS="$save_ifs"
-	    func_quote_for_eval "$arg"
-	    lastarg="$lastarg $func_quote_for_eval_result"
+	    func_append_quoted lastarg "$arg"
 	  done
 	  IFS="$save_ifs"
 	  func_stripname ' ' '' "$lastarg"
 	  lastarg=$func_stripname_result
 
 	  # Add the arguments to base_compile.
-	  base_compile="$base_compile $lastarg"
+	  func_append base_compile " $lastarg"
 	  continue
 	  ;;
 
@@ -1187,8 +2035,7 @@
       esac    #  case $arg_mode
 
       # Aesthetically quote the previous argument.
-      func_quote_for_eval "$lastarg"
-      base_compile="$base_compile $func_quote_for_eval_result"
+      func_append_quoted base_compile "$lastarg"
     done # for arg
 
     case $arg_mode in
@@ -1213,7 +2060,7 @@
     *.[cCFSifmso] | \
     *.ada | *.adb | *.ads | *.asm | \
     *.c++ | *.cc | *.ii | *.class | *.cpp | *.cxx | \
-    *.[fF][09]? | *.for | *.java | *.obj | *.sx)
+    *.[fF][09]? | *.for | *.java | *.go | *.obj | *.sx | *.cu | *.cup)
       func_xform "$libobj"
       libobj=$func_xform_result
       ;;
@@ -1288,7 +2135,7 @@
     # Calculate the filename of the output object if compiler does
     # not support -o with -c
     if test "$compiler_c_o" = no; then
-      output_obj=`$ECHO "X$srcfile" | $Xsed -e 's%^.*/%%' -e 's%\.[^.]*$%%'`.${objext}
+      output_obj=`$ECHO "$srcfile" | $SED 's%^.*/%%; s%\.[^.]*$%%'`.${objext}
       lockfile="$output_obj.lock"
     else
       output_obj=
@@ -1319,17 +2166,16 @@
 	$opt_dry_run || $RM $removelist
 	exit $EXIT_FAILURE
       fi
-      removelist="$removelist $output_obj"
+      func_append removelist " $output_obj"
       $ECHO "$srcfile" > "$lockfile"
     fi
 
     $opt_dry_run || $RM $removelist
-    removelist="$removelist $lockfile"
+    func_append removelist " $lockfile"
     trap '$opt_dry_run || $RM $removelist; exit $EXIT_FAILURE' 1 2 15
 
-    if test -n "$fix_srcfile_path"; then
-      eval srcfile=\"$fix_srcfile_path\"
-    fi
+    func_to_tool_file "$srcfile" func_convert_file_msys_to_w32
+    srcfile=$func_to_tool_file_result
     func_quote_for_eval "$srcfile"
     qsrcfile=$func_quote_for_eval_result
 
@@ -1349,7 +2195,7 @@
 
       if test -z "$output_obj"; then
 	# Place PIC objects in $objdir
-	command="$command -o $lobj"
+	func_append command " -o $lobj"
       fi
 
       func_show_eval_locale "$command"	\
@@ -1396,11 +2242,11 @@
 	command="$base_compile $qsrcfile $pic_flag"
       fi
       if test "$compiler_c_o" = yes; then
-	command="$command -o $obj"
+	func_append command " -o $obj"
       fi
 
       # Suppress compiler output if we already did a PIC compilation.
-      command="$command$suppress_output"
+      func_append command "$suppress_output"
       func_show_eval_locale "$command" \
         '$opt_dry_run || $RM $removelist; exit $EXIT_FAILURE'
 
@@ -1445,13 +2291,13 @@
 }
 
 $opt_help || {
-test "$mode" = compile && func_mode_compile ${1+"$@"}
+  test "$opt_mode" = compile && func_mode_compile ${1+"$@"}
 }
 
 func_mode_help ()
 {
     # We need to display help for each of the modes.
-    case $mode in
+    case $opt_mode in
       "")
         # Generic help is extracted from the usage comments
         # at the start of this file.
@@ -1482,10 +2328,11 @@
 
   -o OUTPUT-FILE    set the output file name to OUTPUT-FILE
   -no-suppress      do not suppress compiler output for multiple passes
-  -prefer-pic       try to building PIC objects only
-  -prefer-non-pic   try to building non-PIC objects only
+  -prefer-pic       try to build PIC objects only
+  -prefer-non-pic   try to build non-PIC objects only
   -shared           do not build a \`.o' file suitable for static linking
   -static           only build a \`.o' file suitable for static linking
+  -Wc,FLAG          pass FLAG directly to the compiler
 
 COMPILE-COMMAND is a command to be used in creating a \`standard' object file
 from the given SOURCEFILE.
@@ -1538,7 +2385,7 @@
 
 The following components of INSTALL-COMMAND are treated specially:
 
-  -inst-prefix PREFIX-DIR  Use PREFIX-DIR as a staging area for installation
+  -inst-prefix-dir PREFIX-DIR  Use PREFIX-DIR as a staging area for installation
 
 The rest of the components are interpreted as arguments to that command (only
 BSD-compatible install options are recognized)."
@@ -1558,6 +2405,8 @@
 
   -all-static       do not do any dynamic linking at all
   -avoid-version    do not add a version suffix if possible
+  -bindir BINDIR    specify path to binaries directory (for systems where
+                    libraries must be found in the PATH setting at runtime)
   -dlopen FILE      \`-dlpreopen' FILE if it cannot be dlopened at runtime
   -dlpreopen FILE   link in FILE and add its symbols to lt_preloaded_symbols
   -export-dynamic   allow symbols from OUTPUT-FILE to be resolved with dlsym(3)
@@ -1586,6 +2435,11 @@
   -version-info CURRENT[:REVISION[:AGE]]
                     specify library version info [each variable defaults to 0]
   -weak LIBNAME     declare that the target provides the LIBNAME interface
+  -Wc,FLAG
+  -Xcompiler FLAG   pass linker-specific FLAG directly to the compiler
+  -Wl,FLAG
+  -Xlinker FLAG     pass linker-specific FLAG directly to the linker
+  -XCClinker FLAG   pass link-specific FLAG to the compiler driver (CC)
 
 All other options (arguments beginning with \`-') are ignored.
 
@@ -1619,18 +2473,44 @@
         ;;
 
       *)
-        func_fatal_help "invalid operation mode \`$mode'"
+        func_fatal_help "invalid operation mode \`$opt_mode'"
         ;;
     esac
 
-    $ECHO
+    echo
     $ECHO "Try \`$progname --help' for more information about other modes."
-
-    exit $?
 }
 
-  # Now that we've collected a possible --mode arg, show help if necessary
-  $opt_help && func_mode_help
+# Now that we've collected a possible --mode arg, show help if necessary
+if $opt_help; then
+  if test "$opt_help" = :; then
+    func_mode_help
+  else
+    {
+      func_help noexit
+      for opt_mode in compile link execute install finish uninstall clean; do
+	func_mode_help
+      done
+    } | sed -n '1p; 2,$s/^Usage:/  or: /p'
+    {
+      func_help noexit
+      for opt_mode in compile link execute install finish uninstall clean; do
+	echo
+	func_mode_help
+      done
+    } |
+    sed '1d
+      /^When reporting/,/^Report/{
+	H
+	d
+      }
+      $x
+      /information about other modes/d
+      /more detailed .*MODE/d
+      s/^Usage:.*--mode=\([^ ]*\) .*/Description of \1 mode:/'
+  fi
+  exit $?
+fi
 
 
 # func_mode_execute arg...
@@ -1643,13 +2523,16 @@
       func_fatal_help "you must specify a COMMAND"
 
     # Handle -dlopen flags immediately.
-    for file in $execute_dlfiles; do
+    for file in $opt_dlopen; do
       test -f "$file" \
 	|| func_fatal_help "\`$file' is not a file"
 
       dir=
       case $file in
       *.la)
+	func_resolve_sysroot "$file"
+	file=$func_resolve_sysroot_result
+
 	# Check to see that this really is a libtool archive.
 	func_lalib_unsafe_p "$file" \
 	  || func_fatal_help "\`$lib' is not a valid libtool archive"
@@ -1671,7 +2554,7 @@
 	dir="$func_dirname_result"
 
 	if test -f "$dir/$objdir/$dlname"; then
-	  dir="$dir/$objdir"
+	  func_append dir "/$objdir"
 	else
 	  if test ! -f "$dir/$dlname"; then
 	    func_fatal_error "cannot find \`$dlname' in \`$dir' or \`$dir/$objdir'"
@@ -1712,7 +2595,7 @@
     for file
     do
       case $file in
-      -*) ;;
+      -* | *.la | *.lo ) ;;
       *)
 	# Do a test to see if this is really a libtool program.
 	if func_ltwrapper_script_p "$file"; then
@@ -1728,8 +2611,7 @@
 	;;
       esac
       # Quote arguments (to preserve shell metacharacters).
-      func_quote_for_eval "$file"
-      args="$args $func_quote_for_eval_result"
+      func_append_quoted args "$file"
     done
 
     if test "X$opt_dry_run" = Xfalse; then
@@ -1754,29 +2636,66 @@
       # Display what would be done.
       if test -n "$shlibpath_var"; then
 	eval "\$ECHO \"\$shlibpath_var=\$$shlibpath_var\""
-	$ECHO "export $shlibpath_var"
+	echo "export $shlibpath_var"
       fi
       $ECHO "$cmd$args"
       exit $EXIT_SUCCESS
     fi
 }
 
-test "$mode" = execute && func_mode_execute ${1+"$@"}
+test "$opt_mode" = execute && func_mode_execute ${1+"$@"}
 
 
 # func_mode_finish arg...
 func_mode_finish ()
 {
     $opt_debug
-    libdirs="$nonopt"
+    libs=
+    libdirs=
     admincmds=
 
+    for opt in "$nonopt" ${1+"$@"}
+    do
+      if test -d "$opt"; then
+	func_append libdirs " $opt"
+
+      elif test -f "$opt"; then
+	if func_lalib_unsafe_p "$opt"; then
+	  func_append libs " $opt"
+	else
+	  func_warning "\`$opt' is not a valid libtool archive"
+	fi
+
+      else
+	func_fatal_error "invalid argument \`$opt'"
+      fi
+    done
+
+    if test -n "$libs"; then
+      if test -n "$lt_sysroot"; then
+        sysroot_regex=`$ECHO "$lt_sysroot" | $SED "$sed_make_literal_regex"`
+        sysroot_cmd="s/\([ ']\)$sysroot_regex/\1/g;"
+      else
+        sysroot_cmd=
+      fi
+
+      # Remove sysroot references
+      if $opt_dry_run; then
+        for lib in $libs; do
+          echo "removing references to $lt_sysroot and \`=' prefixes from $lib"
+        done
+      else
+        tmpdir=`func_mktempdir`
+        for lib in $libs; do
+	  sed -e "${sysroot_cmd} s/\([ ']-[LR]\)=/\1/g; s/\([ ']\)=/\1/g" $lib \
+	    > $tmpdir/tmp-la
+	  mv -f $tmpdir/tmp-la $lib
+	done
+        ${RM}r "$tmpdir"
+      fi
+    fi
+
     if test -n "$finish_cmds$finish_eval" && test -n "$libdirs"; then
-      for dir
-      do
-	libdirs="$libdirs $dir"
-      done
-
       for libdir in $libdirs; do
 	if test -n "$finish_cmds"; then
 	  # Do each command in the finish commands.
@@ -1786,7 +2705,7 @@
 	if test -n "$finish_eval"; then
 	  # Do the single finish_eval.
 	  eval cmds=\"$finish_eval\"
-	  $opt_dry_run || eval "$cmds" || admincmds="$admincmds
+	  $opt_dry_run || eval "$cmds" || func_append admincmds "
        $cmds"
 	fi
       done
@@ -1795,53 +2714,55 @@
     # Exit here if they wanted silent mode.
     $opt_silent && exit $EXIT_SUCCESS
 
-    $ECHO "X----------------------------------------------------------------------" | $Xsed
-    $ECHO "Libraries have been installed in:"
-    for libdir in $libdirs; do
-      $ECHO "   $libdir"
-    done
-    $ECHO
-    $ECHO "If you ever happen to want to link against installed libraries"
-    $ECHO "in a given directory, LIBDIR, you must either use libtool, and"
-    $ECHO "specify the full pathname of the library, or use the \`-LLIBDIR'"
-    $ECHO "flag during linking and do at least one of the following:"
-    if test -n "$shlibpath_var"; then
-      $ECHO "   - add LIBDIR to the \`$shlibpath_var' environment variable"
-      $ECHO "     during execution"
-    fi
-    if test -n "$runpath_var"; then
-      $ECHO "   - add LIBDIR to the \`$runpath_var' environment variable"
-      $ECHO "     during linking"
-    fi
-    if test -n "$hardcode_libdir_flag_spec"; then
-      libdir=LIBDIR
-      eval flag=\"$hardcode_libdir_flag_spec\"
-
-      $ECHO "   - use the \`$flag' linker flag"
-    fi
-    if test -n "$admincmds"; then
-      $ECHO "   - have your system administrator run these commands:$admincmds"
-    fi
-    if test -f /etc/ld.so.conf; then
-      $ECHO "   - have your system administrator add LIBDIR to \`/etc/ld.so.conf'"
-    fi
-    $ECHO
-
-    $ECHO "See any operating system documentation about shared libraries for"
-    case $host in
-      solaris2.[6789]|solaris2.1[0-9])
-        $ECHO "more information, such as the ld(1), crle(1) and ld.so(8) manual"
-	$ECHO "pages."
-	;;
-      *)
-        $ECHO "more information, such as the ld(1) and ld.so(8) manual pages."
-        ;;
-    esac
-    $ECHO "X----------------------------------------------------------------------" | $Xsed
+    if test -n "$finish_cmds$finish_eval" && test -n "$libdirs"; then
+      echo "----------------------------------------------------------------------"
+      echo "Libraries have been installed in:"
+      for libdir in $libdirs; do
+	$ECHO "   $libdir"
+      done
+      echo
+      echo "If you ever happen to want to link against installed libraries"
+      echo "in a given directory, LIBDIR, you must either use libtool, and"
+      echo "specify the full pathname of the library, or use the \`-LLIBDIR'"
+      echo "flag during linking and do at least one of the following:"
+      if test -n "$shlibpath_var"; then
+	echo "   - add LIBDIR to the \`$shlibpath_var' environment variable"
+	echo "     during execution"
+      fi
+      if test -n "$runpath_var"; then
+	echo "   - add LIBDIR to the \`$runpath_var' environment variable"
+	echo "     during linking"
+      fi
+      if test -n "$hardcode_libdir_flag_spec"; then
+	libdir=LIBDIR
+	eval flag=\"$hardcode_libdir_flag_spec\"
+
+	$ECHO "   - use the \`$flag' linker flag"
+      fi
+      if test -n "$admincmds"; then
+	$ECHO "   - have your system administrator run these commands:$admincmds"
+      fi
+      if test -f /etc/ld.so.conf; then
+	echo "   - have your system administrator add LIBDIR to \`/etc/ld.so.conf'"
+      fi
+      echo
+
+      echo "See any operating system documentation about shared libraries for"
+      case $host in
+	solaris2.[6789]|solaris2.1[0-9])
+	  echo "more information, such as the ld(1), crle(1) and ld.so(8) manual"
+	  echo "pages."
+	  ;;
+	*)
+	  echo "more information, such as the ld(1) and ld.so(8) manual pages."
+	  ;;
+      esac
+      echo "----------------------------------------------------------------------"
+    fi
     exit $EXIT_SUCCESS
 }
 
-test "$mode" = finish && func_mode_finish ${1+"$@"}
+test "$opt_mode" = finish && func_mode_finish ${1+"$@"}
 
 
 # func_mode_install arg...
@@ -1852,7 +2773,7 @@
     # install_prog (especially on Windows NT).
     if test "$nonopt" = "$SHELL" || test "$nonopt" = /bin/sh ||
        # Allow the use of GNU shtool's install command.
-       $ECHO "X$nonopt" | $GREP shtool >/dev/null; then
+       case $nonopt in *shtool*) :;; *) false;; esac; then
       # Aesthetically quote it.
       func_quote_for_eval "$nonopt"
       install_prog="$func_quote_for_eval_result "
@@ -1866,7 +2787,12 @@
     # The real first argument should be the name of the installation program.
     # Aesthetically quote it.
     func_quote_for_eval "$arg"
-    install_prog="$install_prog$func_quote_for_eval_result"
+    func_append install_prog "$func_quote_for_eval_result"
+    install_shared_prog=$install_prog
+    case " $install_prog " in
+      *[\\\ /]cp\ *) install_cp=: ;;
+      *) install_cp=false ;;
+    esac
 
     # We need to accept at least all the BSD install flags.
     dest=
@@ -1876,10 +2802,12 @@
     install_type=
     isdir=no
     stripme=
+    no_mode=:
     for arg
     do
+      arg2=
       if test -n "$dest"; then
-	files="$files $dest"
+	func_append files " $dest"
 	dest=$arg
 	continue
       fi
@@ -1887,10 +2815,9 @@
       case $arg in
       -d) isdir=yes ;;
       -f)
-	case " $install_prog " in
-	*[\\\ /]cp\ *) ;;
-	*) prev=$arg ;;
-	esac
+	if $install_cp; then :; else
+	  prev=$arg
+	fi
 	;;
       -g | -m | -o)
 	prev=$arg
@@ -1904,6 +2831,10 @@
       *)
 	# If the previous option needed an argument, then skip it.
 	if test -n "$prev"; then
+	  if test "x$prev" = x-m && test -n "$install_override_mode"; then
+	    arg2=$install_override_mode
+	    no_mode=false
+	  fi
 	  prev=
 	else
 	  dest=$arg
@@ -1914,7 +2845,11 @@
 
       # Aesthetically quote the argument.
       func_quote_for_eval "$arg"
-      install_prog="$install_prog $func_quote_for_eval_result"
+      func_append install_prog " $func_quote_for_eval_result"
+      if test -n "$arg2"; then
+	func_quote_for_eval "$arg2"
+      fi
+      func_append install_shared_prog " $func_quote_for_eval_result"
     done
 
     test -z "$install_prog" && \
@@ -1923,6 +2858,13 @@
     test -n "$prev" && \
       func_fatal_help "the \`$prev' option requires an argument"
 
+    if test -n "$install_override_mode" && $no_mode; then
+      if $install_cp; then :; else
+	func_quote_for_eval "$install_override_mode"
+	func_append install_shared_prog " -m $func_quote_for_eval_result"
+      fi
+    fi
+
     if test -z "$files"; then
       if test -z "$dest"; then
 	func_fatal_help "no file or destination specified"
@@ -1977,10 +2919,13 @@
       case $file in
       *.$libext)
 	# Do the static libraries later.
-	staticlibs="$staticlibs $file"
+	func_append staticlibs " $file"
 	;;
 
       *.la)
+	func_resolve_sysroot "$file"
+	file=$func_resolve_sysroot_result
+
 	# Check to see that this really is a libtool archive.
 	func_lalib_unsafe_p "$file" \
 	  || func_fatal_help "\`$file' is not a valid libtool archive"
@@ -1994,23 +2939,23 @@
 	if test "X$destdir" = "X$libdir"; then
 	  case "$current_libdirs " in
 	  *" $libdir "*) ;;
-	  *) current_libdirs="$current_libdirs $libdir" ;;
+	  *) func_append current_libdirs " $libdir" ;;
 	  esac
 	else
 	  # Note the libdir as a future libdir.
 	  case "$future_libdirs " in
 	  *" $libdir "*) ;;
-	  *) future_libdirs="$future_libdirs $libdir" ;;
+	  *) func_append future_libdirs " $libdir" ;;
 	  esac
 	fi
 
 	func_dirname "$file" "/" ""
 	dir="$func_dirname_result"
-	dir="$dir$objdir"
+	func_append dir "$objdir"
 
 	if test -n "$relink_command"; then
 	  # Determine the prefix the user has applied to our future dir.
-	  inst_prefix_dir=`$ECHO "X$destdir" | $Xsed -e "s%$libdir\$%%"`
+	  inst_prefix_dir=`$ECHO "$destdir" | $SED -e "s%$libdir\$%%"`
 
 	  # Don't allow the user to place us outside of our expected
 	  # location b/c this prevents finding dependent libraries that
@@ -2023,9 +2968,9 @@
 
 	  if test -n "$inst_prefix_dir"; then
 	    # Stick the inst_prefix_dir data into the link command.
-	    relink_command=`$ECHO "X$relink_command" | $Xsed -e "s%@inst_prefix_dir@%-inst-prefix-dir $inst_prefix_dir%"`
+	    relink_command=`$ECHO "$relink_command" | $SED "s%@inst_prefix_dir@%-inst-prefix-dir $inst_prefix_dir%"`
 	  else
-	    relink_command=`$ECHO "X$relink_command" | $Xsed -e "s%@inst_prefix_dir@%%"`
+	    relink_command=`$ECHO "$relink_command" | $SED "s%@inst_prefix_dir@%%"`
 	  fi
 
 	  func_warning "relinking \`$file'"
@@ -2043,7 +2988,7 @@
 	  test -n "$relink_command" && srcname="$realname"T
 
 	  # Install the shared library and build the symlinks.
-	  func_show_eval "$install_prog $dir/$srcname $destdir/$realname" \
+	  func_show_eval "$install_shared_prog $dir/$srcname $destdir/$realname" \
 	      'exit $?'
 	  tstripme="$stripme"
 	  case $host_os in
@@ -2083,7 +3028,7 @@
 	func_show_eval "$install_prog $instname $destdir/$name" 'exit $?'
 
 	# Maybe install the static library, too.
-	test -n "$old_library" && staticlibs="$staticlibs $dir/$old_library"
+	test -n "$old_library" && func_append staticlibs " $dir/$old_library"
 	;;
 
       *.lo)
@@ -2183,7 +3128,7 @@
 	    if test -f "$lib"; then
 	      func_source "$lib"
 	    fi
-	    libfile="$libdir/"`$ECHO "X$lib" | $Xsed -e 's%^.*/%%g'` ### testsuite: skip nested quoting test
+	    libfile="$libdir/"`$ECHO "$lib" | $SED 's%^.*/%%g'` ### testsuite: skip nested quoting test
 	    if test -n "$libdir" && test ! -f "$libfile"; then
 	      func_warning "\`$lib' has not been installed in \`$libdir'"
 	      finalize=no
@@ -2202,7 +3147,7 @@
 		file="$func_basename_result"
 	        outputname="$tmpdir/$file"
 	        # Replace the output file specification.
-	        relink_command=`$ECHO "X$relink_command" | $Xsed -e 's%@OUTPUT@%'"$outputname"'%g'`
+	        relink_command=`$ECHO "$relink_command" | $SED 's%@OUTPUT@%'"$outputname"'%g'`
 
 	        $opt_silent || {
 	          func_quote_for_expand "$relink_command"
@@ -2221,7 +3166,7 @@
 	    }
 	  else
 	    # Install the binary that we compiled earlier.
-	    file=`$ECHO "X$file$stripped_ext" | $Xsed -e "s%\([^/]*\)$%$objdir/\1%"`
+	    file=`$ECHO "$file$stripped_ext" | $SED "s%\([^/]*\)$%$objdir/\1%"`
 	  fi
 	fi
 
@@ -2257,11 +3202,13 @@
 
       # Set up the ranlib parameters.
       oldlib="$destdir/$name"
+      func_to_tool_file "$oldlib" func_convert_file_msys_to_w32
+      tool_oldlib=$func_to_tool_file_result
 
       func_show_eval "$install_prog \$file \$oldlib" 'exit $?'
 
       if test -n "$stripme" && test -n "$old_striplib"; then
-	func_show_eval "$old_striplib $oldlib" 'exit $?'
+	func_show_eval "$old_striplib $tool_oldlib" 'exit $?'
       fi
 
       # Do each command in the postinstall commands.
@@ -2280,7 +3227,7 @@
     fi
 }
 
-test "$mode" = install && func_mode_install ${1+"$@"}
+test "$opt_mode" = install && func_mode_install ${1+"$@"}
 
 
 # func_generate_dlsyms outputname originator pic_p
@@ -2323,6 +3270,22 @@
 extern \"C\" {
 #endif
 
+#if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 4)) || (__GNUC__ > 4))
+#pragma GCC diagnostic ignored \"-Wstrict-prototypes\"
+#endif
+
+/* Keep this code in sync between libtool.m4, ltmain, lt_system.h, and tests.  */
+#if defined(_WIN32) || defined(__CYGWIN__) || defined(_WIN32_WCE)
+/* DATA imports from DLLs on WIN32 con't be const, because runtime
+   relocations are performed -- see ld's documentation on pseudo-relocs.  */
+# define LT_DLSYM_CONST
+#elif defined(__osf__)
+/* This system does not cope well with relocations in const data.  */
+# define LT_DLSYM_CONST
+#else
+# define LT_DLSYM_CONST const
+#endif
+
 /* External symbol declarations for the compiler. */\
 "
 
@@ -2332,10 +3295,11 @@
 	  $opt_dry_run || echo ': @PROGRAM@ ' > "$nlist"
 
 	  # Add our own program objects to the symbol list.
-	  progfiles=`$ECHO "X$objs$old_deplibs" | $SP2NL | $Xsed -e "$lo2o" | $NL2SP`
+	  progfiles=`$ECHO "$objs$old_deplibs" | $SP2NL | $SED "$lo2o" | $NL2SP`
 	  for progfile in $progfiles; do
-	    func_verbose "extracting global C symbols from \`$progfile'"
-	    $opt_dry_run || eval "$NM $progfile | $global_symbol_pipe >> '$nlist'"
+	    func_to_tool_file "$progfile" func_convert_file_msys_to_w32
+	    func_verbose "extracting global C symbols from \`$func_to_tool_file_result'"
+	    $opt_dry_run || eval "$NM $func_to_tool_file_result | $global_symbol_pipe >> '$nlist'"
 	  done
 
 	  if test -n "$exclude_expsyms"; then
@@ -2371,7 +3335,7 @@
 	      eval '$GREP -f "$output_objdir/$outputname.exp" < "$nlist" > "$nlist"T'
 	      eval '$MV "$nlist"T "$nlist"'
 	      case $host in
-	        *cygwin | *mingw* | *cegcc* )
+	        *cygwin* | *mingw* | *cegcc* )
 	          eval "echo EXPORTS "'> "$output_objdir/$outputname.def"'
 	          eval 'cat "$nlist" >> "$output_objdir/$outputname.def"'
 	          ;;
@@ -2384,10 +3348,52 @@
 	  func_verbose "extracting global C symbols from \`$dlprefile'"
 	  func_basename "$dlprefile"
 	  name="$func_basename_result"
-	  $opt_dry_run || {
-	    eval '$ECHO ": $name " >> "$nlist"'
-	    eval "$NM $dlprefile 2>/dev/null | $global_symbol_pipe >> '$nlist'"
-	  }
+          case $host in
+	    *cygwin* | *mingw* | *cegcc* )
+	      # if an import library, we need to obtain dlname
+	      if func_win32_import_lib_p "$dlprefile"; then
+	        func_tr_sh "$dlprefile"
+	        eval "curr_lafile=\$libfile_$func_tr_sh_result"
+	        dlprefile_dlbasename=""
+	        if test -n "$curr_lafile" && func_lalib_p "$curr_lafile"; then
+	          # Use subshell, to avoid clobbering current variable values
+	          dlprefile_dlname=`source "$curr_lafile" && echo "$dlname"`
+	          if test -n "$dlprefile_dlname" ; then
+	            func_basename "$dlprefile_dlname"
+	            dlprefile_dlbasename="$func_basename_result"
+	          else
+	            # no lafile. user explicitly requested -dlpreopen <import library>.
+	            $sharedlib_from_linklib_cmd "$dlprefile"
+	            dlprefile_dlbasename=$sharedlib_from_linklib_result
+	          fi
+	        fi
+	        $opt_dry_run || {
+	          if test -n "$dlprefile_dlbasename" ; then
+	            eval '$ECHO ": $dlprefile_dlbasename" >> "$nlist"'
+	          else
+	            func_warning "Could not compute DLL name from $name"
+	            eval '$ECHO ": $name " >> "$nlist"'
+	          fi
+	          func_to_tool_file "$dlprefile" func_convert_file_msys_to_w32
+	          eval "$NM \"$func_to_tool_file_result\" 2>/dev/null | $global_symbol_pipe |
+	            $SED -e '/I __imp/d' -e 's/I __nm_/D /;s/_nm__//' >> '$nlist'"
+	        }
+	      else # not an import lib
+	        $opt_dry_run || {
+	          eval '$ECHO ": $name " >> "$nlist"'
+	          func_to_tool_file "$dlprefile" func_convert_file_msys_to_w32
+	          eval "$NM \"$func_to_tool_file_result\" 2>/dev/null | $global_symbol_pipe >> '$nlist'"
+	        }
+	      fi
+	    ;;
+	    *)
+	      $opt_dry_run || {
+	        eval '$ECHO ": $name " >> "$nlist"'
+	        func_to_tool_file "$dlprefile" func_convert_file_msys_to_w32
+	        eval "$NM \"$func_to_tool_file_result\" 2>/dev/null | $global_symbol_pipe >> '$nlist'"
+	      }
+	    ;;
+          esac
 	done
 
 	$opt_dry_run || {
@@ -2415,36 +3421,19 @@
 	  if test -f "$nlist"S; then
 	    eval "$global_symbol_to_cdecl"' < "$nlist"S >> "$output_objdir/$my_dlsyms"'
 	  else
-	    $ECHO '/* NONE */' >> "$output_objdir/$my_dlsyms"
+	    echo '/* NONE */' >> "$output_objdir/$my_dlsyms"
 	  fi
 
-	  $ECHO >> "$output_objdir/$my_dlsyms" "\
+	  echo >> "$output_objdir/$my_dlsyms" "\
 
 /* The mapping between symbol names and symbols.  */
 typedef struct {
   const char *name;
   void *address;
 } lt_dlsymlist;
-"
-	  case $host in
-	  *cygwin* | *mingw* | *cegcc* )
-	    $ECHO >> "$output_objdir/$my_dlsyms" "\
-/* DATA imports from DLLs on WIN32 con't be const, because
-   runtime relocations are performed -- see ld's documentation
-   on pseudo-relocs.  */"
-	    lt_dlsym_const= ;;
-	  *osf5*)
-	    echo >> "$output_objdir/$my_dlsyms" "\
-/* This system does not cope well with relocations in const data */"
-	    lt_dlsym_const= ;;
-	  *)
-	    lt_dlsym_const=const ;;
-	  esac
-
-	  $ECHO >> "$output_objdir/$my_dlsyms" "\
-extern $lt_dlsym_const lt_dlsymlist
+extern LT_DLSYM_CONST lt_dlsymlist
 lt_${my_prefix}_LTX_preloaded_symbols[];
-$lt_dlsym_const lt_dlsymlist
+LT_DLSYM_CONST lt_dlsymlist
 lt_${my_prefix}_LTX_preloaded_symbols[] =
 {\
   { \"$my_originator\", (void *) 0 },"
@@ -2457,7 +3446,7 @@
 	    eval "$global_symbol_to_c_name_address_lib_prefix" < "$nlist" >> "$output_objdir/$my_dlsyms"
 	    ;;
 	  esac
-	  $ECHO >> "$output_objdir/$my_dlsyms" "\
+	  echo >> "$output_objdir/$my_dlsyms" "\
   {0, (void *) 0}
 };
 
@@ -2484,7 +3473,7 @@
 	  # linked before any other PIC object.  But we must not use
 	  # pic_flag when linking with -static.  The problem exists in
 	  # FreeBSD 2.2.6 and is fixed in FreeBSD 3.1.
-	  *-*-freebsd2*|*-*-freebsd3.0*|*-*-freebsdelf3.0*)
+	  *-*-freebsd2.*|*-*-freebsd3.0*|*-*-freebsdelf3.0*)
 	    pic_flag_for_symtable=" $pic_flag -DFREEBSD_WORKAROUND" ;;
 	  *-*-hpux*)
 	    pic_flag_for_symtable=" $pic_flag"  ;;
@@ -2500,7 +3489,7 @@
 	for arg in $LTCFLAGS; do
 	  case $arg in
 	  -pie | -fpie | -fPIE) ;;
-	  *) symtab_cflags="$symtab_cflags $arg" ;;
+	  *) func_append symtab_cflags " $arg" ;;
 	  esac
 	done
 
@@ -2515,16 +3504,16 @@
 	case $host in
 	*cygwin* | *mingw* | *cegcc* )
 	  if test -f "$output_objdir/$my_outputname.def"; then
-	    compile_command=`$ECHO "X$compile_command" | $Xsed -e "s%@SYMFILE@%$output_objdir/$my_outputname.def $symfileobj%"`
-	    finalize_command=`$ECHO "X$finalize_command" | $Xsed -e "s%@SYMFILE@%$output_objdir/$my_outputname.def $symfileobj%"`
+	    compile_command=`$ECHO "$compile_command" | $SED "s%@SYMFILE@%$output_objdir/$my_outputname.def $symfileobj%"`
+	    finalize_command=`$ECHO "$finalize_command" | $SED "s%@SYMFILE@%$output_objdir/$my_outputname.def $symfileobj%"`
 	  else
-	    compile_command=`$ECHO "X$compile_command" | $Xsed -e "s%@SYMFILE@%$symfileobj%"`
-	    finalize_command=`$ECHO "X$finalize_command" | $Xsed -e "s%@SYMFILE@%$symfileobj%"`
+	    compile_command=`$ECHO "$compile_command" | $SED "s%@SYMFILE@%$symfileobj%"`
+	    finalize_command=`$ECHO "$finalize_command" | $SED "s%@SYMFILE@%$symfileobj%"`
 	  fi
 	  ;;
 	*)
-	  compile_command=`$ECHO "X$compile_command" | $Xsed -e "s%@SYMFILE@%$symfileobj%"`
-	  finalize_command=`$ECHO "X$finalize_command" | $Xsed -e "s%@SYMFILE@%$symfileobj%"`
+	  compile_command=`$ECHO "$compile_command" | $SED "s%@SYMFILE@%$symfileobj%"`
+	  finalize_command=`$ECHO "$finalize_command" | $SED "s%@SYMFILE@%$symfileobj%"`
 	  ;;
 	esac
 	;;
@@ -2538,8 +3527,8 @@
       # really was required.
 
       # Nullify the symbol file.
-      compile_command=`$ECHO "X$compile_command" | $Xsed -e "s% @SYMFILE@%%"`
-      finalize_command=`$ECHO "X$finalize_command" | $Xsed -e "s% @SYMFILE@%%"`
+      compile_command=`$ECHO "$compile_command" | $SED "s% @SYMFILE@%%"`
+      finalize_command=`$ECHO "$finalize_command" | $SED "s% @SYMFILE@%%"`
     fi
 }
 
@@ -2549,6 +3538,7 @@
 # Need a lot of goo to handle *both* DLLs and import libs
 # Has to be a shell function in order to 'eat' the argument
 # that is supplied when $file_magic_command is called.
+# Despite the name, also deal with 64 bit binaries.
 func_win32_libid ()
 {
   $opt_debug
@@ -2559,9 +3549,11 @@
     win32_libid_type="x86 archive import"
     ;;
   *ar\ archive*) # could be an import, or static
+    # Keep the egrep pattern in sync with the one in _LT_CHECK_MAGIC_METHOD.
     if eval $OBJDUMP -f $1 | $SED -e '10q' 2>/dev/null |
-       $EGREP 'file format pe-i386(.*architecture: i386)?' >/dev/null ; then
-      win32_nmres=`eval $NM -f posix -A $1 |
+       $EGREP 'file format (pei*-i386(.*architecture: i386)?|pe-arm-wince|pe-x86-64)' >/dev/null; then
+      func_to_tool_file "$1" func_convert_file_msys_to_w32
+      win32_nmres=`eval $NM -f posix -A \"$func_to_tool_file_result\" |
 	$SED -n -e '
 	    1,100{
 		/ I /{
@@ -2590,6 +3582,131 @@
   $ECHO "$win32_libid_type"
 }
 
+# func_cygming_dll_for_implib ARG
+#
+# Platform-specific function to extract the
+# name of the DLL associated with the specified
+# import library ARG.
+# Invoked by eval'ing the libtool variable
+#    $sharedlib_from_linklib_cmd
+# Result is available in the variable
+#    $sharedlib_from_linklib_result
+func_cygming_dll_for_implib ()
+{
+  $opt_debug
+  sharedlib_from_linklib_result=`$DLLTOOL --identify-strict --identify "$1"`
+}
+
+# func_cygming_dll_for_implib_fallback_core SECTION_NAME LIBNAMEs
+#
+# The is the core of a fallback implementation of a
+# platform-specific function to extract the name of the
+# DLL associated with the specified import library LIBNAME.
+#
+# SECTION_NAME is either .idata$6 or .idata$7, depending
+# on the platform and compiler that created the implib.
+#
+# Echos the name of the DLL associated with the
+# specified import library.
+func_cygming_dll_for_implib_fallback_core ()
+{
+  $opt_debug
+  match_literal=`$ECHO "$1" | $SED "$sed_make_literal_regex"`
+  $OBJDUMP -s --section "$1" "$2" 2>/dev/null |
+    $SED '/^Contents of section '"$match_literal"':/{
+      # Place marker at beginning of archive member dllname section
+      s/.*/====MARK====/
+      p
+      d
+    }
+    # These lines can sometimes be longer than 43 characters, but
+    # are always uninteresting
+    /:[	 ]*file format pe[i]\{,1\}-/d
+    /^In archive [^:]*:/d
+    # Ensure marker is printed
+    /^====MARK====/p
+    # Remove all lines with less than 43 characters
+    /^.\{43\}/!d
+    # From remaining lines, remove first 43 characters
+    s/^.\{43\}//' |
+    $SED -n '
+      # Join marker and all lines until next marker into a single line
+      /^====MARK====/ b para
+      H
+      $ b para
+      b
+      :para
+      x
+      s/\n//g
+      # Remove the marker
+      s/^====MARK====//
+      # Remove trailing dots and whitespace
+      s/[\. \t]*$//
+      # Print
+      /./p' |
+    # we now have a list, one entry per line, of the stringified
+    # contents of the appropriate section of all members of the
+    # archive which possess that section. Heuristic: eliminate
+    # all those which have a first or second character that is
+    # a '.' (that is, objdump's representation of an unprintable
+    # character.) This should work for all archives with less than
+    # 0x302f exports -- but will fail for DLLs whose name actually
+    # begins with a literal '.' or a single character followed by
+    # a '.'.
+    #
+    # Of those that remain, print the first one.
+    $SED -e '/^\./d;/^.\./d;q'
+}
+
+# func_cygming_gnu_implib_p ARG
+# This predicate returns with zero status (TRUE) if
+# ARG is a GNU/binutils-style import library. Returns
+# with nonzero status (FALSE) otherwise.
+func_cygming_gnu_implib_p ()
+{
+  $opt_debug
+  func_to_tool_file "$1" func_convert_file_msys_to_w32
+  func_cygming_gnu_implib_tmp=`$NM "$func_to_tool_file_result" | eval "$global_symbol_pipe" | $EGREP ' (_head_[A-Za-z0-9_]+_[ad]l*|[A-Za-z0-9_]+_[ad]l*_iname)$'`
+  test -n "$func_cygming_gnu_implib_tmp"
+}
+
+# func_cygming_ms_implib_p ARG
+# This predicate returns with zero status (TRUE) if
+# ARG is an MS-style import library. Returns
+# with nonzero status (FALSE) otherwise.
+func_cygming_ms_implib_p ()
+{
+  $opt_debug
+  func_to_tool_file "$1" func_convert_file_msys_to_w32
+  func_cygming_ms_implib_tmp=`$NM "$func_to_tool_file_result" | eval "$global_symbol_pipe" | $GREP '_NULL_IMPORT_DESCRIPTOR'`
+  test -n "$func_cygming_ms_implib_tmp"
+}
+
+# func_cygming_dll_for_implib_fallback ARG
+# Platform-specific function to extract the
+# name of the DLL associated with the specified
+# import library ARG.
+#
+# This fallback implementation is for use when $DLLTOOL
+# does not support the --identify-strict option.
+# Invoked by eval'ing the libtool variable
+#    $sharedlib_from_linklib_cmd
+# Result is available in the variable
+#    $sharedlib_from_linklib_result
+func_cygming_dll_for_implib_fallback ()
+{
+  $opt_debug
+  if func_cygming_gnu_implib_p "$1" ; then
+    # binutils import library
+    sharedlib_from_linklib_result=`func_cygming_dll_for_implib_fallback_core '.idata$7' "$1"`
+  elif func_cygming_ms_implib_p "$1" ; then
+    # ms-generated import library
+    sharedlib_from_linklib_result=`func_cygming_dll_for_implib_fallback_core '.idata$6' "$1"`
+  else
+    # unknown
+    sharedlib_from_linklib_result=""
+  fi
+}
 
 
 # func_extract_an_archive dir oldlib
@@ -2598,7 +3715,18 @@
     $opt_debug
     f_ex_an_ar_dir="$1"; shift
     f_ex_an_ar_oldlib="$1"
-    func_show_eval "(cd \$f_ex_an_ar_dir && $AR x \"\$f_ex_an_ar_oldlib\")" 'exit $?'
+    if test "$lock_old_archive_extraction" = yes; then
+      lockfile=$f_ex_an_ar_oldlib.lock
+      until $opt_dry_run || ln "$progpath" "$lockfile" 2>/dev/null; do
+	func_echo "Waiting for $lockfile to be removed"
+	sleep 2
+      done
+    fi
+    func_show_eval "(cd \$f_ex_an_ar_dir && $AR x \"\$f_ex_an_ar_oldlib\")" \
+		   'stat=$?; rm -f "$lockfile"; exit $stat'
+    if test "$lock_old_archive_extraction" = yes; then
+      $opt_dry_run || rm -f "$lockfile"
+    fi
     if ($AR t "$f_ex_an_ar_oldlib" | sort | sort -uc >/dev/null 2>&1); then
      :
     else
@@ -2669,7 +3797,7 @@
 	    darwin_file=
 	    darwin_files=
 	    for darwin_file in $darwin_filelist; do
-	      darwin_files=`find unfat-$$ -name $darwin_file -print | $NL2SP`
+	      darwin_files=`find unfat-$$ -name $darwin_file -print | sort | $NL2SP`
 	      $LIPO -create -output "$darwin_file" $darwin_files
 	    done # $darwin_filelist
 	    $RM -rf unfat-$$
@@ -2684,25 +3812,30 @@
         func_extract_an_archive "$my_xdir" "$my_xabs"
 	;;
       esac
-      my_oldobjs="$my_oldobjs "`find $my_xdir -name \*.$objext -print -o -name \*.lo -print | $NL2SP`
+      my_oldobjs="$my_oldobjs "`find $my_xdir -name \*.$objext -print -o -name \*.lo -print | sort | $NL2SP`
     done
 
     func_extract_archives_result="$my_oldobjs"
 }
 
 
-
-# func_emit_wrapper_part1 [arg=no]
-#
-# Emit the first part of a libtool wrapper script on stdout.
-# For more information, see the description associated with
-# func_emit_wrapper(), below.
-func_emit_wrapper_part1 ()
+# func_emit_wrapper [arg=no]
+#
+# Emit a libtool wrapper script on stdout.
+# Don't directly open a file because we may want to
+# incorporate the script contents within a cygwin/mingw
+# wrapper executable.  Must ONLY be called from within
+# func_mode_link because it depends on a number of variables
+# set therein.
+#
+# ARG is the value that the WRAPPER_SCRIPT_BELONGS_IN_OBJDIR
+# variable will take.  If 'yes', then the emitted script
+# will assume that the directory in which it is stored is
+# the $objdir directory.  This is a cygwin/mingw-specific
+# behavior.
+func_emit_wrapper ()
 {
-	func_emit_wrapper_part1_arg1=no
-	if test -n "$1" ; then
-	  func_emit_wrapper_part1_arg1=$1
-	fi
+	func_emit_wrapper_arg1=${1-no}
 
 	$ECHO "\
 #! $SHELL
@@ -2718,7 +3851,6 @@
 
 # Sed substitution that helps us do robust quoting.  It backslashifies
 # metacharacters that are still active within double-quoted strings.
-Xsed='${SED} -e 1s/^X//'
 sed_quote_subst='$sed_quote_subst'
 
 # Be Bourne compatible
@@ -2749,31 +3881,135 @@
 else
   # When we are sourced in execute mode, \$file and \$ECHO are already set.
   if test \"\$libtool_execute_magic\" != \"$magic\"; then
-    ECHO=\"$qecho\"
-    file=\"\$0\"
-    # Make sure echo works.
-    if test \"X\$1\" = X--no-reexec; then
-      # Discard the --no-reexec flag, and continue.
+    file=\"\$0\""
+
+    qECHO=`$ECHO "$ECHO" | $SED "$sed_quote_subst"`
+    $ECHO "\
+
+# A function that is used when there is no print builtin or printf.
+func_fallback_echo ()
+{
+  eval 'cat <<_LTECHO_EOF
+\$1
+_LTECHO_EOF'
+}
+    ECHO=\"$qECHO\"
+  fi
+
+# Very basic option parsing. These options are (a) specific to
+# the libtool wrapper, (b) are identical between the wrapper
+# /script/ and the wrapper /executable/ which is used only on
+# windows platforms, and (c) all begin with the string "--lt-"
+# (application programs are unlikely to have options which match
+# this pattern).
+#
+# There are only two supported options: --lt-debug and
+# --lt-dump-script. There is, deliberately, no --lt-help.
+#
+# The first argument to this parsing function should be the
+# script's $0 value, followed by "$@".
+lt_option_debug=
+func_parse_lt_options ()
+{
+  lt_script_arg0=\$0
+  shift
+  for lt_opt
+  do
+    case \"\$lt_opt\" in
+    --lt-debug) lt_option_debug=1 ;;
+    --lt-dump-script)
+        lt_dump_D=\`\$ECHO \"X\$lt_script_arg0\" | $SED -e 's/^X//' -e 's%/[^/]*$%%'\`
+        test \"X\$lt_dump_D\" = \"X\$lt_script_arg0\" && lt_dump_D=.
+        lt_dump_F=\`\$ECHO \"X\$lt_script_arg0\" | $SED -e 's/^X//' -e 's%^.*/%%'\`
+        cat \"\$lt_dump_D/\$lt_dump_F\"
+        exit 0
+      ;;
+    --lt-*)
+        \$ECHO \"Unrecognized --lt- option: '\$lt_opt'\" 1>&2
+        exit 1
+      ;;
+    esac
+  done
+
+  # Print the debug banner immediately:
+  if test -n \"\$lt_option_debug\"; then
+    echo \"${outputname}:${output}:\${LINENO}: libtool wrapper (GNU $PACKAGE$TIMESTAMP) $VERSION\" 1>&2
+  fi
+}
+
+# Used when --lt-debug. Prints its arguments to stdout
+# (redirection is the responsibility of the caller)
+func_lt_dump_args ()
+{
+  lt_dump_args_N=1;
+  for lt_arg
+  do
+    \$ECHO \"${outputname}:${output}:\${LINENO}: newargv[\$lt_dump_args_N]: \$lt_arg\"
+    lt_dump_args_N=\`expr \$lt_dump_args_N + 1\`
+  done
+}
+
+# Core function for launching the target application
+func_exec_program_core ()
+{
+"
+  case $host in
+  # Backslashes separate directories on plain windows
+  *-*-mingw | *-*-os2* | *-cegcc*)
+    $ECHO "\
+      if test -n \"\$lt_option_debug\"; then
+        \$ECHO \"${outputname}:${output}:\${LINENO}: newargv[0]: \$progdir\\\\\$program\" 1>&2
+        func_lt_dump_args \${1+\"\$@\"} 1>&2
+      fi
+      exec \"\$progdir\\\\\$program\" \${1+\"\$@\"}
+"
+    ;;
+
+  *)
+    $ECHO "\
+      if test -n \"\$lt_option_debug\"; then
+        \$ECHO \"${outputname}:${output}:\${LINENO}: newargv[0]: \$progdir/\$program\" 1>&2
+        func_lt_dump_args \${1+\"\$@\"} 1>&2
+      fi
+      exec \"\$progdir/\$program\" \${1+\"\$@\"}
+"
+    ;;
+  esac
+  $ECHO "\
+      \$ECHO \"\$0: cannot exec \$program \$*\" 1>&2
+      exit 1
+}
+
+# A function to encapsulate launching the target application
+# Strips options in the --lt-* namespace from \$@ and
+# launches target application with the remaining arguments.
+func_exec_program ()
+{
+  case \" \$* \" in
+  *\\ --lt-*)
+    for lt_wr_arg
+    do
+      case \$lt_wr_arg in
+      --lt-*) ;;
+      *) set x \"\$@\" \"\$lt_wr_arg\"; shift;;
+      esac
       shift
-    elif test \"X\`{ \$ECHO '\t'; } 2>/dev/null\`\" = 'X\t'; then
-      # Yippee, \$ECHO works!
-      :
-    else
-      # Restart under the correct shell, and then maybe \$ECHO will work.
-      exec $SHELL \"\$0\" --no-reexec \${1+\"\$@\"}
-    fi
-  fi\
-"
-	$ECHO "\
+    done ;;
+  esac
+  func_exec_program_core \${1+\"\$@\"}
+}
+
+  # Parse options
+  func_parse_lt_options \"\$0\" \${1+\"\$@\"}
 
   # Find the directory that this script lives in.
-  thisdir=\`\$ECHO \"X\$file\" | \$Xsed -e 's%/[^/]*$%%'\`
+  thisdir=\`\$ECHO \"\$file\" | $SED 's%/[^/]*$%%'\`
   test \"x\$thisdir\" = \"x\$file\" && thisdir=.
 
   # Follow symbolic links until we get to the real thisdir.
-  file=\`ls -ld \"\$file\" | ${SED} -n 's/.*-> //p'\`
+  file=\`ls -ld \"\$file\" | $SED -n 's/.*-> //p'\`
   while test -n \"\$file\"; do
-    destdir=\`\$ECHO \"X\$file\" | \$Xsed -e 's%/[^/]*\$%%'\`
+    destdir=\`\$ECHO \"\$file\" | $SED 's%/[^/]*\$%%'\`
 
     # If there was a directory component, then change thisdir.
     if test \"x\$destdir\" != \"x\$file\"; then
@@ -2783,30 +4019,13 @@
       esac
     fi
 
-    file=\`\$ECHO \"X\$file\" | \$Xsed -e 's%^.*/%%'\`
-    file=\`ls -ld \"\$thisdir/\$file\" | ${SED} -n 's/.*-> //p'\`
+    file=\`\$ECHO \"\$file\" | $SED 's%^.*/%%'\`
+    file=\`ls -ld \"\$thisdir/\$file\" | $SED -n 's/.*-> //p'\`
   done
-"
-}
-# end: func_emit_wrapper_part1
-
-# func_emit_wrapper_part2 [arg=no]
-#
-# Emit the second part of a libtool wrapper script on stdout.
-# For more information, see the description associated with
-# func_emit_wrapper(), below.
-func_emit_wrapper_part2 ()
-{
-	func_emit_wrapper_part2_arg1=no
-	if test -n "$1" ; then
-	  func_emit_wrapper_part2_arg1=$1
-	fi
-
-	$ECHO "\
 
   # Usually 'no', except on cygwin/mingw when embedded into
   # the cwrapper.
-  WRAPPER_SCRIPT_BELONGS_IN_OBJDIR=$func_emit_wrapper_part2_arg1
+  WRAPPER_SCRIPT_BELONGS_IN_OBJDIR=$func_emit_wrapper_arg1
   if test \"\$WRAPPER_SCRIPT_BELONGS_IN_OBJDIR\" = \"yes\"; then
     # special case for '.'
     if test \"\$thisdir\" = \".\"; then
@@ -2814,7 +4033,7 @@
     fi
     # remove .libs from thisdir
     case \"\$thisdir\" in
-    *[\\\\/]$objdir ) thisdir=\`\$ECHO \"X\$thisdir\" | \$Xsed -e 's%[\\\\/][^\\\\/]*$%%'\` ;;
+    *[\\\\/]$objdir ) thisdir=\`\$ECHO \"\$thisdir\" | $SED 's%[\\\\/][^\\\\/]*$%%'\` ;;
     $objdir )   thisdir=. ;;
     esac
   fi
@@ -2869,6 +4088,18 @@
 
   if test -f \"\$progdir/\$program\"; then"
 
+	# fixup the dll searchpath if we need to.
+	#
+	# Fix the DLL searchpath if we need to.  Do this before prepending
+	# to shlibpath, because on Windows, both are PATH and uninstalled
+	# libraries must come first.
+	if test -n "$dllsearchpath"; then
+	  $ECHO "\
+    # Add the dll search path components to the executable PATH
+    PATH=$dllsearchpath:\$PATH
+"
+	fi
+
 	# Export our shlibpath_var if we have one.
 	if test "$shlibpath_overrides_runpath" = yes && test -n "$shlibpath_var" && test -n "$temp_rpath"; then
 	  $ECHO "\
@@ -2877,253 +4108,28 @@
 
     # Some systems cannot cope with colon-terminated $shlibpath_var
     # The second colon is a workaround for a bug in BeOS R4 sed
-    $shlibpath_var=\`\$ECHO \"X\$$shlibpath_var\" | \$Xsed -e 's/::*\$//'\`
+    $shlibpath_var=\`\$ECHO \"\$$shlibpath_var\" | $SED 's/::*\$//'\`
 
     export $shlibpath_var
 "
 	fi
 
-	# fixup the dll searchpath if we need to.
-	if test -n "$dllsearchpath"; then
-	  $ECHO "\
-    # Add the dll search path components to the executable PATH
-    PATH=$dllsearchpath:\$PATH
-"
-	fi
-
 	$ECHO "\
     if test \"\$libtool_execute_magic\" != \"$magic\"; then
       # Run the actual program with our arguments.
-"
-	case $host in
-	# Backslashes separate directories on plain windows
-	*-*-mingw | *-*-os2* | *-cegcc*)
-	  $ECHO "\
-      exec \"\$progdir\\\\\$program\" \${1+\"\$@\"}
-"
-	  ;;
-
-	*)
-	  $ECHO "\
-      exec \"\$progdir/\$program\" \${1+\"\$@\"}
-"
-	  ;;
-	esac
-	$ECHO "\
-      \$ECHO \"\$0: cannot exec \$program \$*\" 1>&2
-      exit 1
+      func_exec_program \${1+\"\$@\"}
     fi
   else
     # The program doesn't exist.
     \$ECHO \"\$0: error: \\\`\$progdir/\$program' does not exist\" 1>&2
     \$ECHO \"This script is just a wrapper for \$program.\" 1>&2
-    $ECHO \"See the $PACKAGE documentation for more information.\" 1>&2
+    \$ECHO \"See the $PACKAGE documentation for more information.\" 1>&2
     exit 1
   fi
 fi\
 "
 }
-# end: func_emit_wrapper_part2
-
-
-# func_emit_wrapper [arg=no]
-#
-# Emit a libtool wrapper script on stdout.
-# Don't directly open a file because we may want to
-# incorporate the script contents within a cygwin/mingw
-# wrapper executable.  Must ONLY be called from within
-# func_mode_link because it depends on a number of variables
-# set therein.
-#
-# ARG is the value that the WRAPPER_SCRIPT_BELONGS_IN_OBJDIR
-# variable will take.  If 'yes', then the emitted script
-# will assume that the directory in which it is stored is
-# the $objdir directory.  This is a cygwin/mingw-specific
-# behavior.
-func_emit_wrapper ()
-{
-	func_emit_wrapper_arg1=no
-	if test -n "$1" ; then
-	  func_emit_wrapper_arg1=$1
-	fi
-
-	# split this up so that func_emit_cwrapperexe_src
-	# can call each part independently.
-	func_emit_wrapper_part1 "${func_emit_wrapper_arg1}"
-	func_emit_wrapper_part2 "${func_emit_wrapper_arg1}"
-}
-
-
-# func_to_host_path arg
-#
-# Convert paths to host format when used with build tools.
-# Intended for use with "native" mingw (where libtool itself
-# is running under the msys shell), or in the following cross-
-# build environments:
-#    $build          $host
-#    mingw (msys)    mingw  [e.g. native]
-#    cygwin          mingw
-#    *nix + wine     mingw
-# where wine is equipped with the `winepath' executable.
-# In the native mingw case, the (msys) shell automatically
-# converts paths for any non-msys applications it launches,
-# but that facility isn't available from inside the cwrapper.
-# Similar accommodations are necessary for $host mingw and
-# $build cygwin.  Calling this function does no harm for other
-# $host/$build combinations not listed above.
-#
-# ARG is the path (on $build) that should be converted to
-# the proper representation for $host. The result is stored
-# in $func_to_host_path_result.
-func_to_host_path ()
-{
-  func_to_host_path_result="$1"
-  if test -n "$1" ; then
-    case $host in
-      *mingw* )
-        lt_sed_naive_backslashify='s|\\\\*|\\|g;s|/|\\|g;s|\\|\\\\|g'
-        case $build in
-          *mingw* ) # actually, msys
-            # awkward: cmd appends spaces to result
-            lt_sed_strip_trailing_spaces="s/[ ]*\$//"
-            func_to_host_path_tmp1=`( cmd //c echo "$1" |\
-              $SED -e "$lt_sed_strip_trailing_spaces" ) 2>/dev/null || echo ""`
-            func_to_host_path_result=`echo "$func_to_host_path_tmp1" |\
-              $SED -e "$lt_sed_naive_backslashify"`
-            ;;
-          *cygwin* )
-            func_to_host_path_tmp1=`cygpath -w "$1"`
-            func_to_host_path_result=`echo "$func_to_host_path_tmp1" |\
-              $SED -e "$lt_sed_naive_backslashify"`
-            ;;
-          * )
-            # Unfortunately, winepath does not exit with a non-zero
-            # error code, so we are forced to check the contents of
-            # stdout. On the other hand, if the command is not
-            # found, the shell will set an exit code of 127 and print
-            # *an error message* to stdout. So we must check for both
-            # error code of zero AND non-empty stdout, which explains
-            # the odd construction:
-            func_to_host_path_tmp1=`winepath -w "$1" 2>/dev/null`
-            if test "$?" -eq 0 && test -n "${func_to_host_path_tmp1}"; then
-              func_to_host_path_result=`echo "$func_to_host_path_tmp1" |\
-                $SED -e "$lt_sed_naive_backslashify"`
-            else
-              # Allow warning below.
-              func_to_host_path_result=""
-            fi
-            ;;
-        esac
-        if test -z "$func_to_host_path_result" ; then
-          func_error "Could not determine host path corresponding to"
-          func_error "  '$1'"
-          func_error "Continuing, but uninstalled executables may not work."
-          # Fallback:
-          func_to_host_path_result="$1"
-        fi
-        ;;
-    esac
-  fi
-}
-# end: func_to_host_path
-
-# func_to_host_pathlist arg
-#
-# Convert pathlists to host format when used with build tools.
-# See func_to_host_path(), above. This function supports the
-# following $build/$host combinations (but does no harm for
-# combinations not listed here):
-#    $build          $host
-#    mingw (msys)    mingw  [e.g. native]
-#    cygwin          mingw
-#    *nix + wine     mingw
-#
-# Path separators are also converted from $build format to
-# $host format. If ARG begins or ends with a path separator
-# character, it is preserved (but converted to $host format)
-# on output.
-#
-# ARG is a pathlist (on $build) that should be converted to
-# the proper representation on $host. The result is stored
-# in $func_to_host_pathlist_result.
-func_to_host_pathlist ()
-{
-  func_to_host_pathlist_result="$1"
-  if test -n "$1" ; then
-    case $host in
-      *mingw* )
-        lt_sed_naive_backslashify='s|\\\\*|\\|g;s|/|\\|g;s|\\|\\\\|g'
-        # Remove leading and trailing path separator characters from
-        # ARG. msys behavior is inconsistent here, cygpath turns them
-        # into '.;' and ';.', and winepath ignores them completely.
-        func_to_host_pathlist_tmp2="$1"
-        # Once set for this call, this variable should not be
-        # reassigned. It is used in tha fallback case.
-        func_to_host_pathlist_tmp1=`echo "$func_to_host_pathlist_tmp2" |\
-          $SED -e 's|^:*||' -e 's|:*$||'`
-        case $build in
-          *mingw* ) # Actually, msys.
-            # Awkward: cmd appends spaces to result.
-            lt_sed_strip_trailing_spaces="s/[ ]*\$//"
-            func_to_host_pathlist_tmp2=`( cmd //c echo "$func_to_host_pathlist_tmp1" |\
-              $SED -e "$lt_sed_strip_trailing_spaces" ) 2>/dev/null || echo ""`
-            func_to_host_pathlist_result=`echo "$func_to_host_pathlist_tmp2" |\
-              $SED -e "$lt_sed_naive_backslashify"`
-            ;;
-          *cygwin* )
-            func_to_host_pathlist_tmp2=`cygpath -w -p "$func_to_host_pathlist_tmp1"`
-            func_to_host_pathlist_result=`echo "$func_to_host_pathlist_tmp2" |\
-              $SED -e "$lt_sed_naive_backslashify"`
-            ;;
-          * )
-            # unfortunately, winepath doesn't convert pathlists
-            func_to_host_pathlist_result=""
-            func_to_host_pathlist_oldIFS=$IFS
-            IFS=:
-            for func_to_host_pathlist_f in $func_to_host_pathlist_tmp1 ; do
-              IFS=$func_to_host_pathlist_oldIFS
-              if test -n "$func_to_host_pathlist_f" ; then
-                func_to_host_path "$func_to_host_pathlist_f"
-                if test -n "$func_to_host_path_result" ; then
-                  if test -z "$func_to_host_pathlist_result" ; then
-                    func_to_host_pathlist_result="$func_to_host_path_result"
-                  else
-                    func_to_host_pathlist_result="$func_to_host_pathlist_result;$func_to_host_path_result"
-                  fi
-                fi
-              fi
-              IFS=:
-            done
-            IFS=$func_to_host_pathlist_oldIFS
-            ;;
-        esac
-        if test -z "$func_to_host_pathlist_result" ; then
-          func_error "Could not determine the host path(s) corresponding to"
-          func_error "  '$1'"
-          func_error "Continuing, but uninstalled executables may not work."
-          # Fallback. This may break if $1 contains DOS-style drive
-          # specifications. The fix is not to complicate the expression
-          # below, but for the user to provide a working wine installation
-          # with winepath so that path translation in the cross-to-mingw
-          # case works properly.
-          lt_replace_pathsep_nix_to_dos="s|:|;|g"
-          func_to_host_pathlist_result=`echo "$func_to_host_pathlist_tmp1" |\
-            $SED -e "$lt_replace_pathsep_nix_to_dos"`
-        fi
-        # Now, add the leading and trailing path separators back
-        case "$1" in
-          :* ) func_to_host_pathlist_result=";$func_to_host_pathlist_result"
-            ;;
-        esac
-        case "$1" in
-          *: ) func_to_host_pathlist_result="$func_to_host_pathlist_result;"
-            ;;
-        esac
-        ;;
-    esac
-  fi
-}
-# end: func_to_host_pathlist
+
 
 # func_emit_cwrapperexe_src
 # emit the source code for a wrapper executable on stdout
@@ -3141,31 +4147,23 @@
 
    This wrapper executable should never be moved out of the build directory.
    If it is, it will not operate correctly.
-
-   Currently, it simply execs the wrapper *script* "$SHELL $output",
-   but could eventually absorb all of the scripts functionality and
-   exec $objdir/$outputname directly.
 */
 EOF
 	    cat <<"EOF"
+#ifdef _MSC_VER
+# define _CRT_SECURE_NO_DEPRECATE 1
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #ifdef _MSC_VER
 # include <direct.h>
 # include <process.h>
 # include <io.h>
-# define setmode _setmode
 #else
 # include <unistd.h>
 # include <stdint.h>
 # ifdef __CYGWIN__
 #  include <io.h>
-#  define HAVE_SETENV
-#  ifdef __STRICT_ANSI__
-char *realpath (const char *, char *);
-int putenv (char *);
-int setenv (const char *, const char *, int);
-#  endif
 # endif
 #endif
 #include <malloc.h>
@@ -3177,6 +4175,44 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 
+/* declarations of non-ANSI functions */
+#if defined(__MINGW32__)
+# ifdef __STRICT_ANSI__
+int _putenv (const char *);
+# endif
+#elif defined(__CYGWIN__)
+# ifdef __STRICT_ANSI__
+char *realpath (const char *, char *);
+int putenv (char *);
+int setenv (const char *, const char *, int);
+# endif
+/* #elif defined (other platforms) ... */
+#endif
+
+/* portability defines, excluding path handling macros */
+#if defined(_MSC_VER)
+# define setmode _setmode
+# define stat    _stat
+# define chmod   _chmod
+# define getcwd  _getcwd
+# define putenv  _putenv
+# define S_IXUSR _S_IEXEC
+# ifndef _INTPTR_T_DEFINED
+#  define _INTPTR_T_DEFINED
+#  define intptr_t int
+# endif
+#elif defined(__MINGW32__)
+# define setmode _setmode
+# define stat    _stat
+# define chmod   _chmod
+# define getcwd  _getcwd
+# define putenv  _putenv
+#elif defined(__CYGWIN__)
+# define HAVE_SETENV
+# define FOPEN_WB "wb"
+/* #elif defined (other platforms) ... */
+#endif
+
 #if defined(PATH_MAX)
 # define LT_PATHMAX PATH_MAX
 #elif defined(MAXPATHLEN)
@@ -3192,14 +4228,7 @@
 # define S_IXGRP 0
 #endif
 
-#ifdef _MSC_VER
-# define S_IXUSR _S_IEXEC
-# define stat _stat
-# ifndef _INTPTR_T_DEFINED
-#  define intptr_t int
-# endif
-#endif
-
+/* path handling portability macros */
 #ifndef DIR_SEPARATOR
 # define DIR_SEPARATOR '/'
 # define PATH_SEPARATOR ':'
@@ -3230,10 +4259,6 @@
 # define IS_PATH_SEPARATOR(ch) ((ch) == PATH_SEPARATOR_2)
 #endif /* PATH_SEPARATOR_2 */
 
-#ifdef __CYGWIN__
-# define FOPEN_WB "wb"
-#endif
-
 #ifndef FOPEN_WB
 # define FOPEN_WB "w"
 #endif
@@ -3246,22 +4271,13 @@
   if (stale) { free ((void *) stale); stale = 0; } \
 } while (0)
 
-#undef LTWRAPPER_DEBUGPRINTF
-#if defined DEBUGWRAPPER
-# define LTWRAPPER_DEBUGPRINTF(args) ltwrapper_debugprintf args
-static void
-ltwrapper_debugprintf (const char *fmt, ...)
-{
-    va_list args;
-    va_start (args, fmt);
-    (void) vfprintf (stderr, fmt, args);
-    va_end (args);
-}
+#if defined(LT_DEBUGWRAPPER)
+static int lt_debug = 1;
 #else
-# define LTWRAPPER_DEBUGPRINTF(args)
+static int lt_debug = 0;
 #endif
 
-const char *program_name = NULL;
+const char *program_name = "libtool-wrapper"; /* in case xstrdup fails */
 
 void *xmalloc (size_t num);
 char *xstrdup (const char *string);
@@ -3271,41 +4287,27 @@
 int make_executable (const char *path);
 int check_executable (const char *path);
 char *strendzap (char *str, const char *pat);
-void lt_fatal (const char *message, ...);
+void lt_debugprintf (const char *file, int line, const char *fmt, ...);
+void lt_fatal (const char *file, int line, const char *message, ...);
+static const char *nonnull (const char *s);
+static const char *nonempty (const char *s);
 void lt_setenv (const char *name, const char *value);
 char *lt_extend_str (const char *orig_value, const char *add, int to_end);
-void lt_opt_process_env_set (const char *arg);
-void lt_opt_process_env_prepend (const char *arg);
-void lt_opt_process_env_append (const char *arg);
-int lt_split_name_value (const char *arg, char** name, char** value);
 void lt_update_exe_path (const char *name, const char *value);
 void lt_update_lib_path (const char *name, const char *value);
-
-static const char *script_text_part1 =
-EOF
-
-	    func_emit_wrapper_part1 yes |
-	        $SED -e 's/\([\\"]\)/\\\1/g' \
-	             -e 's/^/  "/' -e 's/$/\\n"/'
-	    echo ";"
-	    cat <<EOF
-
-static const char *script_text_part2 =
-EOF
-	    func_emit_wrapper_part2 yes |
-	        $SED -e 's/\([\\"]\)/\\\1/g' \
-	             -e 's/^/  "/' -e 's/$/\\n"/'
-	    echo ";"
-
-	    cat <<EOF
-const char * MAGIC_EXE = "$magic_exe";
+char **prepare_spawn (char **argv);
+void lt_dump_script (FILE *f);
+EOF
+
+	    cat <<EOF
+volatile const char * MAGIC_EXE = "$magic_exe";
 const char * LIB_PATH_VARNAME = "$shlibpath_var";
 EOF
 
 	    if test "$shlibpath_overrides_runpath" = yes && test -n "$shlibpath_var" && test -n "$temp_rpath"; then
-              func_to_host_pathlist "$temp_rpath"
+              func_to_host_path "$temp_rpath"
 	      cat <<EOF
-const char * LIB_PATH_VALUE   = "$func_to_host_pathlist_result";
+const char * LIB_PATH_VALUE   = "$func_to_host_path_result";
 EOF
 	    else
 	      cat <<"EOF"
@@ -3314,10 +4316,10 @@
 	    fi
 
 	    if test -n "$dllsearchpath"; then
-              func_to_host_pathlist "$dllsearchpath:"
+              func_to_host_path "$dllsearchpath:"
 	      cat <<EOF
 const char * EXE_PATH_VARNAME = "PATH";
-const char * EXE_PATH_VALUE   = "$func_to_host_pathlist_result";
+const char * EXE_PATH_VALUE   = "$func_to_host_path_result";
 EOF
 	    else
 	      cat <<"EOF"
@@ -3340,24 +4342,10 @@
 	    cat <<"EOF"
 
 #define LTWRAPPER_OPTION_PREFIX         "--lt-"
-#define LTWRAPPER_OPTION_PREFIX_LENGTH  5
 
-static const size_t opt_prefix_len         = LTWRAPPER_OPTION_PREFIX_LENGTH;
 static const char *ltwrapper_option_prefix = LTWRAPPER_OPTION_PREFIX;
-
 static const char *dumpscript_opt       = LTWRAPPER_OPTION_PREFIX "dump-script";
-
-static const size_t env_set_opt_len     = LTWRAPPER_OPTION_PREFIX_LENGTH + 7;
-static const char *env_set_opt          = LTWRAPPER_OPTION_PREFIX "env-set";
-  /* argument is putenv-style "foo=bar", value of foo is set to bar */
-
-static const size_t env_prepend_opt_len = LTWRAPPER_OPTION_PREFIX_LENGTH + 11;
-static const char *env_prepend_opt      = LTWRAPPER_OPTION_PREFIX "env-prepend";
-  /* argument is putenv-style "foo=bar", new value of foo is bar${foo} */
-
-static const size_t env_append_opt_len  = LTWRAPPER_OPTION_PREFIX_LENGTH + 10;
-static const char *env_append_opt       = LTWRAPPER_OPTION_PREFIX "env-append";
-  /* argument is putenv-style "foo=bar", new value of foo is ${foo}bar */
+static const char *debug_opt            = LTWRAPPER_OPTION_PREFIX "debug";
 
 int
 main (int argc, char *argv[])
@@ -3374,10 +4362,13 @@
   int i;
 
   program_name = (char *) xstrdup (base_name (argv[0]));
-  LTWRAPPER_DEBUGPRINTF (("(main) argv[0]      : %s\n", argv[0]));
-  LTWRAPPER_DEBUGPRINTF (("(main) program_name : %s\n", program_name));
+  newargz = XMALLOC (char *, argc + 1);
 
-  /* very simple arg parsing; don't want to rely on getopt */
+  /* very simple arg parsing; don't want to rely on getopt
+   * also, copy all non cwrapper options to newargz, except
+   * argz[0], which is handled differently
+   */
+  newargc=0;
   for (i = 1; i < argc; i++)
     {
       if (strcmp (argv[i], dumpscript_opt) == 0)
@@ -3391,25 +4382,57 @@
 	      esac
 
 	    cat <<"EOF"
-	  printf ("%s", script_text_part1);
-	  printf ("%s", script_text_part2);
+	  lt_dump_script (stdout);
 	  return 0;
 	}
+      if (strcmp (argv[i], debug_opt) == 0)
+	{
+          lt_debug = 1;
+          continue;
+	}
+      if (strcmp (argv[i], ltwrapper_option_prefix) == 0)
+        {
+          /* however, if there is an option in the LTWRAPPER_OPTION_PREFIX
+             namespace, but it is not one of the ones we know about and
+             have already dealt with, above (inluding dump-script), then
+             report an error. Otherwise, targets might begin to believe
+             they are allowed to use options in the LTWRAPPER_OPTION_PREFIX
+             namespace. The first time any user complains about this, we'll
+             need to make LTWRAPPER_OPTION_PREFIX a configure-time option
+             or a configure.ac-settable value.
+           */
+          lt_fatal (__FILE__, __LINE__,
+		    "unrecognized %s option: '%s'",
+                    ltwrapper_option_prefix, argv[i]);
+        }
+      /* otherwise ... */
+      newargz[++newargc] = xstrdup (argv[i]);
     }
-
-  newargz = XMALLOC (char *, argc + 1);
+  newargz[++newargc] = NULL;
+
+EOF
+	    cat <<EOF
+  /* The GNU banner must be the first non-error debug message */
+  lt_debugprintf (__FILE__, __LINE__, "libtool wrapper (GNU $PACKAGE$TIMESTAMP) $VERSION\n");
+EOF
+	    cat <<"EOF"
+  lt_debugprintf (__FILE__, __LINE__, "(main) argv[0]: %s\n", argv[0]);
+  lt_debugprintf (__FILE__, __LINE__, "(main) program_name: %s\n", program_name);
+
   tmp_pathspec = find_executable (argv[0]);
   if (tmp_pathspec == NULL)
-    lt_fatal ("Couldn't find %s", argv[0]);
-  LTWRAPPER_DEBUGPRINTF (("(main) found exe (before symlink chase) at : %s\n",
-			  tmp_pathspec));
+    lt_fatal (__FILE__, __LINE__, "couldn't find %s", argv[0]);
+  lt_debugprintf (__FILE__, __LINE__,
+                  "(main) found exe (before symlink chase) at: %s\n",
+		  tmp_pathspec);
 
   actual_cwrapper_path = chase_symlinks (tmp_pathspec);
-  LTWRAPPER_DEBUGPRINTF (("(main) found exe (after symlink chase) at : %s\n",
-			  actual_cwrapper_path));
+  lt_debugprintf (__FILE__, __LINE__,
+                  "(main) found exe (after symlink chase) at: %s\n",
+		  actual_cwrapper_path);
   XFREE (tmp_pathspec);
 
-  actual_cwrapper_name = xstrdup( base_name (actual_cwrapper_path));
+  actual_cwrapper_name = xstrdup (base_name (actual_cwrapper_path));
   strendzap (actual_cwrapper_path, actual_cwrapper_name);
 
   /* wrapper name transforms */
@@ -3427,8 +4450,9 @@
   target_name = tmp_pathspec;
   tmp_pathspec = 0;
 
-  LTWRAPPER_DEBUGPRINTF (("(main) libtool target name: %s\n",
-			  target_name));
+  lt_debugprintf (__FILE__, __LINE__,
+		  "(main) libtool target name: %s\n",
+		  target_name);
 EOF
 
 	    cat <<EOF
@@ -3478,80 +4502,19 @@
 
   lt_setenv ("BIN_SH", "xpg4"); /* for Tru64 */
   lt_setenv ("DUALCASE", "1");  /* for MSK sh */
+  /* Update the DLL searchpath.  EXE_PATH_VALUE ($dllsearchpath) must
+     be prepended before (that is, appear after) LIB_PATH_VALUE ($temp_rpath)
+     because on Windows, both *_VARNAMEs are PATH but uninstalled
+     libraries must come first. */
+  lt_update_exe_path (EXE_PATH_VARNAME, EXE_PATH_VALUE);
   lt_update_lib_path (LIB_PATH_VARNAME, LIB_PATH_VALUE);
-  lt_update_exe_path (EXE_PATH_VARNAME, EXE_PATH_VALUE);
-
-  newargc=0;
-  for (i = 1; i < argc; i++)
-    {
-      if (strncmp (argv[i], env_set_opt, env_set_opt_len) == 0)
-        {
-          if (argv[i][env_set_opt_len] == '=')
-            {
-              const char *p = argv[i] + env_set_opt_len + 1;
-              lt_opt_process_env_set (p);
-            }
-          else if (argv[i][env_set_opt_len] == '\0' && i + 1 < argc)
-            {
-              lt_opt_process_env_set (argv[++i]); /* don't copy */
-            }
-          else
-            lt_fatal ("%s missing required argument", env_set_opt);
-          continue;
-        }
-      if (strncmp (argv[i], env_prepend_opt, env_prepend_opt_len) == 0)
-        {
-          if (argv[i][env_prepend_opt_len] == '=')
-            {
-              const char *p = argv[i] + env_prepend_opt_len + 1;
-              lt_opt_process_env_prepend (p);
-            }
-          else if (argv[i][env_prepend_opt_len] == '\0' && i + 1 < argc)
-            {
-              lt_opt_process_env_prepend (argv[++i]); /* don't copy */
-            }
-          else
-            lt_fatal ("%s missing required argument", env_prepend_opt);
-          continue;
-        }
-      if (strncmp (argv[i], env_append_opt, env_append_opt_len) == 0)
-        {
-          if (argv[i][env_append_opt_len] == '=')
-            {
-              const char *p = argv[i] + env_append_opt_len + 1;
-              lt_opt_process_env_append (p);
-            }
-          else if (argv[i][env_append_opt_len] == '\0' && i + 1 < argc)
-            {
-              lt_opt_process_env_append (argv[++i]); /* don't copy */
-            }
-          else
-            lt_fatal ("%s missing required argument", env_append_opt);
-          continue;
-        }
-      if (strncmp (argv[i], ltwrapper_option_prefix, opt_prefix_len) == 0)
-        {
-          /* however, if there is an option in the LTWRAPPER_OPTION_PREFIX
-             namespace, but it is not one of the ones we know about and
-             have already dealt with, above (inluding dump-script), then
-             report an error. Otherwise, targets might begin to believe
-             they are allowed to use options in the LTWRAPPER_OPTION_PREFIX
-             namespace. The first time any user complains about this, we'll
-             need to make LTWRAPPER_OPTION_PREFIX a configure-time option
-             or a configure.ac-settable value.
-           */
-          lt_fatal ("Unrecognized option in %s namespace: '%s'",
-                    ltwrapper_option_prefix, argv[i]);
-        }
-      /* otherwise ... */
-      newargz[++newargc] = xstrdup (argv[i]);
-    }
-  newargz[++newargc] = NULL;
-
-  LTWRAPPER_DEBUGPRINTF     (("(main) lt_argv_zero : %s\n", (lt_argv_zero ? lt_argv_zero : "<NULL>")));
+
+  lt_debugprintf (__FILE__, __LINE__, "(main) lt_argv_zero: %s\n",
+		  nonnull (lt_argv_zero));
   for (i = 0; i < newargc; i++)
     {
-      LTWRAPPER_DEBUGPRINTF (("(main) newargz[%d]   : %s\n", i, (newargz[i] ? newargz[i] : "<NULL>")));
+      lt_debugprintf (__FILE__, __LINE__, "(main) newargz[%d]: %s\n",
+		      i, nonnull (newargz[i]));
     }
 
 EOF
@@ -3560,11 +4523,14 @@
 	      mingw*)
 		cat <<"EOF"
   /* execv doesn't actually work on mingw as expected on unix */
+  newargz = prepare_spawn (newargz);
   rval = _spawnv (_P_WAIT, lt_argv_zero, (const char * const *) newargz);
   if (rval == -1)
     {
       /* failed to start process */
-      LTWRAPPER_DEBUGPRINTF (("(main) failed to launch target \"%s\": errno = %d\n", lt_argv_zero, errno));
+      lt_debugprintf (__FILE__, __LINE__,
+		      "(main) failed to launch target \"%s\": %s\n",
+		      lt_argv_zero, nonnull (strerror (errno)));
       return 127;
     }
   return rval;
@@ -3586,7 +4552,7 @@
 {
   void *p = (void *) malloc (num);
   if (!p)
-    lt_fatal ("Memory exhausted");
+    lt_fatal (__FILE__, __LINE__, "memory exhausted");
 
   return p;
 }
@@ -3620,8 +4586,8 @@
 {
   struct stat st;
 
-  LTWRAPPER_DEBUGPRINTF (("(check_executable)  : %s\n",
-			  path ? (*path ? path : "EMPTY!") : "NULL!"));
+  lt_debugprintf (__FILE__, __LINE__, "(check_executable): %s\n",
+                  nonempty (path));
   if ((!path) || (!*path))
     return 0;
 
@@ -3638,8 +4604,8 @@
   int rval = 0;
   struct stat st;
 
-  LTWRAPPER_DEBUGPRINTF (("(make_executable)   : %s\n",
-			  path ? (*path ? path : "EMPTY!") : "NULL!"));
+  lt_debugprintf (__FILE__, __LINE__, "(make_executable): %s\n",
+                  nonempty (path));
   if ((!path) || (!*path))
     return 0;
 
@@ -3665,8 +4631,8 @@
   int tmp_len;
   char *concat_name;
 
-  LTWRAPPER_DEBUGPRINTF (("(find_executable)   : %s\n",
-			  wrapper ? (*wrapper ? wrapper : "EMPTY!") : "NULL!"));
+  lt_debugprintf (__FILE__, __LINE__, "(find_executable): %s\n",
+                  nonempty (wrapper));
 
   if ((wrapper == NULL) || (*wrapper == '\0'))
     return NULL;
@@ -3719,7 +4685,8 @@
 		{
 		  /* empty path: current directory */
 		  if (getcwd (tmp, LT_PATHMAX) == NULL)
-		    lt_fatal ("getcwd failed");
+		    lt_fatal (__FILE__, __LINE__, "getcwd failed: %s",
+                              nonnull (strerror (errno)));
 		  tmp_len = strlen (tmp);
 		  concat_name =
 		    XMALLOC (char, tmp_len + 1 + strlen (wrapper) + 1);
@@ -3744,7 +4711,8 @@
     }
   /* Relative path | not found in path: prepend cwd */
   if (getcwd (tmp, LT_PATHMAX) == NULL)
-    lt_fatal ("getcwd failed");
+    lt_fatal (__FILE__, __LINE__, "getcwd failed: %s",
+              nonnull (strerror (errno)));
   tmp_len = strlen (tmp);
   concat_name = XMALLOC (char, tmp_len + 1 + strlen (wrapper) + 1);
   memcpy (concat_name, tmp, tmp_len);
@@ -3770,8 +4738,9 @@
   int has_symlinks = 0;
   while (strlen (tmp_pathspec) && !has_symlinks)
     {
-      LTWRAPPER_DEBUGPRINTF (("checking path component for symlinks: %s\n",
-			      tmp_pathspec));
+      lt_debugprintf (__FILE__, __LINE__,
+		      "checking path component for symlinks: %s\n",
+		      tmp_pathspec);
       if (lstat (tmp_pathspec, &s) == 0)
 	{
 	  if (S_ISLNK (s.st_mode) != 0)
@@ -3793,8 +4762,9 @@
 	}
       else
 	{
-	  char *errstr = strerror (errno);
-	  lt_fatal ("Error accessing file %s (%s)", tmp_pathspec, errstr);
+	  lt_fatal (__FILE__, __LINE__,
+		    "error accessing file \"%s\": %s",
+		    tmp_pathspec, nonnull (strerror (errno)));
 	}
     }
   XFREE (tmp_pathspec);
@@ -3807,7 +4777,8 @@
   tmp_pathspec = realpath (pathspec, buf);
   if (tmp_pathspec == 0)
     {
-      lt_fatal ("Could not follow symlinks for %s", pathspec);
+      lt_fatal (__FILE__, __LINE__,
+		"could not follow symlinks for %s", pathspec);
     }
   return xstrdup (tmp_pathspec);
 #endif
@@ -3833,11 +4804,25 @@
   return str;
 }
 
+void
+lt_debugprintf (const char *file, int line, const char *fmt, ...)
+{
+  va_list args;
+  if (lt_debug)
+    {
+      (void) fprintf (stderr, "%s:%s:%d: ", program_name, file, line);
+      va_start (args, fmt);
+      (void) vfprintf (stderr, fmt, args);
+      va_end (args);
+    }
+}
+
 static void
-lt_error_core (int exit_status, const char *mode,
+lt_error_core (int exit_status, const char *file,
+	       int line, const char *mode,
 	       const char *message, va_list ap)
 {
-  fprintf (stderr, "%s: %s: ", program_name, mode);
+  fprintf (stderr, "%s:%s:%d: %s: ", program_name, file, line, mode);
   vfprintf (stderr, message, ap);
   fprintf (stderr, ".\n");
 
@@ -3846,20 +4831,32 @@
 }
 
 void
-lt_fatal (const char *message, ...)
+lt_fatal (const char *file, int line, const char *message, ...)
 {
   va_list ap;
   va_start (ap, message);
-  lt_error_core (EXIT_FAILURE, "FATAL", message, ap);
+  lt_error_core (EXIT_FAILURE, file, line, "FATAL", message, ap);
   va_end (ap);
 }
 
+static const char *
+nonnull (const char *s)
+{
+  return s ? s : "(null)";
+}
+
+static const char *
+nonempty (const char *s)
+{
+  return (s && !*s) ? "(empty)" : nonnull (s);
+}
+
 void
 lt_setenv (const char *name, const char *value)
 {
-  LTWRAPPER_DEBUGPRINTF (("(lt_setenv) setting '%s' to '%s'\n",
-                          (name ? name : "<NULL>"),
-                          (value ? value : "<NULL>")));
+  lt_debugprintf (__FILE__, __LINE__,
+		  "(lt_setenv) setting '%s' to '%s'\n",
+                  nonnull (name), nonnull (value));
   {
 #ifdef HAVE_SETENV
     /* always make a copy, for consistency with !HAVE_SETENV */
@@ -3904,95 +4901,12 @@
   return new_value;
 }
 
-int
-lt_split_name_value (const char *arg, char** name, char** value)
-{
-  const char *p;
-  int len;
-  if (!arg || !*arg)
-    return 1;
-
-  p = strchr (arg, (int)'=');
-
-  if (!p)
-    return 1;
-
-  *value = xstrdup (++p);
-
-  len = strlen (arg) - strlen (*value);
-  *name = XMALLOC (char, len);
-  strncpy (*name, arg, len-1);
-  (*name)[len - 1] = '\0';
-
-  return 0;
-}
-
-void
-lt_opt_process_env_set (const char *arg)
-{
-  char *name = NULL;
-  char *value = NULL;
-
-  if (lt_split_name_value (arg, &name, &value) != 0)
-    {
-      XFREE (name);
-      XFREE (value);
-      lt_fatal ("bad argument for %s: '%s'", env_set_opt, arg);
-    }
-
-  lt_setenv (name, value);
-  XFREE (name);
-  XFREE (value);
-}
-
-void
-lt_opt_process_env_prepend (const char *arg)
-{
-  char *name = NULL;
-  char *value = NULL;
-  char *new_value = NULL;
-
-  if (lt_split_name_value (arg, &name, &value) != 0)
-    {
-      XFREE (name);
-      XFREE (value);
-      lt_fatal ("bad argument for %s: '%s'", env_prepend_opt, arg);
-    }
-
-  new_value = lt_extend_str (getenv (name), value, 0);
-  lt_setenv (name, new_value);
-  XFREE (new_value);
-  XFREE (name);
-  XFREE (value);
-}
-
-void
-lt_opt_process_env_append (const char *arg)
-{
-  char *name = NULL;
-  char *value = NULL;
-  char *new_value = NULL;
-
-  if (lt_split_name_value (arg, &name, &value) != 0)
-    {
-      XFREE (name);
-      XFREE (value);
-      lt_fatal ("bad argument for %s: '%s'", env_append_opt, arg);
-    }
-
-  new_value = lt_extend_str (getenv (name), value, 1);
-  lt_setenv (name, new_value);
-  XFREE (new_value);
-  XFREE (name);
-  XFREE (value);
-}
-
 void
 lt_update_exe_path (const char *name, const char *value)
 {
-  LTWRAPPER_DEBUGPRINTF (("(lt_update_exe_path) modifying '%s' by prepending '%s'\n",
-                          (name ? name : "<NULL>"),
-                          (value ? value : "<NULL>")));
+  lt_debugprintf (__FILE__, __LINE__,
+		  "(lt_update_exe_path) modifying '%s' by prepending '%s'\n",
+                  nonnull (name), nonnull (value));
 
   if (name && *name && value && *value)
     {
@@ -4011,9 +4925,9 @@
 void
 lt_update_lib_path (const char *name, const char *value)
 {
-  LTWRAPPER_DEBUGPRINTF (("(lt_update_lib_path) modifying '%s' by prepending '%s'\n",
-                          (name ? name : "<NULL>"),
-                          (value ? value : "<NULL>")));
+  lt_debugprintf (__FILE__, __LINE__,
+		  "(lt_update_lib_path) modifying '%s' by prepending '%s'\n",
+                  nonnull (name), nonnull (value));
 
   if (name && *name && value && *value)
     {
@@ -4023,11 +4937,158 @@
     }
 }
 
-
+EOF
+	    case $host_os in
+	      mingw*)
+		cat <<"EOF"
+
+/* Prepares an argument vector before calling spawn().
+   Note that spawn() does not by itself call the command interpreter
+     (getenv ("COMSPEC") != NULL ? getenv ("COMSPEC") :
+      ({ OSVERSIONINFO v; v.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
+         GetVersionEx(&v);
+         v.dwPlatformId == VER_PLATFORM_WIN32_NT;
+      }) ? "cmd.exe" : "command.com").
+   Instead it simply concatenates the arguments, separated by ' ', and calls
+   CreateProcess().  We must quote the arguments since Win32 CreateProcess()
+   interprets characters like ' ', '\t', '\\', '"' (but not '<' and '>') in a
+   special way:
+   - Space and tab are interpreted as delimiters. They are not treated as
+     delimiters if they are surrounded by double quotes: "...".
+   - Unescaped double quotes are removed from the input. Their only effect is
+     that within double quotes, space and tab are treated like normal
+     characters.
+   - Backslashes not followed by double quotes are not special.
+   - But 2*n+1 backslashes followed by a double quote become
+     n backslashes followed by a double quote (n >= 0):
+       \" -> "
+       \\\" -> \"
+       \\\\\" -> \\"
+ */
+#define SHELL_SPECIAL_CHARS "\"\\ \001\002\003\004\005\006\007\010\011\012\013\014\015\016\017\020\021\022\023\024\025\026\027\030\031\032\033\034\035\036\037"
+#define SHELL_SPACE_CHARS " \001\002\003\004\005\006\007\010\011\012\013\014\015\016\017\020\021\022\023\024\025\026\027\030\031\032\033\034\035\036\037"
+char **
+prepare_spawn (char **argv)
+{
+  size_t argc;
+  char **new_argv;
+  size_t i;
+
+  /* Count number of arguments.  */
+  for (argc = 0; argv[argc] != NULL; argc++)
+    ;
+
+  /* Allocate new argument vector.  */
+  new_argv = XMALLOC (char *, argc + 1);
+
+  /* Put quoted arguments into the new argument vector.  */
+  for (i = 0; i < argc; i++)
+    {
+      const char *string = argv[i];
+
+      if (string[0] == '\0')
+	new_argv[i] = xstrdup ("\"\"");
+      else if (strpbrk (string, SHELL_SPECIAL_CHARS) != NULL)
+	{
+	  int quote_around = (strpbrk (string, SHELL_SPACE_CHARS) != NULL);
+	  size_t length;
+	  unsigned int backslashes;
+	  const char *s;
+	  char *quoted_string;
+	  char *p;
+
+	  length = 0;
+	  backslashes = 0;
+	  if (quote_around)
+	    length++;
+	  for (s = string; *s != '\0'; s++)
+	    {
+	      char c = *s;
+	      if (c == '"')
+		length += backslashes + 1;
+	      length++;
+	      if (c == '\\')
+		backslashes++;
+	      else
+		backslashes = 0;
+	    }
+	  if (quote_around)
+	    length += backslashes + 1;
+
+	  quoted_string = XMALLOC (char, length + 1);
+
+	  p = quoted_string;
+	  backslashes = 0;
+	  if (quote_around)
+	    *p++ = '"';
+	  for (s = string; *s != '\0'; s++)
+	    {
+	      char c = *s;
+	      if (c == '"')
+		{
+		  unsigned int j;
+		  for (j = backslashes + 1; j > 0; j--)
+		    *p++ = '\\';
+		}
+	      *p++ = c;
+	      if (c == '\\')
+		backslashes++;
+	      else
+		backslashes = 0;
+	    }
+	  if (quote_around)
+	    {
+	      unsigned int j;
+	      for (j = backslashes; j > 0; j--)
+		*p++ = '\\';
+	      *p++ = '"';
+	    }
+	  *p = '\0';
+
+	  new_argv[i] = quoted_string;
+	}
+      else
+	new_argv[i] = (char *) string;
+    }
+  new_argv[argc] = NULL;
+
+  return new_argv;
+}
+EOF
+		;;
+	    esac
+
+            cat <<"EOF"
+void lt_dump_script (FILE* f)
+{
+EOF
+	    func_emit_wrapper yes |
+	      $SED -n -e '
+s/^\(.\{79\}\)\(..*\)/\1\
+\2/
+h
+s/\([\\"]\)/\\\1/g
+s/$/\\n/
+s/\([^\n]*\).*/  fputs ("\1", f);/p
+g
+D'
+            cat <<"EOF"
+}
 EOF
 }
 # end: func_emit_cwrapperexe_src
 
+# func_win32_import_lib_p ARG
+# True if ARG is an import lib, as indicated by $file_magic_cmd
+func_win32_import_lib_p ()
+{
+    $opt_debug
+    case `eval $file_magic_cmd \"\$1\" 2>/dev/null | $SED -e 10q` in
+    *import*) : ;;
+    *) false ;;
+    esac
+}
+
 # func_mode_link arg...
 func_mode_link ()
 {
@@ -4072,6 +5133,7 @@
     new_inherited_linker_flags=
 
     avoid_version=no
+    bindir=
     dlfiles=
     dlprefiles=
     dlself=no
@@ -4164,6 +5226,11 @@
 	esac
 
 	case $prev in
+	bindir)
+	  bindir="$arg"
+	  prev=
+	  continue
+	  ;;
 	dlfiles|dlprefiles)
 	  if test "$preload" = no; then
 	    # Add the symbol object into the linking commands.
@@ -4195,9 +5262,9 @@
 	    ;;
 	  *)
 	    if test "$prev" = dlfiles; then
-	      dlfiles="$dlfiles $arg"
+	      func_append dlfiles " $arg"
 	    else
-	      dlprefiles="$dlprefiles $arg"
+	      func_append dlprefiles " $arg"
 	    fi
 	    prev=
 	    continue
@@ -4221,7 +5288,7 @@
 	    *-*-darwin*)
 	      case "$deplibs " in
 		*" $qarg.ltframework "*) ;;
-		*) deplibs="$deplibs $qarg.ltframework" # this is fixed later
+		*) func_append deplibs " $qarg.ltframework" # this is fixed later
 		   ;;
 	      esac
 	      ;;
@@ -4240,7 +5307,7 @@
 	    moreargs=
 	    for fil in `cat "$save_arg"`
 	    do
-#	      moreargs="$moreargs $fil"
+#	      func_append moreargs " $fil"
 	      arg=$fil
 	      # A libtool-controlled object.
 
@@ -4269,7 +5336,7 @@
 
 		  if test "$prev" = dlfiles; then
 		    if test "$build_libtool_libs" = yes && test "$dlopen_support" = yes; then
-		      dlfiles="$dlfiles $pic_object"
+		      func_append dlfiles " $pic_object"
 		      prev=
 		      continue
 		    else
@@ -4281,7 +5348,7 @@
 		  # CHECK ME:  I think I busted this.  -Ossama
 		  if test "$prev" = dlprefiles; then
 		    # Preload the old-style object.
-		    dlprefiles="$dlprefiles $pic_object"
+		    func_append dlprefiles " $pic_object"
 		    prev=
 		  fi
 
@@ -4351,12 +5418,12 @@
 	  if test "$prev" = rpath; then
 	    case "$rpath " in
 	    *" $arg "*) ;;
-	    *) rpath="$rpath $arg" ;;
+	    *) func_append rpath " $arg" ;;
 	    esac
 	  else
 	    case "$xrpath " in
 	    *" $arg "*) ;;
-	    *) xrpath="$xrpath $arg" ;;
+	    *) func_append xrpath " $arg" ;;
 	    esac
 	  fi
 	  prev=
@@ -4368,28 +5435,28 @@
 	  continue
 	  ;;
 	weak)
-	  weak_libs="$weak_libs $arg"
+	  func_append weak_libs " $arg"
 	  prev=
 	  continue
 	  ;;
 	xcclinker)
-	  linker_flags="$linker_flags $qarg"
-	  compiler_flags="$compiler_flags $qarg"
+	  func_append linker_flags " $qarg"
+	  func_append compiler_flags " $qarg"
 	  prev=
 	  func_append compile_command " $qarg"
 	  func_append finalize_command " $qarg"
 	  continue
 	  ;;
 	xcompiler)
-	  compiler_flags="$compiler_flags $qarg"
+	  func_append compiler_flags " $qarg"
 	  prev=
 	  func_append compile_command " $qarg"
 	  func_append finalize_command " $qarg"
 	  continue
 	  ;;
 	xlinker)
-	  linker_flags="$linker_flags $qarg"
-	  compiler_flags="$compiler_flags $wl$qarg"
+	  func_append linker_flags " $qarg"
+	  func_append compiler_flags " $wl$qarg"
 	  prev=
 	  func_append compile_command " $wl$qarg"
 	  func_append finalize_command " $wl$qarg"
@@ -4425,6 +5492,11 @@
 	continue
 	;;
 
+      -bindir)
+	prev=bindir
+	continue
+	;;
+
       -dlopen)
 	prev=dlfiles
 	continue
@@ -4475,15 +5547,16 @@
 	;;
 
       -L*)
-	func_stripname '-L' '' "$arg"
-	dir=$func_stripname_result
-	if test -z "$dir"; then
+	func_stripname "-L" '' "$arg"
+	if test -z "$func_stripname_result"; then
 	  if test "$#" -gt 0; then
 	    func_fatal_error "require no space between \`-L' and \`$1'"
 	  else
 	    func_fatal_error "need path for \`-L' option"
 	  fi
 	fi
+	func_resolve_sysroot "$func_stripname_result"
+	dir=$func_resolve_sysroot_result
 	# We need an absolute path.
 	case $dir in
 	[\\/]* | [A-Za-z]:[\\/]*) ;;
@@ -4495,24 +5568,30 @@
 	  ;;
 	esac
 	case "$deplibs " in
-	*" -L$dir "*) ;;
+	*" -L$dir "* | *" $arg "*)
+	  # Will only happen for absolute or sysroot arguments
+	  ;;
 	*)
-	  deplibs="$deplibs -L$dir"
-	  lib_search_path="$lib_search_path $dir"
+	  # Preserve sysroot, but never include relative directories
+	  case $dir in
+	    [\\/]* | [A-Za-z]:[\\/]* | =*) func_append deplibs " $arg" ;;
+	    *) func_append deplibs " -L$dir" ;;
+	  esac
+	  func_append lib_search_path " $dir"
 	  ;;
 	esac
 	case $host in
 	*-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-os2* | *-cegcc*)
-	  testbindir=`$ECHO "X$dir" | $Xsed -e 's*/lib$*/bin*'`
+	  testbindir=`$ECHO "$dir" | $SED 's*/lib$*/bin*'`
 	  case :$dllsearchpath: in
 	  *":$dir:"*) ;;
 	  ::) dllsearchpath=$dir;;
-	  *) dllsearchpath="$dllsearchpath:$dir";;
+	  *) func_append dllsearchpath ":$dir";;
 	  esac
 	  case :$dllsearchpath: in
 	  *":$testbindir:"*) ;;
 	  ::) dllsearchpath=$testbindir;;
-	  *) dllsearchpath="$dllsearchpath:$testbindir";;
+	  *) func_append dllsearchpath ":$testbindir";;
 	  esac
 	  ;;
 	esac
@@ -4522,7 +5601,7 @@
       -l*)
 	if test "X$arg" = "X-lc" || test "X$arg" = "X-lm"; then
 	  case $host in
-	  *-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-beos* | *-cegcc*)
+	  *-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-beos* | *-cegcc* | *-*-haiku*)
 	    # These systems don't actually have a C or math library (as such)
 	    continue
 	    ;;
@@ -4536,7 +5615,7 @@
 	    ;;
 	  *-*-rhapsody* | *-*-darwin1.[012])
 	    # Rhapsody C and math libraries are in the System framework
-	    deplibs="$deplibs System.ltframework"
+	    func_append deplibs " System.ltframework"
 	    continue
 	    ;;
 	  *-*-sco3.2v5* | *-*-sco5v6*)
@@ -4556,7 +5635,7 @@
 	   ;;
 	 esac
 	fi
-	deplibs="$deplibs $arg"
+	func_append deplibs " $arg"
 	continue
 	;;
 
@@ -4568,21 +5647,22 @@
       # Tru64 UNIX uses -model [arg] to determine the layout of C++
       # classes, name mangling, and exception handling.
       # Darwin uses the -arch flag to determine output architecture.
-      -model|-arch|-isysroot)
-	compiler_flags="$compiler_flags $arg"
+      -model|-arch|-isysroot|--sysroot)
+	func_append compiler_flags " $arg"
 	func_append compile_command " $arg"
 	func_append finalize_command " $arg"
 	prev=xcompiler
 	continue
 	;;
 
-      -mt|-mthreads|-kthread|-Kthread|-pthread|-pthreads|--thread-safe|-threads)
-	compiler_flags="$compiler_flags $arg"
+      -mt|-mthreads|-kthread|-Kthread|-pthread|-pthreads|--thread-safe \
+      |-threads|-fopenmp|-openmp|-mp|-xopenmp|-omp|-qsmp=*)
+	func_append compiler_flags " $arg"
 	func_append compile_command " $arg"
 	func_append finalize_command " $arg"
 	case "$new_inherited_linker_flags " in
 	    *" $arg "*) ;;
-	    * ) new_inherited_linker_flags="$new_inherited_linker_flags $arg" ;;
+	    * ) func_append new_inherited_linker_flags " $arg" ;;
 	esac
 	continue
 	;;
@@ -4649,13 +5729,17 @@
 	# We need an absolute path.
 	case $dir in
 	[\\/]* | [A-Za-z]:[\\/]*) ;;
+	=*)
+	  func_stripname '=' '' "$dir"
+	  dir=$lt_sysroot$func_stripname_result
+	  ;;
 	*)
 	  func_fatal_error "only absolute run-paths are allowed"
 	  ;;
 	esac
 	case "$xrpath " in
 	*" $dir "*) ;;
-	*) xrpath="$xrpath $dir" ;;
+	*) func_append xrpath " $dir" ;;
 	esac
 	continue
 	;;
@@ -4708,8 +5792,8 @@
 	for flag in $args; do
 	  IFS="$save_ifs"
           func_quote_for_eval "$flag"
-	  arg="$arg $wl$func_quote_for_eval_result"
-	  compiler_flags="$compiler_flags $func_quote_for_eval_result"
+	  func_append arg " $func_quote_for_eval_result"
+	  func_append compiler_flags " $func_quote_for_eval_result"
 	done
 	IFS="$save_ifs"
 	func_stripname ' ' '' "$arg"
@@ -4724,9 +5808,9 @@
 	for flag in $args; do
 	  IFS="$save_ifs"
           func_quote_for_eval "$flag"
-	  arg="$arg $wl$func_quote_for_eval_result"
-	  compiler_flags="$compiler_flags $wl$func_quote_for_eval_result"
-	  linker_flags="$linker_flags $func_quote_for_eval_result"
+	  func_append arg " $wl$func_quote_for_eval_result"
+	  func_append compiler_flags " $wl$func_quote_for_eval_result"
+	  func_append linker_flags " $func_quote_for_eval_result"
 	done
 	IFS="$save_ifs"
 	func_stripname ' ' '' "$arg"
@@ -4754,23 +5838,27 @@
 	arg="$func_quote_for_eval_result"
 	;;
 
-      # -64, -mips[0-9] enable 64-bit mode on the SGI compiler
-      # -r[0-9][0-9]* specifies the processor on the SGI compiler
-      # -xarch=*, -xtarget=* enable 64-bit mode on the Sun compiler
-      # +DA*, +DD* enable 64-bit mode on the HP compiler
-      # -q* pass through compiler args for the IBM compiler
-      # -m*, -t[45]*, -txscale* pass through architecture-specific
-      # compiler args for GCC
-      # -F/path gives path to uninstalled frameworks, gcc on darwin
-      # -p, -pg, --coverage, -fprofile-* pass through profiling flag for GCC
-      # @file GCC response files
+      # Flags to be passed through unchanged, with rationale:
+      # -64, -mips[0-9]      enable 64-bit mode for the SGI compiler
+      # -r[0-9][0-9]*        specify processor for the SGI compiler
+      # -xarch=*, -xtarget=* enable 64-bit mode for the Sun compiler
+      # +DA*, +DD*           enable 64-bit mode for the HP compiler
+      # -q*                  compiler args for the IBM compiler
+      # -m*, -t[45]*, -txscale* architecture-specific flags for GCC
+      # -F/path              path to uninstalled frameworks, gcc on darwin
+      # -p, -pg, --coverage, -fprofile-*  profiling flags for GCC
+      # @file                GCC response files
+      # -tp=*                Portland pgcc target processor selection
+      # --sysroot=*          for sysroot support
+      # -O*, -flto*, -fwhopr*, -fuse-linker-plugin GCC link-time optimization
       -64|-mips[0-9]|-r[0-9][0-9]*|-xarch=*|-xtarget=*|+DA*|+DD*|-q*|-m*| \
-      -t[45]*|-txscale*|-p|-pg|--coverage|-fprofile-*|-F*|@*)
+      -t[45]*|-txscale*|-p|-pg|--coverage|-fprofile-*|-F*|@*|-tp=*|--sysroot=*| \
+      -O*|-flto*|-fwhopr*|-fuse-linker-plugin)
         func_quote_for_eval "$arg"
 	arg="$func_quote_for_eval_result"
         func_append compile_command " $arg"
         func_append finalize_command " $arg"
-        compiler_flags="$compiler_flags $arg"
+        func_append compiler_flags " $arg"
         continue
         ;;
 
@@ -4782,7 +5870,7 @@
 
       *.$objext)
 	# A standard object.
-	objs="$objs $arg"
+	func_append objs " $arg"
 	;;
 
       *.lo)
@@ -4813,7 +5901,7 @@
 
 	    if test "$prev" = dlfiles; then
 	      if test "$build_libtool_libs" = yes && test "$dlopen_support" = yes; then
-		dlfiles="$dlfiles $pic_object"
+		func_append dlfiles " $pic_object"
 		prev=
 		continue
 	      else
@@ -4825,7 +5913,7 @@
 	    # CHECK ME:  I think I busted this.  -Ossama
 	    if test "$prev" = dlprefiles; then
 	      # Preload the old-style object.
-	      dlprefiles="$dlprefiles $pic_object"
+	      func_append dlprefiles " $pic_object"
 	      prev=
 	    fi
 
@@ -4870,24 +5958,25 @@
 
       *.$libext)
 	# An archive.
-	deplibs="$deplibs $arg"
-	old_deplibs="$old_deplibs $arg"
+	func_append deplibs " $arg"
+	func_append old_deplibs " $arg"
 	continue
 	;;
 
       *.la)
 	# A libtool-controlled library.
 
+	func_resolve_sysroot "$arg"
 	if test "$prev" = dlfiles; then
 	  # This library was specified with -dlopen.
-	  dlfiles="$dlfiles $arg"
+	  func_append dlfiles " $func_resolve_sysroot_result"
 	  prev=
 	elif test "$prev" = dlprefiles; then
 	  # The library was specified with -dlpreopen.
-	  dlprefiles="$dlprefiles $arg"
+	  func_append dlprefiles " $func_resolve_sysroot_result"
 	  prev=
 	else
-	  deplibs="$deplibs $arg"
+	  func_append deplibs " $func_resolve_sysroot_result"
 	fi
 	continue
 	;;
@@ -4925,7 +6014,7 @@
 
     if test -n "$shlibpath_var"; then
       # get the directories listed in $shlibpath_var
-      eval shlib_search_path=\`\$ECHO \"X\${$shlibpath_var}\" \| \$Xsed -e \'s/:/ /g\'\`
+      eval shlib_search_path=\`\$ECHO \"\${$shlibpath_var}\" \| \$SED \'s/:/ /g\'\`
     else
       shlib_search_path=
     fi
@@ -4934,6 +6023,8 @@
 
     func_dirname "$output" "/" ""
     output_objdir="$func_dirname_result$objdir"
+    func_to_tool_file "$output_objdir/"
+    tool_output_objdir=$func_to_tool_file_result
     # Create the object directory.
     func_mkdir_p "$output_objdir"
 
@@ -4954,12 +6045,12 @@
     # Find all interdependent deplibs by searching for libraries
     # that are linked more than once (e.g. -la -lb -la)
     for deplib in $deplibs; do
-      if $opt_duplicate_deps ; then
+      if $opt_preserve_dup_deps ; then
 	case "$libs " in
-	*" $deplib "*) specialdeplibs="$specialdeplibs $deplib" ;;
+	*" $deplib "*) func_append specialdeplibs " $deplib" ;;
 	esac
       fi
-      libs="$libs $deplib"
+      func_append libs " $deplib"
     done
 
     if test "$linkmode" = lib; then
@@ -4972,9 +6063,9 @@
       if $opt_duplicate_compiler_generated_deps; then
 	for pre_post_dep in $predeps $postdeps; do
 	  case "$pre_post_deps " in
-	  *" $pre_post_dep "*) specialdeplibs="$specialdeplibs $pre_post_deps" ;;
+	  *" $pre_post_dep "*) func_append specialdeplibs " $pre_post_deps" ;;
 	  esac
-	  pre_post_deps="$pre_post_deps $pre_post_dep"
+	  func_append pre_post_deps " $pre_post_dep"
 	done
       fi
       pre_post_deps=
@@ -5044,17 +6135,19 @@
 	for lib in $dlprefiles; do
 	  # Ignore non-libtool-libs
 	  dependency_libs=
+	  func_resolve_sysroot "$lib"
 	  case $lib in
-	  *.la)	func_source "$lib" ;;
+	  *.la)	func_source "$func_resolve_sysroot_result" ;;
 	  esac
 
 	  # Collect preopened libtool deplibs, except any this library
 	  # has declared as weak libs
 	  for deplib in $dependency_libs; do
-            deplib_base=`$ECHO "X$deplib" | $Xsed -e "$basename"`
+	    func_basename "$deplib"
+            deplib_base=$func_basename_result
 	    case " $weak_libs " in
 	    *" $deplib_base "*) ;;
-	    *) deplibs="$deplibs $deplib" ;;
+	    *) func_append deplibs " $deplib" ;;
 	    esac
 	  done
 	done
@@ -5070,16 +6163,17 @@
 	lib=
 	found=no
 	case $deplib in
-	-mt|-mthreads|-kthread|-Kthread|-pthread|-pthreads|--thread-safe|-threads)
+	-mt|-mthreads|-kthread|-Kthread|-pthread|-pthreads|--thread-safe \
+        |-threads|-fopenmp|-openmp|-mp|-xopenmp|-omp|-qsmp=*)
 	  if test "$linkmode,$pass" = "prog,link"; then
 	    compile_deplibs="$deplib $compile_deplibs"
 	    finalize_deplibs="$deplib $finalize_deplibs"
 	  else
-	    compiler_flags="$compiler_flags $deplib"
+	    func_append compiler_flags " $deplib"
 	    if test "$linkmode" = lib ; then
 		case "$new_inherited_linker_flags " in
 		    *" $deplib "*) ;;
-		    * ) new_inherited_linker_flags="$new_inherited_linker_flags $deplib" ;;
+		    * ) func_append new_inherited_linker_flags " $deplib" ;;
 		esac
 	    fi
 	  fi
@@ -5164,7 +6258,7 @@
 	    if test "$linkmode" = lib ; then
 		case "$new_inherited_linker_flags " in
 		    *" $deplib "*) ;;
-		    * ) new_inherited_linker_flags="$new_inherited_linker_flags $deplib" ;;
+		    * ) func_append new_inherited_linker_flags " $deplib" ;;
 		esac
 	    fi
 	  fi
@@ -5177,7 +6271,8 @@
 	    test "$pass" = conv && continue
 	    newdependency_libs="$deplib $newdependency_libs"
 	    func_stripname '-L' '' "$deplib"
-	    newlib_search_path="$newlib_search_path $func_stripname_result"
+	    func_resolve_sysroot "$func_stripname_result"
+	    func_append newlib_search_path " $func_resolve_sysroot_result"
 	    ;;
 	  prog)
 	    if test "$pass" = conv; then
@@ -5191,7 +6286,8 @@
 	      finalize_deplibs="$deplib $finalize_deplibs"
 	    fi
 	    func_stripname '-L' '' "$deplib"
-	    newlib_search_path="$newlib_search_path $func_stripname_result"
+	    func_resolve_sysroot "$func_stripname_result"
+	    func_append newlib_search_path " $func_resolve_sysroot_result"
 	    ;;
 	  *)
 	    func_warning "\`-L' is ignored for archives/objects"
@@ -5202,17 +6298,21 @@
 	-R*)
 	  if test "$pass" = link; then
 	    func_stripname '-R' '' "$deplib"
-	    dir=$func_stripname_result
+	    func_resolve_sysroot "$func_stripname_result"
+	    dir=$func_resolve_sysroot_result
 	    # Make sure the xrpath contains only unique directories.
 	    case "$xrpath " in
 	    *" $dir "*) ;;
-	    *) xrpath="$xrpath $dir" ;;
+	    *) func_append xrpath " $dir" ;;
 	    esac
 	  fi
 	  deplibs="$deplib $deplibs"
 	  continue
 	  ;;
-	*.la) lib="$deplib" ;;
+	*.la)
+	  func_resolve_sysroot "$deplib"
+	  lib=$func_resolve_sysroot_result
+	  ;;
 	*.$libext)
 	  if test "$pass" = conv; then
 	    deplibs="$deplib $deplibs"
@@ -5230,7 +6330,7 @@
 		match_pattern*)
 		  set dummy $deplibs_check_method; shift
 		  match_pattern_regex=`expr "$deplibs_check_method" : "$1 \(.*\)"`
-		  if eval "\$ECHO \"X$deplib\"" 2>/dev/null | $Xsed -e 10q \
+		  if eval "\$ECHO \"$deplib\"" 2>/dev/null | $SED 10q \
 		    | $EGREP "$match_pattern_regex" > /dev/null; then
 		    valid_a_lib=yes
 		  fi
@@ -5240,15 +6340,15 @@
 		;;
 	      esac
 	      if test "$valid_a_lib" != yes; then
-		$ECHO
+		echo
 		$ECHO "*** Warning: Trying to link with static lib archive $deplib."
-		$ECHO "*** I have the capability to make that library automatically link in when"
-		$ECHO "*** you link to this library.  But I can only do this if you have a"
-		$ECHO "*** shared version of the library, which you do not appear to have"
-		$ECHO "*** because the file extensions .$libext of this argument makes me believe"
-		$ECHO "*** that it is just a static archive that I should not use here."
+		echo "*** I have the capability to make that library automatically link in when"
+		echo "*** you link to this library.  But I can only do this if you have a"
+		echo "*** shared version of the library, which you do not appear to have"
+		echo "*** because the file extensions .$libext of this argument makes me believe"
+		echo "*** that it is just a static archive that I should not use here."
 	      else
-		$ECHO
+		echo
 		$ECHO "*** Warning: Linking the shared library $output against the"
 		$ECHO "*** static library $deplib is not portable!"
 		deplibs="$deplib $deplibs"
@@ -5275,11 +6375,11 @@
 	    if test "$pass" = dlpreopen || test "$dlopen_support" != yes || test "$build_libtool_libs" = no; then
 	      # If there is no dlopen support or we're linking statically,
 	      # we need to preload.
-	      newdlprefiles="$newdlprefiles $deplib"
+	      func_append newdlprefiles " $deplib"
 	      compile_deplibs="$deplib $compile_deplibs"
 	      finalize_deplibs="$deplib $finalize_deplibs"
 	    else
-	      newdlfiles="$newdlfiles $deplib"
+	      func_append newdlfiles " $deplib"
 	    fi
 	  fi
 	  continue
@@ -5321,20 +6421,20 @@
 
 	# Convert "-framework foo" to "foo.ltframework"
 	if test -n "$inherited_linker_flags"; then
-	  tmp_inherited_linker_flags=`$ECHO "X$inherited_linker_flags" | $Xsed -e 's/-framework \([^ $]*\)/\1.ltframework/g'`
+	  tmp_inherited_linker_flags=`$ECHO "$inherited_linker_flags" | $SED 's/-framework \([^ $]*\)/\1.ltframework/g'`
 	  for tmp_inherited_linker_flag in $tmp_inherited_linker_flags; do
 	    case " $new_inherited_linker_flags " in
 	      *" $tmp_inherited_linker_flag "*) ;;
-	      *) new_inherited_linker_flags="$new_inherited_linker_flags $tmp_inherited_linker_flag";;
+	      *) func_append new_inherited_linker_flags " $tmp_inherited_linker_flag";;
 	    esac
 	  done
 	fi
-	dependency_libs=`$ECHO "X $dependency_libs" | $Xsed -e 's% \([^ $]*\).ltframework% -framework \1%g'`
+	dependency_libs=`$ECHO " $dependency_libs" | $SED 's% \([^ $]*\).ltframework% -framework \1%g'`
 	if test "$linkmode,$pass" = "lib,link" ||
 	   test "$linkmode,$pass" = "prog,scan" ||
 	   { test "$linkmode" != prog && test "$linkmode" != lib; }; then
-	  test -n "$dlopen" && dlfiles="$dlfiles $dlopen"
-	  test -n "$dlpreopen" && dlprefiles="$dlprefiles $dlpreopen"
+	  test -n "$dlopen" && func_append dlfiles " $dlopen"
+	  test -n "$dlpreopen" && func_append dlprefiles " $dlpreopen"
 	fi
 
 	if test "$pass" = conv; then
@@ -5345,17 +6445,17 @@
 	      func_fatal_error "cannot find name of link library for \`$lib'"
 	    fi
 	    # It is a libtool convenience library, so add in its objects.
-	    convenience="$convenience $ladir/$objdir/$old_library"
-	    old_convenience="$old_convenience $ladir/$objdir/$old_library"
+	    func_append convenience " $ladir/$objdir/$old_library"
+	    func_append old_convenience " $ladir/$objdir/$old_library"
 	    tmp_libs=
 	    for deplib in $dependency_libs; do
 	      deplibs="$deplib $deplibs"
-	      if $opt_duplicate_deps ; then
+	      if $opt_preserve_dup_deps ; then
 		case "$tmp_libs " in
-		*" $deplib "*) specialdeplibs="$specialdeplibs $deplib" ;;
+		*" $deplib "*) func_append specialdeplibs " $deplib" ;;
 		esac
 	      fi
-	      tmp_libs="$tmp_libs $deplib"
+	      func_append tmp_libs " $deplib"
 	    done
 	  elif test "$linkmode" != prog && test "$linkmode" != lib; then
 	    func_fatal_error "\`$lib' is not a convenience library"
@@ -5366,9 +6466,15 @@
 
 	# Get the name of the library we link against.
 	linklib=
-	for l in $old_library $library_names; do
-	  linklib="$l"
-	done
+	if test -n "$old_library" &&
+	   { test "$prefer_static_libs" = yes ||
+	     test "$prefer_static_libs,$installed" = "built,no"; }; then
+	  linklib=$old_library
+	else
+	  for l in $old_library $library_names; do
+	    linklib="$l"
+	  done
+	fi
 	if test -z "$linklib"; then
 	  func_fatal_error "cannot find name of link library for \`$lib'"
 	fi
@@ -5385,9 +6491,9 @@
 	    # statically, we need to preload.  We also need to preload any
 	    # dependent libraries so libltdl's deplib preloader doesn't
 	    # bomb out in the load deplibs phase.
-	    dlprefiles="$dlprefiles $lib $dependency_libs"
+	    func_append dlprefiles " $lib $dependency_libs"
 	  else
-	    newdlfiles="$newdlfiles $lib"
+	    func_append newdlfiles " $lib"
 	  fi
 	  continue
 	fi # $pass = dlopen
@@ -5409,14 +6515,14 @@
 
 	# Find the relevant object directory and library name.
 	if test "X$installed" = Xyes; then
-	  if test ! -f "$libdir/$linklib" && test -f "$abs_ladir/$linklib"; then
+	  if test ! -f "$lt_sysroot$libdir/$linklib" && test -f "$abs_ladir/$linklib"; then
 	    func_warning "library \`$lib' was moved."
 	    dir="$ladir"
 	    absdir="$abs_ladir"
 	    libdir="$abs_ladir"
 	  else
-	    dir="$libdir"
-	    absdir="$libdir"
+	    dir="$lt_sysroot$libdir"
+	    absdir="$lt_sysroot$libdir"
 	  fi
 	  test "X$hardcode_automatic" = Xyes && avoidtemprpath=yes
 	else
@@ -5424,12 +6530,12 @@
 	    dir="$ladir"
 	    absdir="$abs_ladir"
 	    # Remove this search path later
-	    notinst_path="$notinst_path $abs_ladir"
+	    func_append notinst_path " $abs_ladir"
 	  else
 	    dir="$ladir/$objdir"
 	    absdir="$abs_ladir/$objdir"
 	    # Remove this search path later
-	    notinst_path="$notinst_path $abs_ladir"
+	    func_append notinst_path " $abs_ladir"
 	  fi
 	fi # $installed = yes
 	func_stripname 'lib' '.la' "$laname"
@@ -5440,20 +6546,46 @@
 	  if test -z "$libdir" && test "$linkmode" = prog; then
 	    func_fatal_error "only libraries may -dlpreopen a convenience library: \`$lib'"
 	  fi
-	  # Prefer using a static library (so that no silly _DYNAMIC symbols
-	  # are required to link).
-	  if test -n "$old_library"; then
-	    newdlprefiles="$newdlprefiles $dir/$old_library"
-	    # Keep a list of preopened convenience libraries to check
-	    # that they are being used correctly in the link pass.
-	    test -z "$libdir" && \
-		dlpreconveniencelibs="$dlpreconveniencelibs $dir/$old_library"
-	  # Otherwise, use the dlname, so that lt_dlopen finds it.
-	  elif test -n "$dlname"; then
-	    newdlprefiles="$newdlprefiles $dir/$dlname"
-	  else
-	    newdlprefiles="$newdlprefiles $dir/$linklib"
-	  fi
+	  case "$host" in
+	    # special handling for platforms with PE-DLLs.
+	    *cygwin* | *mingw* | *cegcc* )
+	      # Linker will automatically link against shared library if both
+	      # static and shared are present.  Therefore, ensure we extract
+	      # symbols from the import library if a shared library is present
+	      # (otherwise, the dlopen module name will be incorrect).  We do
+	      # this by putting the import library name into $newdlprefiles.
+	      # We recover the dlopen module name by 'saving' the la file
+	      # name in a special purpose variable, and (later) extracting the
+	      # dlname from the la file.
+	      if test -n "$dlname"; then
+	        func_tr_sh "$dir/$linklib"
+	        eval "libfile_$func_tr_sh_result=\$abs_ladir/\$laname"
+	        func_append newdlprefiles " $dir/$linklib"
+	      else
+	        func_append newdlprefiles " $dir/$old_library"
+	        # Keep a list of preopened convenience libraries to check
+	        # that they are being used correctly in the link pass.
+	        test -z "$libdir" && \
+	          func_append dlpreconveniencelibs " $dir/$old_library"
+	      fi
+	    ;;
+	    * )
+	      # Prefer using a static library (so that no silly _DYNAMIC symbols
+	      # are required to link).
+	      if test -n "$old_library"; then
+	        func_append newdlprefiles " $dir/$old_library"
+	        # Keep a list of preopened convenience libraries to check
+	        # that they are being used correctly in the link pass.
+	        test -z "$libdir" && \
+	          func_append dlpreconveniencelibs " $dir/$old_library"
+	      # Otherwise, use the dlname, so that lt_dlopen finds it.
+	      elif test -n "$dlname"; then
+	        func_append newdlprefiles " $dir/$dlname"
+	      else
+	        func_append newdlprefiles " $dir/$linklib"
+	      fi
+	    ;;
+	  esac
 	fi # $pass = dlpreopen
 
 	if test -z "$libdir"; then
@@ -5471,7 +6603,7 @@
 
 
 	if test "$linkmode" = prog && test "$pass" != link; then
-	  newlib_search_path="$newlib_search_path $ladir"
+	  func_append newlib_search_path " $ladir"
 	  deplibs="$lib $deplibs"
 
 	  linkalldeplibs=no
@@ -5484,7 +6616,8 @@
 	  for deplib in $dependency_libs; do
 	    case $deplib in
 	    -L*) func_stripname '-L' '' "$deplib"
-	         newlib_search_path="$newlib_search_path $func_stripname_result"
+	         func_resolve_sysroot "$func_stripname_result"
+	         func_append newlib_search_path " $func_resolve_sysroot_result"
 		 ;;
 	    esac
 	    # Need to link against all dependency_libs?
@@ -5495,12 +6628,12 @@
 	      # or/and link against static libraries
 	      newdependency_libs="$deplib $newdependency_libs"
 	    fi
-	    if $opt_duplicate_deps ; then
+	    if $opt_preserve_dup_deps ; then
 	      case "$tmp_libs " in
-	      *" $deplib "*) specialdeplibs="$specialdeplibs $deplib" ;;
+	      *" $deplib "*) func_append specialdeplibs " $deplib" ;;
 	      esac
 	    fi
-	    tmp_libs="$tmp_libs $deplib"
+	    func_append tmp_libs " $deplib"
 	  done # for deplib
 	  continue
 	fi # $linkmode = prog...
@@ -5515,7 +6648,7 @@
 	      # Make sure the rpath contains only unique directories.
 	      case "$temp_rpath:" in
 	      *"$absdir:"*) ;;
-	      *) temp_rpath="$temp_rpath$absdir:" ;;
+	      *) func_append temp_rpath "$absdir:" ;;
 	      esac
 	    fi
 
@@ -5527,7 +6660,7 @@
 	    *)
 	      case "$compile_rpath " in
 	      *" $absdir "*) ;;
-	      *) compile_rpath="$compile_rpath $absdir"
+	      *) func_append compile_rpath " $absdir" ;;
 	      esac
 	      ;;
 	    esac
@@ -5536,7 +6669,7 @@
 	    *)
 	      case "$finalize_rpath " in
 	      *" $libdir "*) ;;
-	      *) finalize_rpath="$finalize_rpath $libdir"
+	      *) func_append finalize_rpath " $libdir" ;;
 	      esac
 	      ;;
 	    esac
@@ -5561,12 +6694,12 @@
 	  case $host in
 	  *cygwin* | *mingw* | *cegcc*)
 	      # No point in relinking DLLs because paths are not encoded
-	      notinst_deplibs="$notinst_deplibs $lib"
+	      func_append notinst_deplibs " $lib"
 	      need_relink=no
 	    ;;
 	  *)
 	    if test "$installed" = no; then
-	      notinst_deplibs="$notinst_deplibs $lib"
+	      func_append notinst_deplibs " $lib"
 	      need_relink=yes
 	    fi
 	    ;;
@@ -5583,7 +6716,7 @@
 	    fi
 	  done
 	  if test -z "$dlopenmodule" && test "$shouldnotlink" = yes && test "$pass" = link; then
-	    $ECHO
+	    echo
 	    if test "$linkmode" = prog; then
 	      $ECHO "*** Warning: Linking the executable $output against the loadable module"
 	    else
@@ -5601,7 +6734,7 @@
 	    *)
 	      case "$compile_rpath " in
 	      *" $absdir "*) ;;
-	      *) compile_rpath="$compile_rpath $absdir"
+	      *) func_append compile_rpath " $absdir" ;;
 	      esac
 	      ;;
 	    esac
@@ -5610,7 +6743,7 @@
 	    *)
 	      case "$finalize_rpath " in
 	      *" $libdir "*) ;;
-	      *) finalize_rpath="$finalize_rpath $libdir"
+	      *) func_append finalize_rpath " $libdir" ;;
 	      esac
 	      ;;
 	    esac
@@ -5664,7 +6797,7 @@
 	    linklib=$newlib
 	  fi # test -n "$old_archive_from_expsyms_cmds"
 
-	  if test "$linkmode" = prog || test "$mode" != relink; then
+	  if test "$linkmode" = prog || test "$opt_mode" != relink; then
 	    add_shlibpath=
 	    add_dir=
 	    add=
@@ -5686,9 +6819,9 @@
 		      if test "X$dlopenmodule" != "X$lib"; then
 			$ECHO "*** Warning: lib $linklib is a module, not a shared library"
 			if test -z "$old_library" ; then
-			  $ECHO
-			  $ECHO "*** And there doesn't seem to be a static archive available"
-			  $ECHO "*** The link will probably fail, sorry"
+			  echo
+			  echo "*** And there doesn't seem to be a static archive available"
+			  echo "*** The link will probably fail, sorry"
 			else
 			  add="$dir/$old_library"
 			fi
@@ -5715,12 +6848,12 @@
 	         test "$hardcode_direct_absolute" = no; then
 		add="$dir/$linklib"
 	      elif test "$hardcode_minus_L" = yes; then
-		add_dir="-L$dir"
+		add_dir="-L$absdir"
 		# Try looking first in the location we're being installed to.
 		if test -n "$inst_prefix_dir"; then
 		  case $libdir in
 		    [\\/]*)
-		      add_dir="$add_dir -L$inst_prefix_dir$libdir"
+		      func_append add_dir " -L$inst_prefix_dir$libdir"
 		      ;;
 		  esac
 		fi
@@ -5742,7 +6875,7 @@
 	    if test -n "$add_shlibpath"; then
 	      case :$compile_shlibpath: in
 	      *":$add_shlibpath:"*) ;;
-	      *) compile_shlibpath="$compile_shlibpath$add_shlibpath:" ;;
+	      *) func_append compile_shlibpath "$add_shlibpath:" ;;
 	      esac
 	    fi
 	    if test "$linkmode" = prog; then
@@ -5756,13 +6889,13 @@
 		 test "$hardcode_shlibpath_var" = yes; then
 		case :$finalize_shlibpath: in
 		*":$libdir:"*) ;;
-		*) finalize_shlibpath="$finalize_shlibpath$libdir:" ;;
+		*) func_append finalize_shlibpath "$libdir:" ;;
 		esac
 	      fi
 	    fi
 	  fi
 
-	  if test "$linkmode" = prog || test "$mode" = relink; then
+	  if test "$linkmode" = prog || test "$opt_mode" = relink; then
 	    add_shlibpath=
 	    add_dir=
 	    add=
@@ -5776,7 +6909,7 @@
 	    elif test "$hardcode_shlibpath_var" = yes; then
 	      case :$finalize_shlibpath: in
 	      *":$libdir:"*) ;;
-	      *) finalize_shlibpath="$finalize_shlibpath$libdir:" ;;
+	      *) func_append finalize_shlibpath "$libdir:" ;;
 	      esac
 	      add="-l$name"
 	    elif test "$hardcode_automatic" = yes; then
@@ -5793,7 +6926,7 @@
 	      if test -n "$inst_prefix_dir"; then
 		case $libdir in
 		  [\\/]*)
-		    add_dir="$add_dir -L$inst_prefix_dir$libdir"
+		    func_append add_dir " -L$inst_prefix_dir$libdir"
 		    ;;
 		esac
 	      fi
@@ -5828,21 +6961,21 @@
 
 	    # Just print a warning and add the library to dependency_libs so
 	    # that the program can be linked against the static library.
-	    $ECHO
+	    echo
 	    $ECHO "*** Warning: This system can not link to static lib archive $lib."
-	    $ECHO "*** I have the capability to make that library automatically link in when"
-	    $ECHO "*** you link to this library.  But I can only do this if you have a"
-	    $ECHO "*** shared version of the library, which you do not appear to have."
+	    echo "*** I have the capability to make that library automatically link in when"
+	    echo "*** you link to this library.  But I can only do this if you have a"
+	    echo "*** shared version of the library, which you do not appear to have."
 	    if test "$module" = yes; then
-	      $ECHO "*** But as you try to build a module library, libtool will still create "
-	      $ECHO "*** a static module, that should work as long as the dlopening application"
-	      $ECHO "*** is linked with the -dlopen flag to resolve symbols at runtime."
+	      echo "*** But as you try to build a module library, libtool will still create "
+	      echo "*** a static module, that should work as long as the dlopening application"
+	      echo "*** is linked with the -dlopen flag to resolve symbols at runtime."
 	      if test -z "$global_symbol_pipe"; then
-		$ECHO
-		$ECHO "*** However, this would only work if libtool was able to extract symbol"
-		$ECHO "*** lists from a program, using \`nm' or equivalent, but libtool could"
-		$ECHO "*** not find such a program.  So, this module is probably useless."
-		$ECHO "*** \`nm' from GNU binutils and a full rebuild may help."
+		echo
+		echo "*** However, this would only work if libtool was able to extract symbol"
+		echo "*** lists from a program, using \`nm' or equivalent, but libtool could"
+		echo "*** not find such a program.  So, this module is probably useless."
+		echo "*** \`nm' from GNU binutils and a full rebuild may help."
 	      fi
 	      if test "$build_old_libs" = no; then
 		build_libtool_libs=module
@@ -5870,27 +7003,33 @@
 	           temp_xrpath=$func_stripname_result
 		   case " $xrpath " in
 		   *" $temp_xrpath "*) ;;
-		   *) xrpath="$xrpath $temp_xrpath";;
+		   *) func_append xrpath " $temp_xrpath";;
 		   esac;;
-	      *) temp_deplibs="$temp_deplibs $libdir";;
+	      *) func_append temp_deplibs " $libdir";;
 	      esac
 	    done
 	    dependency_libs="$temp_deplibs"
 	  fi
 
-	  newlib_search_path="$newlib_search_path $absdir"
+	  func_append newlib_search_path " $absdir"
 	  # Link against this library
 	  test "$link_static" = no && newdependency_libs="$abs_ladir/$laname $newdependency_libs"
 	  # ... and its dependency_libs
 	  tmp_libs=
 	  for deplib in $dependency_libs; do
 	    newdependency_libs="$deplib $newdependency_libs"
-	    if $opt_duplicate_deps ; then
+	    case $deplib in
+              -L*) func_stripname '-L' '' "$deplib"
+                   func_resolve_sysroot "$func_stripname_result";;
+              *) func_resolve_sysroot "$deplib" ;;
+            esac
+	    if $opt_preserve_dup_deps ; then
 	      case "$tmp_libs " in
-	      *" $deplib "*) specialdeplibs="$specialdeplibs $deplib" ;;
+	      *" $func_resolve_sysroot_result "*)
+                func_append specialdeplibs " $func_resolve_sysroot_result" ;;
 	      esac
 	    fi
-	    tmp_libs="$tmp_libs $deplib"
+	    func_append tmp_libs " $func_resolve_sysroot_result"
 	  done
 
 	  if test "$link_all_deplibs" != no; then
@@ -5900,8 +7039,10 @@
 	      case $deplib in
 	      -L*) path="$deplib" ;;
 	      *.la)
+	        func_resolve_sysroot "$deplib"
+	        deplib=$func_resolve_sysroot_result
 	        func_dirname "$deplib" "" "."
-		dir="$func_dirname_result"
+		dir=$func_dirname_result
 		# We need an absolute path.
 		case $dir in
 		[\\/]* | [A-Za-z]:[\\/]*) absdir="$dir" ;;
@@ -5928,8 +7069,8 @@
                       if test -z "$darwin_install_name"; then
                           darwin_install_name=`${OTOOL64} -L $depdepl  | awk '{if (NR == 2) {print $1;exit}}'`
                       fi
-		      compiler_flags="$compiler_flags ${wl}-dylib_file ${wl}${darwin_install_name}:${depdepl}"
-		      linker_flags="$linker_flags -dylib_file ${darwin_install_name}:${depdepl}"
+		      func_append compiler_flags " ${wl}-dylib_file ${wl}${darwin_install_name}:${depdepl}"
+		      func_append linker_flags " -dylib_file ${darwin_install_name}:${depdepl}"
 		      path=
 		    fi
 		  fi
@@ -5962,7 +7103,7 @@
 	  compile_deplibs="$new_inherited_linker_flags $compile_deplibs"
 	  finalize_deplibs="$new_inherited_linker_flags $finalize_deplibs"
 	else
-	  compiler_flags="$compiler_flags "`$ECHO "X $new_inherited_linker_flags" | $Xsed -e 's% \([^ $]*\).ltframework% -framework \1%g'`
+	  compiler_flags="$compiler_flags "`$ECHO " $new_inherited_linker_flags" | $SED 's% \([^ $]*\).ltframework% -framework \1%g'`
 	fi
       fi
       dependency_libs="$newdependency_libs"
@@ -5979,7 +7120,7 @@
 	  for dir in $newlib_search_path; do
 	    case "$lib_search_path " in
 	    *" $dir "*) ;;
-	    *) lib_search_path="$lib_search_path $dir" ;;
+	    *) func_append lib_search_path " $dir" ;;
 	    esac
 	  done
 	  newlib_search_path=
@@ -6037,10 +7178,10 @@
 	    -L*)
 	      case " $tmp_libs " in
 	      *" $deplib "*) ;;
-	      *) tmp_libs="$tmp_libs $deplib" ;;
+	      *) func_append tmp_libs " $deplib" ;;
 	      esac
 	      ;;
-	    *) tmp_libs="$tmp_libs $deplib" ;;
+	    *) func_append tmp_libs " $deplib" ;;
 	    esac
 	  done
 	  eval $var=\"$tmp_libs\"
@@ -6056,7 +7197,7 @@
 	  ;;
 	esac
 	if test -n "$i" ; then
-	  tmp_libs="$tmp_libs $i"
+	  func_append tmp_libs " $i"
 	fi
       done
       dependency_libs=$tmp_libs
@@ -6097,7 +7238,7 @@
       # Now set the variables for building old libraries.
       build_libtool_libs=no
       oldlibs="$output"
-      objs="$objs$old_deplibs"
+      func_append objs "$old_deplibs"
       ;;
 
     lib)
@@ -6130,10 +7271,10 @@
 	if test "$deplibs_check_method" != pass_all; then
 	  func_fatal_error "cannot build libtool library \`$output' from non-libtool objects on this host:$objs"
 	else
-	  $ECHO
+	  echo
 	  $ECHO "*** Warning: Linking the shared library $output against the non-libtool"
 	  $ECHO "*** objects $objs is not portable!"
-	  libobjs="$libobjs $objs"
+	  func_append libobjs " $objs"
 	fi
       fi
 
@@ -6192,13 +7333,14 @@
 	  # which has an extra 1 added just for fun
 	  #
 	  case $version_type in
+	  # correct linux to gnu/linux during the next big refactor
 	  darwin|linux|osf|windows|none)
 	    func_arith $number_major + $number_minor
 	    current=$func_arith_result
 	    age="$number_minor"
 	    revision="$number_revision"
 	    ;;
-	  freebsd-aout|freebsd-elf|sunos)
+	  freebsd-aout|freebsd-elf|qnx|sunos)
 	    current="$number_major"
 	    revision="$number_minor"
 	    age="0"
@@ -6311,7 +7453,7 @@
 	  versuffix="$major.$revision"
 	  ;;
 
-	linux)
+	linux) # correct to gnu/linux during the next big refactor
 	  func_arith $current - $age
 	  major=.$func_arith_result
 	  versuffix="$major.$age.$revision"
@@ -6334,7 +7476,7 @@
 	  done
 
 	  # Make executables depend on our current version.
-	  verstring="$verstring:${current}.0"
+	  func_append verstring ":${current}.0"
 	  ;;
 
 	qnx)
@@ -6402,10 +7544,10 @@
       fi
 
       func_generate_dlsyms "$libname" "$libname" "yes"
-      libobjs="$libobjs $symfileobj"
+      func_append libobjs " $symfileobj"
       test "X$libobjs" = "X " && libobjs=
 
-      if test "$mode" != relink; then
+      if test "$opt_mode" != relink; then
 	# Remove our outputs, but don't remove object files since they
 	# may have been created when compiling PIC objects.
 	removelist=
@@ -6421,7 +7563,7 @@
 		   continue
 		 fi
 	       fi
-	       removelist="$removelist $p"
+	       func_append removelist " $p"
 	       ;;
 	    *) ;;
 	  esac
@@ -6432,27 +7574,28 @@
 
       # Now set the variables for building old libraries.
       if test "$build_old_libs" = yes && test "$build_libtool_libs" != convenience ; then
-	oldlibs="$oldlibs $output_objdir/$libname.$libext"
+	func_append oldlibs " $output_objdir/$libname.$libext"
 
 	# Transform .lo files to .o files.
-	oldobjs="$objs "`$ECHO "X$libobjs" | $SP2NL | $Xsed -e '/\.'${libext}'$/d' -e "$lo2o" | $NL2SP`
+	oldobjs="$objs "`$ECHO "$libobjs" | $SP2NL | $SED "/\.${libext}$/d; $lo2o" | $NL2SP`
       fi
 
       # Eliminate all temporary directories.
       #for path in $notinst_path; do
-      #	lib_search_path=`$ECHO "X$lib_search_path " | $Xsed -e "s% $path % %g"`
-      #	deplibs=`$ECHO "X$deplibs " | $Xsed -e "s% -L$path % %g"`
-      #	dependency_libs=`$ECHO "X$dependency_libs " | $Xsed -e "s% -L$path % %g"`
+      #	lib_search_path=`$ECHO "$lib_search_path " | $SED "s% $path % %g"`
+      #	deplibs=`$ECHO "$deplibs " | $SED "s% -L$path % %g"`
+      #	dependency_libs=`$ECHO "$dependency_libs " | $SED "s% -L$path % %g"`
       #done
 
       if test -n "$xrpath"; then
 	# If the user specified any rpath flags, then add them.
 	temp_xrpath=
 	for libdir in $xrpath; do
-	  temp_xrpath="$temp_xrpath -R$libdir"
+	  func_replace_sysroot "$libdir"
+	  func_append temp_xrpath " -R$func_replace_sysroot_result"
 	  case "$finalize_rpath " in
 	  *" $libdir "*) ;;
-	  *) finalize_rpath="$finalize_rpath $libdir" ;;
+	  *) func_append finalize_rpath " $libdir" ;;
 	  esac
 	done
 	if test "$hardcode_into_libs" != yes || test "$build_old_libs" = yes; then
@@ -6466,7 +7609,7 @@
       for lib in $old_dlfiles; do
 	case " $dlprefiles $dlfiles " in
 	*" $lib "*) ;;
-	*) dlfiles="$dlfiles $lib" ;;
+	*) func_append dlfiles " $lib" ;;
 	esac
       done
 
@@ -6476,19 +7619,19 @@
       for lib in $old_dlprefiles; do
 	case "$dlprefiles " in
 	*" $lib "*) ;;
-	*) dlprefiles="$dlprefiles $lib" ;;
+	*) func_append dlprefiles " $lib" ;;
 	esac
       done
 
       if test "$build_libtool_libs" = yes; then
 	if test -n "$rpath"; then
 	  case $host in
-	  *-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-os2* | *-*-beos* | *-cegcc*)
+	  *-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-os2* | *-*-beos* | *-cegcc* | *-*-haiku*)
 	    # these systems don't actually have a c library (as such)!
 	    ;;
 	  *-*-rhapsody* | *-*-darwin1.[012])
 	    # Rhapsody C library is in the System framework
-	    deplibs="$deplibs System.ltframework"
+	    func_append deplibs " System.ltframework"
 	    ;;
 	  *-*-netbsd*)
 	    # Don't link with libc until the a.out ld.so is fixed.
@@ -6505,7 +7648,7 @@
 	  *)
 	    # Add libc to deplibs on all other systems if necessary.
 	    if test "$build_libtool_need_lc" = "yes"; then
-	      deplibs="$deplibs -lc"
+	      func_append deplibs " -lc"
 	    fi
 	    ;;
 	  esac
@@ -6554,7 +7697,7 @@
 		if test "X$allow_libtool_libs_with_static_runtimes" = "Xyes" ; then
 		  case " $predeps $postdeps " in
 		  *" $i "*)
-		    newdeplibs="$newdeplibs $i"
+		    func_append newdeplibs " $i"
 		    i=""
 		    ;;
 		  esac
@@ -6565,21 +7708,21 @@
 		  set dummy $deplib_matches; shift
 		  deplib_match=$1
 		  if test `expr "$ldd_output" : ".*$deplib_match"` -ne 0 ; then
-		    newdeplibs="$newdeplibs $i"
+		    func_append newdeplibs " $i"
 		  else
 		    droppeddeps=yes
-		    $ECHO
+		    echo
 		    $ECHO "*** Warning: dynamic linker does not accept needed library $i."
-		    $ECHO "*** I have the capability to make that library automatically link in when"
-		    $ECHO "*** you link to this library.  But I can only do this if you have a"
-		    $ECHO "*** shared version of the library, which I believe you do not have"
-		    $ECHO "*** because a test_compile did reveal that the linker did not use it for"
-		    $ECHO "*** its dynamic dependency list that programs get resolved with at runtime."
+		    echo "*** I have the capability to make that library automatically link in when"
+		    echo "*** you link to this library.  But I can only do this if you have a"
+		    echo "*** shared version of the library, which I believe you do not have"
+		    echo "*** because a test_compile did reveal that the linker did not use it for"
+		    echo "*** its dynamic dependency list that programs get resolved with at runtime."
 		  fi
 		fi
 		;;
 	      *)
-		newdeplibs="$newdeplibs $i"
+		func_append newdeplibs " $i"
 		;;
 	      esac
 	    done
@@ -6597,7 +7740,7 @@
 		  if test "X$allow_libtool_libs_with_static_runtimes" = "Xyes" ; then
 		    case " $predeps $postdeps " in
 		    *" $i "*)
-		      newdeplibs="$newdeplibs $i"
+		      func_append newdeplibs " $i"
 		      i=""
 		      ;;
 		    esac
@@ -6608,29 +7751,29 @@
 		    set dummy $deplib_matches; shift
 		    deplib_match=$1
 		    if test `expr "$ldd_output" : ".*$deplib_match"` -ne 0 ; then
-		      newdeplibs="$newdeplibs $i"
+		      func_append newdeplibs " $i"
 		    else
 		      droppeddeps=yes
-		      $ECHO
+		      echo
 		      $ECHO "*** Warning: dynamic linker does not accept needed library $i."
-		      $ECHO "*** I have the capability to make that library automatically link in when"
-		      $ECHO "*** you link to this library.  But I can only do this if you have a"
-		      $ECHO "*** shared version of the library, which you do not appear to have"
-		      $ECHO "*** because a test_compile did reveal that the linker did not use this one"
-		      $ECHO "*** as a dynamic dependency that programs can get resolved with at runtime."
+		      echo "*** I have the capability to make that library automatically link in when"
+		      echo "*** you link to this library.  But I can only do this if you have a"
+		      echo "*** shared version of the library, which you do not appear to have"
+		      echo "*** because a test_compile did reveal that the linker did not use this one"
+		      echo "*** as a dynamic dependency that programs can get resolved with at runtime."
 		    fi
 		  fi
 		else
 		  droppeddeps=yes
-		  $ECHO
+		  echo
 		  $ECHO "*** Warning!  Library $i is needed by this library but I was not able to"
-		  $ECHO "*** make it link in!  You will probably need to install it or some"
-		  $ECHO "*** library that it depends on before this library will be fully"
-		  $ECHO "*** functional.  Installing it before continuing would be even better."
+		  echo "*** make it link in!  You will probably need to install it or some"
+		  echo "*** library that it depends on before this library will be fully"
+		  echo "*** functional.  Installing it before continuing would be even better."
 		fi
 		;;
 	      *)
-		newdeplibs="$newdeplibs $i"
+		func_append newdeplibs " $i"
 		;;
 	      esac
 	    done
@@ -6647,15 +7790,27 @@
 	      if test "X$allow_libtool_libs_with_static_runtimes" = "Xyes" ; then
 		case " $predeps $postdeps " in
 		*" $a_deplib "*)
-		  newdeplibs="$newdeplibs $a_deplib"
+		  func_append newdeplibs " $a_deplib"
 		  a_deplib=""
 		  ;;
 		esac
 	      fi
 	      if test -n "$a_deplib" ; then
 		libname=`eval "\\$ECHO \"$libname_spec\""`
+		if test -n "$file_magic_glob"; then
+		  libnameglob=`func_echo_all "$libname" | $SED -e $file_magic_glob`
+		else
+		  libnameglob=$libname
+		fi
+		test "$want_nocaseglob" = yes && nocaseglob=`shopt -p nocaseglob`
 		for i in $lib_search_path $sys_lib_search_path $shlib_search_path; do
-		  potential_libs=`ls $i/$libname[.-]* 2>/dev/null`
+		  if test "$want_nocaseglob" = yes; then
+		    shopt -s nocaseglob
+		    potential_libs=`ls $i/$libnameglob[.-]* 2>/dev/null`
+		    $nocaseglob
+		  else
+		    potential_libs=`ls $i/$libnameglob[.-]* 2>/dev/null`
+		  fi
 		  for potent_lib in $potential_libs; do
 		      # Follow soft links.
 		      if ls -lLd "$potent_lib" 2>/dev/null |
@@ -6672,13 +7827,13 @@
 			potliblink=`ls -ld $potlib | ${SED} 's/.* -> //'`
 			case $potliblink in
 			[\\/]* | [A-Za-z]:[\\/]*) potlib="$potliblink";;
-			*) potlib=`$ECHO "X$potlib" | $Xsed -e 's,[^/]*$,,'`"$potliblink";;
+			*) potlib=`$ECHO "$potlib" | $SED 's,[^/]*$,,'`"$potliblink";;
 			esac
 		      done
 		      if eval $file_magic_cmd \"\$potlib\" 2>/dev/null |
 			 $SED -e 10q |
 			 $EGREP "$file_magic_regex" > /dev/null; then
-			newdeplibs="$newdeplibs $a_deplib"
+			func_append newdeplibs " $a_deplib"
 			a_deplib=""
 			break 2
 		      fi
@@ -6687,12 +7842,12 @@
 	      fi
 	      if test -n "$a_deplib" ; then
 		droppeddeps=yes
-		$ECHO
+		echo
 		$ECHO "*** Warning: linker path does not have real file for library $a_deplib."
-		$ECHO "*** I have the capability to make that library automatically link in when"
-		$ECHO "*** you link to this library.  But I can only do this if you have a"
-		$ECHO "*** shared version of the library, which you do not appear to have"
-		$ECHO "*** because I did check the linker path looking for a file starting"
+		echo "*** I have the capability to make that library automatically link in when"
+		echo "*** you link to this library.  But I can only do this if you have a"
+		echo "*** shared version of the library, which you do not appear to have"
+		echo "*** because I did check the linker path looking for a file starting"
 		if test -z "$potlib" ; then
 		  $ECHO "*** with $libname but no candidates were found. (...for file magic test)"
 		else
@@ -6703,7 +7858,7 @@
 	      ;;
 	    *)
 	      # Add a -L argument.
-	      newdeplibs="$newdeplibs $a_deplib"
+	      func_append newdeplibs " $a_deplib"
 	      ;;
 	    esac
 	  done # Gone through all deplibs.
@@ -6719,7 +7874,7 @@
 	      if test "X$allow_libtool_libs_with_static_runtimes" = "Xyes" ; then
 		case " $predeps $postdeps " in
 		*" $a_deplib "*)
-		  newdeplibs="$newdeplibs $a_deplib"
+		  func_append newdeplibs " $a_deplib"
 		  a_deplib=""
 		  ;;
 		esac
@@ -6730,9 +7885,9 @@
 		  potential_libs=`ls $i/$libname[.-]* 2>/dev/null`
 		  for potent_lib in $potential_libs; do
 		    potlib="$potent_lib" # see symlink-check above in file_magic test
-		    if eval "\$ECHO \"X$potent_lib\"" 2>/dev/null | $Xsed -e 10q | \
+		    if eval "\$ECHO \"$potent_lib\"" 2>/dev/null | $SED 10q | \
 		       $EGREP "$match_pattern_regex" > /dev/null; then
-		      newdeplibs="$newdeplibs $a_deplib"
+		      func_append newdeplibs " $a_deplib"
 		      a_deplib=""
 		      break 2
 		    fi
@@ -6741,12 +7896,12 @@
 	      fi
 	      if test -n "$a_deplib" ; then
 		droppeddeps=yes
-		$ECHO
+		echo
 		$ECHO "*** Warning: linker path does not have real file for library $a_deplib."
-		$ECHO "*** I have the capability to make that library automatically link in when"
-		$ECHO "*** you link to this library.  But I can only do this if you have a"
-		$ECHO "*** shared version of the library, which you do not appear to have"
-		$ECHO "*** because I did check the linker path looking for a file starting"
+		echo "*** I have the capability to make that library automatically link in when"
+		echo "*** you link to this library.  But I can only do this if you have a"
+		echo "*** shared version of the library, which you do not appear to have"
+		echo "*** because I did check the linker path looking for a file starting"
 		if test -z "$potlib" ; then
 		  $ECHO "*** with $libname but no candidates were found. (...for regex pattern test)"
 		else
@@ -6757,32 +7912,32 @@
 	      ;;
 	    *)
 	      # Add a -L argument.
-	      newdeplibs="$newdeplibs $a_deplib"
+	      func_append newdeplibs " $a_deplib"
 	      ;;
 	    esac
 	  done # Gone through all deplibs.
 	  ;;
 	none | unknown | *)
 	  newdeplibs=""
-	  tmp_deplibs=`$ECHO "X $deplibs" | $Xsed \
-	      -e 's/ -lc$//' -e 's/ -[LR][^ ]*//g'`
+	  tmp_deplibs=`$ECHO " $deplibs" | $SED 's/ -lc$//; s/ -[LR][^ ]*//g'`
 	  if test "X$allow_libtool_libs_with_static_runtimes" = "Xyes" ; then
 	    for i in $predeps $postdeps ; do
 	      # can't use Xsed below, because $i might contain '/'
-	      tmp_deplibs=`$ECHO "X $tmp_deplibs" | $Xsed -e "s,$i,,"`
+	      tmp_deplibs=`$ECHO " $tmp_deplibs" | $SED "s,$i,,"`
 	    done
 	  fi
-	  if $ECHO "X $tmp_deplibs" | $Xsed -e 's/[	 ]//g' |
-	     $GREP . >/dev/null; then
-	    $ECHO
+	  case $tmp_deplibs in
+	  *[!\	\ ]*)
+	    echo
 	    if test "X$deplibs_check_method" = "Xnone"; then
-	      $ECHO "*** Warning: inter-library dependencies are not supported in this platform."
+	      echo "*** Warning: inter-library dependencies are not supported in this platform."
 	    else
-	      $ECHO "*** Warning: inter-library dependencies are not known to be supported."
+	      echo "*** Warning: inter-library dependencies are not known to be supported."
 	    fi
-	    $ECHO "*** All declared inter-library dependencies are being dropped."
+	    echo "*** All declared inter-library dependencies are being dropped."
 	    droppeddeps=yes
-	  fi
+	    ;;
+	  esac
 	  ;;
 	esac
 	versuffix=$versuffix_save
@@ -6794,23 +7949,23 @@
 	case $host in
 	*-*-rhapsody* | *-*-darwin1.[012])
 	  # On Rhapsody replace the C library with the System framework
-	  newdeplibs=`$ECHO "X $newdeplibs" | $Xsed -e 's/ -lc / System.ltframework /'`
+	  newdeplibs=`$ECHO " $newdeplibs" | $SED 's/ -lc / System.ltframework /'`
 	  ;;
 	esac
 
 	if test "$droppeddeps" = yes; then
 	  if test "$module" = yes; then
-	    $ECHO
-	    $ECHO "*** Warning: libtool could not satisfy all declared inter-library"
+	    echo
+	    echo "*** Warning: libtool could not satisfy all declared inter-library"
 	    $ECHO "*** dependencies of module $libname.  Therefore, libtool will create"
-	    $ECHO "*** a static module, that should work as long as the dlopening"
-	    $ECHO "*** application is linked with the -dlopen flag."
+	    echo "*** a static module, that should work as long as the dlopening"
+	    echo "*** application is linked with the -dlopen flag."
 	    if test -z "$global_symbol_pipe"; then
-	      $ECHO
-	      $ECHO "*** However, this would only work if libtool was able to extract symbol"
-	      $ECHO "*** lists from a program, using \`nm' or equivalent, but libtool could"
-	      $ECHO "*** not find such a program.  So, this module is probably useless."
-	      $ECHO "*** \`nm' from GNU binutils and a full rebuild may help."
+	      echo
+	      echo "*** However, this would only work if libtool was able to extract symbol"
+	      echo "*** lists from a program, using \`nm' or equivalent, but libtool could"
+	      echo "*** not find such a program.  So, this module is probably useless."
+	      echo "*** \`nm' from GNU binutils and a full rebuild may help."
 	    fi
 	    if test "$build_old_libs" = no; then
 	      oldlibs="$output_objdir/$libname.$libext"
@@ -6820,16 +7975,16 @@
 	      build_libtool_libs=no
 	    fi
 	  else
-	    $ECHO "*** The inter-library dependencies that have been dropped here will be"
-	    $ECHO "*** automatically added whenever a program is linked with this library"
-	    $ECHO "*** or is declared to -dlopen it."
+	    echo "*** The inter-library dependencies that have been dropped here will be"
+	    echo "*** automatically added whenever a program is linked with this library"
+	    echo "*** or is declared to -dlopen it."
 
 	    if test "$allow_undefined" = no; then
-	      $ECHO
-	      $ECHO "*** Since this library must not contain undefined symbols,"
-	      $ECHO "*** because either the platform does not support them or"
-	      $ECHO "*** it was explicitly requested with -no-undefined,"
-	      $ECHO "*** libtool will only create a static version of it."
+	      echo
+	      echo "*** Since this library must not contain undefined symbols,"
+	      echo "*** because either the platform does not support them or"
+	      echo "*** it was explicitly requested with -no-undefined,"
+	      echo "*** libtool will only create a static version of it."
 	      if test "$build_old_libs" = no; then
 		oldlibs="$output_objdir/$libname.$libext"
 		build_libtool_libs=module
@@ -6846,9 +8001,9 @@
       # Time to change all our "foo.ltframework" stuff back to "-framework foo"
       case $host in
 	*-*-darwin*)
-	  newdeplibs=`$ECHO "X $newdeplibs" | $Xsed -e 's% \([^ $]*\).ltframework% -framework \1%g'`
-	  new_inherited_linker_flags=`$ECHO "X $new_inherited_linker_flags" | $Xsed -e 's% \([^ $]*\).ltframework% -framework \1%g'`
-	  deplibs=`$ECHO "X $deplibs" | $Xsed -e 's% \([^ $]*\).ltframework% -framework \1%g'`
+	  newdeplibs=`$ECHO " $newdeplibs" | $SED 's% \([^ $]*\).ltframework% -framework \1%g'`
+	  new_inherited_linker_flags=`$ECHO " $new_inherited_linker_flags" | $SED 's% \([^ $]*\).ltframework% -framework \1%g'`
+	  deplibs=`$ECHO " $deplibs" | $SED 's% \([^ $]*\).ltframework% -framework \1%g'`
 	  ;;
       esac
 
@@ -6861,7 +8016,7 @@
 	*)
 	  case " $deplibs " in
 	  *" -L$path/$objdir "*)
-	    new_libs="$new_libs -L$path/$objdir" ;;
+	    func_append new_libs " -L$path/$objdir" ;;
 	  esac
 	  ;;
 	esac
@@ -6871,10 +8026,10 @@
 	-L*)
 	  case " $new_libs " in
 	  *" $deplib "*) ;;
-	  *) new_libs="$new_libs $deplib" ;;
+	  *) func_append new_libs " $deplib" ;;
 	  esac
 	  ;;
-	*) new_libs="$new_libs $deplib" ;;
+	*) func_append new_libs " $deplib" ;;
 	esac
       done
       deplibs="$new_libs"
@@ -6886,15 +8041,22 @@
 
       # Test again, we may have decided not to build it any more
       if test "$build_libtool_libs" = yes; then
+	# Remove ${wl} instances when linking with ld.
+	# FIXME: should test the right _cmds variable.
+	case $archive_cmds in
+	  *\$LD\ *) wl= ;;
+        esac
 	if test "$hardcode_into_libs" = yes; then
 	  # Hardcode the library paths
 	  hardcode_libdirs=
 	  dep_rpath=
 	  rpath="$finalize_rpath"
-	  test "$mode" != relink && rpath="$compile_rpath$rpath"
+	  test "$opt_mode" != relink && rpath="$compile_rpath$rpath"
 	  for libdir in $rpath; do
 	    if test -n "$hardcode_libdir_flag_spec"; then
 	      if test -n "$hardcode_libdir_separator"; then
+		func_replace_sysroot "$libdir"
+		libdir=$func_replace_sysroot_result
 		if test -z "$hardcode_libdirs"; then
 		  hardcode_libdirs="$libdir"
 		else
@@ -6903,18 +8065,18 @@
 		  *"$hardcode_libdir_separator$libdir$hardcode_libdir_separator"*)
 		    ;;
 		  *)
-		    hardcode_libdirs="$hardcode_libdirs$hardcode_libdir_separator$libdir"
+		    func_append hardcode_libdirs "$hardcode_libdir_separator$libdir"
 		    ;;
 		  esac
 		fi
 	      else
 		eval flag=\"$hardcode_libdir_flag_spec\"
-		dep_rpath="$dep_rpath $flag"
+		func_append dep_rpath " $flag"
 	      fi
 	    elif test -n "$runpath_var"; then
 	      case "$perm_rpath " in
 	      *" $libdir "*) ;;
-	      *) perm_rpath="$perm_rpath $libdir" ;;
+	      *) func_append perm_rpath " $libdir" ;;
 	      esac
 	    fi
 	  done
@@ -6922,17 +8084,13 @@
 	  if test -n "$hardcode_libdir_separator" &&
 	     test -n "$hardcode_libdirs"; then
 	    libdir="$hardcode_libdirs"
-	    if test -n "$hardcode_libdir_flag_spec_ld"; then
-	      eval dep_rpath=\"$hardcode_libdir_flag_spec_ld\"
-	    else
-	      eval dep_rpath=\"$hardcode_libdir_flag_spec\"
-	    fi
+	    eval "dep_rpath=\"$hardcode_libdir_flag_spec\""
 	  fi
 	  if test -n "$runpath_var" && test -n "$perm_rpath"; then
 	    # We should set the runpath_var.
 	    rpath=
 	    for dir in $perm_rpath; do
-	      rpath="$rpath$dir:"
+	      func_append rpath "$dir:"
 	    done
 	    eval "$runpath_var='$rpath\$$runpath_var'; export $runpath_var"
 	  fi
@@ -6940,7 +8098,7 @@
 	fi
 
 	shlibpath="$finalize_shlibpath"
-	test "$mode" != relink && shlibpath="$compile_shlibpath$shlibpath"
+	test "$opt_mode" != relink && shlibpath="$compile_shlibpath$shlibpath"
 	if test -n "$shlibpath"; then
 	  eval "$shlibpath_var='$shlibpath\$$shlibpath_var'; export $shlibpath_var"
 	fi
@@ -6966,18 +8124,18 @@
 	linknames=
 	for link
 	do
-	  linknames="$linknames $link"
+	  func_append linknames " $link"
 	done
 
 	# Use standard objects if they are pic
-	test -z "$pic_flag" && libobjs=`$ECHO "X$libobjs" | $SP2NL | $Xsed -e "$lo2o" | $NL2SP`
+	test -z "$pic_flag" && libobjs=`$ECHO "$libobjs" | $SP2NL | $SED "$lo2o" | $NL2SP`
 	test "X$libobjs" = "X " && libobjs=
 
 	delfiles=
 	if test -n "$export_symbols" && test -n "$include_expsyms"; then
 	  $opt_dry_run || cp "$export_symbols" "$output_objdir/$libname.uexp"
 	  export_symbols="$output_objdir/$libname.uexp"
-	  delfiles="$delfiles $export_symbols"
+	  func_append delfiles " $export_symbols"
 	fi
 
 	orig_export_symbols=
@@ -7008,13 +8166,45 @@
 	    $opt_dry_run || $RM $export_symbols
 	    cmds=$export_symbols_cmds
 	    save_ifs="$IFS"; IFS='~'
-	    for cmd in $cmds; do
+	    for cmd1 in $cmds; do
 	      IFS="$save_ifs"
-	      eval cmd=\"$cmd\"
-	      func_len " $cmd"
-	      len=$func_len_result
-	      if test "$len" -lt "$max_cmd_len" || test "$max_cmd_len" -le -1; then
-		func_show_eval "$cmd" 'exit $?'
+	      # Take the normal branch if the nm_file_list_spec branch
+	      # doesn't work or if tool conversion is not needed.
+	      case $nm_file_list_spec~$to_tool_file_cmd in
+		*~func_convert_file_noop | *~func_convert_file_msys_to_w32 | ~*)
+		  try_normal_branch=yes
+		  eval cmd=\"$cmd1\"
+		  func_len " $cmd"
+		  len=$func_len_result
+		  ;;
+		*)
+		  try_normal_branch=no
+		  ;;
+	      esac
+	      if test "$try_normal_branch" = yes \
+		 && { test "$len" -lt "$max_cmd_len" \
+		      || test "$max_cmd_len" -le -1; }
+	      then
+		func_show_eval "$cmd" 'exit $?'
+		skipped_export=false
+	      elif test -n "$nm_file_list_spec"; then
+		func_basename "$output"
+		output_la=$func_basename_result
+		save_libobjs=$libobjs
+		save_output=$output
+		output=${output_objdir}/${output_la}.nm
+		func_to_tool_file "$output"
+		libobjs=$nm_file_list_spec$func_to_tool_file_result
+		func_append delfiles " $output"
+		func_verbose "creating $NM input file list: $output"
+		for obj in $save_libobjs; do
+		  func_to_tool_file "$obj"
+		  $ECHO "$func_to_tool_file_result"
+		done > "$output"
+		eval cmd=\"$cmd1\"
+		func_show_eval "$cmd" 'exit $?'
+		output=$save_output
+		libobjs=$save_libobjs
 		skipped_export=false
 	      else
 		# The command line is too long to execute in one step.
@@ -7036,7 +8226,7 @@
 	if test -n "$export_symbols" && test -n "$include_expsyms"; then
 	  tmp_export_symbols="$export_symbols"
 	  test -n "$orig_export_symbols" && tmp_export_symbols="$orig_export_symbols"
-	  $opt_dry_run || eval '$ECHO "X$include_expsyms" | $Xsed | $SP2NL >> "$tmp_export_symbols"'
+	  $opt_dry_run || eval '$ECHO "$include_expsyms" | $SP2NL >> "$tmp_export_symbols"'
 	fi
 
 	if test "X$skipped_export" != "X:" && test -n "$orig_export_symbols"; then
@@ -7048,7 +8238,7 @@
 	  # global variables. join(1) would be nice here, but unfortunately
 	  # isn't a blessed tool.
 	  $opt_dry_run || $SED -e '/[ ,]DATA/!d;s,\(.*\)\([ \,].*\),s|^\1$|\1\2|,' < $export_symbols > $output_objdir/$libname.filter
-	  delfiles="$delfiles $export_symbols $output_objdir/$libname.filter"
+	  func_append delfiles " $export_symbols $output_objdir/$libname.filter"
 	  export_symbols=$output_objdir/$libname.def
 	  $opt_dry_run || $SED -f $output_objdir/$libname.filter < $orig_export_symbols > $export_symbols
 	fi
@@ -7058,7 +8248,7 @@
 	  case " $convenience " in
 	  *" $test_deplib "*) ;;
 	  *)
-	    tmp_deplibs="$tmp_deplibs $test_deplib"
+	    func_append tmp_deplibs " $test_deplib"
 	    ;;
 	  esac
 	done
@@ -7078,21 +8268,21 @@
 	    test "X$libobjs" = "X " && libobjs=
 	  else
 	    gentop="$output_objdir/${outputname}x"
-	    generated="$generated $gentop"
+	    func_append generated " $gentop"
 
 	    func_extract_archives $gentop $convenience
-	    libobjs="$libobjs $func_extract_archives_result"
+	    func_append libobjs " $func_extract_archives_result"
 	    test "X$libobjs" = "X " && libobjs=
 	  fi
 	fi
 
 	if test "$thread_safe" = yes && test -n "$thread_safe_flag_spec"; then
 	  eval flag=\"$thread_safe_flag_spec\"
-	  linker_flags="$linker_flags $flag"
+	  func_append linker_flags " $flag"
 	fi
 
 	# Make a backup of the uninstalled library when relinking
-	if test "$mode" = relink; then
+	if test "$opt_mode" = relink; then
 	  $opt_dry_run || eval '(cd $output_objdir && $RM ${realname}U && $MV $realname ${realname}U)' || exit $?
 	fi
 
@@ -7137,7 +8327,8 @@
 	    save_libobjs=$libobjs
 	  fi
 	  save_output=$output
-	  output_la=`$ECHO "X$output" | $Xsed -e "$basename"`
+	  func_basename "$output"
+	  output_la=$func_basename_result
 
 	  # Clear the reloadable object creation command queue and
 	  # initialize k to one.
@@ -7150,13 +8341,16 @@
 	  if test -n "$save_libobjs" && test "X$skipped_export" != "X:" && test "$with_gnu_ld" = yes; then
 	    output=${output_objdir}/${output_la}.lnkscript
 	    func_verbose "creating GNU ld script: $output"
-	    $ECHO 'INPUT (' > $output
+	    echo 'INPUT (' > $output
 	    for obj in $save_libobjs
 	    do
-	      $ECHO "$obj" >> $output
+	      func_to_tool_file "$obj"
+	      $ECHO "$func_to_tool_file_result" >> $output
 	    done
-	    $ECHO ')' >> $output
-	    delfiles="$delfiles $output"
+	    echo ')' >> $output
+	    func_append delfiles " $output"
+	    func_to_tool_file "$output"
+	    output=$func_to_tool_file_result
 	  elif test -n "$save_libobjs" && test "X$skipped_export" != "X:" && test "X$file_list_spec" != X; then
 	    output=${output_objdir}/${output_la}.lnk
 	    func_verbose "creating linker input file list: $output"
@@ -7170,10 +8364,12 @@
 	    fi
 	    for obj
 	    do
-	      $ECHO "$obj" >> $output
+	      func_to_tool_file "$obj"
+	      $ECHO "$func_to_tool_file_result" >> $output
 	    done
-	    delfiles="$delfiles $output"
-	    output=$firstobj\"$file_list_spec$output\"
+	    func_append delfiles " $output"
+	    func_to_tool_file "$output"
+	    output=$firstobj\"$file_list_spec$func_to_tool_file_result\"
 	  else
 	    if test -n "$save_libobjs"; then
 	      func_verbose "creating reloadable object files..."
@@ -7197,17 +8393,19 @@
 		  # command to the queue.
 		  if test "$k" -eq 1 ; then
 		    # The first file doesn't have a previous command to add.
-		    eval concat_cmds=\"$reload_cmds $objlist $last_robj\"
+		    reload_objs=$objlist
+		    eval concat_cmds=\"$reload_cmds\"
 		  else
 		    # All subsequent reloadable object files will link in
 		    # the last one created.
-		    eval concat_cmds=\"\$concat_cmds~$reload_cmds $objlist $last_robj~\$RM $last_robj\"
+		    reload_objs="$objlist $last_robj"
+		    eval concat_cmds=\"\$concat_cmds~$reload_cmds~\$RM $last_robj\"
 		  fi
 		  last_robj=$output_objdir/$output_la-${k}.$objext
 		  func_arith $k + 1
 		  k=$func_arith_result
 		  output=$output_objdir/$output_la-${k}.$objext
-		  objlist=$obj
+		  objlist=" $obj"
 		  func_len " $last_robj"
 		  func_arith $len0 + $func_len_result
 		  len=$func_arith_result
@@ -7217,11 +8415,12 @@
 	      # reloadable object file.  All subsequent reloadable object
 	      # files will link in the last one created.
 	      test -z "$concat_cmds" || concat_cmds=$concat_cmds~
-	      eval concat_cmds=\"\${concat_cmds}$reload_cmds $objlist $last_robj\"
+	      reload_objs="$objlist $last_robj"
+	      eval concat_cmds=\"\${concat_cmds}$reload_cmds\"
 	      if test -n "$last_robj"; then
 	        eval concat_cmds=\"\${concat_cmds}~\$RM $last_robj\"
 	      fi
-	      delfiles="$delfiles $output"
+	      func_append delfiles " $output"
 
 	    else
 	      output=
@@ -7255,7 +8454,7 @@
 		lt_exit=$?
 
 		# Restore the uninstalled library and exit
-		if test "$mode" = relink; then
+		if test "$opt_mode" = relink; then
 		  ( cd "$output_objdir" && \
 		    $RM "${realname}T" && \
 		    $MV "${realname}U" "$realname" )
@@ -7276,7 +8475,7 @@
 	    if test -n "$export_symbols" && test -n "$include_expsyms"; then
 	      tmp_export_symbols="$export_symbols"
 	      test -n "$orig_export_symbols" && tmp_export_symbols="$orig_export_symbols"
-	      $opt_dry_run || eval '$ECHO "X$include_expsyms" | $Xsed | $SP2NL >> "$tmp_export_symbols"'
+	      $opt_dry_run || eval '$ECHO "$include_expsyms" | $SP2NL >> "$tmp_export_symbols"'
 	    fi
 
 	    if test -n "$orig_export_symbols"; then
@@ -7288,7 +8487,7 @@
 	      # global variables. join(1) would be nice here, but unfortunately
 	      # isn't a blessed tool.
 	      $opt_dry_run || $SED -e '/[ ,]DATA/!d;s,\(.*\)\([ \,].*\),s|^\1$|\1\2|,' < $export_symbols > $output_objdir/$libname.filter
-	      delfiles="$delfiles $export_symbols $output_objdir/$libname.filter"
+	      func_append delfiles " $export_symbols $output_objdir/$libname.filter"
 	      export_symbols=$output_objdir/$libname.def
 	      $opt_dry_run || $SED -f $output_objdir/$libname.filter < $orig_export_symbols > $export_symbols
 	    fi
@@ -7329,10 +8528,10 @@
 	# Add any objects from preloaded convenience libraries
 	if test -n "$dlprefiles"; then
 	  gentop="$output_objdir/${outputname}x"
-	  generated="$generated $gentop"
+	  func_append generated " $gentop"
 
 	  func_extract_archives $gentop $dlprefiles
-	  libobjs="$libobjs $func_extract_archives_result"
+	  func_append libobjs " $func_extract_archives_result"
 	  test "X$libobjs" = "X " && libobjs=
 	fi
 
@@ -7348,7 +8547,7 @@
 	    lt_exit=$?
 
 	    # Restore the uninstalled library and exit
-	    if test "$mode" = relink; then
+	    if test "$opt_mode" = relink; then
 	      ( cd "$output_objdir" && \
 	        $RM "${realname}T" && \
 		$MV "${realname}U" "$realname" )
@@ -7360,7 +8559,7 @@
 	IFS="$save_ifs"
 
 	# Restore the uninstalled library and exit
-	if test "$mode" = relink; then
+	if test "$opt_mode" = relink; then
 	  $opt_dry_run || eval '(cd $output_objdir && $RM ${realname}T && $MV $realname ${realname}T && $MV ${realname}U $realname)' || exit $?
 
 	  if test -n "$convenience"; then
@@ -7441,18 +8640,21 @@
       if test -n "$convenience"; then
 	if test -n "$whole_archive_flag_spec"; then
 	  eval tmp_whole_archive_flags=\"$whole_archive_flag_spec\"
-	  reload_conv_objs=$reload_objs\ `$ECHO "X$tmp_whole_archive_flags" | $Xsed -e 's|,| |g'`
+	  reload_conv_objs=$reload_objs\ `$ECHO "$tmp_whole_archive_flags" | $SED 's|,| |g'`
 	else
 	  gentop="$output_objdir/${obj}x"
-	  generated="$generated $gentop"
+	  func_append generated " $gentop"
 
 	  func_extract_archives $gentop $convenience
 	  reload_conv_objs="$reload_objs $func_extract_archives_result"
 	fi
       fi
 
+      # If we're not building shared, we need to use non_pic_objs
+      test "$build_libtool_libs" != yes && libobjs="$non_pic_objects"
+
       # Create the old-style object.
-      reload_objs="$objs$old_deplibs "`$ECHO "X$libobjs" | $SP2NL | $Xsed -e '/\.'${libext}$'/d' -e '/\.lib$/d' -e "$lo2o" | $NL2SP`" $reload_conv_objs" ### testsuite: skip nested quoting test
+      reload_objs="$objs$old_deplibs "`$ECHO "$libobjs" | $SP2NL | $SED "/\.${libext}$/d; /\.lib$/d; $lo2o" | $NL2SP`" $reload_conv_objs" ### testsuite: skip nested quoting test
 
       output="$obj"
       func_execute_cmds "$reload_cmds" 'exit $?'
@@ -7512,8 +8714,8 @@
       case $host in
       *-*-rhapsody* | *-*-darwin1.[012])
 	# On Rhapsody replace the C library is the System framework
-	compile_deplibs=`$ECHO "X $compile_deplibs" | $Xsed -e 's/ -lc / System.ltframework /'`
-	finalize_deplibs=`$ECHO "X $finalize_deplibs" | $Xsed -e 's/ -lc / System.ltframework /'`
+	compile_deplibs=`$ECHO " $compile_deplibs" | $SED 's/ -lc / System.ltframework /'`
+	finalize_deplibs=`$ECHO " $finalize_deplibs" | $SED 's/ -lc / System.ltframework /'`
 	;;
       esac
 
@@ -7524,14 +8726,14 @@
 	if test "$tagname" = CXX ; then
 	  case ${MACOSX_DEPLOYMENT_TARGET-10.0} in
 	    10.[0123])
-	      compile_command="$compile_command ${wl}-bind_at_load"
-	      finalize_command="$finalize_command ${wl}-bind_at_load"
+	      func_append compile_command " ${wl}-bind_at_load"
+	      func_append finalize_command " ${wl}-bind_at_load"
 	    ;;
 	  esac
 	fi
 	# Time to change all our "foo.ltframework" stuff back to "-framework foo"
-	compile_deplibs=`$ECHO "X $compile_deplibs" | $Xsed -e 's% \([^ $]*\).ltframework% -framework \1%g'`
-	finalize_deplibs=`$ECHO "X $finalize_deplibs" | $Xsed -e 's% \([^ $]*\).ltframework% -framework \1%g'`
+	compile_deplibs=`$ECHO " $compile_deplibs" | $SED 's% \([^ $]*\).ltframework% -framework \1%g'`
+	finalize_deplibs=`$ECHO " $finalize_deplibs" | $SED 's% \([^ $]*\).ltframework% -framework \1%g'`
 	;;
       esac
 
@@ -7545,7 +8747,7 @@
 	*)
 	  case " $compile_deplibs " in
 	  *" -L$path/$objdir "*)
-	    new_libs="$new_libs -L$path/$objdir" ;;
+	    func_append new_libs " -L$path/$objdir" ;;
 	  esac
 	  ;;
 	esac
@@ -7555,17 +8757,17 @@
 	-L*)
 	  case " $new_libs " in
 	  *" $deplib "*) ;;
-	  *) new_libs="$new_libs $deplib" ;;
+	  *) func_append new_libs " $deplib" ;;
 	  esac
 	  ;;
-	*) new_libs="$new_libs $deplib" ;;
+	*) func_append new_libs " $deplib" ;;
 	esac
       done
       compile_deplibs="$new_libs"
 
 
-      compile_command="$compile_command $compile_deplibs"
-      finalize_command="$finalize_command $finalize_deplibs"
+      func_append compile_command " $compile_deplibs"
+      func_append finalize_command " $finalize_deplibs"
 
       if test -n "$rpath$xrpath"; then
 	# If the user specified any rpath flags, then add them.
@@ -7573,7 +8775,7 @@
 	  # This is the magic to use -rpath.
 	  case "$finalize_rpath " in
 	  *" $libdir "*) ;;
-	  *) finalize_rpath="$finalize_rpath $libdir" ;;
+	  *) func_append finalize_rpath " $libdir" ;;
 	  esac
 	done
       fi
@@ -7592,18 +8794,18 @@
 	      *"$hardcode_libdir_separator$libdir$hardcode_libdir_separator"*)
 		;;
 	      *)
-		hardcode_libdirs="$hardcode_libdirs$hardcode_libdir_separator$libdir"
+		func_append hardcode_libdirs "$hardcode_libdir_separator$libdir"
 		;;
 	      esac
 	    fi
 	  else
 	    eval flag=\"$hardcode_libdir_flag_spec\"
-	    rpath="$rpath $flag"
+	    func_append rpath " $flag"
 	  fi
 	elif test -n "$runpath_var"; then
 	  case "$perm_rpath " in
 	  *" $libdir "*) ;;
-	  *) perm_rpath="$perm_rpath $libdir" ;;
+	  *) func_append perm_rpath " $libdir" ;;
 	  esac
 	fi
 	case $host in
@@ -7612,12 +8814,12 @@
 	  case :$dllsearchpath: in
 	  *":$libdir:"*) ;;
 	  ::) dllsearchpath=$libdir;;
-	  *) dllsearchpath="$dllsearchpath:$libdir";;
+	  *) func_append dllsearchpath ":$libdir";;
 	  esac
 	  case :$dllsearchpath: in
 	  *":$testbindir:"*) ;;
 	  ::) dllsearchpath=$testbindir;;
-	  *) dllsearchpath="$dllsearchpath:$testbindir";;
+	  *) func_append dllsearchpath ":$testbindir";;
 	  esac
 	  ;;
 	esac
@@ -7643,18 +8845,18 @@
 	      *"$hardcode_libdir_separator$libdir$hardcode_libdir_separator"*)
 		;;
 	      *)
-		hardcode_libdirs="$hardcode_libdirs$hardcode_libdir_separator$libdir"
+		func_append hardcode_libdirs "$hardcode_libdir_separator$libdir"
 		;;
 	      esac
 	    fi
 	  else
 	    eval flag=\"$hardcode_libdir_flag_spec\"
-	    rpath="$rpath $flag"
+	    func_append rpath " $flag"
 	  fi
 	elif test -n "$runpath_var"; then
 	  case "$finalize_perm_rpath " in
 	  *" $libdir "*) ;;
-	  *) finalize_perm_rpath="$finalize_perm_rpath $libdir" ;;
+	  *) func_append finalize_perm_rpath " $libdir" ;;
 	  esac
 	fi
       done
@@ -7668,8 +8870,8 @@
 
       if test -n "$libobjs" && test "$build_old_libs" = yes; then
 	# Transform all the library objects into standard objects.
-	compile_command=`$ECHO "X$compile_command" | $SP2NL | $Xsed -e "$lo2o" | $NL2SP`
-	finalize_command=`$ECHO "X$finalize_command" | $SP2NL | $Xsed -e "$lo2o" | $NL2SP`
+	compile_command=`$ECHO "$compile_command" | $SP2NL | $SED "$lo2o" | $NL2SP`
+	finalize_command=`$ECHO "$finalize_command" | $SP2NL | $SED "$lo2o" | $NL2SP`
       fi
 
       func_generate_dlsyms "$outputname" "@PROGRAM@" "no"
@@ -7681,15 +8883,15 @@
 
       wrappers_required=yes
       case $host in
+      *cegcc* | *mingw32ce*)
+        # Disable wrappers for cegcc and mingw32ce hosts, we are cross compiling anyway.
+        wrappers_required=no
+        ;;
       *cygwin* | *mingw* )
         if test "$build_libtool_libs" != yes; then
           wrappers_required=no
         fi
         ;;
-      *cegcc)
-        # Disable wrappers for cegcc, we are cross compiling anyway.
-        wrappers_required=no
-        ;;
       *)
         if test "$need_relink" = no || test "$build_libtool_libs" != yes; then
           wrappers_required=no
@@ -7698,13 +8900,19 @@
       esac
       if test "$wrappers_required" = no; then
 	# Replace the output file specification.
-	compile_command=`$ECHO "X$compile_command" | $Xsed -e 's%@OUTPUT@%'"$output"'%g'`
+	compile_command=`$ECHO "$compile_command" | $SED 's%@OUTPUT@%'"$output"'%g'`
 	link_command="$compile_command$compile_rpath"
 
 	# We have no uninstalled library dependencies, so finalize right now.
 	exit_status=0
 	func_show_eval "$link_command" 'exit_status=$?'
 
+	if test -n "$postlink_cmds"; then
+	  func_to_tool_file "$output"
+	  postlink_cmds=`func_echo_all "$postlink_cmds" | $SED -e 's%@OUTPUT@%'"$output"'%g' -e 's%@TOOL_OUTPUT@%'"$func_to_tool_file_result"'%g'`
+	  func_execute_cmds "$postlink_cmds" 'exit $?'
+	fi
+
 	# Delete the generated files.
 	if test -f "$output_objdir/${outputname}S.${objext}"; then
 	  func_show_eval '$RM "$output_objdir/${outputname}S.${objext}"'
@@ -7727,7 +8935,7 @@
 	  # We should set the runpath_var.
 	  rpath=
 	  for dir in $perm_rpath; do
-	    rpath="$rpath$dir:"
+	    func_append rpath "$dir:"
 	  done
 	  compile_var="$runpath_var=\"$rpath\$$runpath_var\" "
 	fi
@@ -7735,7 +8943,7 @@
 	  # We should set the runpath_var.
 	  rpath=
 	  for dir in $finalize_perm_rpath; do
-	    rpath="$rpath$dir:"
+	    func_append rpath "$dir:"
 	  done
 	  finalize_var="$runpath_var=\"$rpath\$$runpath_var\" "
 	fi
@@ -7745,11 +8953,18 @@
 	# We don't need to create a wrapper script.
 	link_command="$compile_var$compile_command$compile_rpath"
 	# Replace the output file specification.
-	link_command=`$ECHO "X$link_command" | $Xsed -e 's%@OUTPUT@%'"$output"'%g'`
+	link_command=`$ECHO "$link_command" | $SED 's%@OUTPUT@%'"$output"'%g'`
 	# Delete the old output file.
 	$opt_dry_run || $RM $output
 	# Link the executable and exit
 	func_show_eval "$link_command" 'exit $?'
+
+	if test -n "$postlink_cmds"; then
+	  func_to_tool_file "$output"
+	  postlink_cmds=`func_echo_all "$postlink_cmds" | $SED -e 's%@OUTPUT@%'"$output"'%g' -e 's%@TOOL_OUTPUT@%'"$func_to_tool_file_result"'%g'`
+	  func_execute_cmds "$postlink_cmds" 'exit $?'
+	fi
+
 	exit $EXIT_SUCCESS
       fi
 
@@ -7764,7 +8979,7 @@
 	if test "$fast_install" != no; then
 	  link_command="$finalize_var$compile_command$finalize_rpath"
 	  if test "$fast_install" = yes; then
-	    relink_command=`$ECHO "X$compile_var$compile_command$compile_rpath" | $Xsed -e 's%@OUTPUT@%\$progdir/\$file%g'`
+	    relink_command=`$ECHO "$compile_var$compile_command$compile_rpath" | $SED 's%@OUTPUT@%\$progdir/\$file%g'`
 	  else
 	    # fast_install is set to needless
 	    relink_command=
@@ -7776,13 +8991,19 @@
       fi
 
       # Replace the output file specification.
-      link_command=`$ECHO "X$link_command" | $Xsed -e 's%@OUTPUT@%'"$output_objdir/$outputname"'%g'`
+      link_command=`$ECHO "$link_command" | $SED 's%@OUTPUT@%'"$output_objdir/$outputname"'%g'`
 
       # Delete the old output files.
       $opt_dry_run || $RM $output $output_objdir/$outputname $output_objdir/lt-$outputname
 
       func_show_eval "$link_command" 'exit $?'
 
+      if test -n "$postlink_cmds"; then
+	func_to_tool_file "$output_objdir/$outputname"
+	postlink_cmds=`func_echo_all "$postlink_cmds" | $SED -e 's%@OUTPUT@%'"$output_objdir/$outputname"'%g' -e 's%@TOOL_OUTPUT@%'"$func_to_tool_file_result"'%g'`
+	func_execute_cmds "$postlink_cmds" 'exit $?'
+      fi
+
       # Now create the wrapper script.
       func_verbose "creating $output"
 
@@ -7800,18 +9021,7 @@
 	  fi
 	done
 	relink_command="(cd `pwd`; $relink_command)"
-	relink_command=`$ECHO "X$relink_command" | $Xsed -e "$sed_quote_subst"`
-      fi
-
-      # Quote $ECHO for shipping.
-      if test "X$ECHO" = "X$SHELL $progpath --fallback-echo"; then
-	case $progpath in
-	[\\/]* | [A-Za-z]:[\\/]*) qecho="$SHELL $progpath --fallback-echo";;
-	*) qecho="$SHELL `pwd`/$progpath --fallback-echo";;
-	esac
-	qecho=`$ECHO "X$qecho" | $Xsed -e "$sed_quote_subst"`
-      else
-	qecho=`$ECHO "X$ECHO" | $Xsed -e "$sed_quote_subst"`
+	relink_command=`$ECHO "$relink_command" | $SED "$sed_quote_subst"`
       fi
 
       # Only actually do things if not in dry run mode.
@@ -7891,7 +9101,7 @@
 	else
 	  oldobjs="$old_deplibs $non_pic_objects"
 	  if test "$preload" = yes && test -f "$symfileobj"; then
-	    oldobjs="$oldobjs $symfileobj"
+	    func_append oldobjs " $symfileobj"
 	  fi
 	fi
 	addlibs="$old_convenience"
@@ -7899,10 +9109,10 @@
 
       if test -n "$addlibs"; then
 	gentop="$output_objdir/${outputname}x"
-	generated="$generated $gentop"
+	func_append generated " $gentop"
 
 	func_extract_archives $gentop $addlibs
-	oldobjs="$oldobjs $func_extract_archives_result"
+	func_append oldobjs " $func_extract_archives_result"
       fi
 
       # Do each command in the archive commands.
@@ -7913,10 +9123,10 @@
 	# Add any objects from preloaded convenience libraries
 	if test -n "$dlprefiles"; then
 	  gentop="$output_objdir/${outputname}x"
-	  generated="$generated $gentop"
+	  func_append generated " $gentop"
 
 	  func_extract_archives $gentop $dlprefiles
-	  oldobjs="$oldobjs $func_extract_archives_result"
+	  func_append oldobjs " $func_extract_archives_result"
 	fi
 
 	# POSIX demands no paths to be encoded in archives.  We have
@@ -7932,9 +9142,9 @@
 	    done | sort | sort -uc >/dev/null 2>&1); then
 	  :
 	else
-	  $ECHO "copying selected object files to avoid basename conflicts..."
+	  echo "copying selected object files to avoid basename conflicts..."
 	  gentop="$output_objdir/${outputname}x"
-	  generated="$generated $gentop"
+	  func_append generated " $gentop"
 	  func_mkdir_p "$gentop"
 	  save_oldobjs=$oldobjs
 	  oldobjs=
@@ -7958,18 +9168,30 @@
 		esac
 	      done
 	      func_show_eval "ln $obj $gentop/$newobj || cp $obj $gentop/$newobj"
-	      oldobjs="$oldobjs $gentop/$newobj"
+	      func_append oldobjs " $gentop/$newobj"
 	      ;;
-	    *) oldobjs="$oldobjs $obj" ;;
+	    *) func_append oldobjs " $obj" ;;
 	    esac
 	  done
 	fi
+	func_to_tool_file "$oldlib" func_convert_file_msys_to_w32
+	tool_oldlib=$func_to_tool_file_result
 	eval cmds=\"$old_archive_cmds\"
 
 	func_len " $cmds"
 	len=$func_len_result
 	if test "$len" -lt "$max_cmd_len" || test "$max_cmd_len" -le -1; then
 	  cmds=$old_archive_cmds
+	elif test -n "$archiver_list_spec"; then
+	  func_verbose "using command file archive linking..."
+	  for obj in $oldobjs
+	  do
+	    func_to_tool_file "$obj"
+	    $ECHO "$func_to_tool_file_result"
+	  done > $output_objdir/$libname.libcmd
+	  func_to_tool_file "$output_objdir/$libname.libcmd"
+	  oldobjs=" $archiver_list_spec$func_to_tool_file_result"
+	  cmds=$old_archive_cmds
 	else
 	  # the command line is too long to link in one step, link in parts
 	  func_verbose "using piecewise archive linking..."
@@ -8043,7 +9265,7 @@
       done
       # Quote the link command for shipping.
       relink_command="(cd `pwd`; $SHELL $progpath $preserve_args --mode=relink $libtool_args @inst_prefix_dir@)"
-      relink_command=`$ECHO "X$relink_command" | $Xsed -e "$sed_quote_subst"`
+      relink_command=`$ECHO "$relink_command" | $SED "$sed_quote_subst"`
       if test "$hardcode_automatic" = yes ; then
 	relink_command=
       fi
@@ -8063,12 +9285,23 @@
 	      *.la)
 		func_basename "$deplib"
 		name="$func_basename_result"
-		eval libdir=`${SED} -n -e 's/^libdir=\(.*\)$/\1/p' $deplib`
+		func_resolve_sysroot "$deplib"
+		eval libdir=`${SED} -n -e 's/^libdir=\(.*\)$/\1/p' $func_resolve_sysroot_result`
 		test -z "$libdir" && \
 		  func_fatal_error "\`$deplib' is not a valid libtool archive"
-		newdependency_libs="$newdependency_libs $libdir/$name"
-		;;
-	      *) newdependency_libs="$newdependency_libs $deplib" ;;
+		func_append newdependency_libs " ${lt_sysroot:+=}$libdir/$name"
+		;;
+	      -L*)
+		func_stripname -L '' "$deplib"
+		func_replace_sysroot "$func_stripname_result"
+		func_append newdependency_libs " -L$func_replace_sysroot_result"
+		;;
+	      -R*)
+		func_stripname -R '' "$deplib"
+		func_replace_sysroot "$func_stripname_result"
+		func_append newdependency_libs " -R$func_replace_sysroot_result"
+		;;
+	      *) func_append newdependency_libs " $deplib" ;;
 	      esac
 	    done
 	    dependency_libs="$newdependency_libs"
@@ -8082,9 +9315,9 @@
 		eval libdir=`${SED} -n -e 's/^libdir=\(.*\)$/\1/p' $lib`
 		test -z "$libdir" && \
 		  func_fatal_error "\`$lib' is not a valid libtool archive"
-		newdlfiles="$newdlfiles $libdir/$name"
+		func_append newdlfiles " ${lt_sysroot:+=}$libdir/$name"
 		;;
-	      *) newdlfiles="$newdlfiles $lib" ;;
+	      *) func_append newdlfiles " $lib" ;;
 	      esac
 	    done
 	    dlfiles="$newdlfiles"
@@ -8101,7 +9334,7 @@
 		eval libdir=`${SED} -n -e 's/^libdir=\(.*\)$/\1/p' $lib`
 		test -z "$libdir" && \
 		  func_fatal_error "\`$lib' is not a valid libtool archive"
-		newdlprefiles="$newdlprefiles $libdir/$name"
+		func_append newdlprefiles " ${lt_sysroot:+=}$libdir/$name"
 		;;
 	      esac
 	    done
@@ -8113,7 +9346,7 @@
 		[\\/]* | [A-Za-z]:[\\/]*) abs="$lib" ;;
 		*) abs=`pwd`"/$lib" ;;
 	      esac
-	      newdlfiles="$newdlfiles $abs"
+	      func_append newdlfiles " $abs"
 	    done
 	    dlfiles="$newdlfiles"
 	    newdlprefiles=
@@ -8122,15 +9355,33 @@
 		[\\/]* | [A-Za-z]:[\\/]*) abs="$lib" ;;
 		*) abs=`pwd`"/$lib" ;;
 	      esac
-	      newdlprefiles="$newdlprefiles $abs"
+	      func_append newdlprefiles " $abs"
 	    done
 	    dlprefiles="$newdlprefiles"
 	  fi
 	  $RM $output
 	  # place dlname in correct position for cygwin
+	  # In fact, it would be nice if we could use this code for all target
+	  # systems that can't hard-code library paths into their executables
+	  # and that have no shared library path variable independent of PATH,
+	  # but it turns out we can't easily determine that from inspecting
+	  # libtool variables, so we have to hard-code the OSs to which it
+	  # applies here; at the moment, that means platforms that use the PE
+	  # object format with DLL files.  See the long comment at the top of
+	  # tests/bindir.at for full details.
 	  tdlname=$dlname
 	  case $host,$output,$installed,$module,$dlname in
-	    *cygwin*,*lai,yes,no,*.dll | *mingw*,*lai,yes,no,*.dll | *cegcc*,*lai,yes,no,*.dll) tdlname=../bin/$dlname ;;
+	    *cygwin*,*lai,yes,no,*.dll | *mingw*,*lai,yes,no,*.dll | *cegcc*,*lai,yes,no,*.dll)
+	      # If a -bindir argument was supplied, place the dll there.
+	      if test "x$bindir" != x ;
+	      then
+		func_relative_path "$install_libdir" "$bindir"
+		tdlname=$func_relative_path_result$dlname
+	      else
+		# Otherwise fall back on heuristic.
+		tdlname=../bin/$dlname
+	      fi
+	      ;;
 	  esac
 	  $ECHO > $output "\
 # $outputname - a libtool library file
@@ -8189,7 +9440,7 @@
     exit $EXIT_SUCCESS
 }
 
-{ test "$mode" = link || test "$mode" = relink; } &&
+{ test "$opt_mode" = link || test "$opt_mode" = relink; } &&
     func_mode_link ${1+"$@"}
 
 
@@ -8209,9 +9460,9 @@
     for arg
     do
       case $arg in
-      -f) RM="$RM $arg"; rmforce=yes ;;
-      -*) RM="$RM $arg" ;;
-      *) files="$files $arg" ;;
+      -f) func_append RM " $arg"; rmforce=yes ;;
+      -*) func_append RM " $arg" ;;
+      *) func_append files " $arg" ;;
       esac
     done
 
@@ -8220,24 +9471,23 @@
 
     rmdirs=
 
-    origobjdir="$objdir"
     for file in $files; do
       func_dirname "$file" "" "."
       dir="$func_dirname_result"
       if test "X$dir" = X.; then
-	objdir="$origobjdir"
+	odir="$objdir"
       else
-	objdir="$dir/$origobjdir"
+	odir="$dir/$objdir"
       fi
       func_basename "$file"
       name="$func_basename_result"
-      test "$mode" = uninstall && objdir="$dir"
+      test "$opt_mode" = uninstall && odir="$dir"
 
-      # Remember objdir for removal later, being careful to avoid duplicates
-      if test "$mode" = clean; then
+      # Remember odir for removal later, being careful to avoid duplicates
+      if test "$opt_mode" = clean; then
 	case " $rmdirs " in
-	  *" $objdir "*) ;;
-	  *) rmdirs="$rmdirs $objdir" ;;
+	  *" $odir "*) ;;
+	  *) func_append rmdirs " $odir" ;;
 	esac
       fi
 
@@ -8263,18 +9513,17 @@
 
 	  # Delete the libtool libraries and symlinks.
 	  for n in $library_names; do
-	    rmfiles="$rmfiles $objdir/$n"
+	    func_append rmfiles " $odir/$n"
 	  done
-	  test -n "$old_library" && rmfiles="$rmfiles $objdir/$old_library"
+	  test -n "$old_library" && func_append rmfiles " $odir/$old_library"
 
-	  case "$mode" in
+	  case "$opt_mode" in
 	  clean)
-	    case "  $library_names " in
-	    # "  " in the beginning catches empty $dlname
+	    case " $library_names " in
 	    *" $dlname "*) ;;
-	    *) rmfiles="$rmfiles $objdir/$dlname" ;;
+	    *) test -n "$dlname" && func_append rmfiles " $odir/$dlname" ;;
 	    esac
-	    test -n "$libdir" && rmfiles="$rmfiles $objdir/$name $objdir/${name}i"
+	    test -n "$libdir" && func_append rmfiles " $odir/$name $odir/${name}i"
 	    ;;
 	  uninstall)
 	    if test -n "$library_names"; then
@@ -8302,19 +9551,19 @@
 	  # Add PIC object to the list of files to remove.
 	  if test -n "$pic_object" &&
 	     test "$pic_object" != none; then
-	    rmfiles="$rmfiles $dir/$pic_object"
+	    func_append rmfiles " $dir/$pic_object"
 	  fi
 
 	  # Add non-PIC object to the list of files to remove.
 	  if test -n "$non_pic_object" &&
 	     test "$non_pic_object" != none; then
-	    rmfiles="$rmfiles $dir/$non_pic_object"
+	    func_append rmfiles " $dir/$non_pic_object"
 	  fi
 	fi
 	;;
 
       *)
-	if test "$mode" = clean ; then
+	if test "$opt_mode" = clean ; then
 	  noexename=$name
 	  case $file in
 	  *.exe)
@@ -8324,7 +9573,7 @@
 	    noexename=$func_stripname_result
 	    # $file with .exe has already been added to rmfiles,
 	    # add $file without .exe
-	    rmfiles="$rmfiles $file"
+	    func_append rmfiles " $file"
 	    ;;
 	  esac
 	  # Do a test to see if this is a libtool program.
@@ -8333,7 +9582,7 @@
 	      func_ltwrapper_scriptname "$file"
 	      relink_command=
 	      func_source $func_ltwrapper_scriptname_result
-	      rmfiles="$rmfiles $func_ltwrapper_scriptname_result"
+	      func_append rmfiles " $func_ltwrapper_scriptname_result"
 	    else
 	      relink_command=
 	      func_source $dir/$noexename
@@ -8341,12 +9590,12 @@
 
 	    # note $name still contains .exe if it was in $file originally
 	    # as does the version of $file that was added into $rmfiles
-	    rmfiles="$rmfiles $objdir/$name $objdir/${name}S.${objext}"
+	    func_append rmfiles " $odir/$name $odir/${name}S.${objext}"
 	    if test "$fast_install" = yes && test -n "$relink_command"; then
-	      rmfiles="$rmfiles $objdir/lt-$name"
+	      func_append rmfiles " $odir/lt-$name"
 	    fi
 	    if test "X$noexename" != "X$name" ; then
-	      rmfiles="$rmfiles $objdir/lt-${noexename}.c"
+	      func_append rmfiles " $odir/lt-${noexename}.c"
 	    fi
 	  fi
 	fi
@@ -8354,7 +9603,6 @@
       esac
       func_show_eval "$RM $rmfiles" 'exit_status=1'
     done
-    objdir="$origobjdir"
 
     # Try to remove the ${objdir}s in the directories where we deleted files
     for dir in $rmdirs; do
@@ -8366,16 +9614,16 @@
     exit $exit_status
 }
 
-{ test "$mode" = uninstall || test "$mode" = clean; } &&
+{ test "$opt_mode" = uninstall || test "$opt_mode" = clean; } &&
     func_mode_uninstall ${1+"$@"}
 
-test -z "$mode" && {
+test -z "$opt_mode" && {
   help="$generic_help"
   func_fatal_help "you must specify a MODE"
 }
 
 test -z "$exec_cmd" && \
-  func_fatal_help "invalid operation mode \`$mode'"
+  func_fatal_help "invalid operation mode \`$opt_mode'"
 
 if test -n "$exec_cmd"; then
   eval exec "$exec_cmd"

=== modified file 'missing'
--- missing	2010-01-17 13:05:04 +0000
+++ missing	2014-01-16 10:42:06 +0000
@@ -1,10 +1,10 @@
 #! /bin/sh
 # Common stub for a few missing GNU programs while installing.
 
-scriptversion=2009-04-28.21; # UTC
+scriptversion=2012-01-06.13; # UTC
 
 # Copyright (C) 1996, 1997, 1999, 2000, 2002, 2003, 2004, 2005, 2006,
-# 2008, 2009 Free Software Foundation, Inc.
+# 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
 # Originally by Fran,cois Pinard <pinard@iro.umontreal.ca>, 1996.
 
 # This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,6 @@
   help2man     touch the output file
   lex          create \`lex.yy.c', if possible, from existing .c
   makeinfo     touch the output file
-  tar          try tar, gnutar, gtar, then tar without non-portable flags
   yacc         create \`y.tab.[ch]', if possible, from existing .[ch]
 
 Version suffixes to PROGRAM as well as the prefixes \`gnu-', \`gnu', and
@@ -122,15 +121,6 @@
     # Not GNU programs, they don't have --version.
     ;;
 
-  tar*)
-    if test -n "$run"; then
-       echo 1>&2 "ERROR: \`tar' requires --run"
-       exit 1
-    elif test "x$2" = "x--version" || test "x$2" = "x--help"; then
-       exit 1
-    fi
-    ;;
-
   *)
     if test -z "$run" && ($1 --version) > /dev/null 2>&1; then
        # We have it, but it failed.
@@ -226,7 +216,7 @@
          \`Bison' from any GNU archive site."
     rm -f y.tab.c y.tab.h
     if test $# -ne 1; then
-        eval LASTARG="\${$#}"
+        eval LASTARG=\${$#}
 	case $LASTARG in
 	*.y)
 	    SRCFILE=`echo "$LASTARG" | sed 's/y$/c/'`
@@ -256,7 +246,7 @@
          \`Flex' from any GNU archive site."
     rm -f lex.yy.c
     if test $# -ne 1; then
-        eval LASTARG="\${$#}"
+        eval LASTARG=\${$#}
 	case $LASTARG in
 	*.l)
 	    SRCFILE=`echo "$LASTARG" | sed 's/l$/c/'`
@@ -318,41 +308,6 @@
     touch $file
     ;;
 
-  tar*)
-    shift
-
-    # We have already tried tar in the generic part.
-    # Look for gnutar/gtar before invocation to avoid ugly error
-    # messages.
-    if (gnutar --version > /dev/null 2>&1); then
-       gnutar "$@" && exit 0
-    fi
-    if (gtar --version > /dev/null 2>&1); then
-       gtar "$@" && exit 0
-    fi
-    firstarg="$1"
-    if shift; then
-	case $firstarg in
-	*o*)
-	    firstarg=`echo "$firstarg" | sed s/o//`
-	    tar "$firstarg" "$@" && exit 0
-	    ;;
-	esac
-	case $firstarg in
-	*h*)
-	    firstarg=`echo "$firstarg" | sed s/h//`
-	    tar "$firstarg" "$@" && exit 0
-	    ;;
-	esac
-    fi
-
-    echo 1>&2 "\
-WARNING: I can't seem to be able to run \`tar' with the given arguments.
-         You may want to install GNU tar or Free paxutils, or check the
-         command line arguments."
-    exit 1
-    ;;
-
   *)
     echo 1>&2 "\
 WARNING: \`$1' is needed, and is $msg.

=== modified file 'src/Makefile.am'
--- src/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/Makefile.am	2014-01-16 10:42:06 +0000
@@ -21,7 +21,7 @@
                         inbandbytestream.cpp messagefilter.cpp vcard.cpp \
                         vcardmanager.cpp md5.cpp sha.cpp search.cpp dataformreported.cpp dataformitem.cpp \
                         mucroom.cpp mucmessagesession.cpp oob.cpp vcardupdate.cpp stanzaextensionfactory.cpp \
-                        delayeddelivery.cpp gpgencrypted.cpp gpgsigned.cpp \
+                        mucinvitationhandler.cpp delayeddelivery.cpp gpgencrypted.cpp gpgsigned.cpp \
                         uniquemucroom.cpp instantmucroom.cpp compressionzlib.cpp tlsgnutlsclient.cpp \
                         connectionhttpproxy.cpp tlsgnutlsserveranon.cpp tlsgnutlsbase.cpp \
                         tlsgnutlsclientanon.cpp tlsschannel.cpp tlsdefault.cpp simanager.cpp siprofileft.cpp \
@@ -35,9 +35,11 @@
                         shim.cpp softwareversion.cpp attention.cpp \
                         tlsopensslclient.cpp tlsopensslbase.cpp \
                         tlsopensslserver.cpp compressiondefault.cpp \
-                        connectiontlsserver.cpp
+                        connectiontlsserver.cpp atomicrefcount.cpp linklocalmanager.cpp linklocalclient.cpp \
+                        forward.cpp jinglesession.cpp jinglecontent.cpp jinglesessionmanager.cpp \
+                        carbons.cpp jinglepluginfactory.cpp jingleiceudp.cpp jinglefiletransfer.cpp
 
-libgloox_la_LDFLAGS = -version-info 8:0:0 -no-undefined -no-allow-shlib-undefined
+libgloox_la_LDFLAGS = -version-info 11:0:0 -no-undefined -no-allow-shlib-undefined
 libgloox_la_LIBADD =
 libgloox_la_CFLAGS = $(CPPFLAGS)
 
@@ -90,7 +92,13 @@
                             nickname.h                pubsubevent.h           xhtmlim.h \
                             eventdispatcher.h         \
                             pubsubitem.h shim.h util.h \
-                            connectiontlsserver.h compressiondefault.h
+                            connectiontlsserver.h compressiondefault.h \
+                            atomicrefcount.h          linklocalmanager.h           linklocalhandler.h \
+                            linklocalclient.h         linklocal.h             forward.h \
+                            jinglesession.h           jinglecontent.h         jingleplugin.h \
+                            jingletransport.h         jinglesessionhandler.h \
+                            jinglesessionmanager.h    carbons.h               jinglepluginfactory.h \
+                            jingleiceudp.h            jinglefiletransfer.h
 
 noinst_HEADERS = config.h prep.h dns.h nonsaslauth.h mucmessagesession.h stanzaextensionfactory.h \
                    tlsgnutlsclient.h \

=== modified file 'src/Makefile.in'
--- src/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -17,6 +17,23 @@
 
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,6 +85,12 @@
 am__base_list = \
   sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
   sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+  test -z "$$files" \
+    || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+    || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+         $(am__cd) "$$dir" && rm -f $$files; }; \
+  }
 am__installdirs = "$(DESTDIR)$(libdir)" \
 	"$(DESTDIR)$(libglooxincludedir)"
 LTLIBRARIES = $(lib_LTLIBRARIES)
@@ -83,22 +106,26 @@
 	gloox.lo inbandbytestream.lo messagefilter.lo vcard.lo \
 	vcardmanager.lo md5.lo sha.lo search.lo dataformreported.lo \
 	dataformitem.lo mucroom.lo mucmessagesession.lo oob.lo \
-	vcardupdate.lo stanzaextensionfactory.lo delayeddelivery.lo \
-	gpgencrypted.lo gpgsigned.lo uniquemucroom.lo \
-	instantmucroom.lo compressionzlib.lo tlsgnutlsclient.lo \
-	connectionhttpproxy.lo tlsgnutlsserveranon.lo tlsgnutlsbase.lo \
-	tlsgnutlsclientanon.lo tlsschannel.lo tlsdefault.lo \
-	simanager.lo siprofileft.lo mutex.lo connectionsocks5proxy.lo \
-	socks5bytestreammanager.lo socks5bytestream.lo \
-	connectiontcpbase.lo connectiontcpserver.lo \
-	socks5bytestreamserver.lo amp.lo pubsubitem.lo \
-	pubsubmanager.lo error.lo util.lo iq.lo message.lo presence.lo \
-	subscription.lo capabilities.lo chatstate.lo connectionbosh.lo \
-	connectiontls.lo messageevent.lo receipt.lo nickname.lo \
-	eventdispatcher.lo pubsubevent.lo xhtmlim.lo featureneg.lo \
-	shim.lo softwareversion.lo attention.lo tlsopensslclient.lo \
+	vcardupdate.lo stanzaextensionfactory.lo \
+	mucinvitationhandler.lo delayeddelivery.lo gpgencrypted.lo \
+	gpgsigned.lo uniquemucroom.lo instantmucroom.lo \
+	compressionzlib.lo tlsgnutlsclient.lo connectionhttpproxy.lo \
+	tlsgnutlsserveranon.lo tlsgnutlsbase.lo tlsgnutlsclientanon.lo \
+	tlsschannel.lo tlsdefault.lo simanager.lo siprofileft.lo \
+	mutex.lo connectionsocks5proxy.lo socks5bytestreammanager.lo \
+	socks5bytestream.lo connectiontcpbase.lo \
+	connectiontcpserver.lo socks5bytestreamserver.lo amp.lo \
+	pubsubitem.lo pubsubmanager.lo error.lo util.lo iq.lo \
+	message.lo presence.lo subscription.lo capabilities.lo \
+	chatstate.lo connectionbosh.lo connectiontls.lo \
+	messageevent.lo receipt.lo nickname.lo eventdispatcher.lo \
+	pubsubevent.lo xhtmlim.lo featureneg.lo shim.lo \
+	softwareversion.lo attention.lo tlsopensslclient.lo \
 	tlsopensslbase.lo tlsopensslserver.lo compressiondefault.lo \
-	connectiontlsserver.lo
+	connectiontlsserver.lo atomicrefcount.lo linklocalmanager.lo \
+	linklocalclient.lo forward.lo jinglesession.lo \
+	jinglecontent.lo jinglesessionmanager.lo carbons.lo \
+	jinglepluginfactory.lo jingleiceudp.lo jinglefiletransfer.lo
 libgloox_la_OBJECTS = $(am_libgloox_la_OBJECTS)
 libgloox_la_LINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) \
 	$(LIBTOOLFLAGS) --mode=link $(CXXLD) $(AM_CXXFLAGS) \
@@ -125,6 +152,11 @@
 	install-pdf-recursive install-ps-recursive install-recursive \
 	installcheck-recursive installdirs-recursive pdf-recursive \
 	ps-recursive uninstall-recursive
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 HEADERS = $(libglooxinclude_HEADERS) $(noinst_HEADERS)
 RECURSIVE_CLEAN_TARGETS = mostlyclean-recursive clean-recursive	\
   distclean-recursive maintainer-clean-recursive
@@ -178,6 +210,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -187,6 +220,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -202,7 +236,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -232,6 +268,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -266,7 +303,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -299,7 +335,7 @@
                         inbandbytestream.cpp messagefilter.cpp vcard.cpp \
                         vcardmanager.cpp md5.cpp sha.cpp search.cpp dataformreported.cpp dataformitem.cpp \
                         mucroom.cpp mucmessagesession.cpp oob.cpp vcardupdate.cpp stanzaextensionfactory.cpp \
-                        delayeddelivery.cpp gpgencrypted.cpp gpgsigned.cpp \
+                        mucinvitationhandler.cpp delayeddelivery.cpp gpgencrypted.cpp gpgsigned.cpp \
                         uniquemucroom.cpp instantmucroom.cpp compressionzlib.cpp tlsgnutlsclient.cpp \
                         connectionhttpproxy.cpp tlsgnutlsserveranon.cpp tlsgnutlsbase.cpp \
                         tlsgnutlsclientanon.cpp tlsschannel.cpp tlsdefault.cpp simanager.cpp siprofileft.cpp \
@@ -313,9 +349,11 @@
                         shim.cpp softwareversion.cpp attention.cpp \
                         tlsopensslclient.cpp tlsopensslbase.cpp \
                         tlsopensslserver.cpp compressiondefault.cpp \
-                        connectiontlsserver.cpp
+                        connectiontlsserver.cpp atomicrefcount.cpp linklocalmanager.cpp linklocalclient.cpp \
+                        forward.cpp jinglesession.cpp jinglecontent.cpp jinglesessionmanager.cpp \
+                        carbons.cpp jinglepluginfactory.cpp jingleiceudp.cpp jinglefiletransfer.cpp
 
-libgloox_la_LDFLAGS = -version-info 8:0:0 -no-undefined -no-allow-shlib-undefined
+libgloox_la_LDFLAGS = -version-info 11:0:0 -no-undefined -no-allow-shlib-undefined
 libgloox_la_LIBADD = 
 libgloox_la_CFLAGS = $(CPPFLAGS)
 libglooxincludedir = $(includedir)/gloox
@@ -367,7 +405,13 @@
                             nickname.h                pubsubevent.h           xhtmlim.h \
                             eventdispatcher.h         \
                             pubsubitem.h shim.h util.h \
-                            connectiontlsserver.h compressiondefault.h
+                            connectiontlsserver.h compressiondefault.h \
+                            atomicrefcount.h          linklocalmanager.h           linklocalhandler.h \
+                            linklocalclient.h         linklocal.h             forward.h \
+                            jinglesession.h           jinglecontent.h         jingleplugin.h \
+                            jingletransport.h         jinglesessionhandler.h \
+                            jinglesessionmanager.h    carbons.h               jinglepluginfactory.h \
+                            jingleiceudp.h            jinglefiletransfer.h
 
 noinst_HEADERS = config.h prep.h dns.h nonsaslauth.h mucmessagesession.h stanzaextensionfactory.h \
                    tlsgnutlsclient.h \
@@ -412,7 +456,6 @@
 $(am__aclocal_m4_deps):
 install-libLTLIBRARIES: $(lib_LTLIBRARIES)
 	@$(NORMAL_INSTALL)
-	test -z "$(libdir)" || $(MKDIR_P) "$(DESTDIR)$(libdir)"
 	@list='$(lib_LTLIBRARIES)'; test -n "$(libdir)" || list=; \
 	list2=; for p in $$list; do \
 	  if test -f $$p; then \
@@ -420,6 +463,8 @@
 	  else :; fi; \
 	done; \
 	test -z "$$list2" || { \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(libdir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(libdir)" || exit 1; \
 	  echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(libdir)'"; \
 	  $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(libdir)"; \
 	}
@@ -441,7 +486,7 @@
 	  echo "rm -f \"$${dir}/so_locations\""; \
 	  rm -f "$${dir}/so_locations"; \
 	done
-libgloox.la: $(libgloox_la_OBJECTS) $(libgloox_la_DEPENDENCIES) 
+libgloox.la: $(libgloox_la_OBJECTS) $(libgloox_la_DEPENDENCIES) $(EXTRA_libgloox_la_DEPENDENCIES) 
 	$(libgloox_la_LINK) -rpath $(libdir) $(libgloox_la_OBJECTS) $(libgloox_la_LIBADD) $(LIBS)
 
 mostlyclean-compile:
@@ -453,10 +498,12 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/adhoc.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/amp.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/annotations.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/atomicrefcount.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/attention.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/base64.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bookmarkstorage.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/capabilities.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/carbons.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/chatstate.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/chatstatefilter.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/client.Plo@am__quote@
@@ -484,6 +531,7 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/eventdispatcher.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/featureneg.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/flexoff.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/forward.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gloox.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gpgencrypted.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gpgsigned.Plo@am__quote@
@@ -491,7 +539,15 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/instantmucroom.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iq.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jid.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglecontent.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglefiletransfer.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jingleiceudp.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglepluginfactory.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglesession.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglesessionmanager.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lastactivity.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/linklocalclient.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/linklocalmanager.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/logsink.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/md5.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/message.Plo@am__quote@
@@ -499,6 +555,7 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/messageeventfilter.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/messagefilter.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/messagesession.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mucinvitationhandler.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mucmessagesession.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mucroom.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mutex.Plo@am__quote@
@@ -575,8 +632,11 @@
 	-rm -rf .libs _libs
 install-libglooxincludeHEADERS: $(libglooxinclude_HEADERS)
 	@$(NORMAL_INSTALL)
-	test -z "$(libglooxincludedir)" || $(MKDIR_P) "$(DESTDIR)$(libglooxincludedir)"
 	@list='$(libglooxinclude_HEADERS)'; test -n "$(libglooxincludedir)" || list=; \
+	if test -n "$$list"; then \
+	  echo " $(MKDIR_P) '$(DESTDIR)$(libglooxincludedir)'"; \
+	  $(MKDIR_P) "$(DESTDIR)$(libglooxincludedir)" || exit 1; \
+	fi; \
 	for p in $$list; do \
 	  if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
 	  echo "$$d$$p"; \
@@ -590,9 +650,7 @@
 	@$(NORMAL_UNINSTALL)
 	@list='$(libglooxinclude_HEADERS)'; test -n "$(libglooxincludedir)" || list=; \
 	files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
-	test -n "$$files" || exit 0; \
-	echo " ( cd '$(DESTDIR)$(libglooxincludedir)' && rm -f" $$files ")"; \
-	cd "$(DESTDIR)$(libglooxincludedir)" && rm -f $$files
+	dir='$(DESTDIR)$(libglooxincludedir)'; $(am__uninstall_files_from_dir)
 
 # This directory's subdirectories are mostly independent; you can cd
 # into them and run `make' without going through this Makefile.
@@ -601,7 +659,7 @@
 #     (which will cause the Makefiles to be regenerated when you run `make');
 # (2) otherwise, pass the desired values on the `make' command line.
 $(RECURSIVE_TARGETS):
-	@failcom='exit 1'; \
+	@fail= failcom='exit 1'; \
 	for f in x $$MAKEFLAGS; do \
 	  case $$f in \
 	    *=* | --[!k]*);; \
@@ -626,7 +684,7 @@
 	fi; test -z "$$fail"
 
 $(RECURSIVE_CLEAN_TARGETS):
-	@failcom='exit 1'; \
+	@fail= failcom='exit 1'; \
 	for f in x $$MAKEFLAGS; do \
 	  case $$f in \
 	    *=* | --[!k]*);; \
@@ -761,13 +819,10 @@
 	done
 	@list='$(DIST_SUBDIRS)'; for subdir in $$list; do \
 	  if test "$$subdir" = .; then :; else \
-	    test -d "$(distdir)/$$subdir" \
-	    || $(MKDIR_P) "$(distdir)/$$subdir" \
-	    || exit 1; \
-	  fi; \
-	done
-	@list='$(DIST_SUBDIRS)'; for subdir in $$list; do \
-	  if test "$$subdir" = .; then :; else \
+	    $(am__make_dryrun) \
+	      || test -d "$(distdir)/$$subdir" \
+	      || $(MKDIR_P) "$(distdir)/$$subdir" \
+	      || exit 1; \
 	    dir1=$$subdir; dir2="$(distdir)/$$subdir"; \
 	    $(am__relativize); \
 	    new_distdir=$$reldir; \
@@ -805,10 +860,15 @@
 
 installcheck: installcheck-recursive
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/adhoc.cpp'
--- src/adhoc.cpp	2010-01-17 13:05:04 +0000
+++ src/adhoc.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -20,6 +20,7 @@
 #include "clientbase.h"
 #include "dataform.h"
 #include "util.h"
+#include "mutexguard.h"
 
 namespace gloox
 {
@@ -227,6 +228,10 @@
 
   Adhoc::~Adhoc()
   {
+    m_adhocTrackMapMutex.lock();
+    m_adhocTrackMap.clear();
+    m_adhocTrackMapMutex.unlock();
+
     if( !m_parent || !m_parent->disco() )
       return;
 
@@ -306,27 +311,32 @@
     if( context != ExecuteAdhocCommand )
       return;
 
+    m_adhocTrackMapMutex.lock();
     AdhocTrackMap::iterator it = m_adhocTrackMap.find( iq.id() );
-    if( it == m_adhocTrackMap.end() || (*it).second.context != context
+    bool haveIdHandler = ( it != m_adhocTrackMap.end() );
+    m_adhocTrackMapMutex.unlock();
+    if( !haveIdHandler || (*it).second.context != context
         || (*it).second.remote != iq.from() )
       return;
 
     switch( iq.subtype() )
     {
       case IQ::Error:
-        (*it).second.ah->handleAdhocError( iq.from(), iq.error() );
+        (*it).second.ah->handleAdhocError( iq.from(), iq.error(), (*it).second.handlerContext );
         break;
       case IQ::Result:
       {
         const Adhoc::Command* ac = iq.findExtension<Adhoc::Command>( ExtAdhocCommand );
         if( ac )
-          (*it).second.ah->handleAdhocExecutionResult( iq.from(), *ac );
+          (*it).second.ah->handleAdhocExecutionResult( iq.from(), *ac, (*it).second.handlerContext );
         break;
       }
       default:
         break;
     }
+    m_adhocTrackMapMutex.lock();
     m_adhocTrackMap.erase( it );
+    m_adhocTrackMapMutex.unlock();
   }
 
   void Adhoc::registerAdhocCommandProvider( AdhocCommandProvider* acp, const std::string& command,
@@ -345,6 +355,8 @@
     if( context != CheckAdhocSupport )
       return;
 
+    util::MutexGuard m( m_adhocTrackMapMutex );
+
     AdhocTrackMap::iterator it = m_adhocTrackMap.begin();
     for( ; it != m_adhocTrackMap.end() && (*it).second.context != context
                                        && (*it).second.remote  != from; ++it )
@@ -352,7 +364,7 @@
     if( it == m_adhocTrackMap.end() )
       return;
 
-    (*it).second.ah->handleAdhocSupport( from, info.hasFeature( XMLNS_ADHOC_COMMANDS ) );
+    (*it).second.ah->handleAdhocSupport( from, info.hasFeature( XMLNS_ADHOC_COMMANDS ), (*it).second.handlerContext );
     m_adhocTrackMap.erase( it );
   }
 
@@ -361,6 +373,8 @@
     if( context != FetchAdhocCommands )
       return;
 
+    util::MutexGuard m( m_adhocTrackMapMutex );
+
     AdhocTrackMap::iterator it = m_adhocTrackMap.begin();
     for( ; it != m_adhocTrackMap.end(); ++it )
     {
@@ -373,7 +387,7 @@
         {
           commands[(*it2)->node()] = (*it2)->name();
         }
-        (*it).second.ah->handleAdhocCommands( from, commands );
+        (*it).second.ah->handleAdhocCommands( from, commands, (*it).second.handlerContext );
 
         m_adhocTrackMap.erase( it );
         break;
@@ -383,19 +397,28 @@
 
   void Adhoc::handleDiscoError( const JID& from, const Error* error, int context )
   {
-    AdhocTrackMap::iterator it = m_adhocTrackMap.begin();
-    for( ; it != m_adhocTrackMap.end(); ++it )
+    util::MutexGuard m( m_adhocTrackMapMutex );
+    for( AdhocTrackMap::iterator it = m_adhocTrackMap.begin(); it != m_adhocTrackMap.end(); )
     {
       if( (*it).second.context == context && (*it).second.remote == from )
       {
-        (*it).second.ah->handleAdhocError( from, error );
+        (*it).second.ah->handleAdhocError( from, error, (*it).second.handlerContext );
 
-        m_adhocTrackMap.erase( it );
+          // Normally we'd just assign it to the return value of the .erase() call,
+          // which is either the next element, or .end().  However,
+          // it's only since C++11 that this works; C++03 version returns void.
+          // So instead, we do a post-increment. this increments the iterator to point
+          // to the next element, then passes a copy of the old iterator (that is to the item to be deleted)
+        m_adhocTrackMap.erase( it++ );
+      }
+      else
+      {
+        ++it;
       }
     }
   }
 
-  void Adhoc::checkSupport( const JID& remote, AdhocHandler* ah )
+  void Adhoc::checkSupport( const JID& remote, AdhocHandler* ah, int context )
   {
     if( !remote || !ah || !m_parent || !m_parent->disco() )
       return;
@@ -404,12 +427,15 @@
     track.remote = remote;
     track.context = CheckAdhocSupport;
     track.ah = ah;
+    track.handlerContext = context;
     const std::string& id = m_parent->getID();
+    m_adhocTrackMapMutex.lock();
     m_adhocTrackMap[id] = track;
+    m_adhocTrackMapMutex.unlock();
     m_parent->disco()->getDiscoInfo( remote, EmptyString, this, CheckAdhocSupport, id );
   }
 
-  void Adhoc::getCommands( const JID& remote, AdhocHandler* ah )
+  void Adhoc::getCommands( const JID& remote, AdhocHandler* ah, int context )
   {
     if( !remote || !ah || !m_parent || !m_parent->disco() )
       return;
@@ -418,12 +444,15 @@
     track.remote = remote;
     track.context = FetchAdhocCommands;
     track.ah = ah;
+    track.handlerContext = context;
     const std::string& id = m_parent->getID();
+    m_adhocTrackMapMutex.lock();
     m_adhocTrackMap[id] = track;
+    m_adhocTrackMapMutex.unlock();
     m_parent->disco()->getDiscoItems( remote, XMLNS_ADHOC_COMMANDS, this, FetchAdhocCommands, id );
   }
 
-  void Adhoc::execute( const JID& remote, const Adhoc::Command* command, AdhocHandler* ah )
+  void Adhoc::execute( const JID& remote, const Adhoc::Command* command, AdhocHandler* ah, int context )
   {
     if( !remote || !command || !m_parent || !ah )
       return;
@@ -437,7 +466,10 @@
     track.context = ExecuteAdhocCommand;
     track.session = command->sessionID();
     track.ah = ah;
+    track.handlerContext = context;
+    m_adhocTrackMapMutex.lock();
     m_adhocTrackMap[id] = track;
+    m_adhocTrackMapMutex.unlock();
 
     m_parent->send( iq, this, ExecuteAdhocCommand );
   }

=== modified file 'src/adhoc.h'
--- src/adhoc.h	2010-01-17 13:05:04 +0000
+++ src/adhoc.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -21,6 +21,7 @@
 #include "discohandler.h"
 #include "iqhandler.h"
 #include "stanzaextension.h"
+#include "mutex.h"
 
 #include <string>
 #include <list>
@@ -35,7 +36,7 @@
   class AdhocCommandProvider;
 
   /**
-   * @brief This class implements a provider for XEP-0050 (Ad-hoc Commands).
+   * @brief This class implements a provider for @xep{0050} (Ad-hoc Commands).
    *
    * The current, not complete, implementation is probably best suited for fire-and-forget
    * type of commands. Any additional feature, like multiple stages, etc., would have to be
@@ -81,7 +82,7 @@
   {
     public:
       /**
-       * @brief An abstraction of an Adhoc Command element (from Adhoc Commands, XEP-0050)
+       * @brief An abstraction of an Adhoc Command element (from Adhoc Commands, @xep{0050})
        * as a StanzaExtension.
        *
        * @author Jakob Schroeter <js@camaya.net>
@@ -372,16 +373,18 @@
        * This function queries the given remote entity for Adhoc Commands support.
        * @param remote The remote entity's JID.
        * @param ah The object handling the result of this request.
+       * @param context A user defined context.
        */
-      void checkSupport( const JID& remote, AdhocHandler* ah );
+      void checkSupport( const JID& remote, AdhocHandler* ah, int context = 0 );
 
       /**
        * Retrieves a list of commands from the remote entity. You should check whether the remote
        * entity actually supports Adhoc Commands by means of checkSupport().
        * @param remote The remote entity's JID.
        * @param ah The object handling the result of this request.
+       * @param context A user defined context.
        */
-      void getCommands( const JID& remote, AdhocHandler* ah );
+      void getCommands( const JID& remote, AdhocHandler* ah, int context = 0 );
 
       /**
        * Executes or continues the given command on the given remote entity.
@@ -392,8 +395,9 @@
        * @param remote The remote entity's JID.
        * @param command The command to execute.
        * @param ah The object handling the result of this request.
+       * @param context A user defined context.
        */
-      void execute( const JID& remote, const Adhoc::Command* command, AdhocHandler* ah );
+      void execute( const JID& remote, const Adhoc::Command* command, AdhocHandler* ah, int context = 0 );
 
       /**
        * Use this function to respond to an execution request submitted by means
@@ -411,8 +415,8 @@
 
       /**
        * Using this function, you can register a AdhocCommandProvider -derived object as
-       * handler for a specific Ad-hoc Command as defined in XEP-0050.
-       * @param acp The obejct to register as handler for the specified command.
+       * handler for a specific Ad-hoc Command as defined in @xep{0050}.
+       * @param acp The object to register as handler for the specified command.
        * @param command The node name of the command. Will be announced in disco#items.
        * @param name The natural-language name of the command. Will be announced in disco#items.
        */
@@ -471,9 +475,11 @@
         AdhocContext context;
         std::string session;
         AdhocHandler* ah;
+        int handlerContext;
       };
       typedef std::map<std::string, TrackStruct> AdhocTrackMap;
       AdhocTrackMap m_adhocTrackMap;
+      util::Mutex m_adhocTrackMapMutex;
 
       ClientBase* m_parent;
 

=== modified file 'src/adhoccommandprovider.h'
--- src/adhoccommandprovider.h	2010-01-17 13:05:04 +0000
+++ src/adhoccommandprovider.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -27,7 +27,7 @@
 {
 
   /**
-   * @brief A virtual interface for an Ad-hoc Command Provider according to XEP-0050.
+   * @brief A virtual interface for an Ad-hoc Command Provider according to @xep{0050}.
    *
    * Derived classes can be registered as Command Providers with the Adhoc object.
    *

=== modified file 'src/adhochandler.h'
--- src/adhochandler.h	2010-01-17 13:05:04 +0000
+++ src/adhochandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -21,7 +21,7 @@
 {
 
   /**
-   * @brief A virtual interface for an Ad-hoc Command users according to XEP-0050.
+   * @brief A virtual interface for an Ad-hoc Command users according to @xep{0050}.
    *
    * Derived classes can be registered with the Adhoc object to receive notifications
    * about Adhoc Commands remote entities support.
@@ -41,17 +41,19 @@
        * This function is called in response to a call to Adhoc::checkSupport().
        * @param remote The queried remote entity's JID.
        * @param support Whether the remote entity supports Adhoc Commands.
+       * @param context A user defined context.
        */
-      virtual void handleAdhocSupport( const JID& remote, bool support ) = 0;
+      virtual void handleAdhocSupport( const JID& remote, bool support, int context ) = 0;
 
       /**
        * This function is called in response to a call to Adhoc::getCommands()
        * and delivers a list of supported commands.
        * @param remote The queried remote entity's JID.
        * @param commands A map of supported commands and their human-readable name.
+       * @param context A user defined context.
        * The map may be empty.
        */
-      virtual void handleAdhocCommands( const JID& remote, const StringMap& commands ) = 0;
+      virtual void handleAdhocCommands( const JID& remote, const StringMap& commands, int context ) = 0;
 
       /**
        * This function is called in response to a call to Adhoc::getCommands() or
@@ -59,15 +61,17 @@
        * an error.
        * @param remote The queried remote entity's JID.
        * @param error The error condition. May be 0.
+       * @param context A user defined context.
        */
-      virtual void handleAdhocError( const JID& remote, const Error* error ) = 0;
+      virtual void handleAdhocError( const JID& remote, const Error* error, int context ) = 0;
 
       /**
        * This function is called in response to a remote command execution.
        * @param remote The remote entity's JID.
        * @param command The command being executed.
+       * @param context A user defined context.
        */
-      virtual void handleAdhocExecutionResult( const JID& remote, const Adhoc::Command& command ) = 0;
+      virtual void handleAdhocExecutionResult( const JID& remote, const Adhoc::Command& command, int context ) = 0;
   };
 
 }

=== modified file 'src/amp.cpp'
--- src/amp.cpp	2010-01-17 13:05:04 +0000
+++ src/amp.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/amp.h'
--- src/amp.h	2010-01-17 13:05:04 +0000
+++ src/amp.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -28,7 +28,7 @@
   class Tag;
 
   /**
-   * @brief This is an implementation of XEP-0079 (Advanced Message Processing)
+   * @brief This is an implementation of @xep{0079} (Advanced Message Processing)
    * as a StanzaExtension.
    *
    * XEP Version: 1.2
@@ -125,7 +125,7 @@
 
           /**
            * Creates a new AMP rule object with a condition of 'expire-at'.
-           * @param date The expiry date/time in the format defined in XEP-0082.
+           * @param date The expiry date/time in the format defined in @xep{0082}.
            * @param action The rule's action.
            */
           Rule( const std::string& date, ActionType action );

=== modified file 'src/annotations.cpp'
--- src/annotations.cpp	2010-01-17 13:05:04 +0000
+++ src/annotations.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/annotations.h'
--- src/annotations.h	2010-01-17 13:05:04 +0000
+++ src/annotations.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,7 +30,7 @@
   class Tag;
 
   /**
-   * @brief This is an implementation of XEP-0145 (Annotations).
+   * @brief This is an implementation of @xep{0145} (Annotations).
    *
    * You can use this class to store arbitrary notes about a roster item on the server
    * (and to retrieve them later on).

=== modified file 'src/annotationshandler.h'
--- src/annotationshandler.h	2010-01-17 13:05:04 +0000
+++ src/annotationshandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== added file 'src/atomicrefcount.cpp'
--- src/atomicrefcount.cpp	1970-01-01 00:00:00 +0000
+++ src/atomicrefcount.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,93 @@
+/*
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "atomicrefcount.h"
+
+#include "config.h"
+
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+# include <windows.h>
+#elif defined( __APPLE__ )
+# include <libkern/OSAtomic.h>
+#elif defined( HAVE_GCC_ATOMIC_BUILTINS )
+ // Use intrinsic functions - no #include required.
+#else
+# include "mutexguard.h"
+#endif
+
+#ifdef _WIN32_WCE
+# include <winbase.h>
+#endif
+
+namespace gloox
+{
+
+  namespace util
+  {
+    AtomicRefCount::AtomicRefCount()
+      : m_count( 0 )
+    {
+    }
+
+    int AtomicRefCount::increment()
+    {
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+      return (int) ::InterlockedIncrement( (volatile LONG*)&m_count );
+#elif defined( __APPLE__ )
+      return (int) OSAtomicIncrement32Barrier( (volatile int32_t*)&m_count );
+#elif defined( HAVE_GCC_ATOMIC_BUILTINS )
+      // Use the gcc intrinsic for atomic increment if supported.
+      return (int) __sync_add_and_fetch( &m_count, 1 );
+#else
+      // Fallback to using a lock
+      MutexGuard m( m_lock );
+      return ++m_count;
+#endif
+    }
+
+    int AtomicRefCount::decrement()
+    {
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+      return (int) ::InterlockedDecrement( (volatile LONG*)&m_count );
+#elif defined( __APPLE__ )
+      return (int) OSAtomicDecrement32Barrier( (volatile int32_t*)&m_count );
+#elif defined( HAVE_GCC_ATOMIC_BUILTINS )
+      // Use the gcc intrinsic for atomic decrement if supported.
+      return (int) __sync_sub_and_fetch( &m_count, 1 );
+#else
+      // Fallback to using a lock
+      MutexGuard m( m_lock );
+      return --m_count;
+#endif
+    }
+
+    void AtomicRefCount::reset()
+    {
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+      ::InterlockedExchange( (volatile LONG*)&m_count, (volatile LONG)0 );
+#elif defined( __APPLE__ )
+      OSAtomicAnd32Barrier( (int32_t)0, (volatile int32_t*)&m_count );
+#elif defined( HAVE_GCC_ATOMIC_BUILTINS )
+      // Use the gcc intrinsic for atomic decrement if supported.
+      __sync_fetch_and_and( &m_count, 0 );
+#else
+      // Fallback to using a lock
+      MutexGuard m( m_lock );
+      m_count = 0;
+#endif
+    }
+
+  }
+
+}
+

=== added file 'src/atomicrefcount.h'
--- src/atomicrefcount.h	1970-01-01 00:00:00 +0000
+++ src/atomicrefcount.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,75 @@
+/*
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef ATOMICREFCOUNT_H__
+#define ATOMICREFCOUNT_H__
+
+#include "macros.h"
+#include "mutex.h"
+
+namespace gloox
+{
+
+  namespace util
+  {
+    /**
+     * @brief A simple implementation of a thread safe 32-bit
+     *  reference count. Native functions are used where possible.
+     *  When not available, a mutex is used for locking and unlocking.
+     *
+     * @author Daniel Bowen
+     * @author Jakob Schröter <js@camaya.net>
+     * @since 1.0.1
+     */
+    class GLOOX_API AtomicRefCount
+    {
+      public:
+        /**
+         * Contructs a new atomic reference count.
+         */
+        AtomicRefCount();
+
+        /**
+         * Increments the reference count, and returns the new value.
+         * @return The new value.
+         */
+        int increment();
+
+        /**
+         * Decrements the reference count, and returns the new value.
+         * @return The new value.
+         */
+        int decrement();
+
+        /**
+         * Resets the reference count to zero.
+         * @since 1.0.4
+         */
+        void reset();
+        
+    private:
+        AtomicRefCount& operator=( const AtomicRefCount& );
+
+        volatile int m_count;
+
+        // The mutex is only used if a native function is unavailable.
+        Mutex m_lock;
+
+    };
+
+  }
+
+}
+
+#endif // ATOMICREFCOUNT_H__
+

=== modified file 'src/attention.cpp'
--- src/attention.cpp	2010-01-17 13:05:04 +0000
+++ src/attention.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/attention.h'
--- src/attention.h	2010-01-17 13:05:04 +0000
+++ src/attention.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
   class Tag;
 
   /**
-   * @brief This is an implementation of XEP-0224 as a StanzaExtension.
+   * @brief This is an implementation of @xep{0224} as a StanzaExtension.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 1.0

=== modified file 'src/base64.cpp'
--- src/base64.cpp	2010-01-17 13:05:04 +0000
+++ src/base64.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/base64.h'
--- src/base64.h	2010-01-17 13:05:04 +0000
+++ src/base64.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/bookmarkhandler.h'
--- src/bookmarkhandler.h	2010-01-17 13:05:04 +0000
+++ src/bookmarkhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/bookmarkstorage.cpp'
--- src/bookmarkstorage.cpp	2010-01-17 13:05:04 +0000
+++ src/bookmarkstorage.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/bookmarkstorage.h'
--- src/bookmarkstorage.h	2010-01-17 13:05:04 +0000
+++ src/bookmarkstorage.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,7 +30,7 @@
   class Tag;
 
   /**
-   * @brief This is an implementation of XEP-0048 (Bookmark Storage).
+   * @brief This is an implementation of @xep{0048} (Bookmark Storage).
    *
    * You can use this class to store bookmarks to multi-user chat rooms or ordinary URLs
    * on the server (and to retrieve them later on).

=== modified file 'src/bytestream.h'
--- src/bytestream.h	2010-01-17 13:05:04 +0000
+++ src/bytestream.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/bytestreamdatahandler.h'
--- src/bytestreamdatahandler.h	2010-01-17 13:05:04 +0000
+++ src/bytestreamdatahandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,8 +26,8 @@
 
   /**
    * @brief A virtual interface that allows implementors to receive data
-   * sent over a SOCKS5 Bytestream as defined in XEP-0066, or an In-Band Bytestream
-   * as defined in XEP-0047. You'll also need it for sending of data.
+   * sent over a SOCKS5 Bytestream as defined in @xep{0066}, or an In-Band Bytestream
+   * as defined in @xep{0047}. You'll also need it for sending of data.
    *
    * An BytestreamDataHandler is registered with a Bytestream.
    *

=== modified file 'src/bytestreamhandler.h'
--- src/bytestreamhandler.h	2010-01-17 13:05:04 +0000
+++ src/bytestreamhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/capabilities.cpp'
--- src/capabilities.cpp	2010-01-17 13:05:04 +0000
+++ src/capabilities.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/capabilities.h'
--- src/capabilities.h	2010-01-17 13:05:04 +0000
+++ src/capabilities.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -27,7 +27,7 @@
   class Tag;
 
   /**
-   * @brief This is an implementation of XEP-0115 (Entity Capabilities).
+   * @brief This is an implementation of @xep{0115} (Entity Capabilities).
    *
    * XEP Version: 1.5-15
    * @author Jakob Schroeter <js@camaya.net>

=== added file 'src/carbons.cpp'
--- src/carbons.cpp	1970-01-01 00:00:00 +0000
+++ src/carbons.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,103 @@
+/*
+ *  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+ *  This file is part of the gloox library. http://camaya.net/gloox
+ *
+ *  This software is distributed under a license. The full license
+ *  agreement can be found in the file LICENSE in this distribution.
+ *  This software may not be copied, modified, sold or distributed
+ *  other than expressed in the named license agreement.
+ *
+ *  This software is distributed without any warranty.
+ */
+
+
+#include "carbons.h"
+
+#include "forward.h"
+#include "util.h"
+
+namespace gloox
+{
+  /* chat state type values */
+  static const char* typeValues [] = {
+    "received",
+    "sent",
+    "enable",
+    "disable",
+    "private"
+  };
+
+  Carbons::Carbons( Carbons::Type type )
+    : StanzaExtension( ExtCarbons ), m_forward( 0 ), m_type( type )
+  {
+  }
+
+  Carbons::Carbons( const Tag* tag )
+    : StanzaExtension( ExtCarbons ), m_forward( 0 ), m_type( Invalid )
+  {
+    if( !tag )
+      return;
+
+    const std::string& name = tag->name();
+    m_type = (Type)util::lookup( name, typeValues );
+
+    switch( m_type )
+    {
+      case Sent:
+      case Received:
+      {
+        Tag* f = tag->findChild( "forwarded", XMLNS, XMLNS_STANZA_FORWARDING );
+        if( f )
+          m_forward = new Forward( f );
+        break;
+      }
+      default:
+        break;
+    }
+  }
+
+  Carbons::~Carbons()
+  {
+    delete m_forward;
+  }
+
+  const std::string& Carbons::filterString() const
+  {
+    static const std::string filter = "/message/*[@xmlns='" + XMLNS_MESSAGE_CARBONS + "']";
+    return filter;
+  }
+
+  Stanza* Carbons::embeddedStanza() const
+  {
+    if( !m_forward || m_type == Invalid )
+      return 0;
+
+    return m_forward->embeddedStanza();
+  }
+
+  Tag* Carbons::embeddedTag() const
+  {
+    if( !m_forward || m_type == Invalid )
+      return 0;
+
+    return m_forward->embeddedTag();
+  }
+
+  Tag* Carbons::tag() const
+  {
+    if( m_type == Invalid )
+      return 0;
+
+    Tag* t = new Tag( util::lookup( m_type, typeValues ), XMLNS, XMLNS_MESSAGE_CARBONS );
+    if( m_forward && ( m_type == Received || m_type == Sent ) )
+      t->addChild( m_forward->tag() );
+
+    return t;
+  }
+
+  StanzaExtension* Carbons::clone() const
+  {
+    return 0; // TODO
+  }
+
+}

=== added file 'src/carbons.h'
--- src/carbons.h	1970-01-01 00:00:00 +0000
+++ src/carbons.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,185 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef CARBONS_H__
+#define CARBONS_H__
+
+#include "macros.h"
+
+#include "stanzaextension.h"
+#include "tag.h"
+
+namespace gloox
+{
+
+  class Forward;
+
+  /**
+   * @brief An implementation of Message Carbons (@xep{0280}) as a StanzaExtension.
+   *
+   * @section enable Enable Mesage Carbons
+   *
+   * Before using Message Carbons you have to check your server for support of the extension.
+   * You can do so using Disco::getDiscoInfo(). You can check the result (in DiscoHandler::handleDiscoInfo())
+   * for a feature of @c XMLNS_MESSAGE_CARBONS (use Disco::Info::hasFeature()).
+   *
+   * If the feature exists, you can enable Message Carbons with the server.
+   *
+   * @code
+   * Client cb( ... );
+   * // ...
+   *
+   * // setup
+   * cb.registerStanzaExtension( new Forward() ); // required for Message Carbons support
+   * cb.registerStanzaExtension( new Carbons() );
+   * // ...
+   *
+   * // enable Message Carbons
+   * IQ iq( IQ::Set, JID() ); // empty JID
+   * iq.addExtension( new Carbons( Carbons::Enable ) );
+   * cb.send( iq, MyIqHandler, 1 ); // myIqHandler will be notified of the result with the given context ('1' in this case).
+   * @endcode
+   *
+   * @note Once enabled, the server will automatically send all received and sent messages @b of @b type @c Chat to all other Carbons-enabled resources of
+   * the current account. You have to make sure that you actually send messages of type @c Chat. The default is currently @c Normal.
+   *
+   * @section disable Disable Message Carbons
+   *
+   * Once enabled, you can easily disable Message carbons. The code is almost identical to the code used to enable the feature,
+   * except that you use a Carbons::Type of Carbons::Disable when you add the Carbons extension to the IQ:
+   * @code
+   * iq.addExtension( new Carbons( Carbons::Disable ) );
+   * @endcode
+   *
+   * @section private Prevent carbon copies for a single message
+   *
+   * To disable carbon copies for a single message, add a Carbons extension of type Private:
+   *
+   * @code
+   * Message msg( Message::Chat, ... );
+   * // ...
+   * msg.addExtension( new Carbons( Carbons::Private ) );
+   * @endcode
+   *
+   * The server will not copy this message to your other connected resources.
+   *
+   * @section access Access received carbon copies
+   *
+   * When receiving a message (sent by either another connected client of the current user, or by a 3rd party), a carbon copy will
+   * have the following characteristics:
+   * @li The message's @c from attribute will be the @b bare JID of the @b receiving entity.
+   * @li The message's @c from attribute will be the @b full JID of the @b receiving entity.
+   * @li The message contains a Carbons StanzaExtension. This extension contains the original message with the @b original
+   * @c from/to attributes.
+   *
+   * Some sample code:
+   * @code
+   * bool Myclass::handleMessage( const Message& msg, MessageSession* )
+   * {
+   *   if( msg.hasEmbeddedStanza() ) // optional, saves some processing time when there is no Carbons extension
+   *   {
+   *     const Carbons* carbon = msg.findExtension<const Carbons>( ExtCarbons );
+   *     if( carbon && carbon->embeddedStanza() )
+   *     {
+   *       Message* embeddedMessage = static_cast<Message *>( carbon->embeddedStanza() );
+   *     }
+   *   }
+   * }
+   * @endcode
+   *
+   * You can also determine whether a carbon was sent by a 3rd party or a different client of the current user by checking the return value of Carbons::type().
+   * @code
+   * Carbons* c = msg.findExtension<...>( ... );
+   * // check that c is valid
+   *
+   * if( c->type() == Carbons::Received )
+   *   // Message was sent by a 3rd party
+   * else if( c->type() == Carbons::Sent )
+   *   // Message was sent by a different client of the current user
+   * @endcode
+   *
+   * XEP Version: 0.8
+   *
+   * @author Jakob Schroeter <js@camaya.net>
+   * @since 1.0.5
+   */
+  class GLOOX_API Carbons : public StanzaExtension
+  {
+    public:
+      /**
+       * The types of Message Carbons stanza extensions.
+       */
+      enum Type
+      {
+        Received,                   /**< Indicates that the message received has been sent by a third party. */
+        Sent,                       /**< Indicates that the message received has been sent by one of the user's own resources. */
+        Enable,                     /**< Indicates that the sender wishes to enable carbon copies. */
+        Disable,                    /**< Indicates that the sender wishes to disable carbon copies. */
+        Private,                    /**< Indicates that the sender does not want carbon copies to be sent for this message. */
+        Invalid                     /**< Invalid type. */
+      };
+
+      /**
+       * Constructs a new Carbons instance of the given type.
+       * You should only use the @c Enable, @c Disable and @c Private types.
+       * @param type The Carbons type to create.
+       */
+      Carbons( Type type );
+
+      /**
+       * Constructs a new Carbons instance from the given tag.
+       * @param tag The Tag to create the Carbons instance from.
+       */
+      Carbons( const Tag* tag = 0 );
+
+      /**
+       * Virtual destructor.
+       */
+      virtual ~Carbons();
+
+      /**
+       * Returns the current instance's type.
+       * @return The intance's type.
+       */
+      Type type() const { return m_type; }
+
+      // reimplemented from StanzaExtension
+      virtual Stanza* embeddedStanza() const;
+
+      // reimplemented from StanzaExtension
+      virtual Tag* embeddedTag() const;
+
+      // reimplemented from StanzaExtension
+      virtual const std::string& filterString() const;
+
+      // reimplemented from StanzaExtension
+      virtual StanzaExtension* newInstance( const Tag* tag ) const
+      {
+        return new Carbons( tag );
+      }
+
+      // reimplemented from StanzaExtension
+      virtual Tag* tag() const;
+
+      // reimplemented from StanzaExtension
+      virtual StanzaExtension* clone() const;
+
+    private:
+      Forward* m_forward;
+      Type m_type;
+
+  };
+
+}
+
+#endif // CARBONS_H__

=== modified file 'src/chatstate.cpp'
--- src/chatstate.cpp	2010-01-17 13:05:04 +0000
+++ src/chatstate.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -32,7 +32,8 @@
   }
 
   ChatState::ChatState( const Tag* tag )
-    : StanzaExtension( ExtChatState )
+    : StanzaExtension( ExtChatState ),
+      m_state( ChatStateInvalid )
   {
     if( tag )
       m_state = chatStateType( tag->name() );

=== modified file 'src/chatstate.h'
--- src/chatstate.h	2010-01-17 13:05:04 +0000
+++ src/chatstate.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,7 +24,7 @@
   class Tag;
 
   /**
-   * @brief An implementation of Chat State Notifications (XEP-0085) as a StanzaExtension.
+   * @brief An implementation of Chat State Notifications (@xep{0085}) as a StanzaExtension.
    *
    * @author Vincent Thomasset
    * @author Jakob Schroeter <js@camaya.net>

=== modified file 'src/chatstatefilter.cpp'
--- src/chatstatefilter.cpp	2010-01-17 13:05:04 +0000
+++ src/chatstatefilter.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/chatstatefilter.h'
--- src/chatstatefilter.h	2010-01-17 13:05:04 +0000
+++ src/chatstatefilter.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
   class Message;
 
   /**
-   * @brief This class adds Chat State Notifications (XEP-0085) support to a MessageSession.
+   * @brief This class adds Chat State Notifications (@xep{0085}) support to a MessageSession.
    *
    * This implementation of Chat States is fully transparent to the user of the class.
    * If the remote entity does not request chat states, ChatStateFilter will not send
@@ -34,6 +34,9 @@
    * You MUST annouce this capability by use of Disco (associated namespace is XMLNS_CHAT_STATES).
    * (This is also required by the protocol specification.)
    *
+   * @note You must register ChatState as a StanzaExtension by calling
+   * ClientBase::registerStanzaExtension() for notifications to work.
+   *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 0.8
    */
@@ -52,7 +55,7 @@
       virtual ~ChatStateFilter();
 
       /**
-       * Use this function to set a chat state as defined in XEP-0085.
+       * Use this function to set a chat state as defined in @xep{0085}.
        * @note The Spec states that Chat States shall not be sent to an entity
        * which did not request them. Reasonable effort is taken in this function to
        * avoid spurious state sending. You should be safe to call this even if Message
@@ -65,7 +68,7 @@
 
       /**
        * The ChatStateHandler registered here will receive Chat States according
-       * to XEP-0085.
+       * to @xep{0085}.
        * @param csh The ChatStateHandler to register.
        */
       void registerChatStateHandler( ChatStateHandler* csh )

=== modified file 'src/chatstatehandler.h'
--- src/chatstatehandler.h	2010-01-17 13:05:04 +0000
+++ src/chatstatehandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -23,7 +23,7 @@
 
   /**
    * @brief A virtual interface that enables an object to be notified about
-   * a remote entity's Chat States (XEP-0085).
+   * a remote entity's Chat States (@xep{0085}).
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 0.8

=== modified file 'src/client.cpp'
--- src/client.cpp	2010-01-17 13:05:04 +0000
+++ src/client.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,8 +30,6 @@
 # include <unistd.h>
 #endif
 
-#include <cstdio>
-
 namespace gloox
 {
 
@@ -107,6 +105,7 @@
       m_rosterManager( 0 ), m_auth( 0 ),
       m_presence( Presence::Available, JID() ), m_resourceBound( false ),
       m_forceNonSasl( false ), m_manageRoster( true ),
+      m_smId( EmptyString ), m_smLocation( EmptyString ), m_smResume( false ), m_smMax( 0 ),
       m_streamFeatures( 0 )
   {
     m_jid.setServer( server );
@@ -118,6 +117,7 @@
       m_rosterManager( 0 ), m_auth( 0 ),
       m_presence( Presence::Available, JID() ), m_resourceBound( false ),
       m_forceNonSasl( false ), m_manageRoster( true ),
+      m_smId( EmptyString ), m_smLocation( EmptyString ), m_smResume( false ), m_smMax( 0 ),
       m_streamFeatures( 0 )
   {
     m_jid = jid;
@@ -176,7 +176,11 @@
       {
         if( m_authed )
         {
-          if( m_streamFeatures & StreamFeatureBind )
+          if( m_streamFeatures & StreamFeatureStreamManagement && m_smWanted && m_smContext >= CtxSMEnabled )
+          {
+            sendStreamManagement();
+          }
+          else if( m_streamFeatures & StreamFeatureBind && m_smContext < CtxSMEnabled )
           {
             notifyStreamEvent( StreamEventResourceBinding );
             bindResource( resource() );
@@ -290,11 +294,66 @@
       }
       else if( name == "success" && xmlns == XMLNS_STREAM_SASL )
       {
+        if( !processSASLSuccess( tag->cdata() ) )
+        {
+          logInstance().err( LogAreaClassClient, "The Server response could not be verified!" );
+          disconnect( ConnAuthenticationFailed );
+          return false;
+        }
+
         logInstance().dbg( LogAreaClassClient, "SASL authentication successful" );
-        processSASLSuccess();
         setAuthed( true );
         header();
       }
+      else if( name == "enabled" && xmlns == XMLNS_STREAM_MANAGEMENT )
+      {
+        m_smContext = CtxSMEnabled;
+        m_smMax = atoi( tag->findAttribute( "max" ).c_str() );
+        m_smId = tag->findAttribute( "id" );
+        const std::string res = tag->findAttribute( "resume" );
+        m_smResume = ( ( res == "true" || res == "1" ) && !m_smId.empty() ) ? true : false;
+        m_smLocation = tag->findAttribute( "location" );
+
+        if( m_streamFeatures & StreamFeatureSession )
+          createSession();
+        else
+          connected();
+      }
+      else if( name == "resumed" && xmlns == XMLNS_STREAM_MANAGEMENT && m_smContext == CtxSMResume )
+      {
+        if( tag->findAttribute( "previd" ) == m_smId )
+        {
+          m_smContext = CtxSMResumed;
+          notifyStreamEvent( StreamEventSMResumed );
+          int h = atoi( tag->findAttribute( "h" ).c_str() );
+          connected();
+          checkQueue( h, true );
+        }
+      }
+      else if( name == "a" && xmlns == XMLNS_STREAM_MANAGEMENT && m_smContext >= CtxSMEnabled )
+      {
+        int h = atoi( tag->findAttribute( "h" ).c_str() );
+        checkQueue( h, false );
+      }
+      else if( name == "r" && xmlns == XMLNS_STREAM_MANAGEMENT )
+      {
+        ackStreamManagement();
+      }
+      else if( name == "failed" && xmlns == XMLNS_STREAM_MANAGEMENT )
+      {
+        switch( m_smContext )
+        {
+          case CtxSMEnable:
+            notifyStreamEvent( StreamEventSMEnableFailed );
+            break;
+          case CtxSMResume:
+            notifyStreamEvent( StreamEventSMResumeFailed );
+            break;
+          default:
+            break;
+        }
+        m_smContext = CtxSMFailed;
+      }
       else
         return false;
     }
@@ -333,6 +392,9 @@
     if( tag->hasChild( "compression", XMLNS, XMLNS_STREAM_COMPRESS ) )
       features |= getCompressionMethods( tag->findChild( "compression" ) );
 
+    if( tag->hasChild( "sm", XMLNS, XMLNS_STREAM_MANAGEMENT ) )
+      features |= StreamFeatureStreamManagement;
+
     if( features == 0 )
       features = StreamFeatureIqAuth;
 
@@ -345,6 +407,12 @@
 
     const std::string mech = "mechanism";
 
+    if( tag->hasChildWithCData( mech, "SCRAM-SHA-1-PLUS" ) )
+      mechs |= SaslMechScramSha1Plus;
+
+    if( tag->hasChildWithCData( mech, "SCRAM-SHA-1" ) )
+      mechs |= SaslMechScramSha1;
+
     if( tag->hasChildWithCData( mech, "DIGEST-MD5" ) )
       mechs |= SaslMechDigestMd5;
 
@@ -383,10 +451,23 @@
   {
     bool retval = true;
 
-    if( m_streamFeatures & SaslMechDigestMd5 && m_availableSaslMechs & SaslMechDigestMd5
+    if( ( m_streamFeatures & SaslMechScramSha1Plus && m_availableSaslMechs & SaslMechScramSha1Plus
+          && m_encryption && m_encryptionActive && m_encryption->hasChannelBinding() )
         && !m_forceNonSasl )
     {
       notifyStreamEvent( StreamEventAuthentication );
+      startSASL( SaslMechScramSha1Plus );
+    }
+    else if( m_streamFeatures & SaslMechScramSha1 && m_availableSaslMechs & SaslMechScramSha1
+             && !m_forceNonSasl )
+    {
+      notifyStreamEvent( StreamEventAuthentication );
+      startSASL( SaslMechScramSha1 );
+    }
+    else if( m_streamFeatures & SaslMechDigestMd5 && m_availableSaslMechs & SaslMechDigestMd5
+             && !m_forceNonSasl )
+    {
+      notifyStreamEvent( StreamEventAuthentication );
       startSASL( SaslMechDigestMd5 );
     }
     else if( m_streamFeatures & SaslMechPlain && m_availableSaslMechs & SaslMechPlain
@@ -438,11 +519,12 @@
 
   bool Client::selectResource( const std::string& resource )
   {
+    m_selectedResource = resource; // TODO: remove for 1.1
+    m_jid.setResource( resource );
+
     if( !( m_streamFeatures & StreamFeatureUnbind ) )
       return false;
 
-    m_selectedResource = resource;
-
     return true;
   }
 
@@ -461,10 +543,12 @@
 
         m_jid = rb->jid();
         m_resourceBound = true;
-        m_selectedResource = m_jid.resource();
+        m_selectedResource = m_jid.resource(); // TODO: remove for 1.1
         notifyOnResourceBind( m_jid.resource() );
 
-        if( m_streamFeatures & StreamFeatureSession )
+        if( m_streamFeatures & StreamFeatureStreamManagement && m_smWanted )
+          sendStreamManagement();
+        else if( m_streamFeatures & StreamFeatureSession )
           createSession();
         else
           connected();
@@ -480,6 +564,71 @@
     }
   }
 
+  void Client::setStreamManagement( bool enable, bool resume )
+  {
+    m_smWanted = enable;
+    m_smResume = resume;
+
+    if( !m_smWanted )
+    {
+      m_smId = EmptyString;
+      m_smLocation = EmptyString;
+      m_smMax = 0;
+      m_smResume = false;
+      return;
+    }
+
+    if( m_smWanted && m_resourceBound )
+      sendStreamManagement();
+  }
+
+  void Client::sendStreamManagement()
+  {
+    if( !m_smWanted )
+      return;
+
+    if( m_smContext == CtxSMInvalid )
+    {
+      notifyStreamEvent( StreamEventSMEnable );
+      Tag* e = new Tag( "enable" );
+      e->setXmlns( XMLNS_STREAM_MANAGEMENT );
+      if( m_smResume )
+        e->addAttribute( "resume", "true" );
+      send( e );
+      m_smContext = CtxSMEnable;
+      m_smHandled = 0;
+    }
+    else if( m_smContext == CtxSMEnabled )
+    {
+      notifyStreamEvent( StreamEventSMResume );
+      Tag* r = new Tag( "resume" );
+      r->setXmlns( XMLNS_STREAM_MANAGEMENT );
+      r->addAttribute( "h", m_smHandled );
+      r->addAttribute( "previd", m_smId );
+      send( r );
+      m_smContext = CtxSMResume;
+    }
+  }
+
+  void Client::ackStreamManagement()
+  {
+    if( m_smContext >= CtxSMEnabled )
+    {
+      Tag* a = new Tag( "a", "xmlns", XMLNS_STREAM_MANAGEMENT );
+      a->addAttribute( "h", m_smHandled );
+      send( a );
+    }
+  }
+
+  void Client::reqStreamManagement()
+  {
+    if( m_smContext >= CtxSMEnabled )
+    {
+      Tag* r = new Tag( "r", "xmlns", XMLNS_STREAM_MANAGEMENT );
+      send( r );
+    }
+  }
+
   void Client::createSession()
   {
     notifyStreamEvent( StreamEventSessionCreation );
@@ -556,7 +705,7 @@
 
   void Client::connected()
   {
-    if( m_authed )
+    if( m_authed && m_smContext != CtxSMResumed )
     {
       if( m_manageRoster )
       {
@@ -582,6 +731,14 @@
 
   void Client::disconnect()
   {
+    m_smContext = CtxSMInvalid;
+    m_smHandled = 0;
+    m_smId = EmptyString;
+    m_smLocation = EmptyString;
+    m_smMax = 0;
+    m_smResume = false;
+    m_smWanted = false;
+
     disconnect( ConnUserDisconnected );
   }
 

=== modified file 'src/client.h'
--- src/client.h	2010-01-17 13:05:04 +0000
+++ src/client.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -28,7 +28,7 @@
   class IQ;
 
   /**
-   * @brief This class implements a basic Jabber Client.
+   * @brief This class implements a basic Jabber/XMPP Client.
    *
    * It supports @ref sasl_auth as well as TLS (Encryption), which can be
    * switched on/off separately. They are used automatically if the server supports them.
@@ -36,7 +36,7 @@
    * To use, create a new Client instance and feed it connection credentials, either in the Constructor or
    * afterwards using the setters. You should then register packet handlers implementing the corresponding
    * Interfaces (ConnectionListener, PresenceHandler, MessageHandler, IqHandler, SubscriptionHandler),
-   * and call @ref connect() to establish the connection to the server.<br>
+   * and call @ref connect() to establish the connection to the server.
    *
    * @note While the MessageHandler interface is still available (and will be in future versions)
    * it is now recommended to use the new @link gloox::MessageSession MessageSession @endlink for any
@@ -67,9 +67,9 @@
    * include:
    * @li jabber:iq:roster: by default the server-side roster is fetched and handled. Use
    * @ref rosterManager() and @ref RosterManager to interact with the Roster.
-   * @li XEP-0092 (Software Version): If no version is specified, a name of "based on gloox" with
+   * @li @xep{0092} (Software Version): If no version is specified, a name of "based on gloox" with
    * gloox's current version is announced.
-   * @li XEP-0030 (Service Discovery): All supported/available services are announced. No items are
+   * @li @xep{0030} (Service Discovery): All supported/available services are announced. No items are
    * returned.
    * @note As of gloox 0.9, by default a priority of 0 is sent along with the initial presence.
    * @note As of gloox 0.9, initial presence is automatically sent. Presence: available, Priority: 0.
@@ -78,7 +78,7 @@
    *
    * @section sasl_auth SASL Authentication
    *
-   * Besides the simple, IQ-based authentication (XEP-0078), gloox supports several SASL (Simple
+   * Besides the simple, IQ-based authentication (@xep{0078}), gloox supports several SASL (Simple
    * Authentication and Security Layer, RFC 2222) authentication mechanisms.
    * @li DIGEST-MD5: This mechanism is preferred over all other mechanisms if username and password are
    * provided to the Client instance. It is secure even without TLS encryption.
@@ -93,6 +93,24 @@
    *
    * Of course, all these mechanisms are not tried unless the server offers them.
    *
+   * @section stream_management Stream Management
+   *
+   * To enable Stream Management (@xep{0198}), call @ref setStreamManagement() with the first parameter set to @b true
+   * at any time. This will tell the server to enable Stream Management, if the feature is available. Once switched on,
+   * Stream Management can not be disabled for a given active stream. However, setting the first
+   * parameter to @b false, it can be disabled inside gloox so that Stream Management will not be used
+   * for subsequent connections.
+   *
+   * To enable the stream resumption feature, pass @b true as the second parameter to @ref setStreamManagement().
+   * Upon re-connect after an unexpected (i.e. neither user-triggered nor server-triggered) disconnect, gloox will try
+   * to resume the stream and re-send any non-acknowledged stanzas automatically.
+   * For stream resumption to work you have to re-connect using the very same Client instance.
+   *
+   * After an unexpected disconnect you may check the send queue using @link ClientBase::sendQueue() sendQueue() @endlink.
+   * Stanzas in the queue have been sent but not yet acknowledged by the server. Depending on the circumstances of the
+   * disconnect, this does not mean that those stanzas have not been received by the recipient.
+   * 
+   *
    * @author Jakob Schroeter <js@camaya.net>
    */
   class GLOOX_API Client : public ClientBase
@@ -149,7 +167,7 @@
        * Use this function to select a resource identifier that has been bound
        * previously by means of bindResource(). It is not necessary to call this function
        * if only one resource is bound. Use hasResourceBind() to find out if the
-       * server supports binding of multiple resources. selectResource() is a NOOP if it doesn't.
+       * server supports binding of multiple resources.
        * @param resource A resource string that has been bound previously.
        * @note If the resource string has not been bound previously, future sending of
        * stanzas will fail.
@@ -182,6 +200,39 @@
       const std::string& resource() const { return m_jid.resource(); }
 
       /**
+       * This function enables Stream Management (@xep{0198}) if the server supports it.
+       * Optionally, stream resumption can be disabled.
+       * @note You can use this function at any time. However, gloox will make sure Stream Management
+       * requests are sent only when allowed by the specification.
+       * @param enable Enable or disable Stream Management. Note: once enabled on a connection, Stream
+       * Management can not be disabled for that connection.
+       * @param resume Tells the server whether to enable stream resumption. Defaults to @b true.
+       * @note This function is part of @xep{0198}.
+       * @since 1.0.4
+       */
+      void setStreamManagement( bool enable = true, bool resume = true );
+
+      /**
+       * Use this function to send an unrequested 'ack' to the server to let it know the number of handled stanzas.
+       * You may use this function at any time. However, gloox will also reply to incoming 'ack requests' automatically.
+       * These automatic 'acks' are not announced anywhere in gloox.
+       * This function is a no-op if called in situations where sending an ack is not
+       * allowed by the protocol.
+       * @note This function is part of @xep{0198}.
+       * @since 1.0.4
+       */
+      void ackStreamManagement();
+
+      /**
+       * Use this function to request the number of handled stanzas from the server.
+       * You may use this function at any time. gloox does not send any such requests
+       * automatically.
+       * @note This function is part of @xep{0198}.
+       * @since 1.0.4
+       */
+      void reqStreamManagement();
+
+      /**
        * Returns the current priority.
        * @return The priority of the current resource.
        */
@@ -288,6 +339,9 @@
       void nonSaslLogin();
 
     private:
+#ifdef CLIENT_TEST
+    public:
+#endif
       /**
        * @brief This is an implementation of a resource binding StanzaExtension.
        *
@@ -396,7 +450,7 @@
 
       };
 
-      virtual void handleStartNode() {}
+      virtual void handleStartNode( const Tag* /*start*/ ) {}
       virtual bool handleNormalNode( Tag* tag );
       virtual void disconnect( ConnectionError reason );
       virtual void handleIqIDForward( const IQ& iq, int context );
@@ -413,6 +467,7 @@
       virtual void rosterFilled();
       virtual void cleanup();
       bool bindOperation( const std::string& resource, bool bind );
+      void sendStreamManagement();
 
       void init();
 
@@ -432,6 +487,12 @@
       bool m_forceNonSasl;
       bool m_manageRoster;
 
+      std::string m_smId;
+      std::string m_smLocation;
+      bool m_smResume;
+      bool m_smWanted;
+      int m_smMax;
+
       int m_streamFeatures;
 
   };

=== modified file 'src/clientbase.cpp'
--- src/clientbase.cpp	2010-01-17 13:05:04 +0000
+++ src/clientbase.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -14,38 +14,41 @@
 
 #include "config.h"
 
+#include "base64.h"
 #include "clientbase.h"
+#include "compressionbase.h"
+#include "compressionzlib.h"
 #include "connectionbase.h"
-#include "tlsbase.h"
-#include "compressionbase.h"
+#include "connectionlistener.h"
 #include "connectiontcpclient.h"
 #include "disco.h"
-#include "messagesessionhandler.h"
-#include "tag.h"
+#include "error.h"
+#include "eventhandler.h"
+#include "event.h"
 #include "iq.h"
+#include "iqhandler.h"
+#include "jid.h"
+#include "loghandler.h"
+#include "md5.h"
 #include "message.h"
-#include "subscription.h"
+#include "messagehandler.h"
+#include "messagesessionhandler.h"
+#include "mucinvitationhandler.h"
+#include "mucroom.h"
+#include "mutexguard.h"
 #include "presence.h"
-#include "connectionlistener.h"
-#include "iqhandler.h"
-#include "messagehandler.h"
 #include "presencehandler.h"
 #include "rosterlistener.h"
+#include "stanzaextensionfactory.h"
+#include "sha.h"
+#include "subscription.h"
 #include "subscriptionhandler.h"
-#include "loghandler.h"
+#include "tag.h"
 #include "taghandler.h"
-#include "mucinvitationhandler.h"
-#include "mucroom.h"
-#include "jid.h"
-#include "base64.h"
-#include "error.h"
-#include "md5.h"
+#include "tlsbase.h"
+#include "tlsdefault.h"
+#include "prep.h"
 #include "util.h"
-#include "tlsdefault.h"
-#include "compressionzlib.h"
-#include "stanzaextensionfactory.h"
-#include "eventhandler.h"
-#include "event.h"
 
 #include <cstdlib>
 #include <string>
@@ -60,6 +63,11 @@
 
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
 #include <tchar.h>
+# ifdef __MINGW32__
+#  ifndef SecureZeroMemory
+#  define SecureZeroMemory(p,s) RtlFillMemory((p),(s),0)
+#  endif
+# endif
 #endif
 
 namespace gloox
@@ -87,13 +95,15 @@
     : m_connection( 0 ), m_encryption( 0 ), m_compression( 0 ), m_disco( 0 ), m_namespace( ns ),
       m_xmllang( "en" ), m_server( server ), m_compressionActive( false ), m_encryptionActive( false ),
       m_compress( true ), m_authed( false ), m_block( false ), m_sasl( true ), m_tls( TLSOptional ), m_port( port ),
-      m_availableSaslMechs( SaslMechAll ),
+      m_availableSaslMechs( SaslMechAll ), m_smContext( CtxSMInvalid ), m_smHandled( 0 ),
       m_statisticsHandler( 0 ), m_mucInvitationHandler( 0 ),
       m_messageSessionHandlerChat( 0 ), m_messageSessionHandlerGroupchat( 0 ),
       m_messageSessionHandlerHeadline( 0 ), m_messageSessionHandlerNormal( 0 ),
       m_parser( this ), m_seFactory( 0 ), m_authError( AuthErrorUndefined ),
       m_streamError( StreamErrorUndefined ), m_streamErrorAppCondition( 0 ),
-      m_selectedSaslMech( SaslMechNone ), m_autoMessageSession( false )
+      m_selectedSaslMech( SaslMechNone ), m_customConnection( false ),
+      m_uniqueBaseId( (unsigned int)( ( (unsigned long long)time( 0 ) & 0xFFFF ) << 16 ) | ( ( (unsigned long long) & m_nextId ) & 0xFFFF ) ),
+      m_smSent( 0 )
   {
     init();
   }
@@ -104,19 +114,23 @@
       m_password( password ),
       m_xmllang( "en" ), m_server( server ), m_compressionActive( false ), m_encryptionActive( false ),
       m_compress( true ), m_authed( false ), m_block( false ), m_sasl( true ), m_tls( TLSOptional ),
-      m_port( port ), m_availableSaslMechs( SaslMechAll ),
+      m_port( port ), m_availableSaslMechs( SaslMechAll ), m_smContext( CtxSMInvalid ), m_smHandled( 0 ),
       m_statisticsHandler( 0 ), m_mucInvitationHandler( 0 ),
       m_messageSessionHandlerChat( 0 ), m_messageSessionHandlerGroupchat( 0 ),
       m_messageSessionHandlerHeadline( 0 ), m_messageSessionHandlerNormal( 0 ),
       m_parser( this ), m_seFactory( 0 ), m_authError( AuthErrorUndefined ),
       m_streamError( StreamErrorUndefined ), m_streamErrorAppCondition( 0 ),
-      m_selectedSaslMech( SaslMechNone ), m_autoMessageSession( false )
+      m_selectedSaslMech( SaslMechNone ), m_customConnection( false ),
+      m_uniqueBaseId( (unsigned int)( ( (unsigned long long)time( 0 ) & 0xFFFF ) << 16 ) | ( ( (unsigned long long) & m_nextId ) & 0xFFFF ) ),
+      m_smSent( 0 )
   {
     init();
   }
 
   void ClientBase::init()
   {
+    srand( time( 0 ) );
+
     if( !m_disco )
     {
       m_disco = new Disco( this );
@@ -136,9 +150,20 @@
 
   ClientBase::~ClientBase()
   {
-    delete m_connection;
-    delete m_encryption;
-    delete m_compression;
+    m_iqHandlerMapMutex.lock();
+    m_iqIDHandlers.clear();
+    m_iqHandlerMapMutex.unlock();
+
+    m_iqExtHandlerMapMutex.lock();
+    m_iqExtHandlers.clear();
+    m_iqExtHandlerMapMutex.unlock();
+
+    util::clearList( m_presenceExtensions );
+    util::clearMap( m_smQueue );
+
+    setConnectionImpl( 0 );
+    setEncryptionImpl( 0 );
+    setCompressionImpl( 0 );
     delete m_seFactory;
     m_seFactory = 0; // to avoid usage when Disco gets deleted below
     delete m_disco;
@@ -177,7 +202,7 @@
       m_compression = getDefaultCompression();
 
     m_logInstance.dbg( LogAreaClassClientbase, "This is gloox " + GLOOX_VERSION + ", connecting to "
-                                               + m_server + ":" + util::int2string( m_port ) + "..." );
+                                               + m_server + ( ( m_customConnection )?( " using a custom connection" ):( m_port > 0 ? ( ":" + util::int2string( m_port ) ) : EmptyString ) ) + "..." );
     m_block = block;
     ConnectionError ret = m_connection->connect();
     if( ret != ConnNoError )
@@ -213,7 +238,7 @@
       }
 
       m_sid = tag->findAttribute( "id" );
-      handleStartNode();
+      handleStartNode( tag );
     }
     else if( tag->name() == "error" && tag->xmlns() == XMLNS_STREAM )
     {
@@ -230,15 +255,23 @@
           {
             IQ iq( tag );
             m_seFactory->addExtensions( iq, tag );
+            if( iq.hasEmbeddedStanza() )
+              m_seFactory->addExtensions( *iq.embeddedStanza(), iq.embeddedTag() );
             notifyIqHandlers( iq );
             ++m_stats.iqStanzasReceived;
+            if( m_smContext >= CtxSMEnabled )
+              ++m_smHandled;
           }
           else if( tag->name() == "message" )
           {
             Message msg( tag );
             m_seFactory->addExtensions( msg, tag );
+            if( msg.hasEmbeddedStanza() )
+              m_seFactory->addExtensions( *msg.embeddedStanza(), msg.embeddedTag() );
             notifyMessageHandlers( msg );
             ++m_stats.messageStanzasReceived;
+            if( m_smContext >= CtxSMEnabled )
+              ++m_smHandled;
           }
           else if( tag->name() == "presence" )
           {
@@ -248,6 +281,8 @@
             {
               Subscription sub( tag );
               m_seFactory->addExtensions( sub, tag );
+              if( sub.hasEmbeddedStanza() )
+                m_seFactory->addExtensions( *sub.embeddedStanza(), sub.embeddedTag() );
               notifySubscriptionHandlers( sub );
               ++m_stats.s10nStanzasReceived;
             }
@@ -255,12 +290,16 @@
             {
               Presence pres( tag );
               m_seFactory->addExtensions( pres, tag );
+              if( pres.hasEmbeddedStanza() )
+                m_seFactory->addExtensions( *pres.embeddedStanza(), pres.embeddedTag() );
               notifyPresenceHandlers( pres );
               ++m_stats.presenceStanzasReceived;
             }
+            if( m_smContext >= CtxSMEnabled )
+              ++m_smHandled;
           }
           else
-            m_logInstance.err( LogAreaClassClientbase, "Received invalid stanza." );
+            m_logInstance.err( LogAreaClassClientbase, "Invalid stanza received: " + tag->name() );
         }
         else
         {
@@ -377,8 +416,13 @@
 
     m_encryptionActive = false;
     m_compressionActive = false;
+    m_smSent = 0;
 
     notifyOnDisconnect( reason );
+
+#ifdef CLIENTBASE_TEST
+    m_nextId.reset();
+#endif
   }
 
   void ClientBase::parse( const std::string& data )
@@ -442,6 +486,40 @@
 
     switch( type )
     {
+      case SaslMechScramSha1Plus:
+      case SaslMechScramSha1:
+      {
+        if( type == SaslMechScramSha1 )
+        {
+          if( ( m_availableSaslMechs & SaslMechScramSha1Plus ) != SaslMechScramSha1Plus )
+            m_gs2Header = "y,";
+          else
+            m_gs2Header = "n,";
+          a->addAttribute( "mechanism", "SCRAM-SHA-1" );
+        }
+        else // SaslMechScramSha1Plus
+        {
+          m_gs2Header = "p=tls-unique,";
+          a->addAttribute( "mechanism", "SCRAM-SHA-1-PLUS" );
+        }
+
+        std::string t;
+        if( m_authzid && prep::saslprep( m_authzid.bare(), t ) )
+          m_gs2Header += "a=" + t;
+
+        m_gs2Header += ",";
+
+        m_clientFirstMessageBare = "n=";
+        if( !m_authcid.empty() && prep::saslprep( m_authcid, t ) )
+          m_clientFirstMessageBare += t;
+        else if( prep::saslprep( m_jid.username(), t ) )
+          m_clientFirstMessageBare += t;
+
+        m_clientFirstMessageBare += ",r=" + getRandom();
+
+        a->setCData( Base64::encode64( m_gs2Header + m_clientFirstMessageBare ) );
+        break;
+      }
       case SaslMechDigestMd5:
         a->addAttribute( "mechanism", "DIGEST-MD5" );
         break;
@@ -495,20 +573,70 @@
       {
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
         a->addAttribute( "mechanism", "NTLM" );
-        SEC_WINNT_AUTH_IDENTITY identity, *ident = 0;
+        SEC_WINNT_AUTH_IDENTITY_W identity, *ident = 0;
         memset( &identity, 0, sizeof( identity ) );
+
+        WCHAR *usernameW = 0, *domainW = 0, *passwordW = 0;
+        int cchUsernameW = 0, cchDomainW = 0, cchPasswordW = 0;
+
         if( m_jid.username().length() > 0 )
         {
-          identity.User = (unsigned char*)m_jid.username().c_str();
-          identity.UserLength = (unsigned long)m_jid.username().length();
-          identity.Domain = (unsigned char*)m_ntlmDomain.c_str();
-          identity.DomainLength = (unsigned long)m_ntlmDomain.length();
-          identity.Password = (unsigned char*)m_password.c_str();
-          identity.PasswordLength = (unsigned long)m_password.length();
+          // NOTE: The return values of MultiByteToWideChar will include room
+          //  for the NUL character since we use -1 for the input length.
+
+          cchUsernameW = ::MultiByteToWideChar( CP_UTF8, 0, m_jid.username().c_str(), -1, 0, 0 );
+          if( cchUsernameW > 0 )
+          {
+            usernameW = new WCHAR[cchUsernameW];
+            ::MultiByteToWideChar( CP_UTF8, 0, m_jid.username().c_str(), -1, usernameW, cchUsernameW );
+            // Guarantee its NUL terminated.
+            usernameW[cchUsernameW-1] = L'\0';
+          }
+          cchDomainW = ::MultiByteToWideChar( CP_UTF8, 0, m_ntlmDomain.c_str(), -1, 0, 0 );
+          if( cchDomainW > 0 )
+          {
+            domainW = new WCHAR[cchDomainW];
+            ::MultiByteToWideChar( CP_UTF8, 0, m_ntlmDomain.c_str(), -1, domainW, cchDomainW );
+            // Guarantee its NUL terminated.
+            domainW[cchDomainW-1] = L'\0';
+          }
+          cchPasswordW = ::MultiByteToWideChar( CP_UTF8, 0, m_password.c_str(), -1, 0, 0 );
+          if( cchPasswordW > 0 )
+          {
+            passwordW = new WCHAR[cchPasswordW];
+            ::MultiByteToWideChar( CP_UTF8, 0, m_password.c_str(), -1, passwordW, cchPasswordW );
+            // Guarantee its NUL terminated.
+            passwordW[cchPasswordW-1] = L'\0';
+          }
+          identity.User = (unsigned short*)usernameW;
+          identity.UserLength = (unsigned long)cchUsernameW-1;
+          identity.Domain = (unsigned short*)domainW;
+          identity.DomainLength = (unsigned long)cchDomainW-1;
+          identity.Password = (unsigned short*)passwordW;
+          identity.PasswordLength = (unsigned long)cchPasswordW-1;
           identity.Flags = SEC_WINNT_AUTH_IDENTITY_UNICODE;
           ident = &identity;
         }
-        AcquireCredentialsHandle( 0, _T( "NTLM" ), SECPKG_CRED_OUTBOUND, 0, ident, 0, 0, &m_credHandle, 0 );
+
+        AcquireCredentialsHandleW( 0, L"NTLM", SECPKG_CRED_OUTBOUND, 0, ident, 0, 0, &m_credHandle, 0 );
+
+        if( usernameW != 0 )
+        {
+          delete[] usernameW;
+          usernameW = 0;
+        }
+        if( domainW != 0 )
+        {
+          delete[] domainW;
+          domainW = 0;
+        }
+        if( passwordW != 0 )
+        {
+          ::SecureZeroMemory( passwordW, cchPasswordW* sizeof( WCHAR ) );
+          delete[] passwordW;
+          passwordW = 0;
+        }
+
 #else
         logInstance().err( LogAreaClassClientbase,
                     "SASL NTLM is not supported on this platform. You should never see this." );
@@ -522,6 +650,52 @@
     send( a );
   }
 
+  std::string ClientBase::hmac( const std::string& key, const std::string& str )
+  {
+    SHA sha;
+    std::string key_ = key;
+    if( key_.length() > 64 )
+    {
+      sha.feed( key_ );
+      key_ = sha.binary();
+      sha.reset();
+    }
+    unsigned char ipad[65];
+    unsigned char opad[65];
+    memset( ipad, '\0', sizeof( ipad ) );
+    memset( opad, '\0', sizeof( opad ) );
+    memcpy( ipad, key_.c_str(), key_.length() );
+    memcpy( opad, key_.c_str(), key_.length() );
+    for( int i = 0; i < 64; i++ )
+    {
+      ipad[i] ^= 0x36;
+      opad[i] ^= 0x5c;
+    }
+    sha.feed( ipad, 64 );
+    sha.feed( str );
+    key_ = sha.binary();
+    sha.reset();
+    sha.feed( opad, 64 );
+    sha.feed( key_ );
+
+    return sha.binary(); // hex() for testing
+  }
+
+  std::string ClientBase::hi( const std::string& str, const std::string& salt, int iter )
+  {
+    unsigned char xored[20];
+    memset( xored, '\0', sizeof( xored ) );
+    std::string tmp = salt;
+    tmp.append( "\0\0\0\1", 4 );
+    for( int i = 0; i < iter; ++i )
+    {
+      tmp = hmac( str, tmp );
+      for( int j = 0; j < 20; ++j )
+        xored[j] ^= tmp.c_str()[j];
+    }
+    return std::string( (char*)xored, 20 );
+  }
+
   void ClientBase::processSASLChallenge( const std::string& challenge )
   {
     Tag* t = new Tag( "response", XMLNS, XMLNS_STREAM_SASL );
@@ -530,6 +704,53 @@
 
     switch( m_selectedSaslMech )
     {
+      case SaslMechScramSha1Plus:
+      case SaslMechScramSha1:
+      {
+        std::string snonce, salt, tmp;
+        int iter = 0;
+        std::string::size_type posn = decoded.find( "r=" );
+        std::string::size_type poss = decoded.find( "s=" );
+        std::string::size_type posi = decoded.find( "i=" );
+        if( posn == std::string::npos || poss == std::string::npos || posi == std::string::npos )
+          break;
+
+        snonce = decoded.substr( posn + 2, poss - posn - 3 );
+        salt = Base64::decode64( decoded.substr( poss + 2, posi - poss - 3 ) );
+        tmp = decoded.substr( posi + 2, decoded.length() - posi - 2 );
+        iter = atoi( tmp.c_str() );
+
+        if( !prep::saslprep( m_password, tmp ) )
+          break;
+
+        std::string saltedPwd = hi( tmp, salt, iter );
+        std::string ck = hmac( saltedPwd, "Client Key" );
+        SHA sha;
+        sha.feed( ck );
+        std::string storedKey = sha.binary();
+
+        if( m_selectedSaslMech == SaslMechScramSha1Plus )
+          tmp = "c=" + Base64::encode64( m_gs2Header + m_encryption->channelBinding() );
+        else
+          tmp = "c=biws";
+        tmp += ",r=" + snonce;
+
+        std::string authMessage = m_clientFirstMessageBare + "," + decoded + "," + tmp; // client-final-message-without-proof
+        std::string clientSignature = hmac( storedKey, authMessage );
+        unsigned char clientProof[20]; // ck XOR clientSignature
+        memcpy( clientProof, ck.c_str(), 20 );
+        for( int i = 0; i < 20; ++i )
+          clientProof[i] ^= clientSignature.c_str()[i];
+        std::string serverKey = hmac( saltedPwd, "Server Key" );
+        m_serverSignature = hmac( serverKey, authMessage );
+
+        tmp += ",p=";
+        tmp.append( Base64::encode64( std::string( (char*)clientProof, 20 ) ) );
+
+        t->setCData( Base64::encode64( tmp ) );
+
+        break;
+      }
       case SaslMechDigestMd5:
       {
         if( !decoded.compare( 0, 7, "rspauth" ) )
@@ -555,11 +776,7 @@
           end = decoded.find( '"', end + 1 );
         std::string nonce = decoded.substr( pos + 7, end - ( pos + 7 ) );
 
-        std::string cnonce;
-        char cn[4*8+1];
-        for( int i = 0; i < 4; ++i )
-          sprintf( cn + i*8, "%08x", rand() );
-        cnonce.assign( cn, 4*8 );
+        std::string cnonce = getRandom();
 
         MD5 md5;
         md5.feed( m_jid.username() );
@@ -699,7 +916,7 @@
 #endif
   }
 
-  void ClientBase::processSASLSuccess()
+  bool ClientBase::processSASLSuccess( const std::string& payload )
   {
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
     if( m_selectedSaslMech == SaslMechNTLM )
@@ -708,6 +925,14 @@
       DeleteSecurityContext( &m_ctxtHandle );
     }
 #endif
+    if( m_selectedSaslMech == SaslMechScramSha1 || m_selectedSaslMech == SaslMechScramSha1Plus )
+    {
+      const std::string decoded = Base64::decode64( payload );
+      if( decoded.length() < 3 || Base64::decode64( decoded.substr( 2 ) ) != m_serverSignature  )
+        return false;
+    }
+
+    return true;
   }
 
   void ClientBase::send( IQ& iq, IqHandler* ih, int context, bool del )
@@ -735,7 +960,7 @@
     Tag* tag = iq.tag();
     addFrom( tag );
     addNamespace( tag );
-    send( tag );
+    send( tag, true, false );
   }
 
   void ClientBase::send( const Message& msg )
@@ -744,7 +969,7 @@
     Tag* tag = msg.tag();
     addFrom( tag );
     addNamespace( tag );
-    send( tag );
+    send( tag, true, false );
   }
 
   void ClientBase::send( const Subscription& sub )
@@ -753,10 +978,10 @@
     Tag* tag = sub.tag();
     addFrom( tag );
     addNamespace( tag );
-    send( tag );
+    send( tag, true, false );
   }
 
-  void ClientBase::send( Presence& pres )
+  void ClientBase::send( const Presence& pres )
   {
     ++m_stats.presenceStanzasSent;
     Tag* tag = pres.tag();
@@ -765,7 +990,7 @@
       tag->addChild( (*it)->tag() );
     addFrom( tag );
     addNamespace( tag );
-    send( tag );
+    send( tag, true, false );
   }
 
   void ClientBase::send( Tag* tag )
@@ -773,6 +998,14 @@
     if( !tag )
       return;
 
+    send( tag, false, true );
+  }
+
+  void ClientBase::send( Tag* tag, bool queue, bool del )
+  {
+    if( !tag )
+    return;
+
     send( tag->xml() );
 
     ++m_stats.totalStanzasSent;
@@ -780,7 +1013,14 @@
     if( m_statisticsHandler )
       m_statisticsHandler->handleStatistics( getStatistics() );
 
-    delete tag;
+    if( queue && m_smContext >= CtxSMEnabled )
+    {
+      m_queueMutex.lock();
+      m_smQueue.insert( std::make_pair( ++m_smSent, tag ) );
+      m_queueMutex.unlock();
+    }
+    else if( del )
+      delete tag;
   }
 
   void ClientBase::send( const std::string& xml )
@@ -798,15 +1038,49 @@
     }
   }
 
+  void ClientBase::checkQueue( int handled, bool resend )
+  {
+    if( m_smContext < CtxSMEnabled || handled < 0 )
+      return;
+
+    util::MutexGuard mg( m_queueMutex );
+    SMQueueMap::iterator it = m_smQueue.begin();
+    while( it != m_smQueue.end() )
+    {
+      if( (*it).first <= handled )
+      {
+        delete (*it).second;
+        m_smQueue.erase( it++ );
+      }
+      else if( resend && (*it).first > handled )
+      {
+        send( (*it).second, false, false );
+        ++it;
+      }
+      else
+      {
+        ++it;
+      }
+    }
+  }
+
+  const TagList ClientBase::sendQueue()
+  {
+    TagList l;
+    util::MutexGuard mg( m_queueMutex );
+    SMQueueMap::iterator it = m_smQueue.begin();
+    for( ; it != m_smQueue.end(); ++it )
+      l.push_back( (*it).second->clone() );
+
+    return l;
+  }
+
   void ClientBase::addFrom( Tag* tag )
   {
     if( !m_authed /*for IQ Auth */ || !tag || tag->hasAttribute( "from" ) )
       return;
 
-    if ( m_selectedResource.empty() )
-      tag->addAttribute( "from", m_jid.bare() );
-    else
-      tag->addAttribute( "from", m_jid.bare() + '/' + m_selectedResource );
+    tag->addAttribute( "from", m_jid.full() );
   }
 
   void ClientBase::addNamespace( Tag* tag )
@@ -885,11 +1159,14 @@
 
   const std::string ClientBase::getID()
   {
-    static unsigned int uniqueBaseID = (unsigned int)time( 0 );
+#ifdef CLIENTBASE_TEST // to create predictable UIDs in test mode
+    return "uid" + util::int2string( m_nextId.increment() );
+#else
     char r[21+1];
-    sprintf( r, "uid:%08x:%08x", uniqueBaseID, rand() );
+    sprintf( r, "uid-%08x-%08x", m_uniqueBaseId, m_nextId.increment() );
     std::string ret( r, 21 );
     return ret;
+#endif
   }
 
   bool ClientBase::checkStreamVersion( const std::string& version )
@@ -898,44 +1175,42 @@
       return false;
 
     int major = 0;
-    int minor = 0;
+//     int minor = 0;
     int myMajor = atoi( XMPP_STREAM_VERSION_MAJOR.c_str() );
 
     size_t dot = version.find( '.' );
     if( !version.empty() && dot && dot != std::string::npos )
     {
       major = atoi( version.substr( 0, dot ).c_str() );
-      minor = atoi( version.substr( dot ).c_str() );
+//       minor = atoi( version.substr( dot ).c_str() );
     }
 
     return myMajor >= major;
   }
 
-  void ClientBase::setConnectionImpl( ConnectionBase* cb )
-  {
-    if( m_connection )
-    {
-      delete m_connection;
-    }
-    m_connection = cb;
-  }
-
-  void ClientBase::setEncryptionImpl( TLSBase* tb )
-  {
-    if( m_encryption )
-    {
-      delete m_encryption;
-    }
-    m_encryption = tb;
-  }
-
-  void ClientBase::setCompressionImpl( CompressionBase* cb )
-  {
-    if( m_compression )
-    {
-      delete m_compression;
-    }
-    m_compression = cb;
+  void ClientBase::setConnectionImpl( ConnectionBase* connection )
+  {
+    ConnectionBase* old = m_connection;
+    m_connection = connection;
+    m_customConnection = true;
+    if( old )
+      delete old;
+  }
+
+  void ClientBase::setEncryptionImpl( TLSBase* encryption )
+  {
+    TLSBase* old = m_encryption;
+    m_encryption = encryption;
+    if( old )
+      delete old;
+  }
+
+  void ClientBase::setCompressionImpl( CompressionBase* compression )
+  {
+    CompressionBase* old = m_compression;
+    m_compression = compression;
+    if( old )
+      delete old;
   }
 
   void ClientBase::handleStreamError( Tag* tag )
@@ -1093,11 +1368,14 @@
     if( !ih )
       return;
 
+    util::MutexGuard m( m_iqExtHandlerMapMutex );
     typedef IqHandlerMap::const_iterator IQci;
     std::pair<IQci, IQci> g = m_iqExtHandlers.equal_range( exttype );
     for( IQci it = g.first; it != g.second; ++it )
+    {
       if( (*it).second == ih )
         return;
+    }
 
     m_iqExtHandlers.insert( std::make_pair( exttype, ih ) );
   }
@@ -1107,6 +1385,7 @@
     if( !ih )
       return;
 
+    util::MutexGuard m( m_iqExtHandlerMapMutex );
     typedef IqHandlerMap::iterator IQi;
     std::pair<IQi, IQi> g = m_iqExtHandlers.equal_range( exttype );
     IQi it2;
@@ -1180,11 +1459,21 @@
   {
     if( th )
     {
-      TagHandlerList::iterator it = m_tagHandlers.begin();
-      for( ; it != m_tagHandlers.end(); ++it )
+      for( TagHandlerList::iterator it = m_tagHandlers.begin(); it != m_tagHandlers.end(); )
       {
         if( (*it).th == th && (*it).tag == tag && (*it).xmlns == xmlns )
-          m_tagHandlers.erase( it );
+        {
+          // Normally we'd just assign it to the return value of the .erase() call,
+          // which is either the next element, or .end().  However,
+          // it's only since C++11 that this works; C++03 version returns void.
+          // So instead, we do a post-increment. this increments the iterator to point
+          // to the next element, then passes a copy of the old iterator (that is to the item to be deleted)
+          m_tagHandlers.erase( it++ );
+        }
+        else
+        {
+          ++it;
+        }
       }
     }
   }
@@ -1309,8 +1598,9 @@
   {
     m_iqHandlerMapMutex.lock();
     IqTrackMap::iterator it_id = m_iqIDHandlers.find( iq.id() );
+    bool haveIdHandler = ( it_id != m_iqIDHandlers.end() );
     m_iqHandlerMapMutex.unlock();
-    if( it_id != m_iqIDHandlers.end() && iq.subtype() & ( IQ::Result | IQ::Error ) )
+    if( haveIdHandler && ( iq.subtype() == IQ::Result || iq.subtype() == IQ::Error ) )
     {
       (*it_id).second.ih->handleIqID( iq, (*it_id).second.context );
       if( (*it_id).second.del )
@@ -1322,9 +1612,17 @@
     }
 
     if( iq.extensions().empty() )
+    {
+      if ( iq.subtype() == IQ::Get || iq.subtype() == IQ::Set )
+      {
+        IQ re( IQ::Error, iq.from(), iq.id() );
+        re.addExtension( new Error( StanzaErrorTypeCancel, StanzaErrorFeatureNotImplemented ) );
+        send( re );
+      }
       return;
+    }
 
-    bool res = false;
+    bool handled = false;
 
     // FIXME remove for 1.1
 //     typedef IqHandlerMapXmlns::const_iterator IQciXmlns
@@ -1337,20 +1635,22 @@
 //     }
 //     delete tag;
 
+    m_iqExtHandlerMapMutex.lock();
     typedef IqHandlerMap::const_iterator IQci;
     const StanzaExtensionList& sel = iq.extensions();
     StanzaExtensionList::const_iterator itse = sel.begin();
-    for( ; itse != sel.end(); ++itse )
+    for( ; !handled && itse != sel.end(); ++itse )
     {
       std::pair<IQci, IQci> g = m_iqExtHandlers.equal_range( (*itse)->extensionType() );
-      for( IQci it = g.first; it != g.second; ++it )
+      for( IQci it = g.first; !handled && it != g.second; ++it )
       {
         if( (*it).second->handleIq( iq ) )
-          res = true;
+          handled = true;
       }
     }
+    m_iqExtHandlerMapMutex.unlock();
 
-    if( !res && iq.subtype() & ( IQ::Get | IQ::Set ) )
+    if( !handled && ( iq.subtype() == IQ::Get || iq.subtype() == IQ::Set ) )
     {
       IQ re( IQ::Error, iq.from(), iq.id() );
       re.addExtension( new Error( StanzaErrorTypeCancel, StanzaErrorServiceUnavailable ) );
@@ -1429,8 +1729,6 @@
 
     if( msHandler )
     {
-      if( msg.subtype() == Message::Chat && msg.body().empty() )
-        return; // don't want a new MS for empty messages
       MessageSession* session = new MessageSession( this, msg.from(), true, msg.subtype() );
       msHandler->handleMessageSession( session );
       session->handleMessage( msg );
@@ -1483,6 +1781,14 @@
     return false;
   }
 
+  std::string ClientBase::getRandom()
+  {
+    char cn[4*8+1];
+    for( int i = 0; i < 4; ++i )
+      sprintf( cn + i*8, "%08x", rand() );
+    return std::string( cn, 4*8 );;
+  }
+
   CompressionBase* ClientBase::getDefaultCompression()
   {
     if( !m_compress )

=== modified file 'src/clientbase.h'
--- src/clientbase.h	2010-01-17 13:05:04 +0000
+++ src/clientbase.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -28,6 +28,7 @@
 #include "compressiondatahandler.h"
 #include "connectiondatahandler.h"
 #include "parser.h"
+#include "atomicrefcount.h"
 
 #include <string>
 #include <list>
@@ -128,7 +129,7 @@
        * until data was available.
        * @return The state of the connection.
        */
-      ConnectionError recv( int timeout = -1 );
+      virtual ConnectionError recv( int timeout = -1 );
 
       /**
        * Reimplement this function to provide a username for connection purposes.
@@ -147,7 +148,7 @@
 
       /**
        * Switches usage of SASL on/off. Default: on. SASL should only be disabled if there are
-       * problems with using it.
+       * problems with using it, and if an alternative authentication method exists.
        * @param sasl Whether to switch SASL usage on or off.
        */
       void setSasl( bool sasl ) { m_sasl = sasl; }
@@ -280,7 +281,7 @@
        * A convenience function that sends the given Presence stanza.
        * @param pres The Presence stanza to send.
        */
-      void send( Presence& pres );
+      void send( const Presence& pres );
 
       /**
        * Returns whether authentication has taken place and was successful.
@@ -363,7 +364,7 @@
       void whitespacePing();
 
       /**
-       * Sends a XMPP Ping (XEP-0199) to the given JID.
+       * Sends a XMPP Ping (@xep{0199}) to the given JID.
        * @param to Then entity to ping.
        * @param eh An EventHandler to inform about the reply.
        * @since 0.9
@@ -433,7 +434,7 @@
 
       /**
        * Removes the given IqHandler from the list of handlers of pending operations, added
-       * using trackID(). Necessary, for example, when closing a GUI element that has an
+       * using send( IQ&, IqHandler*, int, bool ). Necessary, for example, when closing a GUI element that has an
        * operation pending.
        * @param ih The IqHandler to remove.
        * @since 0.8.7
@@ -678,6 +679,15 @@
        */
       const StanzaExtensionList& presenceExtensions() const { return m_presenceExtensions; }
 
+      /**
+       * Returns a list of Tags that are currently in the send queue.
+       * You should not rely on the currentness of this data when there is an established connection.
+       * @return A 'decoupled' list of Tags (deep copies) in the send queue. The caller is responsible
+       * for deleting the tags.
+       * @since 1.0.6
+       */
+      const TagList sendQueue();
+
       // reimplemented from ParserHandler
       virtual void handleTag( Tag* tag );
 
@@ -706,6 +716,9 @@
       virtual void handleHandshakeResult( const TLSBase* base, bool success, CertInfo &certinfo );
 
     protected:
+#ifdef CLIENTBASE_TEST
+    public:
+#endif
       /**
        * This function is called when resource binding yieled an error.
        * @param error A pointer to an Error object that contains more
@@ -786,9 +799,13 @@
       void startSASL( SaslMechanism type );
 
       /**
-       * Releases SASL related resources.
+       * Verifies the server response after successful authentication (if applicable) and
+       * releases SASL related resources (if applicable).
+       * @param payload The server's verification string.
+       * @return @b True if verification is not supported by the chosen SASL mechanism or could be completed successfully,
+       * @b false if verification failed.
        */
-      void processSASLSuccess();
+      bool processSASLSuccess( const std::string& payload );
 
       /**
        * Processes the given SASL challenge and sends a response.
@@ -819,6 +836,35 @@
        */
       bool hasTls();
 
+      /**
+       * Sends the given data unchecked over the underlying transport connection. Use at your own risk.
+       * The server will check any data received anyway and disconnect if something is wrong.
+       * @param xml The data to send.
+       */
+      void send( const std::string& xml );
+
+      /**
+       * This function checks if there are any unacknowledged Tags in the send queue and resends
+       * as necessary.
+       * @param handled The sequence number of the last handled stanza.
+       * @param resend Whether to resend unhandled stanzas.
+       * @note This function is part of @xep{0198}. You should not need to use it directly.
+       * @since 1.0.4
+       */
+      void checkQueue( int handled, bool resend );
+
+      /**
+       * Returns the number of sent stanzas, if Stream Management is enabled.
+       * @return The number of sent stanzas.
+       */
+      int stanzasSent() const { return m_smSent; }
+
+      /**
+       * Returns 32 octets of random characters.
+       * @return Random characters.
+       */
+      std::string getRandom();
+
       JID m_jid;                         /**< The 'self' JID. */
       JID m_authzid;                     /**< An optional authorization ID. See setAuthzid(). */
       std::string m_authcid;             /**< An alternative authentication ID. See setAuthcid(). */
@@ -830,8 +876,10 @@
       /** A list of permanent presence extensions. */
       StanzaExtensionList m_presenceExtensions;
 
-      std::string m_selectedResource;    /**< The currently selected resource.
-                                          * See Client::selectResource() and Client::binRessource(). */
+      GLOOX_DEPRECATED std::string m_selectedResource; /**< The currently selected resource.
+                                          * See Client::selectResource() and Client::bindRessource().
+                                          * @deprecated Not used anymore. Will be removed for 1.1.
+                                          * @todo Remove for 1.1 */
       std::string m_clientCerts;         /**< TLS client certificates. */
       std::string m_clientKey;           /**< TLS client private key. */
       std::string m_namespace;           /**< Default namespace. */
@@ -855,12 +903,29 @@
 
       int m_availableSaslMechs;          /**< The SASL mechanisms the server offered. */
 
+      /**
+       * An enum for the Stream Management state machine.
+       */
+      enum SMContext
+      {
+        CtxSMInvalid,                    /**< Initial value. */
+        CtxSMFailed,                      /**< Either of the above failed. */
+        CtxSMEnable,                     /**< 'enable' request sent */
+        CtxSMResume,                     /**< 'resume' request sent */
+        CtxSMEnabled,                    /**< Stream Management successfully enabled. */
+        CtxSMResumed                     /**< Stream successfully resumed. */
+      };
+
+      SMContext m_smContext;             /**< The Stream Management state. Used in @xep{0198}. */
+      int m_smHandled;                   /**< The number of handled stanzas. Used in @xep{0198}.
+                                          * You should NOT mess with this. */
+
     private:
 #ifdef CLIENTBASE_TEST
     public:
 #endif
       /**
-       * @brief This is an implementation of an XMPP Ping (XEP-199).
+       * @brief This is an implementation of an XMPP Ping (@xep{0199}).
        *
        * @author Jakob Schroeter <js@camaya.net>
        * @since 1.0
@@ -908,18 +973,24 @@
 
       /**
        * This function is called right after the opening &lt;stream:stream&gt; was received.
+       * @param start The complete stream opening tag. Note that the XML representation (Tag::xml())
+       * will contain a closed stream tag. The original is open.
        */
-      virtual void handleStartNode() = 0;
+      virtual void handleStartNode( const Tag* start ) = 0;
 
       /**
        * This function is called for each Tag. Only stream initiation/negotiation should
        * be done here.
        * @param tag A Tag to handle.
+       * @return Returns @b true if the tag has been handled inside the function, @b false otherwise.
        */
       virtual bool handleNormalNode( Tag* tag ) = 0;
       virtual void rosterFilled() = 0;
       virtual void cleanup() {}
       virtual void handleIqIDForward( const IQ& iq, int context ) { (void) iq; (void) context; }
+      void send( Tag* tag, bool queue, bool del );
+      std::string hmac( const std::string& str, const std::string& key );
+      std::string hi( const std::string& str, const std::string& key, int iter );
 
       void parse( const std::string& data );
       void init();
@@ -933,7 +1004,6 @@
       void notifySubscriptionHandlers( Subscription& s10n );
       void notifyTagHandlers( Tag* tag );
       void notifyOnDisconnect( ConnectionError e );
-      void send( const std::string& xml );
       void addFrom( Tag* tag );
       void addNamespace( Tag* tag );
 
@@ -973,6 +1043,7 @@
       typedef std::multimap<const int, IqHandler*>         IqHandlerMap;
       typedef std::map<const std::string, TrackStruct>     IqTrackMap;
       typedef std::map<const std::string, MessageHandler*> MessageHandlerMap;
+      typedef std::map<int, Tag*>                          SMQueueMap;
       typedef std::list<MessageSession*>                   MessageSessionList;
       typedef std::list<MessageHandler*>                   MessageHandlerList;
       typedef std::list<PresenceHandler*>                  PresenceHandlerList;
@@ -984,6 +1055,7 @@
       IqHandlerMapXmlns        m_iqNSHandlers;
       IqHandlerMap             m_iqExtHandlers;
       IqTrackMap               m_iqIDHandlers;
+      SMQueueMap               m_smQueue;
       MessageSessionList       m_messageSessions;
       MessageHandlerList       m_messageHandlers;
       PresenceHandlerList      m_presenceHandlers;
@@ -999,6 +1071,8 @@
       MessageSessionHandler  * m_messageSessionHandlerNormal;
 
       util::Mutex m_iqHandlerMapMutex;
+      util::Mutex m_iqExtHandlerMapMutex;
+      util::Mutex m_queueMutex;
 
       Parser m_parser;
       LogSink m_logInstance;
@@ -1015,8 +1089,16 @@
 
       SaslMechanism m_selectedSaslMech;
 
+      std::string m_clientFirstMessageBare;
+      std::string m_serverSignature;
+      std::string m_gs2Header;
       std::string m_ntlmDomain;
-      bool m_autoMessageSession;
+      bool m_customConnection;
+
+      int m_uniqueBaseId;
+      util::AtomicRefCount m_nextId;
+
+      int m_smSent;
 
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
       CredHandle m_credHandle;

=== modified file 'src/component.cpp'
--- src/component.cpp	2010-01-17 13:05:04 +0000
+++ src/component.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -32,7 +32,7 @@
     m_disco->setIdentity( "component", "generic" );
   }
 
-  void Component::handleStartNode()
+  void Component::handleStartNode( const Tag* /*start*/ )
   {
     if( m_sid.empty() )
       return;

=== modified file 'src/component.h'
--- src/component.h	2010-01-17 13:05:04 +0000
+++ src/component.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   /**
    * @brief This is an implementation of a basic jabber Component.
    *
-   * It's using XEP-0114 (Jabber Component Protocol) to authenticate with a server.
+   * It's using @xep{0114} (Jabber Component Protocol) to authenticate with a server.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 0.3
@@ -36,7 +36,7 @@
       /**
        * Constructs a new Component.
        * @param ns The namespace that qualifies the stream. Either @b jabber:component:accept or
-       * @b jabber:component:connect. See XEP-0114 for details.
+       * @b jabber:component:connect. See @xep{0114} for details.
        * @param server The server to connect to.
        * @param component The component's hostname. FQDN.
        * @param password The component's password.
@@ -54,11 +54,11 @@
       /**
        * Disconnects from the server.
        */
-      void disconnect() { ClientBase::disconnect( ConnUserDisconnected ); }
+      virtual void disconnect() { ClientBase::disconnect( ConnUserDisconnected ); }
 
     protected:
       // reimplemented from ClientBase
-      virtual void handleStartNode();
+      virtual void handleStartNode( const Tag* start );
 
       // reimplemented from ClientBase
       virtual bool handleNormalNode( Tag* tag );

=== modified file 'src/compressionbase.h'
--- src/compressionbase.h	2010-01-17 13:05:04 +0000
+++ src/compressionbase.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/compressiondatahandler.h'
--- src/compressiondatahandler.h	2010-01-17 13:05:04 +0000
+++ src/compressiondatahandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/compressiondefault.cpp'
--- src/compressiondefault.cpp	2010-01-17 13:05:04 +0000
+++ src/compressiondefault.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license

=== modified file 'src/compressiondefault.h'
--- src/compressiondefault.h	2010-01-17 13:05:04 +0000
+++ src/compressiondefault.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license

=== modified file 'src/compressionzlib.cpp'
--- src/compressionzlib.cpp	2010-01-17 13:05:04 +0000
+++ src/compressionzlib.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/compressionzlib.h'
--- src/compressionzlib.h	2010-01-17 13:05:04 +0000
+++ src/compressionzlib.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/config.h'
--- src/config.h	2010-01-17 13:05:04 +0000
+++ src/config.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectionbase.h'
--- src/connectionbase.h	2010-01-17 13:05:04 +0000
+++ src/connectionbase.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectionbosh.cpp'
--- src/connectionbosh.cpp	2010-01-17 13:05:04 +0000
+++ src/connectionbosh.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license

=== modified file 'src/connectionbosh.h'
--- src/connectionbosh.h	2010-01-17 13:05:04 +0000
+++ src/connectionbosh.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license

=== modified file 'src/connectiondatahandler.h'
--- src/connectiondatahandler.h	2010-01-17 13:05:04 +0000
+++ src/connectiondatahandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectionhandler.h'
--- src/connectionhandler.h	2010-01-17 13:05:04 +0000
+++ src/connectionhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectionhttpproxy.cpp'
--- src/connectionhttpproxy.cpp	2010-01-17 13:05:04 +0000
+++ src/connectionhttpproxy.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -139,7 +139,7 @@
         m_proxyHandshakeBuffer = EmptyString;
         m_state = StateConnected;
         m_logInstance.dbg( LogAreaClassConnectionHTTPProxy,
-                           "http proxy connection established" );
+                           "HTTP proxy connection established" );
         m_handler->handleConnect( this );
       }
       else if( !m_proxyHandshakeBuffer.compare( 9, 3, "407" ) )
@@ -174,7 +174,7 @@
           port = host.second;
         }
       }
-      std::string message = "Requesting http proxy connection to " + server + ":"
+      std::string message = "Requesting HTTP proxy connection to " + server + ":"
           + util::int2string( port );
       m_logInstance.dbg( LogAreaClassConnectionHTTPProxy, message );
 

=== modified file 'src/connectionhttpproxy.h'
--- src/connectionhttpproxy.h	2010-01-17 13:05:04 +0000
+++ src/connectionhttpproxy.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectionlistener.h'
--- src/connectionlistener.h	2010-01-17 13:05:04 +0000
+++ src/connectionlistener.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectionsocks5proxy.cpp'
--- src/connectionsocks5proxy.cpp	2014-01-16 01:11:18 +0000
+++ src/connectionsocks5proxy.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectionsocks5proxy.h'
--- src/connectionsocks5proxy.h	2010-01-17 13:05:04 +0000
+++ src/connectionsocks5proxy.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectiontcpbase.cpp'
--- src/connectiontcpbase.cpp	2010-01-17 13:05:04 +0000
+++ src/connectiontcpbase.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -19,6 +19,7 @@
 #include "logsink.h"
 #include "prep.h"
 #include "mutexguard.h"
+#include "util.h"
 
 #ifdef __MINGW32__
 # include <winsock.h>
@@ -31,6 +32,8 @@
 # include <sys/select.h>
 # include <netinet/in.h>
 # include <unistd.h>
+# include <string.h>
+# include <errno.h>
 #elif ( defined( _WIN32 ) || defined( _WIN32_WCE ) ) && !defined( __SYMBIAN32__ )
 # include <winsock.h>
 typedef int socklen_t;
@@ -48,7 +51,7 @@
                                         const std::string& server, int port )
     : ConnectionBase( 0 ),
       m_logInstance( logInstance ), m_buf( 0 ), m_socket( -1 ), m_totalBytesIn( 0 ),
-      m_totalBytesOut( 0 ), m_bufsize( 1024 ), m_cancel( true )
+      m_totalBytesOut( 0 ), m_bufsize( 8192 ), m_cancel( true )
   {
     init( server, port );
   }
@@ -57,7 +60,7 @@
                                         const std::string& server, int port )
     : ConnectionBase( cdh ),
       m_logInstance( logInstance ), m_buf( 0 ), m_socket( -1 ), m_totalBytesIn( 0 ),
-      m_totalBytesOut( 0 ), m_bufsize( 1024 ), m_cancel( true )
+      m_totalBytesOut( 0 ), m_bufsize( 8192 ), m_cancel( true )
   {
     init( server, port );
   }
@@ -109,7 +112,7 @@
       return ConnNotConnected;
 
     ConnectionError err = ConnNoError;
-    while( !m_cancel && ( err = recv( 10 ) ) == ConnNoError )
+    while( !m_cancel && ( err = recv( 1000000 ) ) == ConnNoError )
       ;
     return err == ConnNoError ? ConnNotConnected : err;
   }
@@ -134,8 +137,20 @@
 
     m_sendMutex.unlock();
 
-    if( sent == -1 && m_handler )
-      m_handler->handleDisconnect( this, ConnIoError );
+    if( sent == -1 )
+    {
+        // send() failed for an unexpected reason
+        std::string message = "send() failed. "
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+          "WSAGetLastError: " + util::int2string( ::WSAGetLastError() );
+#else
+          "errno: " + util::int2string( errno ) + ": " + strerror( errno );
+#endif
+      m_logInstance.err( LogAreaClassConnectionTCPBase, message );
+
+      if( m_handler )
+        m_handler->handleDisconnect( this, ConnIoError );
+    }
 
     return sent != -1;
   }

=== modified file 'src/connectiontcpbase.h'
--- src/connectiontcpbase.h	2010-01-17 13:05:04 +0000
+++ src/connectiontcpbase.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectiontcpclient.cpp'
--- src/connectiontcpclient.cpp	2010-01-17 13:05:04 +0000
+++ src/connectiontcpclient.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -18,6 +18,7 @@
 #include "dns.h"
 #include "logsink.h"
 #include "mutexguard.h"
+#include "util.h"
 
 #ifdef __MINGW32__
 # include <winsock.h>
@@ -28,6 +29,8 @@
 # include <sys/socket.h>
 # include <sys/select.h>
 # include <unistd.h>
+# include <string.h>
+# include <errno.h>
 #elif ( defined( _WIN32 ) || defined( _WIN32_WCE ) ) && !defined( __SYMBIAN32__ )
 # include <winsock.h>
 #endif
@@ -142,6 +145,18 @@
 
     if( size <= 0 )
     {
+      if( size == -1 )
+      {
+        // recv() failed for an unexpected reason
+        std::string message = "recv() failed. "
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+          "WSAGetLastError: " + util::int2string( ::WSAGetLastError() );
+#else
+          "errno: " + util::int2string( errno ) + ": " + strerror( errno );
+#endif
+        m_logInstance.err( LogAreaClassConnectionTCPClient, message );
+      }
+
       ConnectionError error = ( size ? ConnIoError : ConnStreamClosed );
       if( m_handler )
         m_handler->handleDisconnect( this, error );

=== modified file 'src/connectiontcpclient.h'
--- src/connectiontcpclient.h	2010-01-17 13:05:04 +0000
+++ src/connectiontcpclient.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/connectiontcpserver.cpp'
--- src/connectiontcpserver.cpp	2010-01-17 13:05:04 +0000
+++ src/connectiontcpserver.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -14,6 +14,8 @@
 
 #include "gloox.h"
 
+#include "config.h"
+
 #include "connectiontcpserver.h"
 #include "connectiontcpclient.h"
 #include "connectionhandler.h"
@@ -87,6 +89,22 @@
     if( m_socket < 0 )
       return ConnIoError;
 
+#ifdef HAVE_SETSOCKOPT
+    int buf = 0;
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+    int bufbytes = sizeof( int );
+#else
+    socklen_t bufbytes = sizeof( int );
+#endif
+    if( ( getsockopt( m_socket, SOL_SOCKET, SO_RCVBUF, (char*)&buf, &bufbytes ) != -1 ) &&
+        ( m_bufsize > buf ) )
+      setsockopt( m_socket, SOL_SOCKET, SO_RCVBUF, (char*)&m_bufsize, sizeof( m_bufsize ) );
+
+    if( ( getsockopt( m_socket, SOL_SOCKET, SO_SNDBUF, (char*)&buf, &bufbytes ) != -1 ) &&
+        ( m_bufsize > buf ) )
+      setsockopt( m_socket, SOL_SOCKET, SO_SNDBUF, (char*)&m_bufsize, sizeof( m_bufsize ) );
+#endif
+
     struct sockaddr_in local;
     local.sin_family = AF_INET;
     local.sin_port = static_cast<unsigned short int>( htons( m_port ) );

=== modified file 'src/connectiontcpserver.h'
--- src/connectiontcpserver.h	2010-01-17 13:05:04 +0000
+++ src/connectiontcpserver.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -38,7 +38,7 @@
     public:
       /**
        * Constructs a new ConnectionTCPServer object.
-       * @param ch An ConnectionHandler-derived object that will handle incoming connections.
+       * @param ch A ConnectionHandler-derived object that will handle incoming connections.
        * @param logInstance The log target. Obtain it from ClientBase::logInstance().
        * @param ip The local IP address to listen on. This must @b not be a hostname.
        * Leave this empty to listen on all local interfaces.

=== modified file 'src/connectiontls.cpp'
--- src/connectiontls.cpp	2010-01-17 13:05:04 +0000
+++ src/connectiontls.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license
@@ -14,6 +14,8 @@
 #include "connectiontls.h"
 #include "tlsdefault.h"
 
+#include <cstdio>
+
 namespace gloox
 {
 
@@ -84,16 +86,7 @@
 
   ConnectionError ConnectionTLS::recv( int timeout )
   {
-    if( m_connection->state() == StateConnected )
-    {
-      return m_connection->recv( timeout );
-    }
-    else
-    {
-      m_log.log( LogLevelWarning, LogAreaClassConnectionTLS,
-                 "Attempt to receive data on a connection that is not connected (or is connecting)" );
-      return ConnNotConnected;
-    }
+    return m_connection ? m_connection->recv( timeout ) : ConnNotConnected;
   }
 
   bool ConnectionTLS::send( const std::string& data )
@@ -198,6 +191,9 @@
       m_log.log( LogLevelWarning, LogAreaClassConnectionTLS, "TLS handshake failed" );
       if( m_tlsHandler )
         m_tlsHandler->handleHandshakeResult( tls, success, certinfo );
+      cleanup();
+      if( m_handler )
+        m_handler->handleDisconnect( this, ConnTlsFailed );
     }
   }
 

=== modified file 'src/connectiontls.h'
--- src/connectiontls.h	2010-01-17 13:05:04 +0000
+++ src/connectiontls.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license
@@ -35,7 +35,7 @@
    * @code
    * Client *c = new Client( ... );
    * c->setConnectionImpl( new ConnectionTLS( c,
-   *                                new ConnectionTCP( c->logInstance(), server, 5223 ),
+   *                                new ConnectionTCPClient( c->logInstance(), server, 5223 ),
    *                                c->logInstance()) );
    * @endcode
    *

=== modified file 'src/connectiontlsserver.cpp'
--- src/connectiontlsserver.cpp	2010-01-17 13:05:04 +0000
+++ src/connectiontlsserver.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license

=== modified file 'src/connectiontlsserver.h'
--- src/connectiontlsserver.h	2010-01-17 13:05:04 +0000
+++ src/connectiontlsserver.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license

=== modified file 'src/dataform.cpp'
--- src/dataform.cpp	2010-01-17 13:05:04 +0000
+++ src/dataform.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/dataform.h'
--- src/dataform.h	2010-01-17 13:05:04 +0000
+++ src/dataform.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -46,7 +46,7 @@
   };
 
   /**
-   * @brief An abstraction of a XEP-0004 Data Form.
+   * @brief An abstraction of a @xep{0004} Data Form.
    *
    *
    *

=== modified file 'src/dataformfield.cpp'
--- src/dataformfield.cpp	2010-01-17 13:05:04 +0000
+++ src/dataformfield.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/dataformfield.h'
--- src/dataformfield.h	2010-01-17 13:05:04 +0000
+++ src/dataformfield.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class Tag;
 
   /**
-    * @brief An abstraction of a single field in a XEP-0004 Data Form.
+    * @brief An abstraction of a single field in a @xep{0004} Data Form.
     *
     * @author Jakob Schroeter <js@camaya.net>
     * @since 0.7

=== modified file 'src/dataformfieldcontainer.cpp'
--- src/dataformfieldcontainer.cpp	2010-01-17 13:05:04 +0000
+++ src/dataformfieldcontainer.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/dataformfieldcontainer.h'
--- src/dataformfieldcontainer.h	2010-01-17 13:05:04 +0000
+++ src/dataformfieldcontainer.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class DataFormField;
 
   /**
-    * @brief An abstract base class for a XEP-0004 Data Form.
+    * @brief An abstract base class for a @xep{0004} Data Form.
     *
     * You shouldn't need to use this class directly. Use DataForm instead.
     *
@@ -52,7 +52,7 @@
       virtual ~DataFormFieldContainer();
 
       /**
-        * A list of XEP-0004 Data Form Fields.
+        * A list of @xep{0004} Data Form Fields.
         */
       typedef std::list<DataFormField*> FieldList;
 

=== modified file 'src/dataformitem.cpp'
--- src/dataformitem.cpp	2010-01-17 13:05:04 +0000
+++ src/dataformitem.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
  /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/dataformitem.h'
--- src/dataformitem.h	2010-01-17 13:05:04 +0000
+++ src/dataformitem.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -20,9 +20,9 @@
 {
 
   /**
-   * @brief An abstraction of an &lt;item&gt; element in a XEP-0004 Data Form of type result.
+   * @brief An abstraction of an &lt;item&gt; element in a @xep{0004} Data Form of type result.
    *
-   * There are some constraints regarding usage of this element you should be aware of. Check XEP-0004
+   * There are some constraints regarding usage of this element you should be aware of. Check @xep{0004}
    * section 3.4. This class does not enforce correct usage at this point.
    *
    * @author Jakob Schroeter <js@camaya.net>

=== modified file 'src/dataformreported.cpp'
--- src/dataformreported.cpp	2010-01-17 13:05:04 +0000
+++ src/dataformreported.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
  /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/dataformreported.h'
--- src/dataformreported.h	2010-01-17 13:05:04 +0000
+++ src/dataformreported.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -22,9 +22,9 @@
   class Tag;
 
   /**
-   * @brief An abstraction of a &lt;reported&gt; element in a XEP-0004 Data Form of type result.
+   * @brief An abstraction of a &lt;reported&gt; element in a @xep{0004} Data Form of type result.
    *
-   * There are some constraints regarding usage of this element you should be aware of. Check XEP-0004
+   * There are some constraints regarding usage of this element you should be aware of. Check @xep{0004}
    * section 3.4. This class does not enforce correct usage at this point.
    *
    * @author Jakob Schroeter <js@camaya.net>

=== modified file 'src/delayeddelivery.cpp'
--- src/delayeddelivery.cpp	2010-01-17 13:05:04 +0000
+++ src/delayeddelivery.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -31,6 +31,7 @@
   {
     if( !tag || !tag->hasAttribute( "stamp" ) )
       return;
+
     if( !( tag->name() == "x" && tag->hasAttribute( XMLNS, XMLNS_X_DELAY ) ) )
       if( !( tag->name() == "delay" && tag->hasAttribute( XMLNS, XMLNS_DELAY ) ) )
         return;

=== modified file 'src/delayeddelivery.h'
--- src/delayeddelivery.h	2010-01-17 13:05:04 +0000
+++ src/delayeddelivery.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,10 +26,10 @@
   class Tag;
 
   /**
-   * @brief This is an implementation of XEP-0203 (Delayed Delivery).
+   * @brief This is an implementation of @xep{0203} (Delayed Delivery).
    *
-   * The class also implements the deprecated XEP-0091 (Delayed Delivery) in a read-only fashion.
-   * It understands both XEP formats for input, but any output will conform to XEP-0203.
+   * The class also implements the deprecated @xep{0091} (Delayed Delivery) in a read-only fashion.
+   * It understands both XEP formats for input, but any output will conform to @xep{0203}.
    *
    * XEP Version: 0.1
    * @author Jakob Schroeter <js@camaya.net>
@@ -61,7 +61,7 @@
 
       /**
        * Returns the datetime when the stanza was originally sent.
-       * The format MUST adhere to the dateTime format specified in XEP-0082 and MUST
+       * The format MUST adhere to the dateTime format specified in @xep{0082} and MUST
        * be expressed in UTC.
        * @return The original datetime.
        */
@@ -76,7 +76,7 @@
       /**
        * Returns the JID of the original sender of the stanza or the entity that
        * delayed the sending.
-       * The format MUST adhere to the dateTime format specified in XEP-0082 and MUST
+       * The format MUST adhere to the dateTime format specified in @xep{0082} and MUST
        * be expressed in UTC.
        * @return The JID.
        */

=== modified file 'src/disco.cpp'
--- src/disco.cpp	2010-01-17 13:05:04 +0000
+++ src/disco.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/disco.h'
--- src/disco.h	2010-01-17 13:05:04 +0000
+++ src/disco.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -34,7 +34,7 @@
   class IQ;
 
   /**
-   * @brief This class implements XEP-0030 (Service Discovery) and XEP-0092 (Software Version).
+   * @brief This class implements @xep{0030} (Service Discovery) and @xep{0092} (Software Version).
    *
    * ClientBase will automatically instantiate a Disco object. It can be used to
    * announce special features of your client, or its version, or...
@@ -56,7 +56,7 @@
       typedef std::list<Identity*> IdentityList;
 
       /**
-       * @brief An abstraction of a Disco Info element (from Service Discovery, XEP-0030)
+       * @brief An abstraction of a Disco Info element (from Service Discovery, @xep{0030})
        * as a StanzaExtension.
        *
        * @author Jakob Schroeter <js@camaya.net>
@@ -93,13 +93,13 @@
           const IdentityList& identities() const { return m_identities; }
 
           /**
-           * Returns an optionally included data form. This is used by e.g. MUC (XEP-0045).
+           * Returns an optionally included data form. This is used by e.g. MUC (@xep{0045}).
            * @return An optional data form included in the disco#info. May be 0.
            */
           const DataForm* form() const { return m_form; }
 
           /**
-           * Adds an optional DataForm, e.g. for XEP-0232. Only one form can be added
+           * Adds an optional DataForm, e.g. for @xep{0232}. Only one form can be added
            * at this point.
            * @param form An optional DataForm to include in the Info reply.
            * The form will be owned by and deleted on destruction of the Info object.
@@ -188,7 +188,7 @@
       };
 
       /**
-       * @brief An abstraction of a Disco identity (Service Discovery, XEP-0030).
+       * @brief An abstraction of a Disco identity (Service Discovery, @xep{0030}).
        *
        * @author Jakob Schroeter <js@camaya.net>
        * @since 1.0
@@ -266,7 +266,7 @@
       typedef std::list<Item*> ItemList;
 
       /**
-       * @brief An abstraction of a Disco query element (from Service Discovery, XEP-0030)
+       * @brief An abstraction of a Disco query element (from Service Discovery, @xep{0030})
        * in the disco#items namespace, implemented as a StanzaExtension.
        *
        * @author Jakob Schroeter <js@camaya.net>
@@ -278,7 +278,7 @@
 
         public:
           // This needs to be public so one can proactively send a list of adhoc commands
-          // see XEP-0050
+          // see @xep{0050}
           /**
            * Creates an empty Items object, suitable for making disco#items requests.
            * @param node The node identifier to query (optional).
@@ -344,7 +344,7 @@
       };
 
       /**
-       * @brief An abstraction of a Disco item (Service Discovery, XEP-0030).
+       * @brief An abstraction of a Disco item (Service Discovery, @xep{0030}).
        *
        * @author Jakob Schroeter <js@camaya.net>
        * @since 1.0
@@ -439,7 +439,7 @@
 
       /**
        * Queries the given JID for general infomation according to
-       * XEP-0030 (Service Discovery).
+       * @xep{0030} (Service Discovery).
        * To receive the results inherit from DiscoHandler and register with the Disco object.
        * @param to The destination-JID of the query.
        * @param node An optional node to query. Not inserted if empty.
@@ -454,7 +454,7 @@
 
       /**
        * Queries the given JID for its items according to
-       * XEP-0030 (Service Discovery).
+       * @xep{0030} (Service Discovery).
        * To receive the results inherit from DiscoHandler and register with the Disco object.
        * @param to The destination-JID of the query.
        * @param node An optional node to query. Not inserted if empty.
@@ -471,8 +471,8 @@
        * Sets the version of the host application using this library.
        * The library takes care of jabber:iq:version requests. These
        * IQ packets will not be forwarded to the IqHandlers.
-       * @param name The name to be returned to inquireing clients.
-       * @param version The version to be returned to inquireing clients.
+       * @param name The name to be returned to inquiring clients.
+       * @param version The version to be returned to inquiring clients.
        * @param os The operating system to announce. Default: don't include.
        */
       void setVersion( const std::string& name, const std::string& version,
@@ -500,10 +500,10 @@
        * Sets the identity of this entity.
        * The library uses this information to answer disco#info requests
        * with a correct identity.
-       * XEP-0030 requires an entity to have at least one identity. See XEP-0030
+       * @xep{0030} requires an entity to have at least one identity. See @xep{0030}
        * for more information on categories and types.
-       * @param category The entity category of this client. Default: client.
-       * @param type The type of this entity. Default: bot.
+       * @param category The entity category of this client. Default: client. May not be empty.
+       * @param type The type of this entity. Default: bot. May not be empty.
        * @param name The name of the entity. Default: empty.
        * @note An entity can have more than one identity. You cann add more identities
        * using addIdentity(). A call to setIdentity() will clear the list of identities
@@ -514,8 +514,8 @@
 
       /**
        * Adds another identity to the list of identities.
-       * @param category The entity category of this client. Default: client.
-       * @param type The type of this entity. Default: bot.
+       * @param category The entity category of this client. Default: client. May not be empty.
+       * @param type The type of this entity. Default: bot. May not be empty.
        * @param name The name of the entity. Default: empty.
        */
       void addIdentity( const std::string& category, const std::string& type,
@@ -529,7 +529,7 @@
       const IdentityList& identities() const { return m_identities; }
 
       /**
-       * Adds an optional DataForm to Disco:Info replies, e.g. for XEP-0232.
+       * Adds an optional DataForm to Disco:Info replies, e.g. for @xep{0232}.
        * Only one form can be added at this point.
        * @param form An optional DataForm to include in the Info reply.
        * The form will be owned by and deleted on destruction of the Disco object.

=== modified file 'src/discohandler.h'
--- src/discohandler.h	2010-01-17 13:05:04 +0000
+++ src/discohandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class IQ;
 
   /**
-   * @brief A virtual interface that enables objects to receive Service Discovery (XEP-0030) events.
+   * @brief A virtual interface that enables objects to receive Service Discovery (@xep{0030}) events.
    *
    * A class implementing this interface can receive the results of sent disco queries.
    *

=== modified file 'src/disconodehandler.h'
--- src/disconodehandler.h	2010-01-17 13:05:04 +0000
+++ src/disconodehandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/dns.cpp'
--- src/dns.cpp	2010-01-17 13:05:04 +0000
+++ src/dns.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -98,7 +98,7 @@
     HEADER* hdr = (HEADER*)srvbuf.buf;
     unsigned char* here = srvbuf.buf + NS_HFIXEDSZ;
 
-    if( ( hdr->tc ) || ( srvbuf.len < NS_HFIXEDSZ ) )
+    if( srvbuf.len < NS_HFIXEDSZ )
       error = true;
 
     if( hdr->rcode >= 1 && hdr->rcode <= 5 )
@@ -156,7 +156,7 @@
     return servers;
   }
 
-#elif defined( _WIN32 ) && defined( HAVE_WINDNS_H )
+#elif defined( _WIN32 ) && defined( HAVE_WINDNS_H ) && !defined( __MINGW32__ )
   DNS::HostMap DNS::resolve( const std::string& service, const std::string& proto,
                              const std::string& domain, const LogSink& logInstance )
   {
@@ -168,7 +168,10 @@
     DNS_STATUS status = DnsQuery_UTF8( dname.c_str(), DNS_TYPE_SRV, DNS_QUERY_STANDARD, NULL, &pRecord, NULL );
     if( status == ERROR_SUCCESS )
     {
-      DNS_RECORD* pRec = pRecord;
+      // NOTE: DnsQuery_UTF8 and DnsQuery_A really should have been defined with
+      // PDNS_RECORDA instead of PDNS_RECORD, since that's what it is (even with _UNICODE defined).
+      // We'll correct for that mistake with a cast.
+      DNS_RECORDA* pRec = (DNS_RECORDA*)pRecord;
       do
       {
         if( pRec->wType == DNS_TYPE_SRV )
@@ -289,10 +292,9 @@
       }
 
       if( res->ai_canonname )
-        logInstance.dbg( LogAreaClassDns, "Connecting to " + std::string( res->ai_canonname )
-                                          + " (" + ip + "), port " + port );
+        logInstance.dbg( LogAreaClassDns, std::string( "Connecting to " ).append( res->ai_canonname ).append( " (" ).append( ip ).append( "), port  " ).append( port ) );
       else
-        logInstance.dbg( LogAreaClassDns, "Connecting to " + ip + ":" + port );
+        logInstance.dbg( LogAreaClassDns, std::string( "Connecting to " ).append( ip ).append( ":" ).append( port ) );
 
       return fd;
     }
@@ -301,7 +303,7 @@
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
         "WSAGetLastError: " + util::int2string( ::WSAGetLastError() );
 #else
-        "errno: " + util::int2string( errno );
+        "errno: " + util::int2string( errno ) + ": " + strerror( errno );
 #endif
     logInstance.dbg( LogAreaClassDns, message );
 
@@ -342,6 +344,7 @@
 #endif
 
     int protocol = IPPROTO_TCP;
+#if !defined( __APPLE__ )  // Sandboxing on Apple doesn't like you to use getprotobyname
     struct protoent* prot;
     if( ( prot = getprotobyname( "tcp" ) ) != 0 )
     {
@@ -353,13 +356,14 @@
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
           "WSAGetLastError: " + util::int2string( ::WSAGetLastError() )
 #else
-          "errno: " + util::int2string( errno );
+          "errno: " + util::int2string( errno ) + ": " + strerror( errno );
 #endif
           + ". Falling back to IPPROTO_TCP: " + util::int2string( IPPROTO_TCP );
       logInstance.dbg( LogAreaClassDns, message );
 
       // Do not return an error. We'll fall back to IPPROTO_TCP.
     }
+#endif // !defined( __APPLE__ )
 
     return getSocket( PF_INET, SOCK_STREAM, protocol, logInstance );
   }
@@ -381,7 +385,7 @@
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
           "WSAGetLastError: " + util::int2string( ::WSAGetLastError() );
 #else
-          "errno: " + util::int2string( errno );
+          "errno: " + util::int2string( errno ) + ": " + strerror( errno );
 #endif
       logInstance.dbg( LogAreaClassDns, message );
 
@@ -391,8 +395,9 @@
 
 #ifdef HAVE_SETSOCKOPT
     int timeout = 5000;
+    int reuseaddr = 1;
     setsockopt( fd, SOL_SOCKET, SO_SNDTIMEO, (char*)&timeout, sizeof( timeout ) );
-    setsockopt( fd, SOL_SOCKET, SO_REUSEADDR, (char*)&timeout, sizeof( timeout ) );
+    setsockopt( fd, SOL_SOCKET, SO_REUSEADDR, (char*)&reuseaddr, sizeof( reuseaddr ) );
 #endif
 
     return (int)fd;
@@ -409,6 +414,7 @@
     {
       logInstance.dbg( LogAreaClassDns, "gethostbyname() failed for " + host + "." );
       cleanup( logInstance );
+      closeSocket( fd, logInstance );
       return -ConnDnsError;
     }
 
@@ -420,6 +426,7 @@
     {
       logInstance.dbg( LogAreaClassDns, "gethostbyname() returned unexpected structure." );
       cleanup( logInstance );
+      closeSocket( fd, logInstance );
       return -ConnDnsError;
     }
     else
@@ -443,7 +450,7 @@
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
         "WSAGetLastError: " + util::int2string( ::WSAGetLastError() );
 #else
-        "errno: " + util::int2string( errno );
+        "errno: " + util::int2string( errno ) + ": " + strerror( errno );
 #endif
     logInstance.dbg( LogAreaClassDns, message );
 
@@ -465,7 +472,7 @@
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
           "WSAGetLastError: " + util::int2string( ::WSAGetLastError() );
 #else
-          "errno: " + util::int2string( errno );
+          "errno: " + util::int2string( errno ) + ": " + strerror( errno );
 #endif
       logInstance.dbg( LogAreaClassDns, message );
     }

=== modified file 'src/dns.h'
--- src/dns.h	2010-01-17 13:05:04 +0000
+++ src/dns.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/error.cpp'
--- src/error.cpp	2010-01-17 13:05:04 +0000
+++ src/error.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/error.h'
--- src/error.h	2010-01-17 13:05:04 +0000
+++ src/error.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/event.h'
--- src/event.h	2010-01-17 13:05:04 +0000
+++ src/event.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -34,9 +34,9 @@
        */
       enum EventType
       {
-        PingPing,                     /**< Incoming Ping (XEP-0199). */
-        PingPong,                     /**< Incoming Pong (XEP-0199). */
-        PingError                     /**< Incoming Error Pong (XEP-0199). */
+        PingPing,                     /**< Incoming Ping (@xep{0199}). */
+        PingPong,                     /**< Incoming Pong (@xep{0199}). */
+        PingError                     /**< Incoming Error Pong (@xep{0199}). */
       };
 
       /**

=== modified file 'src/eventdispatcher.cpp'
--- src/eventdispatcher.cpp	2010-01-17 13:05:04 +0000
+++ src/eventdispatcher.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/eventdispatcher.h'
--- src/eventdispatcher.h	2010-01-17 13:05:04 +0000
+++ src/eventdispatcher.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/eventhandler.h'
--- src/eventhandler.h	2010-01-17 13:05:04 +0000
+++ src/eventhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/examples/Makefile.am'
--- src/examples/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/examples/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,7 +9,7 @@
 noinst_PROGRAMS = register_example disco_example adhoc_example roster_example privatexml_example component_example \
                   bookmarkstorage_example annotations_example privacylist_example message_example flexoff_example \
                   vcard_example reset_example muc_example e2ee_client e2ee_server ft_recv ft_send \
-                  pubsub_example bosh_example
+                  pubsub_example bosh_example linklocal_example reconnect_example
 
 register_example_SOURCES = register_example.cpp
 register_example_LDADD = ../libgloox.la $(LDFLAGS)
@@ -90,3 +90,11 @@
 bosh_example_SOURCES = bosh_example.cpp
 bosh_example_LDADD = ../libgloox.la $(LDFLAGS)
 bosh_example_CFLAGS = $(CPPFLAGS)
+
+linklocal_example_SOURCES = linklocal_example.cpp
+linklocal_example_LDADD = ../libgloox.la $(LDFLAGS)
+linklocal_example_CFLAGS = $(CPPFLAGS)
+
+reconnect_example_SOURCES = reconnect_example.cpp
+reconnect_example_LDADD = ../libgloox.la $(LDFLAGS)
+reconnect_example_CFLAGS = $(CPPFLAGS)

=== modified file 'src/examples/Makefile.in'
--- src/examples/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/examples/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -42,7 +59,8 @@
 	flexoff_example$(EXEEXT) vcard_example$(EXEEXT) \
 	reset_example$(EXEEXT) muc_example$(EXEEXT) \
 	e2ee_client$(EXEEXT) e2ee_server$(EXEEXT) ft_recv$(EXEEXT) \
-	ft_send$(EXEEXT) pubsub_example$(EXEEXT) bosh_example$(EXEEXT)
+	ft_send$(EXEEXT) pubsub_example$(EXEEXT) bosh_example$(EXEEXT) \
+	linklocal_example$(EXEEXT) reconnect_example$(EXEEXT)
 subdir = src/examples
 DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
 ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
@@ -93,6 +111,9 @@
 am_ft_send_OBJECTS = ft_send.$(OBJEXT)
 ft_send_OBJECTS = $(am_ft_send_OBJECTS)
 ft_send_DEPENDENCIES = ../libgloox.la $(am__DEPENDENCIES_1)
+am_linklocal_example_OBJECTS = linklocal_example.$(OBJEXT)
+linklocal_example_OBJECTS = $(am_linklocal_example_OBJECTS)
+linklocal_example_DEPENDENCIES = ../libgloox.la $(am__DEPENDENCIES_1)
 am_message_example_OBJECTS = message_example.$(OBJEXT)
 message_example_OBJECTS = $(am_message_example_OBJECTS)
 message_example_DEPENDENCIES = ../libgloox.la $(am__DEPENDENCIES_1)
@@ -109,6 +130,9 @@
 am_pubsub_example_OBJECTS = pubsub_example.$(OBJEXT)
 pubsub_example_OBJECTS = $(am_pubsub_example_OBJECTS)
 pubsub_example_DEPENDENCIES = ../libgloox.la $(am__DEPENDENCIES_1)
+am_reconnect_example_OBJECTS = reconnect_example.$(OBJEXT)
+reconnect_example_OBJECTS = $(am_reconnect_example_OBJECTS)
+reconnect_example_DEPENDENCIES = ../libgloox.la $(am__DEPENDENCIES_1)
 am_register_example_OBJECTS = register_example.$(OBJEXT)
 register_example_OBJECTS = $(am_register_example_OBJECTS)
 register_example_DEPENDENCIES = ../libgloox.la $(am__DEPENDENCIES_1)
@@ -139,9 +163,10 @@
 	$(component_example_SOURCES) $(disco_example_SOURCES) \
 	$(e2ee_client_SOURCES) $(e2ee_server_SOURCES) \
 	$(flexoff_example_SOURCES) $(ft_recv_SOURCES) \
-	$(ft_send_SOURCES) $(message_example_SOURCES) \
-	$(muc_example_SOURCES) $(privacylist_example_SOURCES) \
-	$(privatexml_example_SOURCES) $(pubsub_example_SOURCES) \
+	$(ft_send_SOURCES) $(linklocal_example_SOURCES) \
+	$(message_example_SOURCES) $(muc_example_SOURCES) \
+	$(privacylist_example_SOURCES) $(privatexml_example_SOURCES) \
+	$(pubsub_example_SOURCES) $(reconnect_example_SOURCES) \
 	$(register_example_SOURCES) $(reset_example_SOURCES) \
 	$(roster_example_SOURCES) $(vcard_example_SOURCES)
 DIST_SOURCES = $(adhoc_example_SOURCES) $(annotations_example_SOURCES) \
@@ -149,11 +174,17 @@
 	$(component_example_SOURCES) $(disco_example_SOURCES) \
 	$(e2ee_client_SOURCES) $(e2ee_server_SOURCES) \
 	$(flexoff_example_SOURCES) $(ft_recv_SOURCES) \
-	$(ft_send_SOURCES) $(message_example_SOURCES) \
-	$(muc_example_SOURCES) $(privacylist_example_SOURCES) \
-	$(privatexml_example_SOURCES) $(pubsub_example_SOURCES) \
+	$(ft_send_SOURCES) $(linklocal_example_SOURCES) \
+	$(message_example_SOURCES) $(muc_example_SOURCES) \
+	$(privacylist_example_SOURCES) $(privatexml_example_SOURCES) \
+	$(pubsub_example_SOURCES) $(reconnect_example_SOURCES) \
 	$(register_example_SOURCES) $(reset_example_SOURCES) \
 	$(roster_example_SOURCES) $(vcard_example_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -176,6 +207,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -185,6 +217,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -200,7 +233,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -230,6 +265,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -264,7 +300,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -344,6 +379,12 @@
 bosh_example_SOURCES = bosh_example.cpp
 bosh_example_LDADD = ../libgloox.la $(LDFLAGS)
 bosh_example_CFLAGS = $(CPPFLAGS)
+linklocal_example_SOURCES = linklocal_example.cpp
+linklocal_example_LDADD = ../libgloox.la $(LDFLAGS)
+linklocal_example_CFLAGS = $(CPPFLAGS)
+reconnect_example_SOURCES = reconnect_example.cpp
+reconnect_example_LDADD = ../libgloox.la $(LDFLAGS)
+reconnect_example_CFLAGS = $(CPPFLAGS)
 all: all-am
 
 .SUFFIXES:
@@ -387,64 +428,70 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-adhoc_example$(EXEEXT): $(adhoc_example_OBJECTS) $(adhoc_example_DEPENDENCIES) 
+adhoc_example$(EXEEXT): $(adhoc_example_OBJECTS) $(adhoc_example_DEPENDENCIES) $(EXTRA_adhoc_example_DEPENDENCIES) 
 	@rm -f adhoc_example$(EXEEXT)
 	$(CXXLINK) $(adhoc_example_OBJECTS) $(adhoc_example_LDADD) $(LIBS)
-annotations_example$(EXEEXT): $(annotations_example_OBJECTS) $(annotations_example_DEPENDENCIES) 
+annotations_example$(EXEEXT): $(annotations_example_OBJECTS) $(annotations_example_DEPENDENCIES) $(EXTRA_annotations_example_DEPENDENCIES) 
 	@rm -f annotations_example$(EXEEXT)
 	$(CXXLINK) $(annotations_example_OBJECTS) $(annotations_example_LDADD) $(LIBS)
-bookmarkstorage_example$(EXEEXT): $(bookmarkstorage_example_OBJECTS) $(bookmarkstorage_example_DEPENDENCIES) 
+bookmarkstorage_example$(EXEEXT): $(bookmarkstorage_example_OBJECTS) $(bookmarkstorage_example_DEPENDENCIES) $(EXTRA_bookmarkstorage_example_DEPENDENCIES) 
 	@rm -f bookmarkstorage_example$(EXEEXT)
 	$(CXXLINK) $(bookmarkstorage_example_OBJECTS) $(bookmarkstorage_example_LDADD) $(LIBS)
-bosh_example$(EXEEXT): $(bosh_example_OBJECTS) $(bosh_example_DEPENDENCIES) 
+bosh_example$(EXEEXT): $(bosh_example_OBJECTS) $(bosh_example_DEPENDENCIES) $(EXTRA_bosh_example_DEPENDENCIES) 
 	@rm -f bosh_example$(EXEEXT)
 	$(CXXLINK) $(bosh_example_OBJECTS) $(bosh_example_LDADD) $(LIBS)
-component_example$(EXEEXT): $(component_example_OBJECTS) $(component_example_DEPENDENCIES) 
+component_example$(EXEEXT): $(component_example_OBJECTS) $(component_example_DEPENDENCIES) $(EXTRA_component_example_DEPENDENCIES) 
 	@rm -f component_example$(EXEEXT)
 	$(CXXLINK) $(component_example_OBJECTS) $(component_example_LDADD) $(LIBS)
-disco_example$(EXEEXT): $(disco_example_OBJECTS) $(disco_example_DEPENDENCIES) 
+disco_example$(EXEEXT): $(disco_example_OBJECTS) $(disco_example_DEPENDENCIES) $(EXTRA_disco_example_DEPENDENCIES) 
 	@rm -f disco_example$(EXEEXT)
 	$(CXXLINK) $(disco_example_OBJECTS) $(disco_example_LDADD) $(LIBS)
-e2ee_client$(EXEEXT): $(e2ee_client_OBJECTS) $(e2ee_client_DEPENDENCIES) 
+e2ee_client$(EXEEXT): $(e2ee_client_OBJECTS) $(e2ee_client_DEPENDENCIES) $(EXTRA_e2ee_client_DEPENDENCIES) 
 	@rm -f e2ee_client$(EXEEXT)
 	$(CXXLINK) $(e2ee_client_OBJECTS) $(e2ee_client_LDADD) $(LIBS)
-e2ee_server$(EXEEXT): $(e2ee_server_OBJECTS) $(e2ee_server_DEPENDENCIES) 
+e2ee_server$(EXEEXT): $(e2ee_server_OBJECTS) $(e2ee_server_DEPENDENCIES) $(EXTRA_e2ee_server_DEPENDENCIES) 
 	@rm -f e2ee_server$(EXEEXT)
 	$(CXXLINK) $(e2ee_server_OBJECTS) $(e2ee_server_LDADD) $(LIBS)
-flexoff_example$(EXEEXT): $(flexoff_example_OBJECTS) $(flexoff_example_DEPENDENCIES) 
+flexoff_example$(EXEEXT): $(flexoff_example_OBJECTS) $(flexoff_example_DEPENDENCIES) $(EXTRA_flexoff_example_DEPENDENCIES) 
 	@rm -f flexoff_example$(EXEEXT)
 	$(CXXLINK) $(flexoff_example_OBJECTS) $(flexoff_example_LDADD) $(LIBS)
-ft_recv$(EXEEXT): $(ft_recv_OBJECTS) $(ft_recv_DEPENDENCIES) 
+ft_recv$(EXEEXT): $(ft_recv_OBJECTS) $(ft_recv_DEPENDENCIES) $(EXTRA_ft_recv_DEPENDENCIES) 
 	@rm -f ft_recv$(EXEEXT)
 	$(CXXLINK) $(ft_recv_OBJECTS) $(ft_recv_LDADD) $(LIBS)
-ft_send$(EXEEXT): $(ft_send_OBJECTS) $(ft_send_DEPENDENCIES) 
+ft_send$(EXEEXT): $(ft_send_OBJECTS) $(ft_send_DEPENDENCIES) $(EXTRA_ft_send_DEPENDENCIES) 
 	@rm -f ft_send$(EXEEXT)
 	$(CXXLINK) $(ft_send_OBJECTS) $(ft_send_LDADD) $(LIBS)
-message_example$(EXEEXT): $(message_example_OBJECTS) $(message_example_DEPENDENCIES) 
+linklocal_example$(EXEEXT): $(linklocal_example_OBJECTS) $(linklocal_example_DEPENDENCIES) $(EXTRA_linklocal_example_DEPENDENCIES) 
+	@rm -f linklocal_example$(EXEEXT)
+	$(CXXLINK) $(linklocal_example_OBJECTS) $(linklocal_example_LDADD) $(LIBS)
+message_example$(EXEEXT): $(message_example_OBJECTS) $(message_example_DEPENDENCIES) $(EXTRA_message_example_DEPENDENCIES) 
 	@rm -f message_example$(EXEEXT)
 	$(CXXLINK) $(message_example_OBJECTS) $(message_example_LDADD) $(LIBS)
-muc_example$(EXEEXT): $(muc_example_OBJECTS) $(muc_example_DEPENDENCIES) 
+muc_example$(EXEEXT): $(muc_example_OBJECTS) $(muc_example_DEPENDENCIES) $(EXTRA_muc_example_DEPENDENCIES) 
 	@rm -f muc_example$(EXEEXT)
 	$(CXXLINK) $(muc_example_OBJECTS) $(muc_example_LDADD) $(LIBS)
-privacylist_example$(EXEEXT): $(privacylist_example_OBJECTS) $(privacylist_example_DEPENDENCIES) 
+privacylist_example$(EXEEXT): $(privacylist_example_OBJECTS) $(privacylist_example_DEPENDENCIES) $(EXTRA_privacylist_example_DEPENDENCIES) 
 	@rm -f privacylist_example$(EXEEXT)
 	$(CXXLINK) $(privacylist_example_OBJECTS) $(privacylist_example_LDADD) $(LIBS)
-privatexml_example$(EXEEXT): $(privatexml_example_OBJECTS) $(privatexml_example_DEPENDENCIES) 
+privatexml_example$(EXEEXT): $(privatexml_example_OBJECTS) $(privatexml_example_DEPENDENCIES) $(EXTRA_privatexml_example_DEPENDENCIES) 
 	@rm -f privatexml_example$(EXEEXT)
 	$(CXXLINK) $(privatexml_example_OBJECTS) $(privatexml_example_LDADD) $(LIBS)
-pubsub_example$(EXEEXT): $(pubsub_example_OBJECTS) $(pubsub_example_DEPENDENCIES) 
+pubsub_example$(EXEEXT): $(pubsub_example_OBJECTS) $(pubsub_example_DEPENDENCIES) $(EXTRA_pubsub_example_DEPENDENCIES) 
 	@rm -f pubsub_example$(EXEEXT)
 	$(CXXLINK) $(pubsub_example_OBJECTS) $(pubsub_example_LDADD) $(LIBS)
-register_example$(EXEEXT): $(register_example_OBJECTS) $(register_example_DEPENDENCIES) 
+reconnect_example$(EXEEXT): $(reconnect_example_OBJECTS) $(reconnect_example_DEPENDENCIES) $(EXTRA_reconnect_example_DEPENDENCIES) 
+	@rm -f reconnect_example$(EXEEXT)
+	$(CXXLINK) $(reconnect_example_OBJECTS) $(reconnect_example_LDADD) $(LIBS)
+register_example$(EXEEXT): $(register_example_OBJECTS) $(register_example_DEPENDENCIES) $(EXTRA_register_example_DEPENDENCIES) 
 	@rm -f register_example$(EXEEXT)
 	$(CXXLINK) $(register_example_OBJECTS) $(register_example_LDADD) $(LIBS)
-reset_example$(EXEEXT): $(reset_example_OBJECTS) $(reset_example_DEPENDENCIES) 
+reset_example$(EXEEXT): $(reset_example_OBJECTS) $(reset_example_DEPENDENCIES) $(EXTRA_reset_example_DEPENDENCIES) 
 	@rm -f reset_example$(EXEEXT)
 	$(CXXLINK) $(reset_example_OBJECTS) $(reset_example_LDADD) $(LIBS)
-roster_example$(EXEEXT): $(roster_example_OBJECTS) $(roster_example_DEPENDENCIES) 
+roster_example$(EXEEXT): $(roster_example_OBJECTS) $(roster_example_DEPENDENCIES) $(EXTRA_roster_example_DEPENDENCIES) 
 	@rm -f roster_example$(EXEEXT)
 	$(CXXLINK) $(roster_example_OBJECTS) $(roster_example_LDADD) $(LIBS)
-vcard_example$(EXEEXT): $(vcard_example_OBJECTS) $(vcard_example_DEPENDENCIES) 
+vcard_example$(EXEEXT): $(vcard_example_OBJECTS) $(vcard_example_DEPENDENCIES) $(EXTRA_vcard_example_DEPENDENCIES) 
 	@rm -f vcard_example$(EXEEXT)
 	$(CXXLINK) $(vcard_example_OBJECTS) $(vcard_example_LDADD) $(LIBS)
 
@@ -465,11 +512,13 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/flexoff_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ft_recv.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ft_send.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/linklocal_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/message_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/muc_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/privacylist_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/privatexml_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pubsub_example.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/reconnect_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/register_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/reset_example.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/roster_example.Po@am__quote@
@@ -598,10 +647,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/examples/ft_send.cpp'
--- src/examples/ft_send.cpp	2010-01-17 13:05:04 +0000
+++ src/examples/ft_send.cpp	2014-01-16 10:42:06 +0000
@@ -229,7 +229,13 @@
 {
   if( argc == 3 )
   {
-    FTTest *r = new FTTest( JID( argv[1] ), argv[2] );
+    JID j( argv[1] );
+    if( j.resource().empty() )
+    {
+      printf( "error: need full jid\n" );
+      return 1;
+    }
+    FTTest *r = new FTTest( j, argv[2] );
     r->start();
     delete( r );
   }

=== added file 'src/examples/linklocal_example.cpp'
--- src/examples/linklocal_example.cpp	1970-01-01 00:00:00 +0000
+++ src/examples/linklocal_example.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,205 @@
+#include "../config.h"
+#include "../linklocalmanager.h"
+#include "../linklocalhandler.h"
+#include "../logsink.h"
+#include "../loghandler.h"
+#include "../connectionhandler.h"
+#include "../connectionlistener.h"
+#include "../messagehandler.h"
+#include "../message.h"
+#include "../linklocalclient.h"
+#include "../linklocal.h"
+#include "../jid.h"
+using namespace gloox;
+
+#include <stdio.h>
+
+#ifdef HAVE_MDNS
+
+#ifndef _WIN32
+# include <unistd.h>
+#endif
+
+#include <string>
+
+#include <cstdio> // [s]print[f]
+
+#if defined( WIN32 ) || defined( _WIN32 )
+# include <windows.h>
+#endif
+
+class LinkLocalExample : public LinkLocal::Handler, LogHandler, ConnectionHandler, MessageHandler, ConnectionListener
+{
+  public:
+    LinkLocalExample() : m_mdns( "js", this, m_log ), m_client( 0 ), m_fClient( 0 ), m_disconnect( false ), m_ok( false ) {}
+
+    virtual ~LinkLocalExample()
+    {
+      delete m_client;
+      delete m_fClient;
+    }
+
+    void start()
+    {
+      m_mdns.registerLinkLocalHandler( this );
+      m_mdns.addTXTData("nick","foo");
+      m_mdns.addTXTData("1st","Firstname");
+      m_mdns.addTXTData("last","Lastname");
+      m_mdns.addTXTData("msg","Hanging out");
+      m_mdns.addTXTData("jid","me@there.com");
+      m_mdns.addTXTData("status","avail");
+      m_mdns.registerService();
+      if( !m_mdns.startBrowsing() )
+      {
+        printf( "startBrowsing() failed\n" );
+        return;
+      }
+      int count = 0;
+      int fCount = 0;
+      while( true )
+      {
+        m_mdns.recv( 1000 );
+        if ( m_disconnect )
+        {
+          delete m_client;
+          m_client = 0;
+          delete m_fClient;
+          m_fClient = 0;
+          m_disconnect = false;
+        }
+        if( m_client )
+        {
+          m_client->recv( 1000 );
+          if( m_ok && count == 1000 )
+          {
+            count = 0;
+            Message m( Message::Chat, JID( "user@Nokia-N900" ), "hey again!" );
+            m_client->send( m );
+          }
+          ++count;
+        }
+        if( m_fClient )
+        {
+          m_fClient->recv( 1000 );
+          if( fCount == 1000 )
+          {
+            fCount = 0;
+            Message m( Message::Chat, JID( "user@Nokia-N900" ), "hey there!" );
+            m_fClient->send( m );
+          }
+          ++fCount;
+        }
+        //         printf( "ok\n" );
+      }
+    }
+
+    virtual void handleBrowseReply( const LinkLocal::ServiceList& services )
+    {
+      LinkLocal::ServiceList::const_iterator it = services.begin();
+      for( ; it != services.end(); ++it )
+      {
+        printf( "%s:\t%s.%s%s on interface %d\n", (*it).flag == LinkLocal::AddService ? "Added" : "Removed", (*it).service.c_str(), (*it).regtype.c_str(),
+                (*it).domain.c_str(), (*it).interface );
+        if( !m_fClient /*&& (*it)->flag == LinkLocal::AddService && (*it)->service != "js@pitufo"*/ )
+        {
+          printf( "setting up new local client and connecting to %s.%s%s on interface %d\n",
+                  (*it).service.c_str(), (*it).regtype.c_str(), (*it).domain.c_str(), (*it).interface );
+          m_fClient = new LinkLocal::Client( JID( "js@pitufo" ) );
+          m_fClient->logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this );
+          m_fClient->registerConnectionListener( this );
+          if( !m_fClient->connect( (*it).service, (*it).regtype, (*it).domain, (*it).interface ) )
+          {
+            printf( "m_fClient->connect() failed\n" );
+          }
+        }
+      }
+    }
+
+    virtual void handleLog( LogLevel level, LogArea area, const std::string& message )
+    {
+      printf("log: level: %d, area: %d, %s\n", level, area, message.c_str() );
+    }
+
+    virtual void handleIncomingConnection( ConnectionBase* /*server*/, ConnectionBase* connection )
+    {
+      printf( "incoming connection on port %d!\n", connection->localPort() );
+      m_client = new LinkLocal::Client( JID( "js@pitufo" ) );
+      m_client->logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this );
+      connection->registerConnectionDataHandler( m_client );
+      m_client->setConnectionImpl( connection );
+      m_client->registerMessageHandler( this );
+      m_client->registerConnectionListener( this );
+      m_client->connect();
+    }
+    
+    virtual void handleMessage( const Message& msg, MessageSession* /*session*/ = 0 )
+    {
+      m_ok = true;
+      printf( "Message received: %s\n", msg.body().c_str() );
+      Message m( Message::Chat, msg.from(), "hey!" );
+      m_client->send( m );
+    }
+    
+    virtual void onConnect() {}
+    
+    virtual void onDisconnect( ConnectionError e )
+    {
+      printf( "onDisconnect\n" );
+      m_disconnect = true;
+    }
+
+//     virtual void handleClient( LinkLocal::Client* client )
+//     {
+//       if( !client)
+//         return;
+// 
+//       printf( "received LinkLocalClient, connect() successful!\n" );
+//       client->logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this );
+//       client->registerMessageHandler( this );
+//       client->registerConnectionListener( this );
+//       Message msg( Message::Chat, JID( "user@Nokia-N900" ), "hex" );
+//       client->send( msg );
+//       if( m_client )
+//         delete m_client;
+//       m_client = client;
+//     }
+    
+    virtual void onResourceBind( const std::string& resource ) { (void)resource; }
+    
+    virtual void onResourceBindError( const Error* error ) { (void) (error); }
+    
+    virtual void onSessionCreateError( const Error* error ) { (void) (error); }
+    
+    virtual bool onTLSConnect( const CertInfo& info ) { return true; }
+    
+    virtual void onStreamEvent( StreamEvent event ) { (void) (event); }
+private:
+    LogSink m_log;
+    LinkLocal::Manager m_mdns;
+    LinkLocal::Client* m_client;
+    LinkLocal::Client* m_fClient;
+    bool m_disconnect;
+    bool m_ok;
+  
+};
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  LinkLocalExample *r = new LinkLocalExample();
+  r->start();
+  while( true )
+    sleep(15);
+  delete( r );
+  return 0;
+}
+
+#else
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  printf( "Link-local support not compiled in\n" );
+  return 0;
+}
+
+
+#endif // HAVE_MDNS

=== added file 'src/examples/reconnect_example.cpp'
--- src/examples/reconnect_example.cpp	1970-01-01 00:00:00 +0000
+++ src/examples/reconnect_example.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,193 @@
+#define CLIENT_TEST
+#define CLIENTBASE_TEST
+#include "../client.h"
+#include "../messagesessionhandler.h"
+#include "../messageeventhandler.h"
+#include "../messageeventfilter.h"
+#include "../chatstatehandler.h"
+#include "../chatstatefilter.h"
+#include "../connectionlistener.h"
+#include "../disco.h"
+#include "../message.h"
+#include "../gloox.h"
+#include "../lastactivity.h"
+#include "../loghandler.h"
+#include "../logsink.h"
+#include "../connectiontcpclient.h"
+#include "../connectionsocks5proxy.h"
+#include "../connectionhttpproxy.h"
+#include "../messagehandler.h"
+using namespace gloox;
+
+#ifndef _WIN32
+# include <unistd.h>
+#endif
+
+#include <stdio.h>
+#include <string>
+
+#include <cstdio> // [s]print[f]
+
+#if defined( WIN32 ) || defined( _WIN32 )
+# include <windows.h>
+#endif
+
+class MessageTest : public MessageSessionHandler, ConnectionListener, LogHandler,
+                    MessageEventHandler, MessageHandler, ChatStateHandler
+{
+  public:
+    MessageTest() : m_session( 0 ), m_reconnect( false ) {}
+
+    virtual ~MessageTest() {}
+
+    void start()
+    {
+
+      JID jid( "admin@jabba.us/gloox" );
+      j = new Client( jid, "test" );
+      j->registerConnectionListener( this );
+      j->registerMessageSessionHandler( this, 0 );
+      j->disco()->setVersion( "reconnectTest", GLOOX_VERSION, "Linux" );
+      j->disco()->setIdentity( "client", "bot" );
+      j->disco()->addFeature( XMLNS_CHAT_STATES );
+//       j->setTls( TLSDisabled );
+      j->setCompression( false );
+      j->setStreamManagement( true, true );
+      StringList ca;
+      ca.push_back( "/path/to/cacert.crt" );
+      j->setCACerts( ca );
+
+      j->logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this );
+
+//
+// this code connects to a jabber server through a SOCKS5 proxy
+//
+//       ConnectionSOCKS5Proxy* conn = new ConnectionSOCKS5Proxy( j,
+//                                   new ConnectionTCP( j->logInstance(),
+//                                                      "sockshost", 1080 ),
+//                                   j->logInstance(), "example.net" );
+//       conn->setProxyAuth( "socksuser", "sockspwd" );
+//       j->setConnectionImpl( conn );
+
+//
+// this code connects to a jabber server through a HTTP proxy through a SOCKS5 proxy
+//
+//       ConnectionTCP* conn0 = new ConnectionTCP( j->logInstance(), "old", 1080 );
+//       ConnectionSOCKS5Proxy* conn1 = new ConnectionSOCKS5Proxy( conn0, j->logInstance(), "old", 8080 );
+//       conn1->setProxyAuth( "socksuser", "sockspwd" );
+//       ConnectionHTTPProxy* conn2 = new ConnectionHTTPProxy( j, conn1, j->logInstance(), "jabber.cc" );
+//       conn2->setProxyAuth( "httpuser", "httppwd" );
+//       j->setConnectionImpl( conn2 );
+
+
+      ConnectionError ce = ConnNoError;
+      if( j->connect( false ) )
+      {
+        while( ce == ConnNoError )
+        {
+          ce = j->recv();
+        }
+        printf( "ce: %d\n", ce );
+      }
+
+      m_reconnect = true;
+      ce = ConnNoError;
+      if( j->connect( false ) )
+      {
+        while( ce == ConnNoError )
+        {
+          ce = j->recv();
+        }
+        printf( "ce: %d\n", ce );
+      }
+
+      delete( j );
+    }
+
+    virtual void onConnect()
+    {
+      printf( "connected!!!\n" );
+    }
+
+    virtual void onDisconnect( ConnectionError e )
+    {
+      printf( "message_test: disconnected: %d\n", e );
+      if( e == ConnAuthenticationFailed )
+        printf( "auth failed. reason: %d\n", j->authError() );
+    }
+
+    virtual bool onTLSConnect( const CertInfo& info )
+    {
+      time_t from( info.date_from );
+      time_t to( info.date_to );
+
+      printf( "status: %d\nissuer: %s\npeer: %s\nprotocol: %s\nmac: %s\ncipher: %s\ncompression: %s\n"
+              "from: %s\nto: %s\n",
+              info.status, info.issuer.c_str(), info.server.c_str(),
+              info.protocol.c_str(), info.mac.c_str(), info.cipher.c_str(),
+              info.compression.c_str(), ctime( &from ), ctime( &to ) );
+      return true;
+    }
+
+    virtual void handleMessage( const Message& msg, MessageSession * /*session*/ )
+    {
+      printf( "type: %d, subject: %s, message: %s, thread id: %s\n", msg.subtype(),
+              msg.subject().c_str(), msg.body().c_str(), msg.thread().c_str() );
+
+
+      if( msg.body().substr( 0, 3 ) == "ack" ) // using substr() to work around some stupid clients
+        j->ackStreamManagement();
+      else if( msg.body().substr( 0, 3 ) == "req" )
+        j->reqStreamManagement();
+      else if( msg.body().substr( 0, 4 ) == "quit" )
+        j->disconnect();
+      else
+      {
+        std::string re = "You said:\n> " + msg.body() + "\nI like that statement.";
+        m_session->send( re, gloox::EmptyString );
+      }
+    }
+
+    virtual void handleMessageEvent( const JID& from, MessageEventType event )
+    {
+      printf( "received event: %d from: %s\n", event, from.full().c_str() );
+    }
+
+    virtual void handleChatState( const JID& from, ChatStateType state )
+    {
+      printf( "received state: %d from: %s\n", state, from.full().c_str() );
+    }
+
+    virtual void handleMessageSession( MessageSession *session )
+    {
+      printf( "got new session\n");
+      // this example can handle only one session. so we get rid of the old session
+      j->disposeMessageSession( m_session );
+      m_session = session;
+      m_session->registerMessageHandler( this );
+    }
+
+    virtual void handleLog( LogLevel level, LogArea area, const std::string& message )
+    {
+      printf("log: level: %d, area: %d, %s\n", level, area, message.c_str() );
+
+      if( message.substr( 0, 10 ) == "<stream:er" )
+        printf( "something's foul\n" );
+
+      if( !m_reconnect && j->m_smHandled > 10 )
+        j->disconnect( ConnTlsFailed ); // fake disconnect reason so that no </stream:stream> is sent
+    }
+
+  private:
+    Client *j;
+    MessageSession *m_session;
+    bool m_reconnect;
+};
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  MessageTest *r = new MessageTest();
+  r->start();
+  delete( r );
+  return 0;
+}

=== modified file 'src/examples/register_example.cpp'
--- src/examples/register_example.cpp	2010-01-17 13:05:04 +0000
+++ src/examples/register_example.cpp	2014-01-16 10:42:06 +0000
@@ -36,7 +36,7 @@
 
 // be sure to read the API documentation for class Registration!
 
-      j = new Client( "example.net" );
+      j = new Client( "jabba.us" );
       j->disableRoster();
       j->registerConnectionListener( this );
 
@@ -78,8 +78,8 @@
     {
       printf( "fields: %d\ninstructions: %s\n", fields, instructions.c_str() );
       RegistrationFields vals;
-      vals.username = "testuser";
-      vals.password = "testpwd";
+      vals.username = "cotest2";
+      vals.password = "test2";
       m_reg->createAccount( fields, vals );
     }
 

=== modified file 'src/examples/roster_example.cpp'
--- src/examples/roster_example.cpp	2010-01-17 13:05:04 +0000
+++ src/examples/roster_example.cpp	2014-01-16 10:42:06 +0000
@@ -97,7 +97,7 @@
       for( ; it != roster.end(); ++it )
       {
         printf( "jid: %s, name: %s, subscription: %d\n",
-                (*it).second->jid().c_str(), (*it).second->name().c_str(),
+                (*it).second->jidJID().full().c_str(), (*it).second->name().c_str(),
                 (*it).second->subscription() );
         StringList g = (*it).second->groups();
         StringList::const_iterator it_g = g.begin();
@@ -117,13 +117,13 @@
     virtual void handleRosterPresence( const RosterItem& item, const std::string& resource,
                                        Presence::PresenceType presence, const std::string& /*msg*/ )
     {
-      printf( "presence received: %s/%s -- %d\n", item.jid().c_str(), resource.c_str(), presence );
+      printf( "presence received: %s/%s -- %d\n", item.jidJID().full().c_str(), resource.c_str(), presence );
     }
 
     virtual void handleSelfPresence( const RosterItem& item, const std::string& resource,
                                        Presence::PresenceType presence, const std::string& /*msg*/ )
     {
-      printf( "self presence received: %s/%s -- %d\n", item.jid().c_str(), resource.c_str(), presence );
+      printf( "self presence received: %s/%s -- %d\n", item.jidJID().full().c_str(), resource.c_str(), presence );
     }
 
     virtual bool handleSubscriptionRequest( const JID& jid, const std::string& /*msg*/ )

=== modified file 'src/featureneg.cpp'
--- src/featureneg.cpp	2010-01-17 13:05:04 +0000
+++ src/featureneg.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/featureneg.h'
--- src/featureneg.h	2010-01-17 13:05:04 +0000
+++ src/featureneg.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class Tag;
 
   /**
-   * @brief An abstraction of Feature Negotiation (XEP-0020), implemented
+   * @brief An abstraction of Feature Negotiation (@xep{0020}), implemented
    * as a StanzaExtension.
    *
    * XEP Version: 1.5

=== modified file 'src/flexoff.cpp'
--- src/flexoff.cpp	2010-01-17 13:05:04 +0000
+++ src/flexoff.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/flexoff.h'
--- src/flexoff.h	2010-01-17 13:05:04 +0000
+++ src/flexoff.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,7 +24,7 @@
 {
 
   /**
-   * @brief An implementation of XEP-0013 (Flexible Offline Message Retrieval).
+   * @brief An implementation of @xep{0013} (Flexible Offline Message Retrieval).
    *
    * Use the FlexibleOfflineHandler to receive results.
    *
@@ -84,7 +84,7 @@
         { messageOperation( FORemoveMsgs, msgs ); }
 
       /**
-       * Registers a FlexibleOfflineHandler as object that receives results of XEP-0013 queries.
+       * Registers a FlexibleOfflineHandler as object that receives results of @xep{0013} queries.
        * Only one Handler at a time is possible.
        * @param foh The Handler object to register.
        */

=== modified file 'src/flexoffhandler.h'
--- src/flexoffhandler.h	2010-01-17 13:05:04 +0000
+++ src/flexoffhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,12 +30,12 @@
     FomrForbidden,               /**< The requester is a JID other than an authorized resource of the
                                   * user. Something wnet serieously wrong */
     FomrItemNotFound,            /**< The requested node (message ID) does not exist. */
-    FomrUnknownError             /**< An error occurred which is not specified in XEP-0013. */
+    FomrUnknownError             /**< An error occurred which is not specified in @xep{0013}. */
   };
 
   /**
    * @brief Implementation of this virtual interface allows for retrieval of offline messages following
-   * XEP-0030.
+   * @xep{0030}.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 0.7
@@ -49,9 +49,9 @@
       virtual ~FlexibleOfflineHandler() {}
 
       /**
-       * This function is called to indicate whether the server supports XEP-0013 or not.
+       * This function is called to indicate whether the server supports @xep{0013} or not.
        * Call @ref FlexibleOffline::checkSupport() to trigger the check.
-       * @param support Whether the server support XEP-0013 or not.
+       * @param support Whether the server support @xep{0013} or not.
        */
       virtual void handleFlexibleOfflineSupport( bool support ) = 0;
 

=== added file 'src/forward.cpp'
--- src/forward.cpp	1970-01-01 00:00:00 +0000
+++ src/forward.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,85 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "forward.h"
+
+#include "delayeddelivery.h"
+#include "message.h"
+#include "stanza.h"
+#include "util.h"
+
+namespace gloox
+{
+
+  Forward::Forward( Stanza *stanza, DelayedDelivery *delay )
+    : StanzaExtension( ExtForward ),
+      m_stanza( stanza ), m_tag( 0 ), m_delay( delay )
+  {
+  }
+
+  Forward::Forward( const Tag* tag )
+    : StanzaExtension( ExtForward ),
+      m_stanza( 0 ), m_tag( 0 ), m_delay( 0 )
+  {
+    if( !tag || !( tag->name() == "forwarded" && tag->hasAttribute( XMLNS, XMLNS_STANZA_FORWARDING ) ) )
+      return;
+
+    m_delay = new DelayedDelivery( tag->findChild( "delay", XMLNS, XMLNS_DELAY ) );
+
+    Tag* m = tag->findChild( "message" );
+    if( !m )
+      return;
+
+    m_tag = m->clone();
+    m_stanza = new Message( m );
+  }
+
+  Forward::~Forward()
+  {
+    delete m_delay;
+    delete m_stanza;
+    delete m_tag;
+  }
+
+  const std::string& Forward::filterString() const
+  {
+    static const std::string filter = "/message/forwarded[@xmlns='" + XMLNS_STANZA_FORWARDING + "']"
+                                      "|/iq/forwarded[@xmlns='" + XMLNS_STANZA_FORWARDING + "']"
+                                      "|/presence/forwarded[@xmlns='" + XMLNS_STANZA_FORWARDING + "']";
+    return filter;
+  }
+
+  Tag* Forward::tag() const
+  {
+    if( !m_stanza )
+      return 0;
+
+    Tag* f = new Tag( "forwarded" );
+    f->setXmlns( XMLNS_STANZA_FORWARDING );
+    if( m_delay )
+      f->addChild( m_delay->tag() );
+    if( m_stanza )
+      f->addChild( m_stanza->tag() );
+
+    return f;
+  }
+
+  StanzaExtension* Forward::clone() const
+  {
+    if( !m_tag || !m_delay )
+      return 0;
+
+    return new Forward( new Message( m_tag ), static_cast<DelayedDelivery*>( m_delay->clone() ) );
+  }
+
+}

=== added file 'src/forward.h'
--- src/forward.h	1970-01-01 00:00:00 +0000
+++ src/forward.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,104 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef FORWARD_H__
+#define FORWARD_H__
+
+#include "stanzaextension.h"
+
+#include <string>
+
+namespace gloox
+{
+
+  class DelayedDelivery;
+  class Stanza;
+
+  /**
+   * @brief This is an implementation of Stanza Forwarding (@xep{0297}) as a StanzaExtension.
+   *
+   * @note At this point, Forward can only hold forwarded Messages, not IQ or Presence.
+   * However, Forward can be used inside any type of stanza (&lt;message&gt;, &lt;iq&gt;,
+   * or &lt;presence&gt;).
+   * 
+   * XEP-Version: 0.5
+   *
+   * @author Jakob Schroeter <js@camaya.net>
+   * @author Fernando Sanchez
+   * @since 1.0.5
+   */
+  class GLOOX_API Forward : public StanzaExtension
+  {
+    public:
+
+      /**
+       * Creates a forwarding StanzaExtension, embedding the given Stanza and DelayedDelivery objects.
+       * @param stanza The forwarded Stanza. This Forward instance will own the Stanza object.
+       * @param delay The date/time the forwarded stanza was received at by the forwarder. This
+       * Forward instance will own the DelayedDelivery object.
+       */
+      Forward( Stanza* stanza, DelayedDelivery* delay );
+      
+      /**
+       * Creates a forwarding Stanza from the given Tag. The original Tag will be ripped off.
+       * If a valid Stanza is conatined (as a child) in the Tag it will be parsed, too.
+       * It can then be accessed through embeddedStanza(). The Tag that the Stanza was built from
+       * is available through embeddedTag().
+       * @param tag The Tag to parse.
+       */
+      Forward( const Tag* tag = 0 );
+
+      /**
+       * Virtual destructor.
+       */
+      virtual ~Forward();
+
+      /**
+       * This function returns a pointer to a DelayedDelivery StanzaExtension which indicates
+       * when the forwarder originally received the forwarded stanza.
+       * 
+       * @return A pointer to a DelayedDelivery object. May be 0.
+       */
+      const DelayedDelivery* when() const { return m_delay; }
+
+      // reimplemented from Stanza
+      virtual Stanza* embeddedStanza() const { return m_stanza; }
+      
+      // reimplemented from Stanza
+      virtual Tag* embeddedTag() const { return m_tag; }
+      
+      // reimplemented from Stanza
+      virtual Tag* tag() const;
+
+      // reimplemented from Stanza
+      const std::string& filterString() const;
+      
+      // reimplemented from Stanza
+      StanzaExtension* newInstance( const Tag* tag ) const
+      {
+        return new Forward( tag );
+      }
+
+      // reimplemented from Stanza
+      StanzaExtension* clone() const;
+
+    private:
+      Stanza* m_stanza;
+      Tag* m_tag;
+      DelayedDelivery* m_delay;
+
+  };
+
+}
+
+#endif // FORWARD_H__

=== modified file 'src/gloox.cpp'
--- src/gloox.cpp	2010-01-17 13:05:04 +0000
+++ src/gloox.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,50 +25,50 @@
   const std::string XMLNS_DISCO_PUBLISH     = "http://jabber.org/protocol/disco#publish";
   const std::string XMLNS_ADHOC_COMMANDS    = "http://jabber.org/protocol/commands";
   const std::string XMLNS_COMPRESSION       = "http://jabber.org/protocol/compress";
+
   const std::string XMLNS_OFFLINE           = "http://jabber.org/protocol/offline";
-
   const std::string XMLNS_CHAT_STATES       = "http://jabber.org/protocol/chatstates";
   const std::string XMLNS_AMP               = "http://jabber.org/protocol/amp";
   const std::string XMLNS_IBB               = "http://jabber.org/protocol/ibb";
   const std::string XMLNS_FEATURE_NEG       = "http://jabber.org/protocol/feature-neg";
+
   const std::string XMLNS_CHATNEG           = "http://jabber.org/protocol/chatneg";
-
   const std::string XMLNS_XHTML_IM          = "http://jabber.org/protocol/xhtml-im";
   const std::string XMLNS_DELAY             = "urn:xmpp:delay";
   const std::string XMLNS_ROSTER            = "jabber:iq:roster";
   const std::string XMLNS_VERSION           = "jabber:iq:version";
+
   const std::string XMLNS_REGISTER          = "jabber:iq:register";
-
   const std::string XMLNS_PRIVACY           = "jabber:iq:privacy";
   const std::string XMLNS_AUTH              = "jabber:iq:auth";
   const std::string XMLNS_PRIVATE_XML       = "jabber:iq:private";
   const std::string XMLNS_LAST              = "jabber:iq:last";
+
   const std::string XMLNS_SEARCH            = "jabber:iq:search";
-
   const std::string XMLNS_IQ_OOB            = "jabber:iq:oob";
   const std::string XMLNS_X_DATA            = "jabber:x:data";
   const std::string XMLNS_X_EVENT           = "jabber:x:event";
   const std::string XMLNS_X_OOB             = "jabber:x:oob";
+
   const std::string XMLNS_X_DELAY           = "jabber:x:delay";
-
   const std::string XMLNS_X_GPGSIGNED       = "jabber:x:signed";
   const std::string XMLNS_X_GPGENCRYPTED    = "jabber:x:encrypted";
   const std::string XMLNS_VCARD_TEMP        = "vcard-temp";
   const std::string XMLNS_X_VCARD_UPDATE    = "vcard-temp:x:update";
+
   const std::string XMLNS_BOOKMARKS         = "storage:bookmarks";
-
   const std::string XMLNS_ANNOTATIONS       = "storage:rosternotes";
   const std::string XMLNS_ROSTER_DELIMITER  = "roster:delimiter";
   const std::string XMLNS_XMPP_PING         = "urn:xmpp:ping";
   const std::string XMLNS_SI                = "http://jabber.org/protocol/si";
+
   const std::string XMLNS_SI_FT             = "http://jabber.org/protocol/si/profile/file-transfer";
-
   const std::string XMLNS_BYTESTREAMS       = "http://jabber.org/protocol/bytestreams";
   const std::string XMLNS_MUC               = "http://jabber.org/protocol/muc";
   const std::string XMLNS_MUC_USER          = "http://jabber.org/protocol/muc#user";
   const std::string XMLNS_MUC_ADMIN         = "http://jabber.org/protocol/muc#admin";
+
   const std::string XMLNS_MUC_UNIQUE        = "http://jabber.org/protocol/muc#unique";
-
   const std::string XMLNS_MUC_OWNER         = "http://jabber.org/protocol/muc#owner";
   const std::string XMLNS_MUC_ROOMINFO      = "http://jabber.org/protocol/muc#roominfo";
   const std::string XMLNS_MUC_ROOMS         = "http://jabber.org/protocol/muc#rooms";
@@ -78,39 +78,43 @@
   const std::string XMLNS_PUBSUB_ERRORS     = "http://jabber.org/protocol/pubsub#errors";
   const std::string XMLNS_PUBSUB_EVENT      = "http://jabber.org/protocol/pubsub#event";
   const std::string XMLNS_PUBSUB_OWNER      = "http://jabber.org/protocol/pubsub#owner";
-
   const std::string XMLNS_CAPS              = "http://jabber.org/protocol/caps";
+
   const std::string XMLNS_FT_FASTMODE       = "http://affinix.com/jabber/stream";
-
   const std::string XMLNS_STREAM            = "http://etherx.jabber.org/streams";
   const std::string XMLNS_XMPP_STREAM       = "urn:ietf:params:xml:ns:xmpp-streams";
   const std::string XMLNS_XMPP_STANZAS      = "urn:ietf:params:xml:ns:xmpp-stanzas";
   const std::string XMLNS_STREAM_TLS        = "urn:ietf:params:xml:ns:xmpp-tls";
+
   const std::string XMLNS_STREAM_SASL       = "urn:ietf:params:xml:ns:xmpp-sasl";
-
   const std::string XMLNS_STREAM_BIND       = "urn:ietf:params:xml:ns:xmpp-bind";
   const std::string XMLNS_STREAM_SESSION    = "urn:ietf:params:xml:ns:xmpp-session";
   const std::string XMLNS_STREAM_IQAUTH     = "http://jabber.org/features/iq-auth";
   const std::string XMLNS_STREAM_IQREGISTER = "http://jabber.org/features/iq-register";
+
   const std::string XMLNS_STREAM_COMPRESS   = "http://jabber.org/features/compress";
-
   const std::string XMLNS_HTTPBIND          = "http://jabber.org/protocol/httpbind";
   const std::string XMLNS_XMPP_BOSH         = "urn:xmpp:xbosh";
   const std::string XMLNS_RECEIPTS          = "urn:xmpp:receipts";
   const std::string XMLNS_NICKNAME          = "http://jabber.org/protocol/nick";
 
-  const std::string XMLNS_JINGLE            = "urn:xmpp:tmp:jingle";
-  const std::string XMLNS_JINGLE_AUDIO_RTP  = "urn:xmpp:tmp:jingle:apps:audio-rtp";
-  const std::string XMLNS_JINGLE_ICE_UDP    = "urn:xmpp:tmp:jingle:transports:ice-udp";
-  const std::string XMLNS_JINGLE_RAW_UDP    = "urn:xmpp:tmp:jingle:transports:raw-udp";
-  const std::string XMLNS_JINGLE_VIDEO_RTP  = "urn:xmpp:tmp:jingle:apps:video-rtp";
+  const std::string XMLNS_JINGLE            = "urn:xmpp:jingle:1";
+  const std::string XMLNS_JINGLE_ERRORS     = "urn:xmpp:jingle:errors:1";
+  const std::string XMLNS_JINGLE_ICE_UDP    = "urn:xmpp:jingle:transports:ice-udp:1";
+  const std::string XMLNS_JINGLE_FILE_TRANSFER = "urn:xmpp:jingle:apps:file-transfer:3";
+  const std::string XMLNS_JINGLE_FILE_TRANSFER_MULTI = "urn:xmpp:jingle:apps:file-transfer:multi";
 
   const std::string XMLNS_SHIM              = "http://jabber.org/protocol/shim";
   const std::string XMLNS_ATTENTION         = "urn:xmpp:attention:0";
+  const std::string XMLNS_STREAM_MANAGEMENT = "urn:xmpp:sm:3";
+  const std::string XMLNS_STANZA_FORWARDING = "urn:xmpp:forward:0";
+  const std::string XMLNS_MESSAGE_CARBONS   = "urn:xmpp:carbons:2";
+
+  const std::string XMLNS_HASHES            = "urn:xmpp:hashes:1";
 
   const std::string XMPP_STREAM_VERSION_MAJOR = "1";
   const std::string XMPP_STREAM_VERSION_MINOR = "0";
-  const std::string GLOOX_VERSION           = "1.0";
+  const std::string GLOOX_VERSION           = "1.0.9";
   const std::string GLOOX_CAPS_NODE         = "http://camaya.net/gloox";
 
   const std::string XMLNS = "xmlns";

=== modified file 'src/gloox.h'
--- src/gloox.h	2010-01-17 13:05:04 +0000
+++ src/gloox.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -115,7 +115,7 @@
  *
  * A component in the Jabber/XMPP network is an add-on to a server which runs externally
  * to the actual server software, but can have similar privileges. Components use a protocol described in
- * XEP-0114 to connect and authenticate to a server.
+ * @xep{0114} to connect and authenticate to a server.
  *
  * The @link gloox::Component Component @endlink class supports this protocol and can be used to create
  * a new Jabber component. It's as simple as:
@@ -262,7 +262,7 @@
  *
  * @section auth_sec Authentication
  *
- * gloox supports old-style IQ-based authentication defined in XEP-0078 as well as several SASL mechanisms.
+ * gloox supports old-style IQ-based authentication defined in @xep{0078} as well as several SASL mechanisms.
  * See the documentation of the @link gloox::Client Client @endlink class for more information.
  *
  * @section msg_sec Sending and Receiving of Chat Messages
@@ -276,58 +276,65 @@
  * The XMPP Standards Foundation has published a number of extensions to the core protocols, called
  * XMPP Extension Protocols (XEPs). A couple of these XEPs are implemented in gloox:
  *
- * @li XEP-0004 @link gloox::DataForm Data Forms @endlink
- * @li XEP-0012 @link gloox::LastActivity  Last Activity @endlink
- * @li XEP-0013 @link gloox::FlexibleOffline Flexible Offline Message Retrieval @endlink
- * @li XEP-0022 Message Events (see @link gloox::MessageSession MessageSession @endlink for examples)
- * @li XEP-0027 Current Jabber OpenPGP Usage (see @link gloox::GPGSigned GPGSigned @endlink
+ * @li @xep{0004} @link gloox::DataForm Data Forms @endlink
+ * @li @xep{0012} @link gloox::LastActivity  Last Activity @endlink
+ * @li @xep{0013} @link gloox::FlexibleOffline Flexible Offline Message Retrieval @endlink
+ * @li @xep{0022} Message Events (see @link gloox::MessageSession MessageSession @endlink for examples)
+ * @li @xep{0027} Current Jabber OpenPGP Usage (see @link gloox::GPGSigned GPGSigned @endlink
  * and @link gloox::GPGEncrypted GPGEncrypted @endlink)
- * @li XEP-0030 @link gloox::Disco Service Discovery @endlink
- * @li XEP-0045 @link gloox::MUCRoom Multi-User Chat @endlink
- * @li XEP-0047 Used with @ref filetransfer_sec
- * @li XEP-0048 @link gloox::BookmarkStorage Bookmark Storage @endlink
- * @li XEP-0049 @link gloox::PrivateXML Private XML Storage @endlink
- * @li XEP-0050 @link gloox::Adhoc Ad-hoc Commands @endlink
- * @li XEP-0054 @link gloox::VCardManager vcard-temp @endlink
- * @li XEP-0060 @link gloox::PubSub::Manager Publish-Subscribe @endlink
- * @li XEP-0065 @link gloox::SOCKS5BytestreamManager SOCKS5 Bytestreams @endlink, used with
+ * @li @xep{0030} @link gloox::Disco Service Discovery @endlink
+ * @li @xep{0045} @link gloox::MUCRoom Multi-User Chat @endlink
+ * @li @xep{0047} Used with @ref filetransfer_sec
+ * @li @xep{0048} @link gloox::BookmarkStorage Bookmark Storage @endlink
+ * @li @xep{0049} @link gloox::PrivateXML Private XML Storage @endlink
+ * @li @xep{0050} @link gloox::Adhoc Ad-hoc Commands @endlink
+ * @li @xep{0054} @link gloox::VCardManager vcard-temp @endlink
+ * @li @xep{0060} @link gloox::PubSub::Manager Publish-Subscribe @endlink
+ * @li @xep{0065} @link gloox::SOCKS5BytestreamManager SOCKS5 Bytestreams @endlink, used with
  * @ref filetransfer_sec and @ref proxy_sec
- * @li XEP-0066 @link gloox::OOB Out of Band Data @endlink, also used with @ref filetransfer_sec
- * @li XEP-0077 @link gloox::Registration In-Band Registration @endlink
- * @li XEP-0078 Non-SASL Authentication (automatically used if the server does not support SASL)
- * @li XEP-0079 @link gloox::AMP Advanced Message Processing @endlink
- * @li XEP-0083 Nested Roster Groups (automatically used if supported by the server. see
+ * @li @xep{0066} @link gloox::OOB Out of Band Data @endlink, also used with @ref filetransfer_sec
+ * @li @xep{0077} @link gloox::Registration In-Band Registration @endlink
+ * @li @xep{0078} Non-SASL Authentication (automatically used if the server does not support SASL)
+ * @li @xep{0079} @link gloox::AMP Advanced Message Processing @endlink
+ * @li @xep{0083} Nested Roster Groups (automatically used if supported by the server. see
  * @link gloox::RosterManager::delimiter() RosterManager @endlink)
- * @li XEP-0085 Chat State Notifications (see @link gloox::MessageSession MessageSession @endlink for
+ * @li @xep{0085} Chat State Notifications (see @link gloox::MessageSession MessageSession @endlink for
  * examples)
- * @li XEP-0091 @link gloox::DelayedDelivery Delayed Delivery @endlink (old spec)
- * @li XEP-0092 Software Version (integrated into @link gloox::Disco Service Discovery @endlink)
- * @li XEP-0095 @link gloox::SIManager Stream Initiation @endlink, used with @ref filetransfer_sec
- * @li XEP-0096 @ref filetransfer_sec
- * @li XEP-0106 @link gloox::JID::escapeNode() JID Escaping @endlink
- * @li XEP-0114 @link gloox::Component Jabber Component Protocol @endlink
- * @li XEP-0115 @link gloox::Capabilities Entity Capabilities @endlink (used automatically internally)
- * @li XEP-0124 @link gloox::ConnectionBOSH Bidirectional-streams Over Synchronous HTTP (BOSH) @endlink
- * @li XEP-0131 @link gloox::SHIM Stanza Headers and Internet Metadata @endlink
- * @li XEP-0138 Stream Compression (used automatically if gloox is compiled with zlib and if the server
+ * @li @xep{0091} @link gloox::DelayedDelivery Delayed Delivery @endlink (old spec)
+ * @li @xep{0092} Software Version (integrated into @link gloox::Disco Service Discovery @endlink)
+ * @li @xep{0095} @link gloox::SIManager Stream Initiation @endlink, used with @ref filetransfer_sec
+ * @li @xep{0096} @ref filetransfer_sec
+ * @li @xep{0106} @link gloox::JID::escapeNode() JID Escaping @endlink
+ * @li @xep{0114} @link gloox::Component Jabber Component Protocol @endlink
+ * @li @xep{0115} @link gloox::Capabilities Entity Capabilities @endlink (used automatically internally)
+ * @li @xep{0124} @link gloox::ConnectionBOSH Bidirectional-streams Over Synchronous HTTP (BOSH) @endlink
+ * @li @xep{0131} @link gloox::SHIM Stanza Headers and Internet Metadata @endlink
+ * @li @xep{0138} Stream Compression (used automatically if gloox is compiled with zlib and if the server
  * supports it)
- * @li XEP-0145 @link gloox::Annotations Annotations @endlink
- * @li XEP-0153 @link gloox::VCardUpdate vCard-based Avatars @endlink
- * @li XEP-0172 @link gloox::Nickname User Nickname @endlink
- * @li XEP-0184 @link gloox::Receipt Message Receipts @endlink
- * @li XEP-0199 @link gloox::ClientBase::xmppPing() XMPP Ping @endlink
- * @li XEP-0203 @link gloox::DelayedDelivery Delayed Delivery @endlink (new spec)
- * @li XEP-0206 @link gloox::ConnectionBOSH see BOSH @endlink
- * @li XEP-0224 @link gloox::Attention Attention @endlink
- * @li XEP-0256 @link gloox::LastActivity::Query Last Activity in Presence @endlink
+ * @li @xep{0145} @link gloox::Annotations Annotations @endlink
+ * @li @xep{0153} @link gloox::VCardUpdate vCard-based Avatars @endlink
+ * @li @xep{0166} @link gloox::Jingle::SessionManager Jingle @endlink
+ * @li @xep{0172} @link gloox::Nickname User Nickname @endlink
+ * @li @xep{0174} @link gloox::LinkLocal::Manager Link-local Messaging @endlink
+ * @li @xep{0176} @link gloox::Jingle::ICEUDP Jingle ICE-UDP Transport Method @endlink
+ * @li @xep{0184} @link gloox::Receipt Message Receipts @endlink
+ * @li @xep{0198} Stream Management (integrated into @link gloox::Client @endlink)
+ * @li @xep{0199} @link gloox::ClientBase::xmppPing() XMPP Ping @endlink
+ * @li @xep{0203} @link gloox::DelayedDelivery Delayed Delivery @endlink (new spec)
+ * @li @xep{0206} @link gloox::ConnectionBOSH see BOSH @endlink
+ * @li @xep{0224} @link gloox::Attention Attention @endlink
+ * @li @xep{0234} @link gloox::Jingle::FileTransfer Jingle File Transfer @endlink
+ * @li @xep{0256} @link gloox::LastActivity::Query Last Activity in Presence @endlink
+ * @li @xep{0280} @link gloox::Carbons Message Carbons @endlink
+ * @li @xep{0297} @link gloox::Forward Stanza Forwarding @endlink
  *
  * Further extensions can easily be implemented using
  * @link gloox::StanzaExtension StanzaExtensions @endlink.
  *
  * @section filetransfer_sec File Transfer
  *
- * For file transfer, gloox implements XEP-0095 (Stream Initiation) as well XEP-0096 (File Transfer)
- * for the signalling, and XEP-0065 (SOCKS5 Bytestreams) as well as XEP-0047 (In-Band Bytestreams)
+ * For file transfer, gloox implements @xep{0095} (Stream Initiation) as well @xep{0096} (File Transfer)
+ * for the signalling, and @xep{0065} (SOCKS5 Bytestreams) as well as @xep{0047} (In-Band Bytestreams)
  * for the transport. See @link gloox::SIProfileFT SIProfileFT @endlink.
  *
  * @section proxy_sec HTTP and SOCKS5 Proxy support
@@ -362,160 +369,160 @@
   /** Client namespace (RFC 3920)*/
   GLOOX_API extern const std::string XMLNS_CLIENT;
 
-  /** Component Accept namespace (XEP-0114) */
+  /** Component Accept namespace (@xep{0114}) */
   GLOOX_API extern const std::string XMLNS_COMPONENT_ACCEPT;
 
-  /** Component Connect namespace (XEP-0114) */
+  /** Component Connect namespace (@xep{0114}) */
   GLOOX_API extern const std::string XMLNS_COMPONENT_CONNECT;
 
-  /** Service Discovery Info namespace (XEP-0030) */
+  /** Service Discovery Info namespace (@xep{0030}) */
   GLOOX_API extern const std::string XMLNS_DISCO_INFO;
 
-  /** Service Discovery Items namespace (XEP-0030) */
+  /** Service Discovery Items namespace (@xep{0030}) */
   GLOOX_API extern const std::string XMLNS_DISCO_ITEMS;
 
-  /** Service Discovery Publish namespace (XEP-0030) */
+  /** Service Discovery Publish namespace (@xep{0030}) */
   GLOOX_API extern const std::string XMLNS_DISCO_PUBLISH;
 
-  /** Adhoc Commands namespace (XEP-0050) */
+  /** Adhoc Commands namespace (@xep{0050}) */
   GLOOX_API extern const std::string XMLNS_ADHOC_COMMANDS;
 
-  /** Stream Compression namespace (XEP-0138) */
+  /** Stream Compression namespace (@xep{0138}) */
   GLOOX_API extern const std::string XMLNS_COMPRESSION;
 
-  /** Flexible Offline Message Retrieval (XEP-0013) */
+  /** Flexible Offline Message Retrieval (@xep{0013}) */
   GLOOX_API extern const std::string XMLNS_OFFLINE;
 
-  /** Chat State Notifications namespace (XEP-0085) */
+  /** Chat State Notifications namespace (@xep{0085}) */
   GLOOX_API extern const std::string XMLNS_CHAT_STATES;
 
-  /** Advanced Message Processing (XEP-0079) */
+  /** Advanced Message Processing (@xep{0079}) */
   GLOOX_API extern const std::string XMLNS_AMP;
 
-  /** In-Band Bytestreams namespace (XEP-0047) */
+  /** In-Band Bytestreams namespace (@xep{0047}) */
   GLOOX_API extern const std::string XMLNS_IBB;
 
-  /** Feature Negotiation namespace (XEP-0020) */
+  /** Feature Negotiation namespace (@xep{0020}) */
   GLOOX_API extern const std::string XMLNS_FEATURE_NEG;
 
-  /** Chat Session Negotiation namespace (XEP-0155) */
+  /** Chat Session Negotiation namespace (@xep{0155}) */
   GLOOX_API extern const std::string XMLNS_CHATNEG;
 
-  /** XHTML-IM namespace (XEP-0071) */
+  /** XHTML-IM namespace (@xep{0071}) */
   GLOOX_API extern const std::string XMLNS_XHTML_IM;
 
-  /** Delayed Delivery namespace (XEP-0203) */
+  /** Delayed Delivery namespace (@xep{0203}) */
   GLOOX_API extern const std::string XMLNS_DELAY;
 
   /** Roster namespace (RFC 3921) */
   GLOOX_API extern const std::string XMLNS_ROSTER;
 
-  /** Software Version namespace (XEP-0092) */
+  /** Software Version namespace (@xep{0092}) */
   GLOOX_API extern const std::string XMLNS_VERSION;
 
-  /** In-Band Registration namespace (XEP-0077) */
+  /** In-Band Registration namespace (@xep{0077}) */
   GLOOX_API extern const std::string XMLNS_REGISTER;
 
   /** Privacy lists namespace (RFC 3921) */
   GLOOX_API extern const std::string XMLNS_PRIVACY;
 
-  /** Non-SASL Authentication namespace (XEP-0078) */
+  /** Non-SASL Authentication namespace (@xep{0078}) */
   GLOOX_API extern const std::string XMLNS_AUTH;
 
-  /** Private XML Storage namespace (XEP-0049) */
+  /** Private XML Storage namespace (@xep{0049}) */
   GLOOX_API extern const std::string XMLNS_PRIVATE_XML;
 
-  /** Last Activity namespace (XEP-0012) */
+  /** Last Activity namespace (@xep{0012}) */
   GLOOX_API extern const std::string XMLNS_LAST;
 
-  /** Jabber Search namespace (XEP-0055) */
+  /** Jabber Search namespace (@xep{0055}) */
   GLOOX_API extern const std::string XMLNS_SEARCH;
 
-  /** Out of Band Data (IQ) namespace (XEP-0066) */
+  /** Out of Band Data (IQ) namespace (@xep{0066}) */
   GLOOX_API extern const std::string XMLNS_IQ_OOB;
 
-  /** Data Forms namespace (XEP-0004) */
+  /** Data Forms namespace (@xep{0004}) */
   GLOOX_API extern const std::string XMLNS_X_DATA;
 
-  /** Message Events (XEP-0022) */
+  /** Message Events (@xep{0022}) */
   GLOOX_API extern const std::string XMLNS_X_EVENT;
 
-  /** Out of Band Data (X) namespace (XEP-0066) */
+  /** Out of Band Data (X) namespace (@xep{0066}) */
   GLOOX_API extern const std::string XMLNS_X_OOB;
 
-  /** Delayed Delivery namespace (XEP-0091) */
+  /** Delayed Delivery namespace (@xep{0091}) */
   GLOOX_API extern const std::string XMLNS_X_DELAY;
 
-  /** Current Jabber OpenPGP Usage (Sign.) (XEP-0027) */
+  /** Current Jabber OpenPGP Usage (Sign.) (@xep{0027}) */
   GLOOX_API extern const std::string XMLNS_X_GPGSIGNED;
 
-  /** Current Jabber OpenPGP Usage (Enc.) (XEP-0027) */
+  /** Current Jabber OpenPGP Usage (Enc.) (@xep{0027}) */
   GLOOX_API extern const std::string XMLNS_X_GPGENCRYPTED;
 
-  /** vcard-temp namespace (XEP-0054) */
+  /** vcard-temp namespace (@xep{0054}) */
   GLOOX_API extern const std::string XMLNS_VCARD_TEMP;
 
-  /** vCard-Based Avatars namespace (XEP-0153) */
+  /** vCard-Based Avatars namespace (@xep{0153}) */
   GLOOX_API extern const std::string XMLNS_X_VCARD_UPDATE;
 
-  /** Bookmark Storage namespace (XEP-0048) */
+  /** Bookmark Storage namespace (@xep{0048}) */
   GLOOX_API extern const std::string XMLNS_BOOKMARKS;
 
-  /** Annotations namespace (XEP-0145) */
+  /** Annotations namespace (@xep{0145}) */
   GLOOX_API extern const std::string XMLNS_ANNOTATIONS;
 
-  /** Nested Roster Groups namespace (XEP-0083) */
+  /** Nested Roster Groups namespace (@xep{0083}) */
   GLOOX_API extern const std::string XMLNS_ROSTER_DELIMITER;
 
-  /** XMPP Ping namespace (XEP-0199) */
+  /** XMPP Ping namespace (@xep{0199}) */
   GLOOX_API extern const std::string XMLNS_XMPP_PING;
 
-  /** Stream Initiation namespace (XEP-0095) */
+  /** Stream Initiation namespace (@xep{0095}) */
   GLOOX_API extern const std::string XMLNS_SI;
 
-  /** File transfer profile of Stream Initiation (XEP-0096) */
+  /** File transfer profile of Stream Initiation (@xep{0096}) */
   GLOOX_API extern const std::string XMLNS_SI_FT;
 
-  /** SOCKS5 Bytestreams namespace (XEP-0065) */
+  /** SOCKS5 Bytestreams namespace (@xep{0065}) */
   GLOOX_API extern const std::string XMLNS_BYTESTREAMS;
 
-  /** Multi-User Chat namespace (XEP-0045) */
+  /** Multi-User Chat namespace (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC;
 
-  /** Multi-User Chat namespace (user) (XEP-0045) */
+  /** Multi-User Chat namespace (user) (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC_USER;
 
-  /** Multi-User Chat namespace (admin) (XEP-0045) */
+  /** Multi-User Chat namespace (admin) (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC_ADMIN;
 
-  /** Multi-User Chat namespace (unique) (XEP-0045) */
+  /** Multi-User Chat namespace (unique) (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC_UNIQUE;
 
-  /** Multi-User Chat namespace (owner) (XEP-0045) */
+  /** Multi-User Chat namespace (owner) (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC_OWNER;
 
-  /** Multi-User Chat namespace (roominfo) (XEP-0045) */
+  /** Multi-User Chat namespace (roominfo) (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC_ROOMINFO;
 
-  /** Multi-User Chat namespace (rooms) (XEP-0045) */
+  /** Multi-User Chat namespace (rooms) (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC_ROOMS;
 
-  /** Multi-User Chat namespace (request) (XEP-0045) */
+  /** Multi-User Chat namespace (request) (@xep{0045}) */
   GLOOX_API extern const std::string XMLNS_MUC_REQUEST;
 
-  /** PubSub namespace (XEP-0060) */
+  /** PubSub namespace (@xep{0060}) */
   GLOOX_API extern const std::string XMLNS_PUBSUB;
 
-  /** PubSub namespace (errors) (XEP-0060) */
+  /** PubSub namespace (errors) (@xep{0060}) */
   GLOOX_API extern const std::string XMLNS_PUBSUB_ERRORS;
 
-  /** PubSub namespace (event) (XEP-0060) */
+  /** PubSub namespace (event) (@xep{0060}) */
   GLOOX_API extern const std::string XMLNS_PUBSUB_EVENT;
 
-  /** PubSub namespace (owner) (XEP-0060) */
+  /** PubSub namespace (owner) (@xep{0060}) */
   GLOOX_API extern const std::string XMLNS_PUBSUB_OWNER;
 
-  /** Entity Capabilities namespace (XEP-0115) */
+  /** Entity Capabilities namespace (@xep{0115}) */
   GLOOX_API extern const std::string XMLNS_CAPS;
 
   /** SOCKS5 Fast Mode namespace */
@@ -542,48 +549,62 @@
   /** Session Create Stream Feature (RFC 3921) */
   GLOOX_API extern const std::string XMLNS_STREAM_SESSION;
 
-  /** Non-SASL Auth. Stream Feature (XEP-0078) */
+  /** Non-SASL Auth. Stream Feature (@xep{0078}) */
   GLOOX_API extern const std::string XMLNS_STREAM_IQAUTH;
 
-  /** In-Band Registration namespace (XEP-0077) */
+  /** In-Band Registration namespace (@xep{0077}) */
   GLOOX_API extern const std::string XMLNS_STREAM_IQREGISTER;
 
-  /** Stream Compression Feature namespace (XEP-0138) */
+  /** Stream Compression Feature namespace (@xep{0138}) */
   GLOOX_API extern const std::string XMLNS_STREAM_COMPRESS;
 
-  /** General HTTP binding (BOSH) namespace (XEP-0124) */
+  /** General HTTP binding (BOSH) namespace (@xep{0124}) */
   GLOOX_API extern const std::string XMLNS_HTTPBIND;
 
-  /** XMPP-over-BOSH extensions (XEP-0206) */
+  /** XMPP-over-BOSH extensions (@xep{0206}) */
   GLOOX_API extern const std::string XMLNS_XMPP_BOSH;
 
-  /** Message Receipt namespace (XEP-0184) */
+  /** Message Receipt namespace (@xep{0184}) */
   GLOOX_API extern const std::string XMLNS_RECEIPTS;
 
-  /** Message Receipt namespace (XEP-0172) */
+  /** Message Receipt namespace (@xep{0172}) */
   GLOOX_API extern const std::string XMLNS_NICKNAME;
 
-  /** Jingle namespace (XEP-0166) */
+  /** Jabber RPC namespace (@xep{0009}) */
+  GLOOX_API extern const std::string XMLNS_JABBER_RPC;
+
+  /** Jingle namespace (@xep{0166}) */
   GLOOX_API extern const std::string XMLNS_JINGLE;
 
-  /** Jingle Audio via RTP namespace (XEP-0167) */
-  GLOOX_API extern const std::string XMLNS_JINGLE_AUDIO_RTP;
+  /** Jingle error namespace (@xep{0166}) */
+  GLOOX_API extern const std::string XMLNS_JINGLE_ERRORS;
 
-  /** Jingle ICE-UDP Transport namespace (XEP-0176) */
+  /** Jingle ICE-UDP Transport namespace (@xep{0176}) */
   GLOOX_API extern const std::string XMLNS_JINGLE_ICE_UDP;
 
-  /** Jingle Raw UDP Transport namespace (XEP-0177) */
-  GLOOX_API extern const std::string XMLNS_JINGLE_RAW_UDP;
-
-  /** Jingle Video via RTP namespace (XEP-0180) */
-  GLOOX_API extern const std::string XMLNS_JINGLE_VIDEO_RTP;
-
-  /** Stanza Headers and Internet Metadata (SHIM) namespace (XEP-0131) */
+  /** Jingle File Transfer namespace (@xep{0234}) */
+  GLOOX_API extern const std::string XMLNS_JINGLE_FILE_TRANSFER;
+
+  /** Jingle File Transfer namespace (multiple files) (@xep{0234}) */
+  GLOOX_API extern const std::string XMLNS_JINGLE_FILE_TRANSFER_MULTI;
+
+  /** Stanza Headers and Internet Metadata (SHIM) namespace (@xep{0131}) */
   GLOOX_API extern const std::string XMLNS_SHIM;
 
-  /** Attention namespace (XEP-0224) */
+  /** Attention namespace (@xep{0224}) */
   GLOOX_API extern const std::string XMLNS_ATTENTION;
 
+  /** Stream Management namespace (@xep{0198}) */
+  GLOOX_API extern const std::string XMLNS_STREAM_MANAGEMENT;
+
+  /** Stanza Forwarding namespace (@xep{0297}) */
+  GLOOX_API extern const std::string XMLNS_STANZA_FORWARDING;
+
+  /** Message Carbons namespace (@xep{0280}) */
+  GLOOX_API extern const std::string XMLNS_MESSAGE_CARBONS;
+
+  /** Use of Cryptographic Hash Functions in XMPP namespace (@xep{0300}) */
+  GLOOX_API extern const std::string XMLNS_HASHES;
 
   /** Supported stream version (major). */
   GLOOX_API extern const std::string XMPP_STREAM_VERSION_MAJOR;
@@ -629,6 +650,20 @@
     StreamEventAuthentication,      /**< The Client is about to authenticate. */
     StreamEventSessionInit,         /**< The Client is about to create a session. */
     StreamEventResourceBinding,     /**< The Client is about to bind a resource to the stream. */
+    StreamEventSMEnable,            /**< The Client is about to request Stream Management (@xep{0198}).
+                                     * @since 1.0.4 */
+    StreamEventSMResume,            /**< The Client is about to request resumption by means of Stream Management
+                                     * (@xep{0198}).
+                                     * @since 1.0.4 */
+    StreamEventSMResumed,           /**< The stream has successfully been resumed by means of Stream Management
+                                     * (@xep{0198}).
+                                     * @since 1.0.4 */
+    StreamEventSMEnableFailed,      /**< The attempt to enable Stream Management
+                                     * (@xep{0198}) failed. This is not critical.
+                                     * @since 1.0.4 */
+    StreamEventSMResumeFailed,      /**< The attempt to resume an aborted session by means of Stream Management
+                                     * (@xep{0198}) failed. This is not critical.
+                                     * @since 1.0.4 */
     StreamEventSessionCreation,     /**< The Client is about to create a session.
                                      * @since 0.9.1 */
     StreamEventRoster,              /**< The Client is about to request the roster. */
@@ -694,15 +729,16 @@
     StreamFeatureUnbind           =    2, /**< The server supports binding multiple resources. */
     StreamFeatureSession          =    4, /**< The server supports sessions. */
     StreamFeatureStartTls         =    8, /**< The server supports &lt;starttls&gt;. */
-    StreamFeatureIqRegister       =   16, /**< The server supports XEP-0077 (In-Band
+    StreamFeatureIqRegister       =   16, /**< The server supports @xep{0077} (In-Band
                                            * Registration). */
-    StreamFeatureIqAuth           =   32, /**< The server supports XEP-0078 (Non-SASL
+    StreamFeatureIqAuth           =   32, /**< The server supports @xep{0078} (Non-SASL
                                            * Authentication). */
-    StreamFeatureCompressZlib     =   64, /**< The server supports XEP-0138 (Stream
+    StreamFeatureCompressZlib     =   64, /**< The server supports @xep{0138} (Stream
                                            * Compression) (Zlib). */
-    StreamFeatureCompressDclz     =  128  /**< The server supports XEP-0138 (Stream
+    StreamFeatureCompressDclz     =  128, /**< The server supports @xep{0138} (Stream
                                            * Compression) (LZW/DCLZ). */
-    // SASLMechanism below must be adjusted accordingly.
+    StreamFeatureStreamManagement =  256  /**< The server supports @xep{0198} (Stream Management). */
+    // SaslMechanism below must be adjusted accordingly.
   };
 
   /**
@@ -711,15 +747,17 @@
   // must be adjusted with changes to StreamFeature enum above
   enum SaslMechanism
   {
-    SaslMechNone           =     0, /**< Invalid SASL Mechanism. */
-    SaslMechDigestMd5      =   256, /**< SASL Digest-MD5 according to RFC 2831. */
-    SaslMechPlain          =   512, /**< SASL PLAIN according to RFC 2595 Section 6. */
-    SaslMechAnonymous      =  1024, /**< SASL ANONYMOUS according to draft-ietf-sasl-anon-05.txt/
+    SaslMechNone          =      0, /**< Invalid SASL Mechanism. */
+    SaslMechScramSha1     =   2048, /**< SASL SCRAM-SHA-1-PLUS accroding to RFC 5801 */
+    SaslMechScramSha1Plus =   1024, /**< SASL SCRAM-SHA-1 accroding to RFC 5801 */
+    SaslMechDigestMd5     =   4096, /**< SASL Digest-MD5 according to RFC 2831. */
+    SaslMechPlain         =   8192, /**< SASL PLAIN according to RFC 2595 Section 6. */
+    SaslMechAnonymous     =  16384, /**< SASL ANONYMOUS according to draft-ietf-sasl-anon-05.txt/
                                      * RFC 2245 Section 6. */
-    SaslMechExternal       =  2048, /**< SASL EXTERNAL according to RFC 2222 Section 7.4. */
-    SaslMechGssapi         =  4096, /**< SASL GSSAPI (Win32 only). */
-    SaslMechNTLM           =  8192, /**< SASL NTLM (Win32 only). */
-    SaslMechAll            = 65535  /**< Includes all supported SASL mechanisms. */
+    SaslMechExternal      =  32768, /**< SASL EXTERNAL according to RFC 2222 Section 7.4. */
+    SaslMechGssapi        =  65536, /**< SASL GSSAPI (Win32 only). */
+    SaslMechNTLM          = 131072, /**< SASL NTLM (Win32 only). */
+    SaslMechAll           = 262143  /**< Includes all supported SASL mechanisms. */
   };
 
   /**
@@ -800,7 +838,7 @@
     StreamErrorXmlNotWellFormed,    /**< The initiating entity has sent XML that is not well-formed as
                                      * defined by [XML]. */
     StreamErrorUndefined            /**< An undefined/unknown error occured. Also used if a diconnect was
-     * user-initiated. Also set before and during a established connection
+                                     * user-initiated. Also set before and during a established connection
                                      * (where obviously no error occured). */
   };
 
@@ -993,9 +1031,9 @@
     SaslTemporaryAuthFailure,       /**< The authentication failed because of a temporary error condition
                                      * within the receiving entity; sent in reply to an &lt;auth/&gt; element
                                      * or &lt;response/&gt; element. */
-    NonSaslConflict,                /**< XEP-0078: Resource Conflict */
-    NonSaslNotAcceptable,           /**< XEP-0078: Required Information Not Provided */
-    NonSaslNotAuthorized            /**< XEP-0078: Incorrect Credentials */
+    NonSaslConflict,                /**< @xep{0078}: Resource Conflict */
+    NonSaslNotAcceptable,           /**< @xep{0078}: Required Information Not Provided */
+    NonSaslNotAuthorized            /**< @xep{0078}: Incorrect Credentials */
   };
 
   /**
@@ -1017,6 +1055,7 @@
     LogAreaClassSOCKS5Bytestream      = 0x000800, /**< Log messages from SOCKS5Bytestream. */
     LogAreaClassConnectionBOSH        = 0x001000, /**< Log messages from ConnectionBOSH */
     LogAreaClassConnectionTLS         = 0x002000, /**< Log messages from ConnectionTLS */
+    LogAreaLinkLocalManager           = 0x004000, /**< Log messages from LinkLocalManager */
     LogAreaAllClasses                 = 0x01FFFF, /**< All log messages from all the classes. */
     LogAreaXmlIncoming                = 0x020000, /**< Incoming XML. */
     LogAreaXmlOutgoing                = 0x040000, /**< Outgoing XML. */
@@ -1035,7 +1074,7 @@
   };
 
   /**
-   * The possible Message Events according to XEP-0022.
+   * The possible Message Events according to @xep{0022}.
    */
   enum MessageEventType
   {
@@ -1050,7 +1089,7 @@
   };
 
   /**
-   * The possible Chat States according to XEP-0085.
+   * The possible Chat States according to @xep{0085}.
    */
   enum ChatStateType
   {
@@ -1091,12 +1130,12 @@
    */
   enum MessageSessionFilter
   {
-    FilterMessageEvents    = 1,     /**< Message Events (XEP-0022) */
-    FilterChatStates       = 2      /**< Chat State Notifications (XEP-0085) */
+    FilterMessageEvents    = 1,     /**< Message Events (@xep{0022}) */
+    FilterChatStates       = 2      /**< Chat State Notifications (@xep{0085}) */
   };
 
   /**
-   * Defined MUC room affiliations. See XEP-0045 for default privileges.
+   * Defined MUC room affiliations. See @xep{0045} for default privileges.
    */
   enum MUCRoomAffiliation
   {
@@ -1109,7 +1148,7 @@
   };
 
   /**
-   * Defined MUC room roles. See XEP-0045 for default privileges.
+   * Defined MUC room roles. See @xep{0045} for default privileges.
    */
   enum MUCRoomRole
   {

=== modified file 'src/glooxversion.h'
--- src/glooxversion.h	2010-01-17 13:05:04 +0000
+++ src/glooxversion.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -10,4 +10,4 @@
   This software is distributed without any warranty.
 */
 
-#define GLOOXVERSION 0x010000
+#define GLOOXVERSION 0x010001

=== modified file 'src/gpgencrypted.cpp'
--- src/gpgencrypted.cpp	2010-01-17 13:05:04 +0000
+++ src/gpgencrypted.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/gpgencrypted.h'
--- src/gpgencrypted.h	2010-01-17 13:05:04 +0000
+++ src/gpgencrypted.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class Tag;
 
   /**
-   * @brief This is an abstraction of a jabber:x:encrypted namespace element, as used in XEP-0027
+   * @brief This is an abstraction of a jabber:x:encrypted namespace element, as used in @xep{0027}
    * (Current Jabber OpenPGP Usage).
    *
    * This class does not encrypt or decrypt any stanza content. It's meant to be an abstraction

=== modified file 'src/gpgsigned.cpp'
--- src/gpgsigned.cpp	2010-01-17 13:05:04 +0000
+++ src/gpgsigned.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/gpgsigned.h'
--- src/gpgsigned.h	2010-01-17 13:05:04 +0000
+++ src/gpgsigned.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class Tag;
 
   /**
-   * @brief This is an abstraction of a jabber:x:signed namespace element, as used in XEP-0027
+   * @brief This is an abstraction of a jabber:x:signed namespace element, as used in @xep{0027}
    * (Current Jabber OpenPGP Usage).
    *
    * This class does not sign or verify any stanza content. It's meant to be an abstraction

=== modified file 'src/inbandbytestream.cpp'
--- src/inbandbytestream.cpp	2010-01-17 13:05:04 +0000
+++ src/inbandbytestream.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -113,6 +113,8 @@
 
   InBandBytestream::~InBandBytestream()
   {
+    m_handler = 0; // to prevent handleBytestreamClose() from being called in close()
+
     if( m_open )
       close();
 
@@ -161,7 +163,7 @@
   bool InBandBytestream::handleIq( const IQ& iq ) // data or open request, always 'set'
   {
     const IBB* i = iq.findExtension<IBB>( ExtIBB );
-    if( !i || !m_handler || iq.subtype() != IQ::Set )
+    if( !i || !m_handler || iq.subtype() != IQ::Set || i->sid() != this->sid() )
       return false;
 
     if( !m_open )
@@ -254,7 +256,7 @@
     do
     {
       const std::string& id = m_clientbase->getID();
-      IQ iq( IQ::Set, m_target, id );
+      IQ iq( IQ::Set, m_clientbase->jid() == m_target ? m_initiator : m_target, id );
       iq.addExtension( new IBB( m_sid, ++m_sequence, data.substr( pos, m_blockSize ) ) );
       m_clientbase->send( iq, this, IBBData );
 

=== modified file 'src/inbandbytestream.h'
--- src/inbandbytestream.h	2010-01-17 13:05:04 +0000
+++ src/inbandbytestream.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -27,7 +27,7 @@
   class Message;
 
   /**
-   * @brief An implementation of a single In-Band Bytestream (XEP-0047).
+   * @brief An implementation of a single In-Band Bytestream (@xep{0047}).
    *
    * One instance of this class handles a single byte stream.
    *

=== modified file 'src/instantmucroom.cpp'
--- src/instantmucroom.cpp	2010-01-17 13:05:04 +0000
+++ src/instantmucroom.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/instantmucroom.h'
--- src/instantmucroom.h	2010-01-17 13:05:04 +0000
+++ src/instantmucroom.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/iq.cpp'
--- src/iq.cpp	2010-01-17 13:05:04 +0000
+++ src/iq.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/iq.h'
--- src/iq.h	2010-01-17 13:05:04 +0000
+++ src/iq.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/iqhandler.h'
--- src/iqhandler.h	2010-01-17 13:05:04 +0000
+++ src/iqhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -40,7 +40,7 @@
        * Reimplement this function if you want to be notified about incoming IQs.
        * @param iq The complete IQ stanza.
        * @return Indicates whether a request of type 'get' or 'set' has been handled. This includes
-       * the obligatory 'result' answer. If you return @b false, a 'error' will be sent.
+       * the obligatory 'result' answer. If you return @b false, an 'error' will be sent.
        * @since 1.0
        */
       virtual bool handleIq( const IQ& iq ) = 0;

=== modified file 'src/jid.cpp'
--- src/jid.cpp	2010-01-17 13:05:04 +0000
+++ src/jid.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -80,7 +80,7 @@
     if( !m_username.empty() )
       m_bare = m_username + '@';
     else
-      m_bare = EmptyString;
+      m_bare = ""/*EmptyString*/;
     m_bare += m_server;
   }
 

=== modified file 'src/jid.h'
--- src/jid.h	2010-01-17 13:05:04 +0000
+++ src/jid.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -140,19 +140,48 @@
       bool operator!=( const JID& right ) const { return full() != right.full(); }
 
       /**
+       * Compares two JIDs to see if the left is less than the right.
+       * Needed for JID to be a key in a map.
+       * @param right The second JID.
+       * @since 1.0.4
+       */
+      bool operator<( const JID& right ) const { return full() < right.full(); }
+
+      /**
+       * Compares two JIDs to see if the left is less than or equal to the right.
+       * @param right The second JID.
+       * @since 1.0.4
+       */
+      bool operator<=( const JID& right ) const { return full() <= right.full(); }
+
+      /**
+       * Compares two JIDs to see if the left is greater than the right.
+       * @param right The second JID.
+       * @since 1.0.4
+       */
+      bool operator>( const JID& right ) const { return full() > right.full(); }
+
+      /**
+       * Compares two JIDs to see if the left is greater than the right.
+       * @param right The second JID.
+       * @since 1.0.4
+       */
+      bool operator>=( const JID& right ) const { return full() >= right.full(); }
+
+      /**
        * Converts to  @b true if the JID is valid, @b false otherwise.
        */
       operator bool() const { return m_valid; }
 
       /**
-       * XEP-0106: JID Escaping
+       * @xep{0106}: JID Escaping
        * @param node The node to escape.
        * @return The escaped node.
        */
       static std::string escapeNode( const std::string& node );
 
       /**
-       * XEP-0106: JID Escaping
+       * @xep{0106}: JID Escaping
        * @param node The node to unescape.
        * @return The unescaped node.
        */

=== added file 'src/jinglecontent.cpp'
--- src/jinglecontent.cpp	1970-01-01 00:00:00 +0000
+++ src/jinglecontent.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,102 @@
+/*
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "jinglecontent.h"
+#include "jinglepluginfactory.h"
+#include "util.h"
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    static const char* creatorValues [] = {
+      "initiator",
+      "responder"
+    };
+
+    static inline Content::Creator creatorType( const std::string& type )
+    {
+      return (Content::Creator)util::lookup( type, creatorValues );
+    }
+
+    static const char* sendersValues [] = {
+      "initiator",
+      "responder",
+      "both",
+      "none"
+    };
+
+    static inline Content::Senders sendersType( const std::string& type )
+    {
+      return (Content::Senders)util::lookup( type, sendersValues );
+    }
+
+    Content::Content( const std::string& name, const PluginList& plugins, Creator creator,
+                      Senders senders, const std::string& disposition )
+      : m_creator( creator ), m_disposition( disposition ),
+        m_name( name ), m_senders( senders )
+    {
+      m_plugins = plugins;
+    }
+
+    Content::Content( const Tag* tag, PluginFactory* factory )
+    {
+      if( !factory || !tag || tag->name() != "content" )
+        return;
+
+      m_name = tag->findAttribute( "name" );
+      m_creator = (Creator)util::lookup( tag->findAttribute( "creator" ), creatorValues );
+      m_senders = (Senders)util::lookup( tag->findAttribute( "senders" ), sendersValues );
+      m_disposition = tag->findAttribute( "disposition" );
+
+      factory->addPlugins( *this, tag );
+    }
+
+    Content::~Content()
+    {
+    }
+
+    const std::string& Content::filterString() const
+    {
+      static const std::string filter = "jingle/content";
+      return filter;
+    }
+
+    Tag* Content::tag() const
+    {
+      if( m_creator == InvalidCreator || m_name.empty() )
+        return 0;
+
+      Tag* t = new Tag( "content" );
+      t->addAttribute( "creator", util::lookup( m_creator, creatorValues ) );
+      t->addAttribute( "disposition", m_disposition );
+      t->addAttribute( "name", m_name );
+      t->addAttribute( "senders", util::lookup( m_senders, sendersValues ) );
+
+      PluginList::const_iterator it = m_plugins.begin();
+      for( ; it != m_plugins.end(); ++it )
+        t->addChild( (*it)->tag() );
+
+      return t;
+    }
+
+    Plugin* Content::clone() const
+    {
+      return 0;
+    }
+
+  }
+
+}

=== added file 'src/jinglecontent.h'
--- src/jinglecontent.h	1970-01-01 00:00:00 +0000
+++ src/jinglecontent.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,138 @@
+/*
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLECONTENT_H__
+#define JINGLECONTENT_H__
+
+
+#include "jingleplugin.h"
+#include "tag.h"
+
+#include <string>
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    class PluginFactory;
+
+    /**
+     * @brief An abstraction of a Jingle Content Type. This is part of Jingle (@xep{0166}).
+     *
+     * See @link gloox::Jingle::Session Jingle::Session @endlink for more info on Jingle.
+     *
+     * XEP Version: 1.1
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.5
+     */
+    class GLOOX_API Content : public Plugin
+    {
+      public:
+        /**
+         * The original creator of the content type.
+         */
+        enum Creator
+        {
+          CInitiator,                /**< The creator is the initiator of the session. */
+          CResponder,                /**< The creator is the responder. */
+          InvalidCreator             /**< Invalid value. */
+        };
+
+        /**
+         * The parties in the session that will be generating content.
+         */
+        enum Senders
+        {
+          SInitiator,                /**< The initiator generates/sends content. */
+          SResponder,                /**< The responder generates/sends content. */
+          SBoth,                     /**< Both parties generate/send content( default). */
+          SNone,                     /**< No party generates/sends content. */
+          InvalidSender              /**< Invalid value. */
+        };
+
+        /**
+         * Creates a new Content wrapper.
+         * @param name A unique name for the content type.
+         * @param plugins A list of application formats, transport methods, security preconditions, ...
+         * @param creator Which party originally generated the content type; the defined values are "SInitiator" and "SResponder".
+         * @param senders Which parties in the session will be generating content.
+         * @param disposition How the content definition is to be interpreted by the recipient. The meaning of this attribute
+         * matches the "Content-Disposition" header as defined in RFC 2183 and applied to SIP by RFC 3261.
+         */
+        Content( const std::string& name, const PluginList& plugins, Creator creator = CInitiator,
+                 Senders senders = SBoth, const std::string& disposition = "session" );
+
+        /**
+         * Creates a new Content object from the given tag.
+         * @param tag The Tag to parse.
+         * @param factory A PluginFactory instance to use for embedding plugins.
+         */
+        Content( const Tag* tag = 0, PluginFactory* factory = 0 );
+
+        /**
+         * Returns the content's creator.
+         * @return The content's creator.
+         */
+        Creator creator() const { return m_creator; }
+
+        /**
+         * Returns the senders.
+         * @return The senders.
+         */
+        Senders senders() const { return m_senders; }
+
+        /**
+         * Returns the disposition.
+         * @return The disposition.
+         */
+        const std::string& disposition() const { return m_disposition; }
+
+        /**
+         * Returns the content name.
+         * @return The content name.
+         */
+        const std::string& name() const { return m_name; }
+
+        /**
+         * Virtual destructor.
+         */
+        virtual ~Content();
+
+        // reimplemented from Plugin
+        virtual const std::string& filterString() const;
+
+        // reimplemented from Plugin
+        virtual Tag* tag() const;
+
+        // reimplemented from Plugin
+        virtual Plugin* newInstance( const Tag* tag ) const { return new Content( tag, m_factory ); }
+
+        // reimplemented from Plugin
+        virtual Plugin* clone() const;
+
+      private:
+        Creator m_creator;
+        std::string m_disposition;
+        std::string m_name;
+        Senders m_senders;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLECONTENT_H__

=== added file 'src/jinglefiletransfer.cpp'
--- src/jinglefiletransfer.cpp	1970-01-01 00:00:00 +0000
+++ src/jinglefiletransfer.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,173 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "jinglefiletransfer.h"
+
+#include "tag.h"
+#include "gloox.h"
+#include "util.h"
+
+#include <cstdlib>
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    static const char* typeValues [] = {
+      "offer",
+      "request",
+      "checksum",
+      "abort",
+      "received"
+    };
+
+    FileTransfer::FileTransfer( Type type, const FileList& files )
+      : m_type( type ), m_files( files )
+    {
+    }
+
+    FileTransfer::FileTransfer( const Tag* tag )
+      : m_type( Invalid )
+    {
+      if( !tag || tag->xmlns() != XMLNS_JINGLE_FILE_TRANSFER )
+        return;
+
+      std::string name = tag->name();
+      if( name == "description" )
+      {
+        const Tag* c = tag->findTag( "description/offer|description/request" );
+        if( c )
+        {
+          parseFileList( c->findChildren( "file" ) );
+          name = c->name();
+        }
+      }
+      else if( name == "checksum" || name == "abort" || name == "received" )
+      {
+        parseFileList( tag->findChildren( "file" ) );
+      }
+
+      m_type = (Type)util::lookup( name, typeValues );
+    }
+
+    void FileTransfer::parseFileList( const TagList& files )
+    {
+      TagList::const_iterator it = files.begin();
+      for( ; it != files.end(); ++it )
+      {
+        File f;
+        Tag *t = (*it)->findChild( "name" );
+        f.name = t ? t->cdata() : EmptyString;
+        t = (*it)->findChild( "desc" );
+        f.desc = t ? t->cdata() : EmptyString;
+        t = (*it)->findChild( "date" );
+        f.date = t ? t->cdata() : EmptyString;
+        t = (*it)->findChild( "size" );
+        f.size = t ? atoi( t->cdata().c_str() ) : -1;
+        t = (*it)->findChild( "range" );
+        if( t )
+        {
+          f.range = true;
+          f.offset = t->hasAttribute( "offset" ) ? atoi( t->findAttribute( "offset" ).c_str() ) : -1;
+        }
+        t = (*it)->findChild( "hash", XMLNS, XMLNS_HASHES );
+        if( t )
+        {
+          f.hash_algo = t->findAttribute( "algo" );
+          f.hash = t->cdata();
+        }
+        m_files.push_back( f );
+      }
+    }
+
+    const StringList FileTransfer::features() const
+    {
+      StringList sl;
+      sl.push_back( XMLNS_JINGLE_FILE_TRANSFER );
+      return sl;
+    }
+
+    const std::string& FileTransfer::filterString() const
+    {
+      static const std::string filter = "content/description[@xmlns='" + XMLNS_JINGLE_FILE_TRANSFER + "']"
+                                        "|jingle/abort[@xmlns='" + XMLNS_JINGLE_FILE_TRANSFER + "']"
+                                        "|jingle/received[@xmlns='" + XMLNS_JINGLE_FILE_TRANSFER + "']"
+                                        "|jingle/checksum[@xmlns='" + XMLNS_JINGLE_FILE_TRANSFER + "']";
+      return filter;
+    }
+
+    Plugin* FileTransfer::newInstance( const Tag* tag ) const
+    {
+      return new FileTransfer( tag );
+    }
+
+    Tag* FileTransfer::tag() const
+    {
+      if( m_type == Invalid )
+        return 0;
+
+      Tag* r = 0;
+
+      switch( m_type )
+      {
+        case Offer:
+        case Request:
+        {
+          r = new Tag( "description", XMLNS, XMLNS_JINGLE_FILE_TRANSFER );
+          Tag* o = new Tag( r, util::lookup( m_type, typeValues ) );
+          FileList::const_iterator it = m_files.begin();
+          for( ; it != m_files.end(); ++it )
+          {
+            Tag* f = new Tag( o, "file" );
+            new Tag( f, "date", (*it).date );
+            new Tag( f, "name", (*it).name );
+            new Tag( f, "desc", (*it).desc );
+            new Tag( f, "size", util::long2string( (*it).size ) );
+            Tag* h = new Tag( f, "hash", XMLNS, XMLNS_HASHES );
+            h->addAttribute( "algo", (*it).hash_algo );
+            h->setCData( (*it).hash );
+            if( (*it).range )
+              new Tag( f, "range", "offset", (*it).offset ? util::long2string( (*it).offset ) : EmptyString );
+          }
+          break;
+        }
+        case Abort:
+        case Checksum:
+        case Received:
+        {
+          r = new Tag( util::lookup( m_type, typeValues ), XMLNS, XMLNS_JINGLE_FILE_TRANSFER );
+          FileList::const_iterator it = m_files.begin();
+          Tag* f = new Tag( r, "file" );
+          new Tag( f, "date", (*it).date );
+          new Tag( f, "name", (*it).name );
+          new Tag( f, "desc", (*it).desc );
+          new Tag( f, "size", util::long2string( (*it).size ) );
+          Tag* h = new Tag( f, "hash", XMLNS, XMLNS_HASHES );
+          h->addAttribute( "algo", (*it).hash_algo );
+          h->setCData( (*it).hash );
+          if( (*it).range )
+            new Tag( f, "range" );
+          break;
+        }
+        default:
+          break;
+      }
+
+      return r;
+    }
+
+  }
+
+}

=== added file 'src/jinglefiletransfer.h'
--- src/jinglefiletransfer.h	1970-01-01 00:00:00 +0000
+++ src/jinglefiletransfer.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,134 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLEFILETRANSFER_H__
+#define JINGLEFILETRANSFER_H__
+
+#include "jingleplugin.h"
+#include "tag.h"
+
+#include <string>
+#include <list>
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    /**
+     * @brief An abstraction of the signaling part of Jingle File Transfer (@xep{0234}), implemented as a Jingle::Plugin.
+     *
+     * XEP Version: 0.15
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.7
+     */
+    class FileTransfer : public Plugin
+    {
+      public:
+
+        /**
+         * The type of a FileTransfer instance.
+         */
+        enum Type
+        {
+          Offer,                    /**< Signifies a file transfer offer (send). */
+          Request,                  /**< Signifies a file request (pull). */
+          Checksum,                 /**< Used to send a file's checksum. */
+          Abort,                    /**< used to abort a running transfer. */
+          Received,                 /**< Signifies a successful file transfer. */
+          Invalid                   /**< Invalid type. */
+        };
+
+        /**
+         * A struct holding information about a file.
+         */
+        struct File
+        {
+          std::string name;         /**< The file's name. */
+          std::string date;         /**< The file's (creation?) date */
+          std::string desc;         /**< A description. */
+          std::string hash;         /**< The file's cehcksum. */
+          std::string hash_algo;    /**< The algorithm used to calculate the checksum */
+          long int size;            /**< The filesize in Bytes. */
+          bool range;               /**< Signifies that an offset transfer is possible. */
+          long int offset;          /**< An (optional) offset. */
+        };
+
+        /** A list of file information structs. */
+        typedef std::list<File> FileList;
+
+        /**
+         * Creates a new instance.
+         * @param type The type of the object.
+         * @param files A list of files to offer, request, acknowledge, ... Most of
+         * the time this list will contain only one file.
+         */
+        FileTransfer( Type type, const FileList& files );
+
+        /**
+         * Creates a new instance from the given Tag
+         * @param tag The Tag to parse.
+         */
+        FileTransfer( const Tag* tag = 0 );
+
+        /**
+         * Virtual destructor.
+         */
+        virtual ~FileTransfer() {}
+
+        /**
+         * Returns the type.
+         * @return The type.
+         */
+        Type type() const { return m_type; }
+
+        /**
+         * Returns a list of embedded file infos.
+         * @return A list of embedded file infos.
+         */
+        const FileList& files() const { return m_files; }
+
+        // reimplemented from Plugin
+        virtual const StringList features() const;
+
+        // reimplemented from Plugin
+        virtual const std::string& filterString() const;
+
+        // reimplemented from Plugin
+        virtual Tag* tag() const;
+
+        // reimplemented from Plugin
+        virtual Plugin* newInstance( const Tag* tag ) const;
+
+        // reimplemented from Plugin
+        virtual Plugin* clone() const
+        {
+          return new FileTransfer( *this );
+        }
+
+      private:
+
+        void parseFileList( const TagList& files );
+
+        Type m_type;
+        FileList m_files;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLEFILETRANSFER_H__

=== added file 'src/jingleiceudp.cpp'
--- src/jingleiceudp.cpp	1970-01-01 00:00:00 +0000
+++ src/jingleiceudp.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,111 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "jingleiceudp.h"
+
+#include "tag.h"
+#include "gloox.h"
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    static const char* typeValues [] = {
+      "host",
+      "prflx",
+      "relay",
+      "srflx"
+    };
+
+    ICEUDP::ICEUDP( const std::string& pwd, const std::string& ufrag, CandidateList& candidates )
+      : m_pwd( pwd ), m_ufrag( ufrag), m_candidates( candidates )
+    {
+    }
+
+    ICEUDP::ICEUDP( const Tag* tag )
+    {
+      if( !tag || tag->name() != "transport" || tag->xmlns() != XMLNS_JINGLE_ICE_UDP )
+        return;
+
+      m_pwd = tag->findAttribute( "pwd" );
+      m_ufrag = tag->findAttribute( "ufrag" );
+      const TagList candidates = tag->findChildren( "candidate" );
+      TagList::const_iterator it = candidates.begin();
+      for( ; it != candidates.end(); ++it )
+      {
+        Candidate c;
+        c.component = (*it)->findAttribute( "component" );
+        c.foundation = (*it)->findAttribute( "foundation" );
+        c.generation = (*it)->findAttribute( "generation" );
+        c.id = (*it)->findAttribute( "id" );
+        c.ip = (*it)->findAttribute( "ip" );
+        c.network = (*it)->findAttribute( "network" );
+        c.port = atoi( (*it)->findAttribute( "port" ).c_str() );
+        c.priority = atoi( (*it)->findAttribute( "priority" ).c_str() );
+        c.protocol = (*it)->findAttribute( "protocol" );
+        c.rel_addr = (*it)->findAttribute( "rel-addr" );
+        c.rel_port = atoi( (*it)->findAttribute( "rel-port" ).c_str() );
+        c.type = (Type)util::lookup( (*it)->findAttribute( "type" ), typeValues );
+      }
+    }
+
+    const StringList ICEUDP::features() const
+    {
+      StringList sl;
+      sl.push_back( XMLNS_JINGLE_ICE_UDP );
+      return sl;
+    }
+
+    const std::string& ICEUDP::filterString() const
+    {
+      static const std::string filter = "content/transport[@xmlns='" + XMLNS_JINGLE_ICE_UDP + "']";
+      return filter;
+    }
+
+    Plugin* ICEUDP::newInstance( const Tag* tag ) const
+    {
+      return new ICEUDP( tag );
+    }
+
+    Tag* ICEUDP::tag() const
+    {
+      Tag* t = new Tag( "transport", XMLNS, XMLNS_JINGLE_ICE_UDP );
+      t->addAttribute( "pwd", m_pwd );
+      t->addAttribute( "ufrag", m_ufrag );
+
+      CandidateList::const_iterator it = m_candidates.begin();
+      for( ; it != m_candidates.end(); ++it )
+      {
+        Tag* c = new Tag( t, "candidate" );
+        c->addAttribute( "component", (*it).component );
+        c->addAttribute( "foundation", (*it).foundation );
+        c->addAttribute( "generation", (*it).generation );
+        c->addAttribute( "id", (*it).id );
+        c->addAttribute( "ip", (*it).ip );
+        c->addAttribute( "network", (*it).network );
+        c->addAttribute( "port", (*it).port );
+        c->addAttribute( "priority", (*it).priority );
+        c->addAttribute( "protocol", (*it).protocol );
+        c->addAttribute( "rel-addr", (*it).rel_addr );
+        c->addAttribute( "rel-port", (*it).rel_port );
+        c->addAttribute( "type", util::lookup( (*it).type, typeValues ) );
+      }
+
+      return t;
+    }
+
+  }
+
+}

=== added file 'src/jingleiceudp.h'
--- src/jingleiceudp.h	1970-01-01 00:00:00 +0000
+++ src/jingleiceudp.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,141 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLEICEUDP_H__
+#define JINGLEICEUDP_H__
+
+#include "jingleplugin.h"
+
+#include <string>
+#include <list>
+
+namespace gloox
+{
+
+  class Tag;
+
+  namespace Jingle
+  {
+
+    /**
+     * @brief An abstraction of the signaling part of Jingle ICE-UDP Transport Method (@xep{0176}).
+     *
+     * XEP Version: 1.0
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.7
+     */
+    class ICEUDP : public Plugin
+    {
+      public:
+        /**
+         * Describes the candidate type.
+         */
+        enum Type
+        {
+          Host,                     /**< A host candidate. */
+          PeerReflexive,            /**< A peer reflexive candidate. */
+          Relayed,                  /**< A relayed candidate. */
+          ServerReflexive           /**< A server reflexive candidate. */
+        };
+
+        /**
+         * Describes a single transport candidate.
+         */
+        struct Candidate
+        {
+          std::string component;    /**< A Component ID as defined in ICE-CORE. */
+          std::string foundation;   /**< A Foundation as defined in ICE-CORE.*/
+          std::string generation;   /**< An index, starting at 0, that enables the parties to keep track of
+                                         updates to the candidate throughout the life of the session. */
+          std::string id;           /**< A unique identifier for the candidate. */
+          std::string ip;           /**< The IP address for the candidate transport mechanism. */
+          std::string network;      /**< An index, starting at 0, referencing which network this candidate is on for a given peer. */
+          int port;                 /**< The port at the candidate IP address. */
+          int priority;             /**< A Priority as defined in ICE-CORE. */
+          std::string protocol;     /**< The protocol to be used. Should be @b udp. */
+          std::string rel_addr;     /**< A related address as defined in ICE-CORE. */
+          int rel_port;             /**< A related port as defined in ICE-CORE. */
+          Type type;                /**< A Candidate Type as defined in ICE-CORE. */
+        };
+
+        /** A list of transport candidates. */
+        typedef std::list<Candidate> CandidateList;
+
+        /**
+         * Constructs a new instance.
+         * @param pwd The @c pwd value.
+         * @param ufrag The @c ufrag value.
+         * @param candidates A list of connection candidates.
+         */
+        ICEUDP( const std::string& pwd, const std::string& ufrag, CandidateList& candidates );
+
+        /**
+         * Constructs a new instance from the given tag.
+         * @param tag The Tag to parse.
+         */
+        ICEUDP( const Tag* tag = 0 );
+
+        /**
+         * Virtual destructor.
+         */
+        virtual ~ICEUDP() {}
+
+        /**
+         * Returns the @c pwd value.
+         * @return The @c pwd value.
+         */
+        const std::string& pwd() const { return m_pwd; }
+
+        /**
+         * Returns the @c ufrag value.
+         * @return The @c ufrag value.
+         */
+        const std::string& ufrag() const { return m_ufrag; }
+
+        /**
+         * Returns the list of connection candidates.
+         * @return The list of connection candidates.
+         */
+        const CandidateList& candidates() const { return m_candidates; }
+
+        // reimplemented from Plugin
+        virtual const StringList features() const;
+
+        // reimplemented from Plugin
+        virtual const std::string& filterString() const;
+
+        // reimplemented from Plugin
+        virtual Tag* tag() const;
+
+        // reimplemented from Plugin
+        virtual Plugin* newInstance( const Tag* tag ) const;
+
+        // reimplemented from Plugin
+        virtual Plugin* clone() const
+        {
+          return new ICEUDP( *this );
+        }
+
+      private:
+        std::string m_pwd;
+        std::string m_ufrag;
+        CandidateList m_candidates;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLEICEUDP_H__

=== added file 'src/jingleplugin.h'
--- src/jingleplugin.h	1970-01-01 00:00:00 +0000
+++ src/jingleplugin.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,129 @@
+/*
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLEPLUGIN_H__
+#define JINGLEPLUGIN_H__
+
+#include "macros.h"
+#include "util.h"
+
+#include <string>
+#include <list>
+
+namespace gloox
+{
+
+  class Tag;
+
+  namespace Jingle
+  {
+
+    class Plugin;
+    class PluginFactory;
+
+    /**
+     * A list of Jingle plugins.
+     */
+    typedef std::list<const Plugin*> PluginList;
+
+    /**
+     * @brief An abstraction of a Jingle plugin. This is part of Jingle (@xep{0166}) et al.
+     *
+     * This is the base class for Content and all other pluggable Jingle-related containers, e.g.
+     * session information, such as the 'ringing' info in Jingle Audio, or Jingle DTMF, etc.
+     *
+     * A Plugin abstracts the XML that gets sent and received as part of a Jingle session negotiation.
+     *
+     * XEP Version: 1.1
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.5
+     */
+    class GLOOX_API Plugin
+    {
+
+      friend class PluginFactory;
+
+      public:
+        /**
+         * Simple initializer.
+         */
+        Plugin() : m_factory( 0 ) {}
+
+        /**
+         * Virtual destructor.
+         */
+        virtual ~Plugin() { util::clearList( m_plugins ) ; }
+
+        /**
+         * Adds another Plugin as child.
+         * @param plugin A plugin to be embedded. Will be owned by this instance and deleted in the destructor.
+         */
+        void addPlugin( const Plugin* plugin ) { if( plugin ) m_plugins.push_back( plugin ); }
+
+        /**
+         * Returns a reference to a list of embedded plugins.
+         * @return A reference to a list of embedded plugins.
+         */
+        const PluginList& plugins() const { return m_plugins; }
+
+        /**
+         * Reimplement this function if your plugin wants to add anything to the list of
+         * features announced via Disco.
+         * @return A list of additional feature strings.
+         */
+        virtual const StringList features() const { return StringList(); }
+
+        /**
+         * Returns an XPath expression that describes a path to child elements of a
+         * jingle element that the plugin handles.
+         * The result should be a single Tag.
+         *
+         * @return The plugin's filter string.
+         */
+        virtual const std::string& filterString() const = 0;
+
+        /**
+         * Returns a Tag representation of the plugin.
+         * @return A Tag representation of the plugin.
+         */
+        virtual Tag* tag() const = 0;
+
+        /**
+         * Returns a new instance of the same plugin type,
+         * based on the Tag provided.
+         * @param tag The Tag to parse and create a new instance from.
+         * @return The new plugin instance.
+         */
+        virtual Plugin* newInstance( const Tag* tag ) const = 0;
+
+        /**
+         * Creates an identical deep copy of the current instance.
+         * @return An identical deep copy of the current instance.
+         */
+        virtual Plugin* clone() const = 0;
+
+      protected:
+        PluginList m_plugins;
+        PluginFactory* m_factory;
+
+      private:
+        void setFactory( PluginFactory* factory ) { m_factory = factory; }
+
+    };
+
+  }
+
+}
+
+#endif // JINGLEPLUGIN_H__

=== added file 'src/jinglepluginfactory.cpp'
--- src/jinglepluginfactory.cpp	1970-01-01 00:00:00 +0000
+++ src/jinglepluginfactory.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,91 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "jinglepluginfactory.h"
+#include "tag.h"
+#include "util.h"
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    PluginFactory::PluginFactory()
+    {
+    }
+
+    PluginFactory::~PluginFactory()
+    {
+      util::clearList( m_plugins );
+    }
+
+    void PluginFactory::registerPlugin( Plugin* plugin )
+    {
+      if( !plugin )
+        return;
+
+      plugin->setFactory( this );
+      m_plugins.push_back( plugin );
+    }
+
+    void PluginFactory::addPlugins( Plugin& plugin, const Tag* tag )
+    {
+      if( !tag )
+        return;
+
+      ConstTagList::const_iterator it;
+
+      PluginList::const_iterator itp = m_plugins.begin();
+      for( ; itp != m_plugins.end(); ++itp )
+      {
+        const ConstTagList& match = tag->findTagList( (*itp)->filterString() );
+        it = match.begin();
+        for( ; it != match.end(); ++it )
+        {
+          Plugin* pl = (*itp)->newInstance( (*it) );
+          if( pl )
+          {
+            plugin.addPlugin( pl );
+          }
+        }
+      }
+    }
+
+    void PluginFactory::addPlugins( Session::Jingle& jingle, const Tag* tag )
+    {
+      if( !tag )
+        return;
+
+      ConstTagList::const_iterator it;
+
+      PluginList::const_iterator itp = m_plugins.begin();
+      for( ; itp != m_plugins.end(); ++itp )
+      {
+        const ConstTagList& match = tag->findTagList( (*itp)->filterString() );
+        it = match.begin();
+        for( ; it != match.end(); ++it )
+        {
+          Plugin* pl = (*itp)->newInstance( (*it) );
+          if( pl )
+          {
+            jingle.addPlugin( pl );
+          }
+        }
+      }
+    }
+
+
+  }
+
+}

=== added file 'src/jinglepluginfactory.h'
--- src/jinglepluginfactory.h	1970-01-01 00:00:00 +0000
+++ src/jinglepluginfactory.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,82 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLEPLUGINFACTORY_H__
+#define JINGLEPLUGINFACTORY_H__
+
+#include "jingleplugin.h"
+#include "jinglesession.h"
+
+namespace gloox
+{
+
+  class Tag;
+
+  namespace Jingle
+  {
+
+    /**
+     * @brief A factory for which creates Plugin instances based on Tags. This is part of Jingle (@xep{0166}).
+     *
+     * Used by Jingle::SessionManager. You should not need to use this class directly.
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.7
+     */
+    class PluginFactory
+    {
+      friend class SessionManager;
+
+      public:
+        /**
+         * Virtual destructor.
+         */
+        virtual ~PluginFactory();
+
+        /**
+         * Registers an empty Plugin as a template with the factory.
+         * @param plugin The plugin to register.
+         */
+        void registerPlugin( Plugin* plugin );
+
+        /**
+         * Based on the template plugins' filter string, this function checks the supplied tag for
+         * supported extensions and adds them as new plugins to the supplied Plugin instance.
+         * @param plugin The Plugin-derived object that will have the newly created plugins embedded.
+         * @param tag The Tag to check for supported extensions.
+         */
+        void addPlugins( Plugin& plugin, const Tag* tag );
+
+        /**
+         * Based on the template plugins' filter string, this function checks the supplied tag for
+         * supported extensions and adds them as new plugins to the supplied Jingle instance.
+         * @param jingle The Jingle object that will have the newly created plugins embedded.
+         * @param tag The Tag to check for supported extensions.
+         */
+        void addPlugins( Session::Jingle& jingle, const Tag* tag );
+
+      private:
+        /**
+         * Creates a new instance.
+         */
+        PluginFactory();
+
+        PluginList m_plugins;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLEPLUGINFACTORY_H__

=== added file 'src/jinglesession.cpp'
--- src/jinglesession.cpp	1970-01-01 00:00:00 +0000
+++ src/jinglesession.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,496 @@
+/*
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "jinglesession.h"
+
+#include "clientbase.h"
+#include "error.h"
+#include "jinglecontent.h"
+#include "jinglesessionhandler.h"
+#include "tag.h"
+#include "util.h"
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    static const char* actionValues [] = {
+      "content-accept",
+      "content-add",
+      "content-modify",
+      "content-reject",
+      "content-remove",
+      "description-info",
+      "security-info",
+      "session-accept",
+      "session-info",
+      "session-initiate",
+      "session-terminate",
+      "transport-accept",
+      "transport-info",
+      "transport-reject",
+      "transport-replace"
+    };
+
+    static inline Action actionType( const std::string& type )
+    {
+      return (Action)util::lookup( type, actionValues );
+    }
+
+    // ---- Session::Reason ----
+    static const char* reasonValues [] = {
+      "alternative-session",
+      "busy",
+      "cancel",
+      "connectivity-error",
+      "decline",
+      "expired",
+      "failed-application",
+      "failed-transport",
+      "general-error",
+      "gone",
+      "incompatible-parameters",
+      "media-error",
+      "security-error",
+      "success",
+      "timeout",
+      "unsupported-applications",
+      "unsupported-transports"
+    };
+
+    static inline Session::Reason::Reasons reasonType( const std::string& type )
+    {
+      return (Session::Reason::Reasons)util::lookup( type, reasonValues );
+    }
+
+    Session::Reason::Reason( Reasons reason,
+                             const std::string& sid,
+                             const std::string& text)
+      : m_reason( reason ), m_sid( sid ), m_text( text )
+    {
+    }
+
+    Session::Reason::Reason( const Tag* tag )
+    {
+      if( !tag || tag->name() != "reason" )
+        return;
+
+      const TagList& l = tag->children();
+      TagList::const_iterator it = l.begin();
+      for( ; it != l.end(); ++it )
+      {
+        if( (*it)->name() == "text" )
+          m_text = (*it)->cdata();
+        else if( (*it)->xmlns() == XMLNS_JINGLE )
+          m_reason = reasonType( (*it)->name() );
+      }
+    }
+
+    const std::string& Session::Reason::filterString() const
+    {
+      static const std::string filter = "jingle/reason";
+      return filter;
+    }
+
+    Tag* Session::Reason::tag() const
+    {
+      if( m_reason == InvalidReason )
+        return 0;
+
+      Tag* t = new Tag( "reason" );
+      Tag* r = new Tag( t, util::lookup( m_reason, reasonValues ) );
+      if( m_reason == AlternativeSession && !m_sid.empty() )
+        new Tag( r, "sid", m_sid );
+
+      if( !m_text.empty() )
+        new Tag( t, "text", m_text );
+
+      return t;
+    }
+
+    Plugin* Session::Reason::clone() const
+    {
+      return new Reason( *this );
+    }
+    // ---- ~Session::Reason ----
+
+    // ---- Session::Jingle ----
+    Session::Jingle::Jingle( Action action, const JID& initiator,
+                             const PluginList& plugins, const std::string& sid )
+      : StanzaExtension( ExtJingle ), m_action( action ), m_sid( sid ),
+        m_initiator( initiator ), m_plugins( plugins ), m_tag( 0 )
+    {
+    }
+
+    Session::Jingle::Jingle( Action action, const JID& initiator,
+                             const Plugin* plugin, const std::string& sid )
+      : StanzaExtension( ExtJingle ), m_action( action ), m_sid( sid ),
+        m_initiator( initiator ), m_tag( 0 )
+    {
+      if( plugin )
+        m_plugins.push_back( plugin );
+    }
+
+    Session::Jingle::Jingle( const Tag* tag )
+      : StanzaExtension( ExtJingle ), m_action( InvalidAction ), m_tag( 0 )
+    {
+      if( !tag || tag->name() != "jingle" )
+        return;
+
+      m_action = actionType( tag->findAttribute( "action" ) );
+      m_initiator.setJID( tag->findAttribute( "initiator" ) );
+      m_responder.setJID( tag->findAttribute( "responder" ) );
+      m_sid = tag->findAttribute( "sid" );
+
+//       const TagList& l = tag->children();
+//       TagList::const_iterator it = l.begin();
+//       for( ; it != l.end(); ++it )
+//       {
+//         const std::string& name = (*it)->name();
+//         if( name == "content" )
+//           m_plugins.push_back( new Content( (*it) ) );
+//       }
+
+      m_tag = tag->clone();
+    }
+
+//     Session::Jingle::Jingle( const Jingle& right )
+//       : StanzaExtension( ExtJingle ), m_action( right.m_action ),
+//         m_sid( right.m_sid ), m_initiator( right.m_initiator ),
+//         m_responder( right.m_responder )
+//     {
+//       PluginList::const_iterator it = right.m_plugins.begin();
+//       for( ; it != right.m_plugins.end(); ++it )
+//         m_plugins.push_back( (*it)->clone() );
+//     }
+
+    Session::Jingle::~Jingle()
+    {
+      util::clearList( m_plugins );
+    }
+
+    const std::string& Session::Jingle::filterString() const
+    {
+      static const std::string filter = "/iq/jingle[@xmlns='" + XMLNS_JINGLE + "']";
+      return filter;
+    }
+
+    Tag* Session::Jingle::tag() const
+    {
+      if( m_action == InvalidAction || m_sid.empty() )
+        return 0;
+
+      Tag* t = new Tag( "jingle" );
+      t->setXmlns( XMLNS_JINGLE );
+      t->addAttribute( "action", util::lookup( m_action, actionValues ) );
+
+      if( m_initiator && m_action == SessionInitiate )
+        t->addAttribute( "initiator", m_initiator.full() );
+
+      if( m_responder && m_action == SessionAccept )
+        t->addAttribute( "responder", m_responder.full() );
+
+      t->addAttribute( "sid", m_sid );
+
+      PluginList::const_iterator it = m_plugins.begin();
+      for( ; it != m_plugins.end(); ++it )
+        t->addChild( (*it)->tag() );
+
+      return t;
+    }
+
+    StanzaExtension* Session::Jingle::clone() const
+    {
+      return new Jingle( *this );
+    }
+    // ---- ~Session::Jingle ----
+
+    // ---- Session ----
+    Session::Session( ClientBase* parent, const JID& callee, SessionHandler* jsh )
+      : m_parent( parent ), m_state( Ended ), m_callee( callee ),
+        m_handler( jsh ), m_valid( false )
+    {
+      if( !m_parent || !m_handler || !m_callee )
+        return;
+
+      m_initiator = m_parent->jid();
+      m_sid = m_parent->getID();
+
+//       m_parent->registerIqHandler( this, ExtJingle );
+
+      m_valid = true;
+    }
+
+    Session::Session( ClientBase* parent, const Session::Jingle* jingle, SessionHandler* jsh )
+      : m_parent( parent ), m_state( Ended ), m_handler( jsh ), m_valid( false )
+    {
+      if( !m_parent || !m_handler /*|| !jingle || jingle->action() != SessionInitiate*/ )
+        return;
+
+//       m_parent->registerIqHandler( this, ExtJingle );
+      m_callee = m_parent->jid();
+//       m_initiator = jingle->initiator();
+//       m_state = Pending;
+      m_sid = jingle->sid();
+
+      m_valid = true;
+    }
+
+    Session::~Session()
+    {
+      if( m_parent )
+        m_parent->removeIDHandler( this );
+    }
+
+    bool Session::contentAccept( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( ContentAccept, content );
+    }
+
+    bool Session::contentAdd( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( ContentAdd, content );
+    }
+
+    bool Session::contentAdd( const PluginList& contents )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( ContentAdd, contents );
+    }
+
+    bool Session::contentModify( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( ContentModify, content );
+    }
+
+    bool Session::contentReject( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( ContentReject, content );
+    }
+
+    bool Session::contentRemove( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( ContentRemove, content );
+    }
+
+    bool Session::descriptionInfo( const Plugin* info )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( DescriptionInfo, info );
+    }
+
+    bool Session::securityInfo( const Plugin* info )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( SecurityInfo, info );
+    }
+
+    bool Session::sessionAccept( const Content* content )
+    {
+      if( !content || m_state > Pending )
+        return false;
+
+      m_state = Active;
+      return doAction( SessionAccept, content );
+    }
+
+    bool Session::sessionInfo( const Plugin* info )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( SessionInfo, info );
+    }
+
+    bool Session::sessionInitiate( const Content* content )
+    {
+      if( !content || !m_initiator || m_state >= Pending )
+        return false;
+
+      m_state = Pending;
+      return doAction( SessionInitiate, content );
+    }
+
+    bool Session::sessionInitiate( const PluginList& plugins )
+    {
+      if( plugins.empty() || !m_initiator || m_state >= Pending )
+        return false;
+
+      m_state = Pending;
+      return doAction( SessionInitiate, plugins );
+    }
+
+    bool Session::sessionTerminate( Session::Reason* reason )
+    {
+      if( m_state < Pending /*|| !m_initiator*/ )
+        return false;
+
+      m_state = Ended;
+
+      return doAction( SessionTerminate, reason );
+    }
+
+    bool Session::transportAccept( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( TransportAccept, content );
+    }
+
+    bool Session::transportInfo( const Plugin* info )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( TransportInfo, info );
+    }
+
+    bool Session::transportReject( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( TransportReject, content );
+    }
+
+    bool Session::transportReplace( const Content* content )
+    {
+      if( m_state < Pending )
+        return false;
+
+      return doAction( TransportReplace, content );
+    }
+
+    bool Session::doAction( Action action, const Plugin* plugin )
+    {
+      PluginList pl;
+      pl.push_back( plugin );
+      return doAction( action, pl );
+    }
+
+    bool Session::doAction( Action action, const PluginList& plugins )
+    {
+      if( !m_valid || !m_parent )
+        return false;
+
+      IQ init( IQ::Set, m_callee, m_parent->getID() );
+      init.addExtension( new Jingle( action, m_initiator, plugins, m_sid ) );
+      m_parent->send( init, this, action );
+
+      return true;
+    }
+
+    bool Session::handleIq( const IQ& iq )
+    {
+      const Jingle* j = iq.findExtension<Jingle>( ExtJingle );
+      if( !j || j->sid() != m_sid || !m_handler )
+        return false;
+
+      switch( j->action() )
+      {
+        case SessionAccept:
+          m_state = Active;
+          break;
+        case SessionInitiate:
+          m_state = Pending;
+          m_initiator = j->initiator();
+          break;
+        case SessionTerminate:
+          m_state = Ended;
+          break;
+        default:
+          break;
+      }
+
+      m_handler->handleSessionAction( j->action(), this, j );
+
+      IQ re( IQ::Result, iq.from(), iq.id() );
+      m_parent->send( re );
+
+      return true;
+    }
+
+    void Session::handleIqID( const IQ& iq, int context )
+    {
+      if( iq.subtype() == IQ::Error )
+      {
+
+        const Error* e = iq.findExtension<Error>( ExtError );
+        m_handler->handleSessionActionError( (Action)context, this, e );
+
+        switch( context )
+        {
+          case ContentAccept:
+            break;
+          case ContentAdd:
+            break;
+          case ContentModify:
+            break;
+          case ContentReject:
+            break;
+          case ContentRemove:
+            break;
+          case DescriptionInfo:
+            break;
+          case SessionAccept:
+            break;
+          case SessionInfo:
+            break;
+          case SessionInitiate:
+            m_state = Ended;
+            break;
+          case SessionTerminate:
+            break;
+          case TransportAccept:
+            break;
+          case TransportInfo:
+            break;
+          case TransportReject:
+            break;
+          case TransportReplace:
+            break;
+          case InvalidAction:
+            break;
+          default:
+            break;
+        }
+      }
+    }
+
+  }
+
+}

=== added file 'src/jinglesession.h'
--- src/jinglesession.h	1970-01-01 00:00:00 +0000
+++ src/jinglesession.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,512 @@
+/*
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLESESSION_H__
+#define JINGLESESSION_H__
+
+#include "stanzaextension.h"
+#include "tag.h"
+#include "iqhandler.h"
+#include "jingleplugin.h"
+
+#include <string>
+
+namespace gloox
+{
+
+  class ClientBase;
+
+  /**
+   * @brief The namespace containing Jingle-related (@xep{0166} et. al.) classes.
+   *
+   * See @link gloox::Jingle::SessionManager SessionManager @endlink for more information
+   * about Jingle in gloox.
+   *
+   * @author Jakob Schroeter <js@camaya.net>
+   * @since 1.0.5
+   */
+  namespace Jingle
+  {
+
+    class Description;
+    class Transport;
+    class SessionHandler;
+    class Content;
+
+    /**
+     * Jingle Session actions.
+     */
+    enum Action
+    {
+      ContentAccept,                /**< Accept a content-add action received from another party. */
+      ContentAdd,                   /**< Add one or more new content definitions to the session. */
+      ContentModify,                /**< Change the directionality of media sending. */
+      ContentReject,                /**< Reject a content-add action received from another party. */
+      ContentRemove,                /**< Remove one or more content definitions from the session. */
+      DescriptionInfo,              /**< Exchange information about parameters for an application type. */
+      SecurityInfo,                 /**< Send information related to establishment or maintenance of security preconditions. */
+      SessionAccept,                /**< Definitively accept a session negotiation. */
+      SessionInfo,                  /**< Send session-level information, such as a ping or a ringing message. */
+      SessionInitiate,              /**< Request negotiation of a new Jingle session. */
+      SessionTerminate,             /**< End an existing session. */
+      TransportAccept,              /**< Accept a transport-replace action received from another party. */
+      TransportInfo,                /**< Exchange transport candidates. */
+      TransportReject,              /**< Reject a transport-replace action received from another party. */
+      TransportReplace,             /**< Redefine a transport method or replace it with a different method. */
+      InvalidAction                 /**< Invalid action. */
+    };
+
+    /**
+     * @brief This is an implementation of a Jingle Session (@xep{0166}).
+     *
+     * See @link gloox::Jingle::SessionManager Jingle::SessionManager @endlink for info on how to use
+     * Jingle in gloox.
+     *
+     * XEP Version: 1.1
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.5
+     */
+    class GLOOX_API Session : public IqHandler
+    {
+
+      friend class SessionManager;
+
+      public:
+        /**
+         * Session state.
+         */
+        enum State
+        {
+          Ended,                    /**< The session has ended or was not active yet. */
+          Pending,                  /**< The session has been initiated but has not yet been accepted by the remote party. */
+          Active                    /**< The session is active. */
+        };
+
+        /**
+         * @brief An abstraction of a Jingle (@xep{0166}) session terminate reason.
+         *
+         * XEP Version: 1.1
+         *
+         * @author Jakob Schroeter <js@camaya.net>
+         * @since 1.0.5
+         */
+        class GLOOX_API Reason : public Plugin
+        {
+          public:
+            /**
+             * Defined reasons for terminating a Jingle Session.
+             */
+            enum Reasons
+            {
+              AlternativeSession,           /**< An alternative session exists that should be used. */
+              Busy,                         /**< The terminating party is busy. */
+              Cancel,                       /**< The session has been canceled. */
+              ConnectivityError,            /**< Connectivity error. */
+              Decline,                      /**< The terminating party formally declines the request. */
+              Expired,                      /**< The session has expired. */
+              FailedApplication,            /**< Application type setup failed. */
+              FailedTransport,              /**< Transport setup has failed. */
+              GeneralError,                 /**< General error. */
+              Gone,                         /**< Participant went away. */
+              IncompatibleParameters,       /**< Offered or negotiated application type parameters not supported. */
+              MediaError,                   /**< Media error. */
+              SecurityError,                /**< Security error. */
+              Success,                      /**< Session terminated after successful call. */
+              Timeout,                      /**< A timeout occured. */
+              UnsupportedApplications,      /**< The terminating party does not support any of the offered application formats. */
+              UnsupportedTransports,        /**< The terminating party does not support any of the offered transport methods. */
+              InvalidReason                 /**< Invalid reason. */
+            };
+
+            /**
+             * Constructor.
+             * @param reason The reason for the termination of the session.
+             * @param sid An optional session ID (only used if reason is AlternativeSession).
+             * @param text An optional human-readable text explaining the reason for the session termination.
+             */
+            Reason( Reasons reason, const std::string& sid = EmptyString,
+                    const std::string& text = EmptyString );
+
+            /**
+             * Constructs a new element by parsing the given Tag.
+             * @param tag A tag to parse.
+             */
+            Reason( const Tag* tag = 0 );
+
+            /**
+             * Virtual destructor.
+             */
+            virtual ~Reason() {}
+
+            /**
+             * Returns the reason for the session termination.
+             * @return The reason for the session termination.
+             */
+            Reasons reason() const { return m_reason; }
+
+            /**
+             * Returns the session ID of the alternate session, if given (only applicable
+             * if reason() returns AlternativeSession).
+             * @return The session ID of the alternative session, or an empty string.
+             */
+            const std::string& sid() const { return m_sid; }
+
+            /**
+             * Returns the content of an optional, human-readable
+             * &lt;text&gt; element.
+             * @return An optional text describing the reason for the terminate action.
+             */
+            const std::string& text() const { return m_text; }
+
+            // reimplemented from Plugin
+            virtual const std::string& filterString() const;
+
+            // reimplemented from Plugin
+            virtual Tag* tag() const;
+
+            // reimplemented from Plugin
+            virtual Plugin* newInstance( const Tag* tag ) const { return new Reason( tag ); }
+
+            // reimplemented from Plugin
+            virtual Plugin* clone() const;
+
+          private:
+            Reasons m_reason;
+            std::string m_sid;
+            std::string m_text;
+
+        };
+
+        /**
+         * @brief This is an abstraction of Jingle's (@xep{0166}) &lt;jingle&gt; element as a StanzaExtension.
+         *
+         * XEP Version: 1.1
+         * @author Jakob Schroeter <js@camaya.net>
+         * @since 1.0.5
+         */
+        class Jingle : public StanzaExtension
+        {
+
+          friend class Session;
+
+          public:
+            /**
+             * Constructs a new object from the given Tag.
+             * @param tag The Tag to parse.
+             */
+            Jingle( const Tag* tag = 0 );
+
+            /**
+             * Virtual Destructor.
+             */
+            virtual ~Jingle();
+
+            /**
+             * Returns the session ID.
+             * @return The session ID.
+             */
+            const std::string& sid() const { return m_sid; }
+
+            /**
+             * Set's the session's initiator.
+             * @param jid The session initiator's JID.
+             */
+            void setInitiator( const JID& jid ) { m_initiator = jid; }
+
+            /**
+             * Returns the initiator.
+             * @return The initiator.
+             */
+            const JID& initiator() const { return m_initiator; }
+
+            /**
+             * Set's the session's responder.
+             * @param jid The session responder's JID.
+             */
+            void setResponder( const JID& jid ) { m_responder = jid; }
+
+            /**
+             * Returns this Jingle's action.
+             * @return The action.
+             */
+            Action action() const { return m_action; }
+
+            /**
+             * Adds a Plugin as child.
+             * @param plugin A plugin to be embedded. Will be owned by this instance and deleted in the destructor.
+             */
+            void addPlugin( const Plugin* plugin ) { if( plugin ) m_plugins.push_back( plugin ); }
+
+            /**
+             * Returns a reference to a list of embedded plugins.
+             * @return A reference to a list of embedded plugins.
+             */
+            const PluginList& plugins() const { return m_plugins; }
+
+            /**
+             * Returns the tag to build plugins from.
+             * @return The tag to build plugins from.
+             */
+            Tag* embeddedTag() const { return m_tag; }
+
+            // reimplemented from StanzaExtension
+            virtual const std::string& filterString() const;
+
+            // reimplemented from StanzaExtension
+            virtual StanzaExtension* newInstance( const Tag* tag ) const
+            {
+              return new Jingle( tag );
+            }
+
+            // reimplemented from StanzaExtension
+            virtual Tag* tag() const;
+
+            // reimplemented from StanzaExtension
+            virtual StanzaExtension* clone() const;
+
+#ifdef JINGLE_TEST
+          public:
+#else
+          private:
+#endif
+            /**
+             * Constructs a new object and fills it according to the parameters.
+             * @param action The Action to carry out.
+             * @param initiator The full JID initiator of the session flow.
+             * @param plugins A list of contents (plugins) for the &lt;jingle&gt;
+             * element. Usually, this will be Content objects.
+             * @param sid The session ID:
+             */
+            Jingle( Action action, const JID& initiator,
+                    const PluginList& plugins, const std::string& sid );
+
+            /**
+             * Constructs a new object and fills it according to the parameters.
+             * @param action The Action to carry out.
+             * @param initiator The full JID initiator of the session flow.
+             * @param plugin A single content (plugin) for the &lt;jingle&gt;
+             * element. This may be Content object, but can be any Plugin-derived object.
+             * @param sid The session ID:
+             */
+            Jingle( Action action, const JID& initiator,
+                    const Plugin* plugin, const std::string& sid );
+
+//             /**
+//              * Copy constructor.
+//              * @param right The instance to copy.
+//              */
+//             Jingle( const Jingle& right );
+
+            Action m_action;
+            std::string m_sid;
+            JID m_initiator;
+            JID m_responder;
+            PluginList m_plugins;
+            Tag* m_tag;
+
+        };
+
+        /**
+         * Virtual Destructor.
+         */
+        virtual ~Session();
+
+        /**
+         * Sends a 'content-accept' notification.
+         * @param content The accepted content.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool contentAccept( const Content* content );
+
+        /**
+         * Sends a 'content-add' request.
+         * @param content The proposed content to be added.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool contentAdd( const Content* content );
+
+        /**
+         * Sends a 'content-add' request.
+         * @param contents A list of proposed content to be added.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool contentAdd( const PluginList& contents );
+
+        /**
+         * Sends a 'content-modify' request.
+         * @param content The proposed content type to be modified.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool contentModify( const Content* content );
+
+        /**
+         * Sends a 'content-reject' reply.
+         * @param content The rejected content.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool contentReject( const Content* content );
+
+        /**
+         * Sends a 'content-remove' request.
+         * @param content The content type to be removed.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool contentRemove( const Content* content );
+
+        /**
+         * Sends a 'description-info' notice.
+         * @param info The payload.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool descriptionInfo( const Plugin* info );
+
+        /**
+         * Sends a 'security-info' notice.
+         * @param info A security pre-condition.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool securityInfo( const Plugin* info );
+
+        /**
+         * Accepts an incoming session with the given content.
+         * @param content A pair of application description and transport method wrapped in a Content that describes
+         * the accepted session parameters.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool sessionAccept( const Content* content );
+
+        /**
+         * Sends a 'session-info' notice.
+         * @param info The payload.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool sessionInfo( const Plugin* info );
+
+        /**
+         * Initiates a session with a remote entity.
+         * @param content A Content object. You may use initiate( const PluginList& contents ) for more than one Content.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool sessionInitiate( const Content* content );
+
+        /**
+         * Initiates a session with a remote entity.
+         * @param plugins A list of Content objects. It is important to pass a (list of) Content objects here.
+         * Even though e.g. Jingle::ICEUDP are Plugin-derived, too, using anything other than Content here will result
+         * in erroneous behaviour at best. You may use sessionInitiate( const Content* content ) for just one Content.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool sessionInitiate( const PluginList& plugins );
+
+        /**
+         * Terminates the current session, if it is at least in Pending state, with the given reason. The sid parameter
+         * is ignored unless the reason is AlternativeSession.
+         * @param reason The reason for terminating the session.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool sessionTerminate( Session::Reason* reason );
+
+        /**
+         * Sends a 'transport-accept' reply.
+         * @param content The accepted transport wrapped in a Content.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool transportAccept( const Content* content );
+
+        /**
+         * Sends a 'transport-info' notice.
+         * @param info The payload.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool transportInfo( const Plugin* info );
+
+        /**
+         * Sends a 'transport-reject' reply.
+         * @param content The rejected transport wrapped in a Content.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool transportReject( const Content* content );
+
+        /**
+         * Sends a 'transport-replace' request.
+         * @param content The proposed transport to be replaced wrapped in a Content.
+         * @return @b False if a prerequisite is not met, @b true otherwise.
+         */
+        bool transportReplace( const Content* content );
+
+        /**
+         * Returns the session's state.
+         * @return The session's state.
+         */
+        State state() const { return m_state; }
+
+        /**
+         * Sets the session's ID.
+         * @param sid  The session's id.
+         */
+        void setSID( const std::string& sid ) { m_sid = sid; }
+
+        /**
+         * Returns the session's ID.
+         * @return The session's ID.
+         */
+        const std::string& sid() const { return m_sid; }
+
+        // reimplemented from IqHandler
+        virtual bool handleIq( const IQ& iq );
+
+        // reimplemented from IqHandler
+        virtual void handleIqID( const IQ& iq, int context );
+
+#ifdef JINGLE_TEST
+      public:
+#else
+      private:
+#endif
+        /**
+         * Creates a new Jingle Session.
+         * @param parent The ClientBase to use for communication.
+         * @param callee The remote end of the session.
+         * @param jsh The handler to receive events and results.
+         */
+        Session( ClientBase* parent, const JID& callee, SessionHandler* jsh );
+
+        /**
+         * Creates a new Session from the incoming Jingle object.
+         * This is a NOOP for Jingles that have an action() different from SessionInitiate.
+         * @param parent The ClientBase to use for communication.
+         * @param jingle The Jingle object to init the Session from.
+         * @param jsh The handler to receive events and results.
+         */
+        Session( ClientBase* parent, const Session::Jingle* jingle,
+                 SessionHandler* jsh );
+
+        bool doAction( Action action, const Plugin* plugin );
+        bool doAction( Action action, const PluginList& plugin );
+
+        ClientBase* m_parent;
+        State m_state;
+        JID m_callee;
+        JID m_initiator;
+        SessionHandler* m_handler;
+        std::string m_sid;
+        bool m_valid;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLESESSION_H__

=== added file 'src/jinglesessionhandler.h'
--- src/jinglesessionhandler.h	1970-01-01 00:00:00 +0000
+++ src/jinglesessionhandler.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,74 @@
+/*
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLESESSIONHANDLER_H__
+#define JINGLESESSIONHANDLER_H__
+
+#include "macros.h"
+#include "jinglesession.h"
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    /**
+     * @brief A Jingle session handler.
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.5
+     */
+    class GLOOX_API SessionHandler
+    {
+      public:
+        /**
+         * Virtual destructor.
+         */
+        virtual ~SessionHandler() {}
+
+        /**
+         * This function is called when the remote party requests an action to be taken.
+         * @param action The requested action. A convenience parameter, identical to jingle->action().
+         * @param session The affected session.
+         * @param jingle The complete Jingle.
+         * @note Note that an action can cause a session state change. You may check using session->state().
+         * @note Also note that you have to reply to most actions, usually with the *Accept or *Reject counterpart,
+         * using the similarly-named functions that Session offers.
+         */
+        virtual void handleSessionAction( Action action, const Session* session, const Session::Jingle* jingle ) = 0;
+
+        /**
+         * This function is called when a request to a remote entity returns an error.
+         * @param action The Action that failed.
+         * @param session The affected session.
+         * @param error The error. May be 0 in special cases.
+         * @note Note that an action can cause a session state change. You may check using session->state().
+         */
+        virtual void handleSessionActionError( Action action, const Session* session, const Error* error ) = 0;
+
+        /**
+         * This function is called if a remote entity wants to establish a Jingle session.
+         * @param session The new Jingle session.
+         * @note Note that you have to explicitely accept or reject the session by calling either of session->sessionAccept() and
+         * session->sessionReject(), respectively.
+         */
+        virtual void handleIncomingSession( Session* session ) = 0;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLESESSIONHANDLER_H__

=== added file 'src/jinglesessionmanager.cpp'
--- src/jinglesessionmanager.cpp	1970-01-01 00:00:00 +0000
+++ src/jinglesessionmanager.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,103 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#include "jinglesessionmanager.h"
+
+#include "clientbase.h"
+#include "jinglesession.h"
+#include "jinglesessionhandler.h"
+#include "disco.h"
+#include "util.h"
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    SessionManager::SessionManager( ClientBase* parent, SessionHandler* sh )
+      : m_parent( parent ), m_handler( sh )
+    {
+      if( m_parent )
+      {
+        m_parent->registerStanzaExtension( new Session::Jingle() );
+        m_parent->registerIqHandler( this, ExtJingle );
+        m_parent->disco()->addFeature( XMLNS_JINGLE );
+      }
+    }
+
+    SessionManager::~SessionManager()
+    {
+      util::clearList( m_sessions );
+    }
+
+    void SessionManager::registerPlugin( Plugin* plugin )
+    {
+      if( !plugin )
+        return;
+
+      m_factory.registerPlugin( plugin );
+      if( m_parent )
+      {
+        StringList features = plugin->features();
+        StringList::const_iterator it = features.begin();
+        for( ; it != features.end(); ++it )
+          m_parent->disco()->addFeature( (*it) );
+      }
+    }
+
+    Session* SessionManager::createSession( const JID& callee, SessionHandler* handler )
+    {
+      if( !( handler || m_handler ) || !callee )
+        return 0;
+
+      Session* sess = new Session( m_parent, callee, handler ? handler : m_handler );
+      m_sessions.push_back( sess );
+      return sess;
+    }
+
+    void SessionManager::discardSession( Session* session )
+    {
+      if( !session )
+        return;
+
+      m_sessions.remove( session );
+      delete session;
+    }
+
+    bool SessionManager::handleIq( const IQ& iq )
+    {
+      const Session::Jingle* j = iq.findExtension<Session::Jingle>( ExtJingle );
+      if( !j )
+        return false;
+
+      m_factory.addPlugins( const_cast<Session::Jingle&>( *j ), j->embeddedTag() );
+
+      SessionList::iterator it = m_sessions.begin();
+      for( ; it != m_sessions.end() && (*it)->sid() != j->sid(); ++it ) ;
+      if( it == m_sessions.end() )
+      {
+        Session* s = new Session( m_parent, j, m_handler );
+        m_handler->handleIncomingSession( s );
+        s->handleIq( iq );
+      }
+      else
+      {
+        (*it)->handleIq( iq );
+      }
+      return true;
+    }
+
+  }
+
+}

=== added file 'src/jinglesessionmanager.h'
--- src/jinglesessionmanager.h	1970-01-01 00:00:00 +0000
+++ src/jinglesessionmanager.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,117 @@
+/*
+  Copyright (c) 2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLESESSIONMANAGER_H__
+#define JINGLESESSIONMANAGER_H__
+
+#include "macros.h"
+#include "iqhandler.h"
+#include "jinglepluginfactory.h"
+
+#include <list>
+
+namespace gloox
+{
+
+  class ClientBase;
+
+  namespace Jingle
+  {
+
+    class Session;
+    class SessionHandler;
+
+    /**
+     * @brief The SessionManager is responsible for creating and destroying Jingle sessions, as well as for delegating incoming
+     * IQs to their respective sessions. This is part of Jingle (@xep{0166}).
+     *
+     * @note The classes in the Jingle namespace implement the signaling part of Jingle only.
+     * Establishing connections to a remote entity or transfering data outside the XMPP channel
+     * is out of scope of gloox.
+     *
+     * To use Jingle with gloox you should first instantiate a Jingle::SessionManager. The SessionManager will
+     * let you create new Jingle sessions and notify the respective handler about incoming Jingle session requests.
+     * It will also announce generic Jingle support via Disco. You have to register any
+     * @link gloox::Jingle::Plugin Jingle plugins @endlink you want to use using registerPlugin().
+     * These will automatically announce any additional features via Disco.
+     *
+     * Use createSession() to create a new Session.
+     *
+     * Implement SessionHandler::handleIncomingSession() to receive incoming session requests.
+     *
+     * Use discardSession() to get rid of a session. Do not delete a session manually.
+     *
+     * There is no limit to the number of concurrent sessions.
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.5
+     */
+    class GLOOX_API SessionManager : public IqHandler
+    {
+      public:
+        /**
+         * Creates new instance. There should be only one SessionManager per ClientBase.
+         * @param parent A ClientBase instance used for sending and receiving.
+         * @param sh A session handler that will be notified about incoming session requests.
+         * Only handleIncomingSession() will be called in that handler.
+         */
+        SessionManager( ClientBase* parent, SessionHandler* sh );
+
+        /**
+         * Virtual destructor.
+         */
+        virtual ~SessionManager();
+
+        /**
+         * Registers an empty Plugin as a template with the manager.
+         * @param plugin The plugin to register.
+         */
+        void registerPlugin( Plugin* plugin );
+
+        /**
+         * Lets you create a new Jingle session.
+         * @param callee The remote entity's JID.
+         * @param handler The handler responsible for handling events assicoated with the new session.
+         * @return The new session.
+         * @note You should not delete a session yourself. Instead, pass it to discardSession().
+         */
+        Session* createSession( const JID& callee, SessionHandler* handler );
+
+        /**
+         * Removes a given session from the nternal queue and deletes it.
+         * @param session The session to delete.
+         */
+        void discardSession( Session* session );
+
+
+        // reimplemented from IqHandler
+        virtual bool handleIq( const IQ& iq );
+
+        // reimplemented from IqHandler
+        virtual void handleIqID( const IQ& /*iq*/, int /*context*/ ) {}
+
+      private:
+        typedef std::list<Jingle::Session*> SessionList;
+
+        SessionList m_sessions;
+        ClientBase* m_parent;
+        SessionHandler* m_handler;
+        PluginFactory m_factory;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLESESSIONMANAGER_H__

=== added file 'src/jingletransport.h'
--- src/jingletransport.h	1970-01-01 00:00:00 +0000
+++ src/jingletransport.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,56 @@
+/*
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef JINGLETRANSPORT_H__
+#define JINGLETRANSPORT_H__
+
+#include "jingleplugin.h"
+
+#include <string>
+
+namespace gloox
+{
+
+  namespace Jingle
+  {
+
+    /**
+     * @brief An abstract base class of a Jingle Transport. This is part of Jingle (@xep{0166}).
+     *
+     * You should not need to use this class directly unless you are extending gloox. See
+     * @link gloox::Jingle::Session Jingle::Session @endlink for more info on Jingle.
+     *
+     * XEP Version: 1.1
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.5
+     */
+    class Transport : public Plugin
+    {
+      public:
+        /**
+         * Virtual destructor.
+         */
+        virtual ~Transport() {}
+
+      protected:
+        /** The Transport's namespace. */
+//         const std::string m_xmlns;
+
+    };
+
+  }
+
+}
+
+#endif // JINGLETRANSPORT_H__

=== modified file 'src/lastactivity.cpp'
--- src/lastactivity.cpp	2010-01-17 13:05:04 +0000
+++ src/lastactivity.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/lastactivity.h'
--- src/lastactivity.h	2010-01-17 13:05:04 +0000
+++ src/lastactivity.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
   class LastActivityHandler;
 
   /**
-   * @brief This is an implementation of XEP-0012 (Last Activity) for both clients and components.
+   * @brief This is an implementation of @xep{0012} (Last Activity) for both clients and components.
    *
    * LastActivity can be used to query remote entities about their last activity time as well
    * as answer incoming last-activity-queries.
@@ -41,10 +41,10 @@
     public:
       /**
        * @brief This is an abstraction of a LastActivity Query that
-       * can be used in XEP-0012 as well as XEP-0256.
+       * can be used in @xep{0012} as well as @xep{0256}.
        *
-       * XEP-Version: 2.0 (XEP-0012)
-       * XEP-Version: 0.1 (XEP-0256)
+       * XEP-Version: 2.0 (@xep{0012})
+       * XEP-Version: 0.1 (@xep{0256})
        *
        * @author Jakob Schroeter <js@camaya.net>
        * @since 1.0

=== modified file 'src/lastactivityhandler.h'
--- src/lastactivityhandler.h	2010-01-17 13:05:04 +0000
+++ src/lastactivityhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== added file 'src/linklocal.h'
--- src/linklocal.h	1970-01-01 00:00:00 +0000
+++ src/linklocal.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,79 @@
+/*
+  Copyright (c) 2012-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+#ifndef LINKLOCAL_H__
+#define LINKLOCAL_H__
+
+#include "config.h"
+
+#ifdef HAVE_MDNS
+
+#include <string>
+#include <list>
+
+namespace gloox
+{
+
+  /**
+   * @brief Namespace holding all the Link-local-related structures and definitions.
+   *
+   * See @ref gloox::LinkLocal::Manager for more information on how to implement
+   * link-local messaging.
+   */
+  namespace LinkLocal
+  {
+
+    class Client;
+
+    /**
+     * Used in conjunction with Service to indicate whether a service has been added (newly advertised) or removed.
+     */
+    enum Flag
+    {
+      AddService,            /**< A service has been added. */
+      RemoveService          /**< A service has been removed. */
+    };
+    
+    /**
+     * @brief An abstraction of the parameters of a single link-local service.
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.x
+     */
+    struct Service
+    {
+      friend class Manager;
+
+      private:
+        Service( Flag _flag, const std::string& _service, const std::string& _regtype, const std::string& _domain, int _interface )
+         : flag( _flag ), service( _service ), regtype( _regtype ), domain( _domain ), interface( _interface ) {}
+
+      public:
+        Flag flag;
+        std::string service;
+        std::string regtype;
+        std::string domain;
+        int interface;
+    };
+
+    /**
+     * A list of services.
+     */
+    typedef std::list<Service> ServiceList;
+    
+  }
+
+}
+
+#endif // HAVE_MDNS
+
+#endif // LINKLOCAL_H__

=== added file 'src/linklocalclient.cpp'
--- src/linklocalclient.cpp	1970-01-01 00:00:00 +0000
+++ src/linklocalclient.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,219 @@
+/*
+  Copyright (c) 2012-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+ 
+  This software is distributed without any warranty.
+*/
+
+#include "linklocalclient.h"
+
+#ifdef HAVE_MDNS
+
+#include "gloox.h"
+#include "tag.h"
+#include "util.h"
+#include "connectiontcpclient.h"
+
+#include <cstdio>
+
+#if ( !defined( _WIN32 ) && !defined( _WIN32_WCE ) ) || defined( __SYMBIAN32__ )
+# include <arpa/inet.h>
+#endif
+
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+# include <winsock.h>
+#elif defined( _WIN32_WCE )
+# include <winsock2.h>
+#endif
+
+namespace gloox
+{
+
+  namespace LinkLocal
+  {
+
+    Client::Client( const JID& jid )
+      : gloox::Client( jid, EmptyString ), m_qRef( 0 ), m_rRef( 0 ), m_currentRef( 0 ),
+        m_interface( 0 ), m_port( 0 ), m_streamSent( false )
+    {
+    }
+
+    Client::~Client()
+    {
+    }
+
+    bool Client::connect()
+    {
+      return ClientBase::connect( false );
+    }
+
+    bool Client::connect( const std::string& service, const std::string& type,
+                          const std::string& domain, int interface )
+    {
+      m_interface = interface;
+      return resolve( service, type, domain );
+    }
+
+    ConnectionError Client::recv( int timeout )
+    {
+      if( m_connection && m_connection->state() == StateConnected )
+        return ClientBase::recv( timeout );
+      else
+      {
+        if( !m_currentRef )
+          return ConnNoError;
+        
+        struct timeval tv;
+        
+        fd_set fds;
+        FD_ZERO( &fds );
+        // the following causes a C4127 warning in VC++ Express 2008 and possibly other versions.
+        // however, the reason for the warning can't be fixed in gloox.
+        FD_SET( DNSServiceRefSockFD( m_currentRef ), &fds );
+        
+        tv.tv_sec = timeout / 1000000;
+        tv.tv_usec = timeout % 1000000;
+        
+        if( select( FD_SETSIZE, &fds, 0, 0, timeout == -1 ? 0 : &tv ) > 0 )
+        {
+          if( FD_ISSET( DNSServiceRefSockFD( m_currentRef ), &fds ) != 0 )
+            DNSServiceProcessResult( m_currentRef );
+        }
+        
+        return ConnNoError;
+      }
+    }
+    
+
+    bool Client::resolve( const std::string& service, const std::string& type,
+                          const std::string& domain )
+    {
+      m_to = service;
+      m_rRef = 0;
+      DNSServiceErrorType e = DNSServiceResolve( &m_rRef, 0, m_interface, service.c_str(), type.c_str(),
+                                                domain.c_str(), &handleResolveReply, this );
+      if( e != kDNSServiceErr_NoError )
+      {
+        DNSServiceRefDeallocate( m_rRef );
+        m_rRef = 0;
+        return false;
+      }
+      m_currentRef = m_rRef;
+
+      return true;
+    }
+
+    void Client::handleResolveReply( DNSServiceRef sdRef, DNSServiceFlags flags, uint32_t interfaceIndex,
+                                     DNSServiceErrorType errorCode, const char* fullname, const char* hosttarget,
+                                     uint16_t port, uint16_t txtLen, const unsigned char* txtRecord, void* context )
+    {
+      if( !context || errorCode != kDNSServiceErr_NoError )
+        return;
+
+      // printf("Client::handleResolveReply susccessful, querying %s\n", hosttarget );
+
+      static_cast<Client*>( context )->query( hosttarget, ntohs( port ) );
+    }
+
+    bool Client::query( const std::string& hostname, int port )
+    {
+      m_port = port;
+      m_qRef = 0;
+      DNSServiceErrorType e = DNSServiceQueryRecord( &m_qRef, 0, m_interface, hostname.c_str(), kDNSServiceType_A,
+                                                    kDNSServiceClass_IN, &handleQueryReply, this );
+      if( e != kDNSServiceErr_NoError )
+      {
+        // printf( "Client::query() failed\n" );
+        DNSServiceRefDeallocate( m_qRef );
+        m_qRef = 0;
+        return false;
+      }
+      m_currentRef = m_qRef;
+
+      return true;
+    }
+
+    void Client::handleQueryReply( DNSServiceRef sdRef, DNSServiceFlags flags, uint32_t interfaceIndex,
+                                   DNSServiceErrorType errorCode, const char *fullname, uint16_t rrtype,
+                                   uint16_t rrclass, uint16_t rdlen, const void *rdata, uint32_t ttl,
+                                   void *context )
+    {
+      // printf("Client::handleQueryReply returned\n" );
+
+      if( !context || errorCode != kDNSServiceErr_NoError )
+        return;
+
+      const unsigned char* rd = static_cast<const unsigned char*>( rdata );
+      std::string addr = util::int2string( rd[0] );
+      addr += '.';
+      addr += util::int2string( rd[1] );
+      addr += '.';
+      addr += util::int2string( rd[2] );
+      addr += '.';
+      addr += util::int2string( rd[3] );
+      // printf( "host %s is at %s\n", fullname, addr.c_str() );
+      static_cast<Client*>( context )->handleQuery( addr );
+    }
+
+    void Client::handleQuery( const std::string& addr )
+    {
+      if( m_rRef )
+      {
+        DNSServiceRefDeallocate( m_rRef );
+        m_rRef = 0;
+      }
+
+      ConnectionTCPClient* connection = new ConnectionTCPClient( this, logInstance(), addr, m_port );
+      // printf( "LinkLocal::Client: connecting to %s:%d\n", addr.c_str(), m_port );
+      ConnectionError e = connection->connect();
+      if( e != ConnNoError )
+      {
+        // printf( "connection error: %d\n", e );
+        delete connection;
+      }
+    }
+
+    void Client::handleConnect( const ConnectionBase* connection )
+    {
+      if( m_qRef )
+      {
+        DNSServiceRefDeallocate( m_qRef );
+        m_qRef = 0;
+        m_currentRef = 0;
+      }
+
+      // printf( "LinkLocal::Client::handleConnect()!!!\n" );
+      ConnectionBase* cb = const_cast<ConnectionBase*>( connection );
+      gloox::Client::setConnectionImpl( cb );
+      gloox::Client::connect( false );
+      sendStart( m_to );
+    }
+
+    void Client::handleStartNode( const Tag* start )
+    {
+      // printf( "LinkLocal::Client::handleStartNode()\n" );
+      if( start && !m_streamSent )
+        sendStart( start->findAttribute( "from" ) );
+    }
+
+    void Client::sendStart( const std::string& to )
+    {
+      m_streamSent = true;
+      std::string s = "<?xml version='1.0' encoding='UTF-8'?><stream:stream xmlns='jabber:client' xmlns:stream='http://etherx.jabber.org/streams' to='";
+      s += to;
+      s += "' from='";
+      s += m_jid.full().c_str();
+      s += "' version='1.0'>";
+      send( s );
+    }
+
+  }
+
+}
+
+#endif // HAVE_MDNS

=== added file 'src/linklocalclient.h'
--- src/linklocalclient.h	1970-01-01 00:00:00 +0000
+++ src/linklocalclient.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,125 @@
+/*
+  Copyright (c) 2012-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+ 
+  This software is distributed without any warranty.
+*/
+
+
+#ifndef LINKLOCALCLIENT_H__
+#define LINKLOCALCLIENT_H__
+
+#include "config.h"
+
+#ifdef HAVE_MDNS
+
+#include "client.h"
+#include "jid.h"
+
+#include <string>
+
+#include <dns_sd.h>
+
+namespace gloox
+{
+
+  class Tag;
+
+  namespace LinkLocal
+  {
+
+    /**
+     * @brief An implementation of a link-local client.
+     *
+     * See @ref gloox::LinkLocal::Manager for more information on how to implement
+     * link-local messaging.
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.x
+     */
+    class Client : public gloox::Client
+    {
+      public:
+        /**
+         * Constructs a new instance.
+         * @param jid The local JID to use.
+         */
+        Client( const JID& jid );
+
+        /**
+         * Virtual destructor.
+         */
+        virtual ~Client();
+
+        /**
+         * Internally sets up an already connected connection.
+         * @note Use this function only on a Client instance that you created for an @b incoming connection.
+         */
+        bool connect();
+        
+        /**
+         * Starts resolving the given service. Use values from Handler::handleBrowseReply().
+         * @param service The service to connect to.
+         * @param type The service type.
+         * @param domain The service's domain.
+         * @param interface The network interface the service was found on. May be 0 to try
+         * to resolve the service on all available interfaces.
+         * @return @b True if resolving the service could be started successfully, @b false otherwise.
+         * @note Use this function only for @b outgoing connections.
+         */
+        bool connect( const std::string& service, const std::string& type, const std::string& domain, int interface = 0 );
+
+        /**
+         * Call this periodically to receive data from the underlying socket.
+         * @param timeout An optional timeout in microseconds. Default of -1 means blocking
+         * until data was available.
+         * @return The state of the underlying connection.
+         */
+        virtual ConnectionError recv( int timeout = -1 );
+        
+        // reimplemented from ConnectionDataHandler, overwriting ClientBase::handleConnect()
+        virtual void handleConnect( const ConnectionBase* connection );
+                
+      protected:
+        // reimplemented from ClientBase
+        virtual void handleStartNode( const Tag* start );
+
+      private:
+        static void handleResolveReply( DNSServiceRef sdRef, DNSServiceFlags flags, uint32_t interfaceIndex,
+                                        DNSServiceErrorType errorCode, const char *fullname, const char *hosttarget,
+                                        uint16_t port, uint16_t txtLen, const unsigned char *txtRecord, void *context );
+        static void handleQueryReply( DNSServiceRef sdRef, DNSServiceFlags flags, uint32_t interfaceIndex,
+                                      DNSServiceErrorType errorCode, const char *fullname, uint16_t rrtype,
+                                      uint16_t rrclass, uint16_t rdlen, const void *rdata, uint32_t ttl,
+                                      void *context );
+
+        bool resolve( const std::string& serviceName, const std::string& regtype, const std::string& replyDomain );
+        bool query( const std::string& hostname, int port );
+        void handleQuery( const std::string& addr );
+        void sendStart( const std::string& to );
+
+        DNSServiceRef m_qRef;
+        DNSServiceRef m_rRef;
+        DNSServiceRef m_currentRef;
+
+        std::string m_to;
+        
+        int m_interface;
+        int m_port;
+
+        bool m_streamSent;
+
+    };
+
+  }
+
+}
+
+#endif // HAVE_MDNS
+
+#endif // LINKLOCALCLIENT_H__

=== added file 'src/linklocalhandler.h'
--- src/linklocalhandler.h	1970-01-01 00:00:00 +0000
+++ src/linklocalhandler.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,66 @@
+/*
+  Copyright (c) 2012-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+#ifndef LINKLOCALHANDLER_H__
+#define LINKLOCALHANDLER_H__
+
+#ifdef HAVE_MDNS
+
+#include "linklocal.h"
+#include "macros.h"
+#include "gloox.h"
+
+#include <string>
+
+namespace gloox
+{
+
+  namespace LinkLocal
+  {
+
+//     class Client;
+
+    /**
+     * @brief A base class that gets informed about advertised or removed XMPP services on the local network.
+     *
+     * See @ref gloox::LinkLocal::Manager for more information on how to implement
+     * link-local messaging.
+     * 
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.x
+     */
+    class GLOOX_API Handler
+    {
+      public:
+        /**
+         * Reimplement this function to be notified about services available on (or removed from)
+         * the local network.
+         * @param services A list of services.
+         * @note Make a copy of the service list as the list will not be valid after the function
+         * returned.
+         */
+        virtual void handleBrowseReply( const ServiceList& services ) = 0;
+
+//         /**
+//          *
+//          */
+//         virtual void handleClient( Client* client ) = 0;
+
+    };
+
+  }
+
+}
+
+#endif // HAVE_MDNS
+
+#endif // LINKLOCALHANDLER_H__

=== added file 'src/linklocalmanager.cpp'
--- src/linklocalmanager.cpp	1970-01-01 00:00:00 +0000
+++ src/linklocalmanager.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,255 @@
+/*
+  Copyright (c) 2012-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+ 
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+ 
+  This software is distributed without any warranty.
+*/
+
+#include "linklocalmanager.h"
+
+#ifdef HAVE_MDNS
+
+#include "linklocalhandler.h"
+#include "connectiontcpclient.h"
+#include "jid.h"
+#include "util.h"
+
+#include <cstdio>
+#include <unistd.h>
+
+#if ( !defined( _WIN32 ) && !defined( _WIN32_WCE ) ) || defined( __SYMBIAN32__ )
+# include <arpa/inet.h>
+#endif
+
+#if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+# include <winsock.h>
+#elif defined( _WIN32_WCE )
+# include <winsock2.h>
+#endif
+
+#define LINKLOCAL_SERVICE_PORT 5562
+
+const std::string LINKLOCAL_SERVICE_TYPE = "_presence._tcp";
+
+namespace gloox
+{
+
+  namespace LinkLocal
+  {
+
+    Manager::Manager( const std::string& user, ConnectionHandler* connHandler, const LogSink &logInstance )
+      : m_publishRef( 0 ), m_browseRef( 0 ), m_user( user ), m_interface( 0 ), m_port( 0 ),
+        m_logInstance( logInstance ), m_browseFd( 0 ), m_server( connHandler, m_logInstance, EmptyString, LINKLOCAL_SERVICE_PORT ),
+        m_linkLocalHandler( 0 ), m_connectionHandler( connHandler )
+    {
+
+      setPort( LINKLOCAL_SERVICE_PORT ); // does more than just setting m_port
+      addTXTData( "node", GLOOX_CAPS_NODE );
+    }
+
+    Manager::~Manager()
+    {
+      deregisterService();
+      stopBrowsing();
+    }
+
+    void Manager::addTXTData( const std::string& key, const std::string& value )
+    {
+      if( value.empty() || key.empty() || key == "txtvers" )
+        return;
+
+      m_txtData[key] = value;
+    }
+
+    void Manager::removeTXTData( const std::string& key )
+    {
+      m_txtData.erase( key );
+    }
+
+    void Manager::registerService()
+    {
+      if( m_publishRef )
+        deregisterService();
+
+      m_server.connect();
+
+      std::string txtRecord;
+      txtRecord += (char)9; // length of mandatory txtvers=1
+      txtRecord += "txtvers=1"; // this is here because it SHOULD be the first entry
+      StringMap::const_iterator it = m_txtData.begin();
+      for( ; it != m_txtData.end(); ++it )
+      {
+        txtRecord += (char)( (*it).first.length() + (*it).second.length() + 1 );
+        txtRecord += (*it).first;
+        txtRecord += '=';
+        txtRecord += (*it).second;
+      }
+
+      std::string service = m_user + "@";
+      if( m_host.empty() )
+      {
+        char host[65];
+        gethostname( host, 65 );
+        service += host;
+      }
+      else
+        service += m_host;
+
+      /*DNSServiceErrorType e =*/ DNSServiceRegister( &m_publishRef,
+                                                  0,                                      // flags
+                                                  m_interface,                            // interface, 0 = any, -1 = local only
+                                                  service.c_str(),                        // service name, 0 = local computer name
+                                                  LINKLOCAL_SERVICE_TYPE.c_str(),              // service type
+                                                  m_domain.c_str(),                       // domain, 0 = default domain(s)
+                                                  m_host.c_str(),                         // host, 0 = default host name(s)
+                                                  htons( m_port ),                        // port
+                                                  (short unsigned int)txtRecord.length(), // TXT record length
+                                                  (const void*)txtRecord.c_str(),         // TXT record
+                                                  0,                                      // callback
+                                                  0 );                                    // context
+    }
+
+    void Manager::deregisterService()
+    {
+      if( m_publishRef )
+      {
+        DNSServiceRefDeallocate( m_publishRef );
+        m_publishRef = 0;
+      }
+    }
+
+    bool Manager::startBrowsing()
+    {
+      if( !m_linkLocalHandler )
+        return false;
+
+      if( m_browseRef )
+        stopBrowsing();
+
+      DNSServiceErrorType e = DNSServiceBrowse( &m_browseRef,
+                                                0,                              // flags, currently ignored
+                                                m_interface,                    // interface, 0 = any, -1 = local only
+                                                LINKLOCAL_SERVICE_TYPE.c_str(), // service type
+                                                m_domain.c_str(),               // domain, 0 = default domain(s)
+                                                &handleBrowseReply,             // callback
+                                                this );                         // context
+      if ( e != kDNSServiceErr_NoError )
+        return false;
+
+      return true;
+    }
+
+    void Manager::stopBrowsing()
+    {
+      if( m_browseRef )
+      {
+        DNSServiceRefDeallocate( m_browseRef );
+        m_browseRef = 0;
+      }
+    }
+
+    void Manager::recv( int timeout )
+    {
+      if( !m_browseRef )
+        return;
+
+      struct timeval tv;
+
+      fd_set fds;
+      FD_ZERO( &fds );
+      // the following causes a C4127 warning in VC++ Express 2008 and possibly other versions.
+      // however, the reason for the warning can't be fixed in gloox.
+      FD_SET( DNSServiceRefSockFD( m_browseRef ), &fds );
+
+      tv.tv_sec = timeout / 1000000;
+      tv.tv_usec = timeout % 1000000;
+
+      if( select( FD_SETSIZE, &fds, 0, 0, timeout == -1 ? 0 : &tv ) > 0 )
+      {
+        if( FD_ISSET( DNSServiceRefSockFD( m_browseRef ), &fds ) != 0 )
+          DNSServiceProcessResult( m_browseRef );
+      }
+
+      m_server.recv( timeout );
+    }
+
+
+    void Manager::handleBrowseReply( DNSServiceRef /*sdRef*/, DNSServiceFlags flags, uint32_t interfaceIndex,
+                                        DNSServiceErrorType errorCode, const char* serviceName, const char* regtype,
+                                        const char* replyDomain, void* context )
+    {
+      if( !context || errorCode != kDNSServiceErr_NoError )
+        return;
+
+      Flag f = ( flags & kDNSServiceFlagsAdd ) == kDNSServiceFlagsAdd
+                                              ? AddService
+                                              : RemoveService;
+
+      Manager* m = static_cast<Manager*>( context );
+      m->handleBrowse( f, serviceName, regtype, replyDomain, interfaceIndex, ( flags & kDNSServiceFlagsMoreComing ) == kDNSServiceFlagsMoreComing );
+                                              
+    }
+
+    void Manager::handleBrowse( Flag flag, const std::string& service, const std::string& regtype, const std::string& domain, int interface, bool moreComing )
+    {
+      Service s( flag, service, regtype, domain, interface );
+      m_tmpServices.push_back( s );
+
+//       switch( flag )
+//       {
+//         case AddService:
+//         {
+//           m_services.push_back( s );
+//           break;
+//         }
+//         case RemoveService:
+//         {
+//           ServiceList::iterator it = m_services.begin();
+//           for( ; it != m_services.end(); ++it )
+//           {
+//             if( (*it)->service == service && (*it)->regtype == regtype && (*it)->domain == domain )
+//             {
+//               m_services.erase( it );
+//             }
+//           }
+//           break;
+//         }
+//       }
+
+      if( !moreComing )
+      {
+        m_linkLocalHandler->handleBrowseReply( m_tmpServices );
+        m_tmpServices.clear();
+      }
+    }
+
+
+//     const StringMap Manager::decodeTXT( const std::string& txt )
+//     {
+//       StringMap result;
+//       if( txt.empty() )
+//         return result;
+// 
+//       std::string::const_iterator it = txt.begin();
+//       while( it < txt.end() )
+//       {
+//         int len = (int)(*it);
+//         std::string tmp( ++it, it + len + 1 );
+//         it += len;
+//         size_t pos = tmp.find( '=' );
+//         result.insert( std::make_pair( tmp.substr( 0, pos ), tmp.substr( pos + 1 ) ) );
+//       }
+// 
+//       return result;
+//     }
+
+  }
+
+}
+
+#endif // HAVE_MDNS

=== added file 'src/linklocalmanager.h'
--- src/linklocalmanager.h	1970-01-01 00:00:00 +0000
+++ src/linklocalmanager.h	2014-01-16 10:42:06 +0000
@@ -0,0 +1,356 @@
+/*
+  Copyright (c) 2012-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+ 
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+#ifndef LINKLOCALMANAGER_H___
+#define LINKLOCALMANAGER_H___
+
+#include "config.h"
+
+#ifdef HAVE_MDNS
+
+#include "linklocal.h"
+#include "macros.h"
+#include "gloox.h"
+#include "util.h"
+#include "logsink.h"
+#include "connectiontcpserver.h"
+#include "mutex.h"
+#include "jid.h"
+
+#include <string>
+
+#include <dns_sd.h>
+
+namespace gloox
+{
+
+  class ConnectionHandler;
+  class ConnectionTCPClient;
+
+  namespace LinkLocal
+  {
+
+    class Handler;
+
+    /**
+     * @brief This is a manager for server-less messaging (@xep{0174}).
+     *
+     * Enable compilation of this code with the @c \-\-enable-mdns switch to @c configure, or add
+     * @c \#define @c HAVE_MDNS to your platform's @c config.h. @c dns_sd.h, @c libdns_sd.so, as well
+     * as the @c mdnsd daemon from Apple's bonjour distribution are required. The @c mdnsd daemon has
+     * to be running on the local host.
+     *
+     * ### Browsing the local network for XMPP services
+     *
+     * You can use the Manager to browse the local network for XMPP services.
+     * First, create a new instance, register a LinkLocal::Handler, and call startBrowsing().
+     * @code
+     * m_mdns = new LinkLocal::Manager( ... );
+     * m_mdns->registerLinkLocalHandler( yourHandler );
+     * m_mdns->startBrowsing();
+     * @endcode
+     *
+     * Then you will need to call @c recv() periodcally. The handler will then receive lists of available
+     * or removed services. Check the @c flag member of the Service struct.
+     *
+     * @code
+     * void MyClass::handleBrowseReply( const Service& service )
+     * {
+     *   LinkLocal::ServiceList::const_iterator it = services.begin();
+     *   for( ; it != services.end(); ++it )
+     *   {
+     *     if( (*it).flag == LinkLocal::AddService )
+     *     {
+     *       // new service
+     *     }
+     *     else
+     *     {
+     *       // service removed
+     *     }
+     *   }
+     * }
+     * @endcode
+     *
+     * @note Note that your own service may show up in the list, too.
+     * 
+     * ### Connecting to an XMPP service
+     *
+     * Using the info from the Service struct you can initiate a connection to the remote entity.
+     * First, create a new instance of LinkLocal::Client and register some basic handlers like you
+     * would with a normal gloox::Client:
+     *
+     * @code
+     * LinkLocal::Client c( JID( "romeo@montague.net" ) );
+     * c.logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this ); // optional
+     * c.registerConnectionListener( yourConnectionListener );
+     * @endcode
+     *
+     * Then call @link gloox::LinkLocal::Client::connect( const std::string&, const std::string&, const std::string&, int ) connect() @endlink
+     * and pass the paramters from the Service struct that you received in handleBrowseReply().
+     *
+     * @code
+     * c.connect( "juliet@laptop", "_presence._tcp", ".local", 4 ); // don't use literal values
+     * @endcode
+     *
+     * Put your LinkLocal::Client instance in your event loop (or in a separate thread) and call
+     * @link gloox::LinkLocal::Client::recv() recv() @endlink periodically.
+     *
+     * ### Advertising an XMPP service on the local network
+     *
+     * To advertise your own XMPP service you can (re-)use the same Manager instance from 'browsing the local network'
+     * above.
+     *
+     * You can publish some basic info about your service in a DNS TXT record. The Manager offers the addTXTData() function
+     * for that. See http://xmpp.org/registrar/linklocal.html for a list of official parameters.
+     *
+     * @code
+     * m_mdns->addTXTData("nick","July");
+     * m_mdns->addTXTData("1st","Juliet");
+     * m_mdns->addTXTData("last","Capulet");
+     * m_mdns->addTXTData("msg","Hanging out");
+     * m_mdns->addTXTData("jid","julia@capulet.com");
+     * m_mdns->addTXTData("status","avail");
+     * @endcode
+     *
+     * Then, to start publishing the availability of your service as well as the TXT record with the additional info
+     * you just call @c registerService().
+     *
+     * @code
+     * m_mdns->registerService();
+     * @endcode
+     *
+     * Other entities on the network will now be informed about the availability of your service.
+     * 
+     * ### Listening for incoming connections
+     *
+     * The second argument to Manager's constructor is a ConnectionHandler-derived class that
+     * will receive incoming connections.
+     * 
+     * When registerService() gets called, the Manager will also start a local server that will
+     * accept incoming connections. By default, it will listen on port 5562.
+     *
+     * In @link gloox::ConnectionHandler::handleIncomingConnection() handleIncomingConnection() @endlink
+     * you should create a new LinkLocal::Client and register some basic handlers:
+     *
+     * @code
+     * LinkLocal::Client c( JID( "romeo@desktop" ) );
+     * c.logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this );
+     * c.registerMessageHandler( this );
+     * c.registerConnectionListener( this );
+     * @endcode
+     *
+     * Finally you have to attach the incoming connection to the Client instance, and call connect().
+     * 
+     * @code
+     * connection->registerConnectionDataHandler( &c );
+     * c.setConnectionImpl( connection );
+     * c.connect();
+     * @endcode
+     *
+     * Add the Client to your event loop to call recv() periodically.
+     *
+     * @see @c linklocal_example.cpp in @c src/examples/ for a (very) simple implementation of a bot
+     * handling both incoming and outgoing connections.
+     *
+     * @author Jakob Schroeter <js@camaya.net>
+     * @since 1.0.x
+     */
+    class GLOOX_API Manager
+    {
+      
+      public:
+        
+        /**
+         * Creates a new Link-local Manager instance. You can call @c registerService() and/or @c startBrowsing()
+         * immediately on a new Manager object, it will use sane defaults.
+         * @param user The username to advertise, preferably (as per @xep{0174}) the locally
+         * logged-in user. This is just the local part of the local JID.
+         * @param connHandler A pointer to a ConnectionHandler that will receive incoming connections.
+         * @param logInstance The log target. Obtain it from ClientBase::logInstance().
+         */
+        Manager( const std::string& user, ConnectionHandler* connHandler, const LogSink &logInstance );
+
+        /**
+         * Virtual destructor.
+         * @note @c deregisterService() and @c stopBrowsing() will be called automatically if necessary.
+         */
+        virtual ~Manager();
+
+        /**
+         * Lets you add additional data to the published TXT record.
+         * @note The @c txtvers=1 parameter is included by default and cannot be changed.
+         * @param key The key of a key=value parameter pair. Must be non-empty. If the given key
+         * has been set before, its value will be overwritten by the new value.
+         * @param value The value of a @c key=value parameter pair. Must be non-empty.
+         * @note If either parameter is empty, this function is a NOOP.
+         * @note The additional data will not be automatically published if you have already called
+         * @c registerService(). You will have to call @c registerService() again to update the
+         * TXT record.
+         */
+        void addTXTData( const std::string& key, const std::string& value );
+
+        /**
+         * Lets you remove TXT record data by key.
+         * @note The @c txtvers=1 parameter is included by default and cannot be removed.
+         * @param key The key of the @c key=value parameter pair that should be removed. Must be non-empty.
+         * @note A published TXT record will not be automatically updated if you have already called
+         * @c registerService(). You will have to call @c registerService() again to update the TXT record.
+         */
+        void removeTXTData( const std::string& key );
+
+        /**
+         * Starts advertising link-local messaging capabilities by publishing a number of DNS records,
+         * as per @xep{0174}.
+         * You can call this function again to publish any values you updated after the first call.
+         */
+        void registerService();
+
+        /**
+         * Removes the published DNS records and thereby stops advertising link-local messaging
+         * capabilities.
+         */
+        void deregisterService();
+
+        /**
+         * Lets you specify a new username.
+         * @param user The new username.
+         * @note The new username will not be automatically advertised if you have already called
+         * @c registerService(). You will have to call @c registerService() again to update the username.
+         */
+        void setUser( const std::string& user ) { m_user = user; }
+
+        /**
+         * Lets you specify an alternate host name to advertise. By default the local machine's hostname
+         * as returned by @c gethostname() will be used.
+         * @param host The hostname to use.
+         * @note The new hostname will not be automatically advertised if you have already called
+         * @c registerService(). You will have to call @c registerService() again to update the hostname.
+         */
+        void setHost( const std::string& host ) { m_host = host; }
+
+        /**
+         * This function lets you set an alternate browse domain. The default domain should work in most cases.
+         * @param domain The browse domain to set.
+         * @note The new domain will not be automatically used if you have already called
+         * @c registerService(). You will have to call @c registerService() again to update the domain.
+         * The same applies to @c startBrowsing().
+         */
+        void setDomain( const std::string& domain ) { m_domain = domain; }
+
+        /**
+         * Lets you specifiy a port to listen on for incoming server-less XMPP connections. Default
+         * for this implementation is port 5562, but any unused port can be used.
+         * @note In addition to the SRV record, the port will also be published in the TXT record
+         * automaticlly, you do not have to add it manually. That is, you should not call
+         * @c addTXTData() with a key of @c "port.p2pj".
+         * @param port The port to use.
+         * @note The new port will not be automatically advertised if you have already called
+         * @c registerService(). You will have to call @c registerService() again to update the port.
+         */
+        void setPort( const int port ) { m_port = port; addTXTData( "port.p2pj", util::int2string( m_port ) ); }
+
+        /**
+         * This function can be used to set a non-default interface. Use @c if_nametoindex() to
+         * find the index for a specific named device.
+         * By default DNS records will be broadcast on all available interfaces, and all available
+         * interfaces will be used or browsing services.
+         * @param iface The interface to use. If you set an interface here, and want to change it
+         * back to 'any', use @b 0. Use @b -1 to broadcast only on the local machine.
+         * @note The new interface will not be automatically used if you have already called
+         * @c registerService(). You will have to call @c registerService() again to use the new
+         * interface. The same applies to @c startBrowsing().
+         */
+        void setInterface( unsigned iface ) { m_interface = iface; }
+
+        /**
+         * Starts looking for other entities of type @c _presence. You have to set a handler for
+         * results using @c registerLinkLocalHandler() before calling this function.
+         * You can call this function again to re-start browsing with updated parameters.
+         * @return Returns @b true if browsing could be started successfully, @b false otherwise.
+         */
+        bool startBrowsing();
+
+        /**
+         * Stops the browsing.
+         */
+        void stopBrowsing();
+
+        /**
+         * Exposes the socket used for browsing so you can have it checked in your own event loop,
+         * if desired. If your event loop signals new data on the socket, you should NOT
+         * try to read from it directly. Instead you should call @c recv().
+         * As an alternative to using the raw socket you could also put the Manager in a
+         * separate thread and call @c recv() repeatedly, or achieve this in any other way.
+         */
+        int socket() const { return m_browseFd; }
+
+        /**
+         * Checks once for new data on the socket used for browsing.
+         * @param timeout The timeout for @c select() in microseconds. Use @b -1 if blocking behavior
+         * is acceptable.
+         */
+        void recv( int timeout );
+
+        /**
+         * Registers a handler that will be notfied about entities found on the network that match
+         * the given browse criteria.
+         * @param handler The handler to register.
+         */
+        void registerLinkLocalHandler( Handler* handler ) { m_linkLocalHandler = handler; }
+
+//         /**
+//          *
+//          */
+//         static const StringMap decodeTXT( const std::string& txt );
+
+      private:
+        static void handleBrowseReply( DNSServiceRef sdRef, DNSServiceFlags flags, unsigned interfaceIndex,
+                                       DNSServiceErrorType errorCode, const char* serviceName, const char* regtype,
+                                       const char* replyDomain, void* context );
+
+        void handleBrowse( Flag flag, const std::string& service, const std::string& regtype, const std::string& domain, int interface, bool moreComing );
+
+        typedef std::list<ConnectionTCPClient*> ConnectionList;
+        typedef std::map<ConnectionTCPClient*, const JID> ConnectionMap;
+
+        DNSServiceRef m_publishRef;
+        DNSServiceRef m_browseRef;
+
+        ServiceList m_tmpServices;
+//         ServiceList m_services;
+         
+        std::string m_user;
+        std::string m_host;
+        std::string m_domain;
+        unsigned m_interface;
+        int m_port;
+
+        const LogSink& m_logInstance;
+
+        int m_browseFd;
+
+        StringMap m_txtData;
+
+        ConnectionTCPServer m_server;
+
+        Handler* m_linkLocalHandler;
+        ConnectionHandler* m_connectionHandler;
+
+    };
+
+  }
+
+}
+
+#endif // HAVE_MDNS
+
+#endif // LINKLOCALMANAGER_H___

=== modified file 'src/loghandler.h'
--- src/loghandler.h	2010-01-17 13:05:04 +0000
+++ src/loghandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/logsink.cpp'
--- src/logsink.cpp	2010-01-17 13:05:04 +0000
+++ src/logsink.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/logsink.h'
--- src/logsink.h	2010-01-17 13:05:04 +0000
+++ src/logsink.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/macros.h'
--- src/macros.h	2010-01-17 13:05:04 +0000
+++ src/macros.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/md5.cpp'
--- src/md5.cpp	2010-01-17 13:05:04 +0000
+++ src/md5.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/message.cpp'
--- src/message.cpp	2010-01-17 13:05:04 +0000
+++ src/message.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -71,7 +71,7 @@
     if( m_subtype == Invalid )
       return 0;
 
-    Tag* t = new Tag( "message" );
+    Tag* t = new Tag( "message", XMLNS, XMLNS_CLIENT );
     if( m_to )
       t->addAttribute( "to", m_to.full() );
     if( m_from )

=== modified file 'src/message.h'
--- src/message.h	2010-01-17 13:05:04 +0000
+++ src/message.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -34,6 +34,7 @@
   {
 
     friend class ClientBase;
+    friend class Forward;
 
     public:
 
@@ -123,6 +124,8 @@
       /**
        * Convenience function that returns a pointer to a DelayedDelivery StanzaExtension, if the
        * message contains one.
+       * Make sure you have registered a DelayedDelivery instance with your ClientBase (this is not done automatically),
+       * otherwise this method will always return 0.
        * @return A pointer to a DelayedDelivery object, or 0.
        */
       const DelayedDelivery* when() const

=== modified file 'src/messageevent.cpp'
--- src/messageevent.cpp	2010-01-17 13:05:04 +0000
+++ src/messageevent.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -28,6 +28,9 @@
   MessageEvent::MessageEvent( const Tag* tag )
     : StanzaExtension( ExtMessageEvent ), m_event( MessageEventCancel )
   {
+    if( !tag )
+      return;
+
     const TagList& l = tag->children();
     TagList::const_iterator it = l.begin();
     int event = 0;

=== modified file 'src/messageevent.h'
--- src/messageevent.h	2010-01-17 13:05:04 +0000
+++ src/messageevent.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,7 +24,7 @@
   class Tag;
 
   /**
-   * @brief An implementation of Message Events (XEP-0022) as a StanzaExtension.
+   * @brief An implementation of Message Events (@xep{0022}) as a StanzaExtension.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 1.0

=== modified file 'src/messageeventfilter.cpp'
--- src/messageeventfilter.cpp	2010-01-17 13:05:04 +0000
+++ src/messageeventfilter.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/messageeventfilter.h'
--- src/messageeventfilter.h	2010-01-17 13:05:04 +0000
+++ src/messageeventfilter.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
   class MessageSession;
 
   /**
-   * @brief This class adds Message Event (XEP-0022) support to a MessageSession.
+   * @brief This class adds Message Event (@xep{0022}) support to a MessageSession.
    *
    * This implementation of Message Events is fully transparent to the user of the class.
    * If the remote entity does not request message events, MessageEventFilter will not send
@@ -50,7 +50,7 @@
       virtual ~MessageEventFilter();
 
       /**
-       * Use this function to raise an event as defined in XEP-0022.
+       * Use this function to raise an event as defined in @xep{0022}.
        * @note The Spec states that Message Events shall not be sent to an entity
        * which did not request them. Reasonable effort is taken in this function to
        * avoid spurious event sending. You should be safe to call this even if Message
@@ -63,7 +63,7 @@
 
       /**
        * The MessageEventHandler registered here will receive Message Events according
-       * to XEP-0022.
+       * to @xep{0022}.
        * @param meh The MessageEventHandler to register.
        */
       void registerMessageEventHandler( MessageEventHandler* meh );

=== modified file 'src/messageeventhandler.h'
--- src/messageeventhandler.h	2010-01-17 13:05:04 +0000
+++ src/messageeventhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -23,7 +23,7 @@
 
   /**
    * @brief A virtual interface that enables an object to be notified about
-   * Message Events (XEP-0022).
+   * Message Events (@xep{0022}).
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 0.8

=== modified file 'src/messagefilter.cpp'
--- src/messagefilter.cpp	2010-01-17 13:05:04 +0000
+++ src/messagefilter.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/messagefilter.h'
--- src/messagefilter.h	2010-01-17 13:05:04 +0000
+++ src/messagefilter.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/messagehandler.h'
--- src/messagehandler.h	2010-01-17 13:05:04 +0000
+++ src/messagehandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/messagesession.cpp'
--- src/messagesession.cpp	2010-01-17 13:05:04 +0000
+++ src/messagesession.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -21,9 +21,9 @@
 namespace gloox
 {
 
-  MessageSession::MessageSession( ClientBase* parent, const JID& jid, bool wantUpgrade, int types, bool honorTID )
+  MessageSession::MessageSession( ClientBase* parent, const JID& jid, bool wantResourceTracking, int types, bool honorTID )
     : m_parent( parent ), m_target( jid ), m_messageHandler( 0 ),
-      m_types( types ), m_wantUpgrade( wantUpgrade ), m_hadMessages( false ), m_honorThreadID( honorTID )
+      m_types( types ), m_wantResourceTracking( wantResourceTracking ), m_hadMessages( false ), m_honorThreadID( honorTID )
   {
     if( m_parent )
       m_parent->registerMessageSession( this );
@@ -36,7 +36,7 @@
 
   void MessageSession::handleMessage( Message& msg )
   {
-    if( m_wantUpgrade && msg.from().bare() == m_target.full() )
+    if( m_wantResourceTracking && msg.from().resource() != m_target.resource() )
       setResource( msg.from().resource() );
 
     if( !m_hadMessages )
@@ -55,10 +55,15 @@
     for( ; it != m_messageFilterList.end(); ++it )
       (*it)->filter( msg );
 
-    if( m_messageHandler && !msg.body().empty() )
+    if( m_messageHandler )
       m_messageHandler->handleMessage( msg, this );
   }
 
+  void MessageSession::send( const std::string& message )
+  {
+    send( message, EmptyString );
+  }
+
   void MessageSession::send( const std::string& message, const std::string& subject, const StanzaExtensionList& sel )
   {
     if( !m_hadMessages )
@@ -93,7 +98,6 @@
 
   void MessageSession::resetResource()
   {
-    m_wantUpgrade = true;
     m_target.setResource( EmptyString );
   }
 

=== modified file 'src/messagesession.h'
--- src/messagesession.h	2010-01-17 13:05:04 +0000
+++ src/messagesession.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -163,7 +163,8 @@
        * JID that has no resource. This 'upgrade' will only happen once.
        * @param types ORed list of Message::MessageType values this MessageSession shall receive.
        * Defaults to 0 which means any type is received.
-       * @param honorTID Indicates whether thread IDs should be honored when matching incoming messages to MessageSessions. The default is usually fine.
+       * @param honorTID Indicates whether thread IDs should be honored when matching incoming messages to MessageSessions.
+       * The default (@b true) is usually fine.
        */
       MessageSession( ClientBase* parent, const JID& jid, bool wantUpgrade = true, int types = 0, bool honorTID = true );
 
@@ -219,6 +220,12 @@
         { m_messageHandler = 0; }
 
       /**
+       * A convenience function to quickly send a message.
+       * @param message The message to send.
+       */
+      virtual void send( const std::string& message );
+
+      /**
        * A convenience function to quickly send a message (optionally with subject). This is
        * the preferred way to send a message from a MessageSession.
        * @param message The message to send.
@@ -226,7 +233,7 @@
        * @param sel An optional list of StanzaExtensions. The extensions will be owned by the message-to-be-sent;
        * do not attempt to re-use or delete them.
        */
-      virtual void send( const std::string& message, const std::string& subject = EmptyString,
+      virtual void send( const std::string& message, const std::string& subject,
                          const StanzaExtensionList& sel = StanzaExtensionList() );
 
       /**
@@ -265,7 +272,9 @@
        * This function resets the session's target JID to its bare form such that
        * subsequently sent messages will be sent to that bare JID. The server will
        * determine the best resource to deliver to. Useful if the target
-       * resource changed presence to e.g. away or offline.
+       * resource changed presence to e.g. away or offline. This does not automatically
+       * set the wantResourceTracking option. If you need escalation, be sure to set
+       * this option in the constructor.
        */
       void resetResource();
 
@@ -298,7 +307,7 @@
 
       std::string m_thread;
       int m_types;
-      bool m_wantUpgrade;
+      bool m_wantResourceTracking;
       bool m_hadMessages;
       bool m_honorThreadID;
 

=== modified file 'src/messagesessionhandler.h'
--- src/messagesessionhandler.h	2010-01-17 13:05:04 +0000
+++ src/messagesessionhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,7 +24,7 @@
    * @brief A virtual interface which can be reimplemented to receive incoming message sessions.
    *
    * Derived classes can be registered as MessageSessionHandlers with the Client.
-   * If you have enabled automatic MessageSession creation by calling Client::setAutoMessageSession(),
+   * If you have registered as a MessageSessionHandler by calling ClientBase::registerMessageSessionHandler(),
    * handleMessageSession() will be called if a message stanza arrives for which there is no
    * MessageSession yet.
    *
@@ -48,10 +48,10 @@
        * @note Make sure to read the note in ClientBase::registerMessageSessionHandler()
        * regarding the feeding of decorators.
        *
-       * @note After receiving a MessageSession your object is the owner and is responsible
-       * for the destruction of the session.
+       * @note You should never delete the MessageSession manually. Instead call
+       * ClientBase::disposeMessageSession() when you no longer need the session.
        *
-       * @note If you don't need the MessageSession, you should not delete it here. You will
+       * @note If you don't need the MessageSession, you should not dispose it here. You will
        * get an endless loop if you do.
        *
        * @note You should register your MessageHandler here, or else the first message

=== added file 'src/mucinvitationhandler.cpp'
--- src/mucinvitationhandler.cpp	1970-01-01 00:00:00 +0000
+++ src/mucinvitationhandler.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,27 @@
+/*
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
+  This file is part of the gloox library. http://camaya.net/gloox
+
+  This software is distributed under a license. The full license
+  agreement can be found in the file LICENSE in this distribution.
+  This software may not be copied, modified, sold or distributed
+  other than expressed in the named license agreement.
+
+  This software is distributed without any warranty.
+*/
+
+
+
+#include "mucinvitationhandler.h"
+#include "mucroom.h"
+
+namespace gloox
+{
+
+  MUCInvitationHandler::MUCInvitationHandler( ClientBase* parent )
+  {
+    if( parent )
+      parent->registerStanzaExtension( new MUCRoom::MUCUser() );
+  }
+
+}

=== modified file 'src/mucinvitationhandler.h'
--- src/mucinvitationhandler.h	2010-01-17 13:05:04 +0000
+++ src/mucinvitationhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -18,7 +18,6 @@
 #include "clientbase.h"
 #include "macros.h"
 #include "jid.h"
-#include "mucroom.h"
 
 #include <string>
 
@@ -40,11 +39,7 @@
        * Constructor. Prepares the given ClientBase for receiving MUC invitations..
        * @param parent A ClientBase instance to prepare.
        */
-      MUCInvitationHandler( ClientBase* parent )
-      {
-        if( parent )
-          parent->registerStanzaExtension( new MUCRoom::MUCUser() );
-      }
+      MUCInvitationHandler( ClientBase* parent );
 
       /**
        * Virtual Destructor.

=== modified file 'src/mucmessagesession.cpp'
--- src/mucmessagesession.cpp	2010-01-17 13:05:04 +0000
+++ src/mucmessagesession.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/mucmessagesession.h'
--- src/mucmessagesession.h	2010-01-17 13:05:04 +0000
+++ src/mucmessagesession.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/mucroom.cpp'
--- src/mucroom.cpp	2010-01-17 13:05:04 +0000
+++ src/mucroom.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -969,6 +969,9 @@
         m_roomHandler->handleMUCParticipantPresence( this, party, presence );
 
       delete party.nick;
+      delete party.jid;
+      delete party.actor;
+      delete party.alternate;
     }
   }
 
@@ -1081,12 +1084,9 @@
       {
         std::string when;
         bool privMsg = false;
-        bool history = false;
         if( msg.when() )
-        {
           when = msg.when()->stamp();
-          history = true;
-        }
+
         if( msg.subtype() & ( Message::Chat | Message::Normal ) )
           privMsg = true;
 

=== modified file 'src/mucroom.h'
--- src/mucroom.h	2010-01-17 13:05:04 +0000
+++ src/mucroom.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -36,7 +36,7 @@
   class Message;
 
   /**
-   * @brief This is an implementation of XEP-0045 (Multi-User Chat).
+   * @brief This is an implementation of @xep{0045} (Multi-User Chat).
    *
    * Usage is pretty simple:
    *
@@ -99,7 +99,7 @@
         HistorySeconds,             /**< Send only the messages received in the last "X" seconds. */
         HistorySince,               /**< Send only the messages received since the datetime specified
                                      * (which MUST conform to the DateTime profile specified in Jabber
-                                     * Date and Time Profiles (XEP-0082)). */
+                                     * Date and Time Profiles (@xep{0082})). */
         HistoryUnknown              /**< It is up to the service to decide how much history to send.
                                      * This is the default. */
       };
@@ -535,7 +535,7 @@
        * Use this function to request room history since specific datetime.
        * History is sent only once after entering a room. You should use this function before joining.
        * @param since A string representing a datetime conforming to the DateTime profile specified
-       * in Jabber Date and Time Profiles (XEP-0082).
+       * in Jabber Date and Time Profiles (@xep{0082}).
        * @note If this function is not used to request a specific amount of room history, it is up
        * to the MUC service to decide how much history to send.
        */

=== modified file 'src/mucroomconfighandler.h'
--- src/mucroomconfighandler.h	2010-01-17 13:05:04 +0000
+++ src/mucroomconfighandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/mucroomhandler.h'
--- src/mucroomhandler.h	2010-01-17 13:05:04 +0000
+++ src/mucroomhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -192,7 +192,7 @@
        * @param features ORed MUCRoomFlag's.
        * @param name The room's name as returned by Service Discovery.
        * @param infoForm A DataForm containing extended room information. May be 0 if the service
-       * doesn't support extended room information. See Section 15.5 of XEP-0045 for defined
+       * doesn't support extended room information. See Section 15.5 of @xep{0045} for defined
        * field types. You should not delete the form.
        *
        * @note This function may be called without a prior call to MUCRoom::getRoomInfo(). This

=== modified file 'src/mutex.cpp'
--- src/mutex.cpp	2010-01-17 13:05:04 +0000
+++ src/mutex.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -56,9 +56,17 @@
     Mutex::MutexImpl::MutexImpl()
     {
 #if defined( _WIN32 ) && !defined( __SYMBIAN32__ )
+      // NOTE: Critical sections by nature allow "recursive"
+      //  (the same thread can get it again, and just bump the ref count).
       InitializeCriticalSection( &m_cs );
 #elif defined( HAVE_PTHREAD )
-      pthread_mutex_init( &m_mutex, 0 );
+      // For pthreads, configured the mutex to be recursive
+      //  (the same thread can get it again, and just bump the ref count).
+      pthread_mutexattr_t mutexAttribute;
+      pthread_mutexattr_init( &mutexAttribute );
+      pthread_mutexattr_settype( &mutexAttribute, PTHREAD_MUTEX_RECURSIVE );
+      pthread_mutex_init( &m_mutex, &mutexAttribute );
+      pthread_mutexattr_destroy( &mutexAttribute );
 #endif
     }
 

=== modified file 'src/mutex.h'
--- src/mutex.h	2010-01-17 13:05:04 +0000
+++ src/mutex.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/mutexguard.h'
--- src/mutexguard.h	2010-01-17 13:05:04 +0000
+++ src/mutexguard.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/nickname.cpp'
--- src/nickname.cpp	2010-01-17 13:05:04 +0000
+++ src/nickname.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/nickname.h'
--- src/nickname.h	2010-01-17 13:05:04 +0000
+++ src/nickname.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,7 +24,7 @@
   class Tag;
 
   /**
-   * @brief An implementation of User Nickname (XEP-0172) as a StanzaExtension.
+   * @brief An implementation of User Nickname (@xep{0172}) as a StanzaExtension.
    *
    * XEP version: 1.0
    * @author Jakob Schroeter <js@camaya.net>

=== modified file 'src/nonsaslauth.cpp'
--- src/nonsaslauth.cpp	2010-01-17 13:05:04 +0000
+++ src/nonsaslauth.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/nonsaslauth.h'
--- src/nonsaslauth.h	2010-01-17 13:05:04 +0000
+++ src/nonsaslauth.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
   class Tag;
 
   /**
-   * @brief This class is an implementation of XEP-0078 (Non-SASL Authentication).
+   * @brief This class is an implementation of @xep{0078} (Non-SASL Authentication).
    *
    * It is invoked by @ref Client automatically if supported by the server and if SASL authentication
    * is not supported.
@@ -68,7 +68,7 @@
     public:
 #endif
       /**
-       * @brief An abstraction of an IQ extension used for Non-SASL authentication (XEP-0078).
+       * @brief An abstraction of an IQ extension used for Non-SASL authentication (@xep{0078}).
        *
        * @author Jakob Schroeter <js@camaya.net>
        * @since 1.0

=== modified file 'src/oob.cpp'
--- src/oob.cpp	2010-01-17 13:05:04 +0000
+++ src/oob.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/oob.h'
--- src/oob.h	2010-01-17 13:05:04 +0000
+++ src/oob.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
 
   /**
    * @brief This is an abstraction of a jabber:x:oob namespace element or a jabber:iq:oob namespace element
-   * as specified in XEP-0066.
+   * as specified in @xep{0066}.
    *
    * XEP version: 1.5
    * @author Jakob Schroeter <js@camaya.net>

=== modified file 'src/parser.cpp'
--- src/parser.cpp	2010-01-17 13:05:04 +0000
+++ src/parser.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -123,6 +123,7 @@
 
     switch( m_state )
     {
+      case InterTag:
       case TagInside:
         m_cdata += rep;
         break;
@@ -200,10 +201,29 @@
 //           printf( "InterTag: %c\n", c );
           m_tag = EmptyString;
           if( isWhitespace( c ) )
+          {
+            m_state = TagInside;
+            if( m_current )
+              m_cdata += c;
             break;
+          }
 
           switch( c )
           {
+            case '&':
+//               printf( "InterTag, calling decode\n" );
+              switch( decode( i, data ) )
+              {
+                case DecodeValid:
+                  m_state = TagInside;
+                  break;
+                case DecodeInvalid:
+                  cleanup();
+                  return static_cast<int>( i );
+                case DecodeInsufficient:
+                  return -1;
+              }
+              break;
             case '<':
               m_state = TagOpening;
               break;

=== modified file 'src/parser.h'
--- src/parser.h	2010-01-17 13:05:04 +0000
+++ src/parser.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/prep.cpp'
--- src/prep.cpp	2010-01-17 13:05:04 +0000
+++ src/prep.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -92,6 +92,18 @@
 #endif
     }
 
+    bool saslprep( const std::string& input, std::string& out )
+    {
+      #ifdef HAVE_LIBIDN
+      return prepare( input, out, stringprep_saslprep );
+      #else
+      if( input.length() > JID_PORTION_SIZE )
+        return false;
+      out = input;
+      return true;
+      #endif
+    }
+
     bool idna( const std::string& domain, std::string& out )
     {
 #ifdef HAVE_LIBIDN
@@ -103,6 +115,7 @@
       if( rc == IDNA_SUCCESS )
       {
         out = prepped;
+        free( prepped );
         return true;
       }
       if( rc != IDNA_MALLOC_ERROR )

=== modified file 'src/prep.h'
--- src/prep.h	2010-01-17 13:05:04 +0000
+++ src/prep.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -42,7 +42,7 @@
      * @param node The string to apply the profile to.
      * @param out The prepped string. In case of an error this string is not touched.
      * If LibIDN is not available the string is returned unchanged.
-     * @return @b True if prepping was successful, @b false otherwise or of LibIDN
+     * @return @b True if prepping was successful, @b false otherwise or if LibIDN
      * is not available.
      */
     bool nodeprep( const std::string& node, std::string& out );
@@ -52,7 +52,7 @@
      * @param domain The string to apply the profile to.
      * @param out The prepped string. In case of an error this string is not touched.
      * If LibIDN is not available the string is returned unchanged.
-     * @return @b True if prepping was successful, @b false otherwise or of LibIDN
+     * @return @b True if prepping was successful, @b false otherwise or if LibIDN
      * is not available.
      */
     bool nameprep( const std::string& domain, std::string& out );
@@ -62,18 +62,28 @@
      * @param resource The string to apply the profile to.
      * @param out The prepped string. In case of an error this string is not touched.
      * If LibIDN is not available the string is returned unchanged.
-     * @return @b True if prepping was successful, @b false otherwise or of LibIDN
+     * @return @b True if prepping was successful, @b false otherwise or if LibIDN
      * is not available.
      */
     bool resourceprep( const std::string& resource, std::string& out );
 
     /**
+     * This function applies the Saslprep profile of Stringprep to a std::string.
+     * @param input The string to apply the profile to.
+     * @param out The prepped string. In case of an error this string is not touched.
+     * If LibIDN is not available the string is returned unchanged.
+     * @return @b True if prepping was successful, @b false otherwise or if LibIDN
+     * is not available.
+     */
+    bool saslprep( const std::string& input, std::string& out );
+
+    /**
      * This function applies the idna() function to a string. I.e. it transforms
      * internationalized domain names into plain ASCII.
      * @param domain The string to convert.
      * @param out The converted string. In case of an error this string is not touched.
      * If LibIDN is not available the string is returned unchanged.
-     * @return @b True if prepping was successful, @b false otherwise or of LibIDN
+     * @return @b True if prepping was successful, @b false otherwise or if LibIDN
      * is not available.
      */
     bool idna( const std::string& domain, std::string& out );

=== modified file 'src/presence.cpp'
--- src/presence.cpp	2010-01-17 13:05:04 +0000
+++ src/presence.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/presence.h'
--- src/presence.h	2010-01-17 13:05:04 +0000
+++ src/presence.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/presencehandler.h'
--- src/presencehandler.h	2010-01-17 13:05:04 +0000
+++ src/presencehandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/privacyitem.cpp'
--- src/privacyitem.cpp	2010-01-17 13:05:04 +0000
+++ src/privacyitem.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/privacyitem.h'
--- src/privacyitem.h	2010-01-17 13:05:04 +0000
+++ src/privacyitem.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/privacylisthandler.h'
--- src/privacylisthandler.h	2010-01-17 13:05:04 +0000
+++ src/privacylisthandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/privacymanager.cpp'
--- src/privacymanager.cpp	2010-01-17 13:05:04 +0000
+++ src/privacymanager.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/privacymanager.h'
--- src/privacymanager.h	2010-01-17 13:05:04 +0000
+++ src/privacymanager.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/privatexml.cpp'
--- src/privatexml.cpp	2010-01-17 13:05:04 +0000
+++ src/privatexml.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/privatexml.h'
--- src/privatexml.h	2010-01-17 13:05:04 +0000
+++ src/privatexml.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,7 +30,7 @@
   class Stanza;
 
   /**
-   * @brief This class implements XEP-0049 (Private XML Storage).
+   * @brief This class implements @xep{0049} (Private XML Storage).
    *
    * @author Jakob Schroeter <js@camaya.net>
    */

=== modified file 'src/privatexmlhandler.h'
--- src/privatexmlhandler.h	2010-01-17 13:05:04 +0000
+++ src/privatexmlhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/pubsub.h'
--- src/pubsub.h	2010-01-17 13:05:04 +0000
+++ src/pubsub.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -128,7 +128,7 @@
     };
 
     /**
-     * Describes the different PubSub features (XEP-0060 Sect. 10).
+     * Describes the different PubSub features (@xep{0060} Sect. 10).
      */
     enum PubSubFeature
     {

=== modified file 'src/pubsubevent.cpp'
--- src/pubsubevent.cpp	2010-01-17 13:05:04 +0000
+++ src/pubsubevent.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/pubsubevent.h'
--- src/pubsubevent.h	2010-01-17 13:05:04 +0000
+++ src/pubsubevent.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/pubsubitem.cpp'
--- src/pubsubitem.cpp	2010-01-17 13:05:04 +0000
+++ src/pubsubitem.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/pubsubitem.h'
--- src/pubsubitem.h	2010-01-17 13:05:04 +0000
+++ src/pubsubitem.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -27,7 +27,7 @@
   {
 
     /**
-     * @brief Abstracts a PubSub Item (XEP-0060).
+     * @brief Abstracts a PubSub Item (@xep{0060}).
      *
      * XEP Version: 1.12
      *

=== modified file 'src/pubsubmanager.cpp'
--- src/pubsubmanager.cpp	2010-01-17 13:05:04 +0000
+++ src/pubsubmanager.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -343,8 +343,21 @@
       if( o )
       {
         if( m_ctx == InvalidContext )
-          m_ctx = GetSubscriptionOptions;
-        m_jid.setJID( o->findAttribute( "jid" ) );
+        {
+          Tag* parent = tag->parent();
+          if( parent && parent->findAttribute("type") == "set" )
+            m_ctx = SetSubscriptionOptions;
+          else
+            m_ctx = GetSubscriptionOptions;
+        }
+        if( m_ctx == SetSubscriptionOptions || m_ctx == GetSubscriptionOptions )
+        {
+          // We set both m_node and m_options.node for
+          // get/set options, since m_options.node is not exposed externally
+          m_node = o->findAttribute( "node" );
+          m_jid.setJID( o->findAttribute( "jid" ) );
+          m_subid = o->findAttribute( "subid" );
+        }
         m_options.node = o->findAttribute( "node" );
         m_options.df = new DataForm( o->findChild( "x", "xmlns", XMLNS_X_DATA ) );
       }
@@ -389,7 +402,7 @@
         m_ctx = DeleteItem;
         m_node = r->findAttribute( "node" );
         m_notify = r->hasAttribute( "notify", "1" ) || r->hasAttribute( "notify", "true" );
-        const TagList& l = p->children();
+        const TagList& l = r->children();
         TagList::const_iterator it = l.begin();
         for( ; it != l.end(); ++it )
           m_items.push_back( new Item( (*it) ) );
@@ -475,12 +488,13 @@
         u->addAttribute( "subid", m_subid );
       }
       else if( m_ctx == GetSubscriptionOptions
-               || m_ctx == SetSubscriptionOptions
-               || ( m_ctx == Subscription && m_options.df ) )
+               || m_ctx == SetSubscriptionOptions )
       {
         Tag* o = new Tag( t, "options" );
         o->addAttribute( "node", m_options.node );
         o->addAttribute( "jid", m_jid.full() );
+        if( !m_subid.empty() )
+          o->addAttribute( "subid", m_subid );
         if( m_options.df )
           o->addChild( m_options.df->tag() );
       }
@@ -594,22 +608,18 @@
       if( !m_parent || !handler || !service || node.empty() )
         return EmptyString;
 
-      const std::string& id = m_parent->getID();
-      IQ iq( IQ::Set, service, id );
-      PubSub* ps = new PubSub( Subscription );
-      ps->setJID( jid ? jid : m_parent->jid() );
-      ps->setNode( node );
+      DataForm* options = 0;
       if( type != SubscriptionNodes || depth != 1 )
       {
-        DataForm* df = new DataForm( TypeSubmit );
-        df->addField( DataFormField::TypeHidden, "FORM_TYPE", XMLNS_PUBSUB_SUBSCRIBE_OPTIONS );
+        options = new DataForm( TypeSubmit );
+        options->addField( DataFormField::TypeHidden, "FORM_TYPE", XMLNS_PUBSUB_SUBSCRIBE_OPTIONS );
 
         if( type == SubscriptionItems )
-          df->addField( DataFormField::TypeNone, "pubsub#subscription_type", "items" );
+          options->addField( DataFormField::TypeNone, "pubsub#subscription_type", "items" );
 
         if( depth != 1 )
         {
-          DataFormField* field = df->addField( DataFormField::TypeNone, "pubsub#subscription_depth" );
+          DataFormField* field = options->addField( DataFormField::TypeNone, "pubsub#subscription_depth" );
           if( depth == 0 )
             field->setValue( "all" );
           else
@@ -618,12 +628,31 @@
 
         if( !expire.empty() )
         {
-          DataFormField* field = df->addField( DataFormField::TypeNone, "pubsub#expire" );
+          DataFormField* field = options->addField( DataFormField::TypeNone, "pubsub#expire" );
           field->setValue( expire );
         }
-
-        ps->setOptions( node, df );
       }
+
+      return subscribe( service, node, handler, jid, options );
+    }
+
+    const std::string Manager::subscribe( const JID& service,
+                                          const std::string& node,
+                                          ResultHandler* handler,
+                                          const JID& jid,
+                                          DataForm* options
+                                          )
+    {
+      if( !m_parent || !handler || !service || node.empty() )
+        return EmptyString;
+
+      const std::string& id = m_parent->getID();
+      IQ iq( IQ::Set, service, id );
+      PubSub* ps = new PubSub( Subscription );
+      ps->setJID( jid ? jid : m_parent->jid() );
+      ps->setNode( node );
+      if( options != NULL )
+        ps->setOptions( node, options );
       iq.addExtension( ps  );
 
       m_trackMapMutex.lock();
@@ -664,7 +693,8 @@
                                                     const JID& jid,
                                                     const std::string& node,
                                                     ResultHandler* handler,
-                                                    DataForm* df )
+                                                    DataForm* df,
+                                                    const std::string& subid )
     {
       if( !m_parent || !handler || !service )
         return EmptyString;
@@ -673,6 +703,8 @@
       IQ iq( df ? IQ::Set : IQ::Get, service, id );
       PubSub* ps = new PubSub( context );
       ps->setJID( jid ? jid : m_parent->jid() );
+      if( !subid.empty() )
+        ps->setSubscriptionID( subid );
       ps->setOptions( node, df );
       iq.addExtension( ps );
 
@@ -1041,12 +1073,9 @@
             case PublishItem:
             {
               const PubSub* ps = iq.findExtension<PubSub>( ExtPubSub );
-              if( ps && ps->items().size())
-              {
-                const ItemList il = ps->items();
-                rh->handleItemPublication( id, service, "",
-                                           il, error );
-              }
+              rh->handleItemPublication( id, service, "",
+                                         ps ? ps->items() : ItemList(),
+                                         error );
               break;
             }
             case DeleteItem:
@@ -1094,6 +1123,7 @@
                                                    ps->jid(),
                                                    ps->node(),
                                                    ps->options(),
+                                                   ps->subscriptionID(),
                                                    error );
                   }
                   break;
@@ -1123,8 +1153,22 @@
                     switch( context )
                     {
                       case SetSubscriptionOptions:
-                        rh->handleSubscriptionOptionsResult( id, service, JID( /* FIXME */ ), node, error );
+                      {
+                        const PubSub* ps = iq.findExtension<PubSub>( ExtPubSub );
+                        if( ps )
+                        {
+                          rh->handleSubscriptionOptionsResult( id, service,
+                                                         ps->jid(),
+                                                         node,
+                                                         ps->subscriptionID(),
+                                                         error );
+                        }
+                        else
+                        {
+                          rh->handleSubscriptionOptionsResult( id, service, JID( /* FIXME */ ), node, /* FIXME */ EmptyString, error );
+                        }
                         break;
+                      }
                       case SetSubscriberList:
                         rh->handleSubscribersResult( id, service, node, 0, error );
                         break;

=== modified file 'src/pubsubmanager.h'
--- src/pubsubmanager.h	2010-01-17 13:05:04 +0000
+++ src/pubsubmanager.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -32,7 +32,7 @@
     class ResultHandler;
 
     /**
-     * @brief This manager is used to interact with PubSub services (XEP-0060).
+     * @brief This manager is used to interact with PubSub services (@xep{0060}).
      *
      * @note PubSub support in gloox is still relatively young and you are most
      * welcome to ask questions, criticize the API and so on.
@@ -111,6 +111,27 @@
                                      int depth = 1, const std::string& expire = EmptyString );
 
         /**
+         * Subscribe to a node and configure options.
+         *
+         * @param service Service hosting the node.
+         * @param node ID of the node to subscribe to.
+         * @param handler The ResultHandler.
+         * @param jid JID to subscribe. If empty, the client's JID will be used
+         *        (ie. self subscription).
+         * @param options The options to configure while subscribing.
+         *        Should be a TypeSubmit form, with a field named FORM_TYPE having the value
+         *        http://jabber.org/protocol/pubsub#subscribe_options
+         *        See @xep{0060}, "Subscribe and Configure".
+         *        Will be owned and deleted by the PubSub object.
+         * @return The IQ ID used in the request.
+         *
+         * @see ResultHandler::handleSubscriptionResult
+         */
+        const std::string subscribe( const JID& service, const std::string& node,
+                                     ResultHandler* handler, const JID& jid,
+                                     DataForm* options );
+
+        /**
          * Unsubscribe from a node.
          *
          * @param service Service hosting the node.
@@ -170,6 +191,7 @@
          * @param jid Subscribed entity.
          * @param node Node ID of the node.
          * @param handler The SubscriptionListHandler to handle the result.
+         * @param subid An optional subscription ID.
          * @return The IQ ID used in the request.
          *
          * @see ResultHandler::handleSubscriptionOptions
@@ -177,8 +199,9 @@
         const std::string getSubscriptionOptions( const JID& service,
                                                   const JID& jid,
                                                   const std::string& node,
-                                                  ResultHandler* handler)
-          { return subscriptionOptions( GetSubscriptionOptions, service, jid, node, handler, 0 ); }
+                                                  ResultHandler* handler,
+                                                  const std::string& subid = EmptyString)
+          { return subscriptionOptions( GetSubscriptionOptions, service, jid, node, handler, 0, subid ); }
 
         /**
          * Modifies subscription options.
@@ -188,6 +211,7 @@
          * @param node Node ID of the node.
          * @param df New configuration. The DataForm will be owned and deleted by the Manager.
          * @param handler The handler to handle the result.
+         * @param subid An optional subscription ID.
          * @return The IQ ID used in the request.
          *
          * @see ResultHandler::handleSubscriptionOptionsResult
@@ -196,8 +220,9 @@
                                                   const JID& jid,
                                                   const std::string& node,
                                                   DataForm* df,
-                                                  ResultHandler* handler )
-          { return subscriptionOptions( SetSubscriptionOptions, service, jid, node, handler, df ); }
+                                                  ResultHandler* handler,
+                                                  const std::string& subid = EmptyString )
+          { return subscriptionOptions( SetSubscriptionOptions, service, jid, node, handler, df, subid ); }
 
         /**
          * Requests the affiliation list for a node.
@@ -660,6 +685,8 @@
             void setOptions( const std::string& node, DataForm* df )
             {
               m_options.node = node;
+              if( m_options.df != 0 )
+                delete m_options.df;
               m_options.df = df;
             }
 
@@ -803,7 +830,8 @@
                                                const JID& jid,
                                                const std::string& node,
                                                ResultHandler* handler,
-                                               DataForm* df );
+                                               DataForm* df,
+                                               const std::string& subid = EmptyString );
 
         const std::string getSubscriptionsOrAffiliations( const JID& service,
             ResultHandler* handler,

=== modified file 'src/pubsubresulthandler.h'
--- src/pubsubresulthandler.h	2010-01-17 13:05:04 +0000
+++ src/pubsubresulthandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -160,6 +160,7 @@
          * @param jid Subscribed entity.
          * @param node ID of the node.
          * @param options Options DataForm.
+         * @param sid An optional subscription ID.
          * @param error Subscription options retrieval Error.
          *
          * @see Manager::getSubscriptionOptions
@@ -169,6 +170,7 @@
                                                 const JID& jid,
                                                 const std::string& node,
                                                 const DataForm* options,
+                                                const std::string& sid = EmptyString,
                                                 const Error* error = 0 ) = 0;
 
         /**
@@ -178,6 +180,7 @@
          * @param service Service hosting the queried node.
          * @param jid Subscribed entity.
          * @param node ID of the queried node.
+         * @param sid An optional subscription ID.
          * @param error Subscription options modification Error.
          *
          * @see Manager::setSubscriptionOptions
@@ -186,6 +189,7 @@
                                                       const JID& service,
                                                       const JID& jid,
                                                       const std::string& node,
+                                                      const std::string& sid = EmptyString,
                                                       const Error* error = 0 ) = 0;
 
 

=== modified file 'src/receipt.cpp'
--- src/receipt.cpp	2010-01-17 13:05:04 +0000
+++ src/receipt.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -29,9 +29,13 @@
   }
 
   Receipt::Receipt( const Tag* tag )
-    : StanzaExtension( ExtReceipt ),
-      m_rcpt( receiptType( tag->name() ) )
+    : StanzaExtension( ExtReceipt ), m_rcpt( Invalid )
   {
+    if( !tag )
+      return;
+
+    m_rcpt = receiptType( tag->name() );
+    m_id = tag->findAttribute( "id" );
   }
 
   const std::string& Receipt::filterString() const
@@ -47,7 +51,10 @@
     if( m_rcpt == Invalid )
       return 0;
 
-    return new Tag( util::lookup( m_rcpt, receiptValues ), XMLNS, XMLNS_RECEIPTS );
+    Tag* tag = new Tag( util::lookup( m_rcpt, receiptValues ), XMLNS, XMLNS_RECEIPTS );
+    if ( !m_id.empty() )
+      tag->addAttribute( "id", m_id );
+    return tag;
   }
 
 }

=== modified file 'src/receipt.h'
--- src/receipt.h	2010-01-17 13:05:04 +0000
+++ src/receipt.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,7 +24,7 @@
   class Tag;
 
   /**
-   * @brief An implementation of Message Receipts (XEP-0184) as a StanzaExtension.
+   * @brief An implementation of Message Receipts (@xep{0184}) as a StanzaExtension.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 1.0
@@ -33,7 +33,7 @@
   {
     public:
       /**
-       * Contains valid receipt types (XEP-0184).
+       * Contains valid receipt types (@xep{0184}).
        */
       enum ReceiptType
       {
@@ -51,9 +51,10 @@
       /**
        * Constructs a new object of the given type.
        * @param rcpt The receipt type.
+       * @param id The message ID.
        */
-      Receipt( ReceiptType rcpt )
-        : StanzaExtension( ExtReceipt ), m_rcpt( rcpt )
+      Receipt( ReceiptType rcpt, const std::string& id = EmptyString )
+        : StanzaExtension( ExtReceipt ), m_rcpt( rcpt ), m_id( id )
       {}
 
       /**
@@ -67,6 +68,12 @@
        */
       ReceiptType rcpt() const { return m_rcpt; }
 
+      /**
+       * Returns the message id for acknowledgement tracking.
+       * @return The message ID for acknowledgement tracking.
+       */
+      std::string id() const { return m_id; }
+
       // reimplemented from StanzaExtension
       virtual const std::string& filterString() const;
 
@@ -87,6 +94,7 @@
 
     private:
       ReceiptType m_rcpt;
+      std::string m_id;
 
   };
 

=== modified file 'src/registration.cpp'
--- src/registration.cpp	2010-01-17 13:05:04 +0000
+++ src/registration.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/registration.h'
--- src/registration.h	2010-01-17 13:05:04 +0000
+++ src/registration.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -31,7 +31,7 @@
 
   /**
    * Holds all the possible fields a server may require for registration according
-   * to Section 14.1, XEP-0077.
+   * to Section 14.1, @xep{0077}.
    */
   struct RegistrationFields
   {
@@ -54,7 +54,7 @@
   };
 
   /**
-   * @brief This class is an implementation of XEP-0077 (In-Band Registration).
+   * @brief This class is an implementation of @xep{0077} (In-Band Registration).
    *
    * Derive your object from @ref RegistrationHandler and implement the
    * virtual functions offered by that interface. Then use it like this:
@@ -94,30 +94,30 @@
     public:
 
       /**
-       * The possible fields of a XEP-0077 account registration.
+       * The possible fields of a @xep{0077} account registration.
        */
       enum fieldEnum
       {
-        FieldUsername  =     1,
-        FieldNick      =     2,
-        FieldPassword  =     4,
-        FieldName      =     8,
-        FieldFirst     =    16,
-        FieldLast      =    32,
-        FieldEmail     =    64,
-        FieldAddress   =   128,
-        FieldCity      =   256,
-        FieldState     =   512,
-        FieldZip       =  1024,
-        FieldPhone     =  2048,
-        FieldUrl       =  4096,
-        FieldDate      =  8192,
-        FieldMisc      = 16384,
-        FieldText      = 32768
+        FieldUsername  =     1,     /**< Username requested */
+        FieldNick      =     2,     /**< Nickname requested */
+        FieldPassword  =     4,     /**< Password requested */
+        FieldName      =     8,     /**< Name requested */
+        FieldFirst     =    16,     /**< Given name requested */
+        FieldLast      =    32,     /**< Family name requested */
+        FieldEmail     =    64,     /**< Email address requested */
+        FieldAddress   =   128,     /**< Postal address requested */
+        FieldCity      =   256,     /**< Locality requested */
+        FieldState     =   512,     /**< State/Province requested */
+        FieldZip       =  1024,     /**< ZIP requested */
+        FieldPhone     =  2048,     /**< Phone no. requested */
+        FieldUrl       =  4096,     /**< Homepage or other URL requested */
+        FieldDate      =  8192,     /**< Date requested (unknown purpose; see @xep{0077}) */
+        FieldMisc      = 16384,     /**< Misc data requested (unknown purpose; see @xep{0077}) */
+        FieldText      = 32768      /**< Extra text requested (unknown purpose; see @xep{0077}) */
       };
 
       /**
-       * @brief A wrapping class for the XEP-0077 &lt;query&gt; element.
+       * @brief A wrapping class for the @xep{0077} &lt;query&gt; element.
        *
        * @author Jakob Schroeter <js@camaya.net>
        * @since 1.0
@@ -276,7 +276,7 @@
       /**
        * Attempts to register an account with the given credentials. This can only be called with an
        * unauthenticated parent (@ref Client).
-       * @note According to XEP-0077, if the server sends both old-style fields and data form,
+       * @note According to @xep{0077}, if the server sends both old-style fields and data form,
        * implementations SHOULD prefer data forms.
        * @param form The DataForm containing the registration credentials.
        */

=== modified file 'src/registrationhandler.h'
--- src/registrationhandler.h	2010-01-17 13:05:04 +0000
+++ src/registrationhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -27,7 +27,7 @@
   class DataForm;
 
   /**
-   * Possible results of a XEP-0077 operation.
+   * Possible results of a @xep{0077} operation.
    */
   enum RegistrationResult
   {

=== modified file 'src/resource.h'
--- src/resource.h	2010-01-17 13:05:04 +0000
+++ src/resource.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/rosteritem.cpp'
--- src/rosteritem.cpp	2010-01-17 13:05:04 +0000
+++ src/rosteritem.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -19,8 +19,10 @@
 namespace gloox
 {
 
+  JID EmptyJID();
+
   RosterItem::RosterItem( const std::string& jid, const std::string& name )
-    : m_data( new RosterItemData( jid, name, StringList() ) )
+    : m_data( new RosterItemData( JID( jid ), name, StringList() ) )
   {
   }
 
@@ -49,6 +51,14 @@
       return EmptyString;
   }
 
+  const JID& RosterItem::jidJID() const
+  {
+    if( m_data )
+      return m_data->jidJID();
+    else
+      return EmptyJID;
+  }
+
   const std::string& RosterItem::jid() const
   {
     if( m_data )

=== modified file 'src/rosteritem.h'
--- src/rosteritem.h	2010-01-17 13:05:04 +0000
+++ src/rosteritem.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -14,6 +14,7 @@
 #ifndef ROSTERITEM_H__
 #define ROSTERITEM_H__
 
+#include "jid.h"
 #include "gloox.h"
 #include "resource.h"
 #include "presence.h"
@@ -47,6 +48,11 @@
       typedef std::map<std::string, Resource*> ResourceMap;
 
       /**
+       * An empty string.
+       */
+      const JID EmptyJID;
+
+      /**
        * Constructs a new item of the roster.
        * @param jid The JID of the contact.
        * @param name The displayed name of the contact.
@@ -80,8 +86,16 @@
       /**
        * Returns the contact's bare JID.
        * @return The contact's bare JID.
-       */
-      const std::string& jid() const;
+       * @deprecated Use jidJID() for now. In 1.1, jidJID() will be renamed back to jid().
+       */
+      GLOOX_DEPRECATED const std::string& jid() const;
+
+      /**
+       * Returns the contact's bare JID.
+       * @return The contact's bare JID.
+       * @todo Rename to jid() for 1.1.
+       */
+      const JID& jidJID() const;
 
       /**
        * Sets the current subscription status of the contact.

=== modified file 'src/rosteritemdata.h'
--- src/rosteritemdata.h	2010-01-17 13:05:04 +0000
+++ src/rosteritemdata.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -43,18 +43,51 @@
        * @param name The displayed name of the contact.
        * @param groups A list of groups the contact belongs to.
        */
-      RosterItemData( const std::string& jid, const std::string& name,
-                      const StringList& groups )
-        : m_jid( jid ), m_name( name ), m_groups( groups ),
-          m_subscription( S10nNone ), m_changed( false ), m_remove( false )
-      {}
-
-      /**
-       * Constructs a new item of the roster, scheduled for removal.
-       * @param jid The JID of the contact to remove.
-       */
-      RosterItemData( const std::string& jid )
-        : m_jid( jid ), m_subscription( S10nNone ), m_changed( false ),
+      RosterItemData( const JID& jid, const std::string& name,
+                      const StringList& groups )
+        : m_jid( jid.full() ), m_jidJID( jid ), m_name( name ), m_groups( groups ),
+          m_subscription( S10nNone ), m_changed( false ), m_remove( false )
+      {}
+
+      /**
+       * Constructs a new item of the roster, scheduled for removal.
+       * @param jid The JID of the contact to remove.
+       */
+      RosterItemData( const JID& jid )
+        : m_jid( jid.full() ), m_jidJID( jid ), m_subscription( S10nNone ), m_changed( false ),
+          m_remove( true )
+      {}
+
+      /**
+       * Copy constructor.
+       * @param right The RosterItemData to copy.
+       */
+      RosterItemData( const RosterItemData& right )
+        : m_jid( right.m_jid ), m_jidJID( right.m_jidJID ), m_name( right.m_name ),
+          m_groups( right.m_groups ), m_subscription( right.m_subscription ),
+          m_changed( right.m_changed ), m_remove( right.m_remove )
+      {}
+
+      /**
+       * Constructs a new item of the roster.
+       * @param jid The JID of the contact.
+       * @param name The displayed name of the contact.
+       * @param groups A list of groups the contact belongs to.
+       * @deprecated Will be removed for 1.1.
+       */
+      GLOOX_DEPRECATED_CTOR RosterItemData( const std::string& jid, const std::string& name,
+                      const StringList& groups )
+        : m_jid( jid ), m_jidJID( jid), m_name( name ), m_groups( groups ),
+          m_subscription( S10nNone ), m_changed( false ), m_remove( false )
+      {}
+
+      /**
+       * Constructs a new item of the roster, scheduled for removal.
+       * @param jid The JID of the contact to remove.
+       * @deprecated Will be removed for 1.1.
+       */
+      GLOOX_DEPRECATED_CTOR RosterItemData( const std::string& jid )
+        : m_jid( jid ), m_jidJID( jid), m_subscription( S10nNone ), m_changed( false ),
           m_remove( true )
       {}
 
@@ -66,8 +99,16 @@
       /**
        * Returns the contact's bare JID.
        * @return The contact's bare JID.
-       */
-      const std::string& jid() const { return m_jid; }
+       * @deprecated Will be removed for 1.1.
+       */
+      GLOOX_DEPRECATED const std::string& jid() const { return m_jid; }
+
+      /**
+       * Returns the contact's bare JID.
+       * @return The contact's bare JID.
+       * @todo Rename to jid() for 1.1.
+       */
+      const JID& jidJID() const { return m_jidJID; }
 
       /**
        * Sets the displayed name of a contact/roster item.
@@ -158,7 +199,7 @@
       Tag* tag() const
       {
         Tag* i = new Tag( "item" );
-        i->addAttribute( "jid", m_jid );
+        i->addAttribute( "jid", m_jidJID.full() );
         if( m_remove )
           i->addAttribute( "subscription", "remove" );
         else
@@ -174,7 +215,8 @@
       }
 
     protected:
-      std::string m_jid;
+      GLOOX_DEPRECATED std::string m_jid; /**< @deprecated Will be removed for 1.1. */
+      JID m_jidJID; /**< @todo Rename to m_jid for 1.1. */
       std::string m_name;
       StringList m_groups;
       SubscriptionType m_subscription;

=== modified file 'src/rosterlistener.h'
--- src/rosterlistener.h	2010-01-17 13:05:04 +0000
+++ src/rosterlistener.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/rostermanager.cpp'
--- src/rostermanager.cpp	2010-01-17 13:05:04 +0000
+++ src/rostermanager.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -30,13 +30,13 @@
   RosterManager::Query::Query( const JID& jid, const std::string& name, const StringList& groups )
     : StanzaExtension( ExtRoster )
   {
-    m_roster.push_back( new RosterItemData( jid.bare(), name, groups ) );
+    m_roster.push_back( new RosterItemData( jid, name, groups ) );
   }
 
   RosterManager::Query::Query( const JID& jid )
     : StanzaExtension( ExtRoster )
   {
-    m_roster.push_back( new RosterItemData( jid.bare() ) );
+    m_roster.push_back( new RosterItemData( jid ) );
   }
 
   RosterManager::Query::Query( const Tag* tag )
@@ -57,10 +57,10 @@
 
       const std::string sub = (*it)->findAttribute( "subscription" );
       if( sub == "remove" )
-        m_roster.push_back( new RosterItemData( (*it)->findAttribute( "jid" ) ) );
+        m_roster.push_back( new RosterItemData( JID( (*it)->findAttribute( "jid" ) ) ) );
       else
       {
-        RosterItemData* rid = new RosterItemData( (*it)->findAttribute( "jid" ),
+        RosterItemData* rid = new RosterItemData( JID( (*it)->findAttribute( "jid" ) ),
                                                   (*it)->findAttribute( "name" ),
                                                   groups );
         rid->setSubscription( sub, (*it)->findAttribute( "ask" ) );
@@ -203,7 +203,7 @@
 
     bool self = false;
     Roster::iterator it = m_roster.find( presence.from().bare() );
-    if( it != m_roster.end() || ( self = ( presence.from().bare() == m_self->jid() ) ) )
+    if( it != m_roster.end() || ( self = ( presence.from().bareJID() == m_self->jidJID() ) ) )
     {
       RosterItem* ri = self ? m_self : (*it).second;
       const std::string& resource = presence.from().resource();
@@ -288,7 +288,7 @@
         continue;
 
       IQ iq( IQ::Set, JID(), m_parent->getID() );
-      iq.addExtension( new Query( (*it).second->jid(), (*it).second->name(), (*it).second->groups() ) );
+      iq.addExtension( new Query( (*it).second->jidJID(), (*it).second->name(), (*it).second->groups() ) );
       m_parent->send( iq, this, SynchronizeRoster );
     }
   }
@@ -385,13 +385,13 @@
     RosterData::const_iterator it = data.begin();
     for( ; it != data.end(); ++it )
     {
-      Roster::iterator itr = m_roster.find( (*it)->jid() );
+      Roster::iterator itr = m_roster.find( (*it)->jidJID().full() );
       if( itr != m_roster.end() )
       {
         if( (*it)->remove() )
         {
           if( m_rosterListener )
-            m_rosterListener->handleItemRemoved( (*it)->jid() );
+            m_rosterListener->handleItemRemoved( (*it)->jidJID().full() );
           delete (*itr).second;
           m_roster.erase( itr );
         }
@@ -399,14 +399,14 @@
         {
           (*itr).second->setData( *(*it) );
           if( m_rosterListener )
-            m_rosterListener->handleItemUpdated( (*it)->jid() );
+            m_rosterListener->handleItemUpdated( (*it)->jidJID().full() );
         }
       }
       else if( !(*it)->remove() )
       {
-        m_roster.insert( std::make_pair( (*it)->jid(), new RosterItem( *(*it) ) ) );
+        m_roster.insert( std::make_pair( (*it)->jidJID().full(), new RosterItem( *(*it) ) ) );
         if( m_rosterListener )
-          m_rosterListener->handleItemAdded( (*it)->jid() );
+          m_rosterListener->handleItemAdded( (*it)->jidJID().full() );
       }
     }
   }
@@ -415,7 +415,7 @@
   {
     RosterData::const_iterator it = data.begin();
     for( ; it != data.end(); ++it )
-      m_roster.insert( std::make_pair( (*it)->jid(), new RosterItem( *(*it) ) ) );
+      m_roster.insert( std::make_pair( (*it)->jidJID().full(), new RosterItem( *(*it) ) ) );
   }
 
 }

=== modified file 'src/rostermanager.h'
--- src/rostermanager.h	2010-01-17 13:05:04 +0000
+++ src/rostermanager.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -39,7 +39,7 @@
    * You can modify any number of RosterItems within the Roster at any time. These changes must be
    * synchronized with the server by calling @ref synchronize(). Note that incoming Roster pushes
    * initiated by other resources may overwrite changed values.
-   * Additionally, XEP-0083 (Nested Roster Groups) is implemented herein.
+   * Additionally, @xep{0083} (Nested Roster Groups) is implemented herein.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 0.3
@@ -134,14 +134,14 @@
       void ackSubscriptionRequest( const JID& to, bool ack );
 
       /**
-       * Use this function to retrieve the delimiter of Nested Roster Groups (XEP-0083).
+       * Use this function to retrieve the delimiter of Nested Roster Groups (@xep{0083}).
        * @return The group delimiter.
        * @since 0.7
        */
       const std::string& delimiter() const { return m_delimiter; }
 
       /**
-       * Use this function to set the group delimiter (XEP-0083).
+       * Use this function to set the group delimiter (@xep{0083}).
        * @param delimiter The group delimiter.
        * @since 0.7
        */

=== modified file 'src/search.cpp'
--- src/search.cpp	2010-01-17 13:05:04 +0000
+++ src/search.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -157,7 +157,7 @@
 
     const std::string& id = m_parent->getID();
 
-    IQ iq( IQ::Set, directory );
+    IQ iq( IQ::Set, directory, id );
     iq.addExtension( new Query( fields, values ) );
 
     m_track[id] = sh;

=== modified file 'src/search.h'
--- src/search.h	2010-01-17 13:05:04 +0000
+++ src/search.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -32,7 +32,7 @@
   class Disco;
 
   /**
-   * @brief An implementation of XEP-0055 (Jabber Search)
+   * @brief An implementation of @xep{0055} (Jabber Search)
    *
    * To perform a search in a directory (e.g., a User Directory):
    *
@@ -113,7 +113,7 @@
     public:
 #endif
       /**
-       * @brief A wrapping class for the XEP-0055 &lt;query&gt; element.
+       * @brief A wrapping class for the @xep{0055} &lt;query&gt; element.
        *
        * @author Jakob Schroeter <js@camaya.net>
        * @since 1.0

=== modified file 'src/searchhandler.h'
--- src/searchhandler.h	2010-01-17 13:05:04 +0000
+++ src/searchhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
 
   /**
    * Holds all the possible fields a server may require for searching according
-   * to Section 7, XEP-0055.
+   * to Section 7, @xep{0055}.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 1.0
@@ -118,7 +118,7 @@
   };
 
   /**
-   * The possible fields of a XEP-0055 user search.
+   * The possible fields of a @xep{0055} user search.
    */
   enum SearchFieldEnum
   {
@@ -134,7 +134,7 @@
   typedef std::list<const SearchFieldStruct*> SearchResultList;
 
   /**
-   * @brief A virtual interface that enables objects to receive Jabber Search (XEP-0055) results.
+   * @brief A virtual interface that enables objects to receive Jabber Search (@xep{0055}) results.
    *
    * A class implementing this interface can receive the result of a Jabber Search.
    *

=== modified file 'src/sha.cpp'
--- src/sha.cpp	2010-01-17 13:05:04 +0000
+++ src/sha.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -55,7 +55,8 @@
     if( m_corrupted )
       return EmptyString;
 
-    finalize();
+    if( !m_finished )
+      finalize();
 
     char buf[41];
     for( int i = 0; i < 20; ++i )
@@ -214,7 +215,7 @@
   {
     Message_Block[Message_Block_Index++] = 0x80;
 
-    if( Message_Block_Index > 55 )
+    if( Message_Block_Index > 56 )
     {
       while( Message_Block_Index < 64 )
       {

=== modified file 'src/sha.h'
--- src/sha.h	2010-01-17 13:05:04 +0000
+++ src/sha.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/shim.cpp'
--- src/shim.cpp	2010-01-17 13:05:04 +0000
+++ src/shim.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/shim.h'
--- src/shim.h	2010-01-17 13:05:04 +0000
+++ src/shim.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class Tag;
 
   /**
-   * @brief An implementation/abstraction of Stanza Headers and Internet Metadata (SHIM, XEP-0131).
+   * @brief An implementation/abstraction of Stanza Headers and Internet Metadata (SHIM, @xep{0131}).
    *
    * XEP Version: 1.2
    *

=== modified file 'src/sihandler.h'
--- src/sihandler.h	2010-01-17 13:05:04 +0000
+++ src/sihandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/simanager.cpp'
--- src/simanager.cpp	2010-01-17 13:05:04 +0000
+++ src/simanager.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/simanager.h'
--- src/simanager.h	2010-01-17 13:05:04 +0000
+++ src/simanager.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,7 +24,7 @@
   class SIHandler;
 
   /**
-   * @brief This class manages streams initiated using XEP-0095.
+   * @brief This class manages streams initiated using @xep{0095}.
    *
    * You need only one SIManager object per ClientBase instance.
    *
@@ -148,11 +148,11 @@
        * Starts negotiating a stream with a remote entity.
        * @param sih The SIHandler to handle the result of this request.
        * @param to The entity to talk to.
-       * @param profile The SI profile to use. See XEP-0095 for more info.
+       * @param profile The SI profile to use. See @xep{0095} for more info.
        * @param child1 The first of the two allowed children of the SI offer. See
-       * XEP-0095 for more info.
+       * @xep{0095} for more info.
        * @param child2 The second of the two allowed children of the SI offer. See
-       * XEP-0095 for more info. Defaults to 0.
+       * @xep{0095} for more info. Defaults to 0.
        * @param mimetype The stream's/file's mime-type. Defaults to 'binary/octet-stream'.
        * @param from An optional 'from' address to stamp outgoing requests with.
        * Used in component scenario only. Defaults to empty JID.
@@ -170,8 +170,8 @@
        * SIProfileHandler::handleSIRequest().
        * @param to The requestor.
        * @param id The request's id, as passed to SIProfileHandler::handleSIRequest().
-       * @param child1 The &lt;feature/&gt; child of the SI request. See XEP-0095 for details.
-       * @param child2 The profile-specific child of the SI request. May be 0. See XEP-0095
+       * @param child1 The &lt;feature/&gt; child of the SI request. See @xep{0095} for details.
+       * @param child2 The profile-specific child of the SI request. May be 0. See @xep{0095}
        * for details.
        * @param from An optional 'from' address to stamp outgoing stanzas with.
        * Used in component scenario only. Defaults to empty JID.

=== modified file 'src/siprofileft.cpp'
--- src/siprofileft.cpp	2010-01-17 13:05:04 +0000
+++ src/siprofileft.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/siprofileft.h'
--- src/siprofileft.h	2010-01-17 13:05:04 +0000
+++ src/siprofileft.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -35,7 +35,7 @@
   class SOCKS5Bytestream;
 
   /**
-   * @brief An implementation of the file transfer SI profile (XEP-0096).
+   * @brief An implementation of the file transfer SI profile (@xep{0096}).
    *
    * An SIProfileFT object acts as a 'plugin' to the SIManager. SIProfileFT
    * manages most of the file transfer functionality. The naming comes from the fact that
@@ -190,7 +190,7 @@
        * @param size The file's size. Mandatory and must be > 0.
        * @param hash The file content's MD5 hash.
        * @param desc A description.
-       * @param date The file's last modification date/time. See XEP-0082 for details.
+       * @param date The file's last modification date/time. See @xep{0082} for details.
        * @param mimetype The file's mime-type. Defaults to 'binary/octet-stream' if empty.
        * @param streamTypes ORed StreamType that can be used for this transfer.
        * @param from An optional 'from' address to stamp outgoing requests with.

=== modified file 'src/siprofilefthandler.h'
--- src/siprofilefthandler.h	2010-01-17 13:05:04 +0000
+++ src/siprofilefthandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/siprofilehandler.h'
--- src/siprofilehandler.h	2010-01-17 13:05:04 +0000
+++ src/siprofilehandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/socks5bytestream.cpp'
--- src/socks5bytestream.cpp	2010-01-17 13:05:04 +0000
+++ src/socks5bytestream.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -144,12 +144,17 @@
   void SOCKS5Bytestream::handleConnect( const ConnectionBase* /*connection*/ )
   {
     m_manager->acknowledgeStreamHost( true, m_proxy, m_sid );
+
+    if( !m_open )
+    {
+      m_open = true;
+      m_handler->handleBytestreamOpen( this );
+    }
   }
 
   void SOCKS5Bytestream::handleDisconnect( const ConnectionBase* /*connection*/, ConnectionError /*reason*/ )
   {
-    if( m_handler && m_connected )
-      m_handler->handleBytestreamClose( this );
+    close();
   }
 
 }

=== modified file 'src/socks5bytestream.h'
--- src/socks5bytestream.h	2010-01-17 13:05:04 +0000
+++ src/socks5bytestream.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -29,7 +29,7 @@
   class LogSink;
 
   /**
-   * @brief An implementation of a single SOCKS5 Bytestream (XEP-0065).
+   * @brief An implementation of a single SOCKS5 Bytestream (@xep{0065}).
    *
    * One instance of this class handles one bytestream.
    *

=== modified file 'src/socks5bytestreammanager.cpp'
--- src/socks5bytestreammanager.cpp	2010-01-17 13:05:04 +0000
+++ src/socks5bytestreammanager.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/socks5bytestreammanager.h'
--- src/socks5bytestreammanager.h	2010-01-17 13:05:04 +0000
+++ src/socks5bytestreammanager.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -101,7 +101,7 @@
        * without waiting for success.
        * @param to The recipient of the requested bytestream.
        * @param mode The desired transport layer protocol.
-       * @param sid The bytestream's stream ID, if previously negotiated e.g. using SI (XEP-0095).
+       * @param sid The bytestream's stream ID, if previously negotiated e.g. using SI (@xep{0095}).
        * @param from An optional 'from' address to stamp outgoing
        * requests with. Only useful in component scenarios. Defaults to empty JID.
        * @return @b False in case of an error, @b true otherwise. A return value of @b true does

=== modified file 'src/socks5bytestreamserver.cpp'
--- src/socks5bytestreamserver.cpp	2010-01-17 13:05:04 +0000
+++ src/socks5bytestreamserver.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -12,7 +12,6 @@
 
 
 #include "socks5bytestreamserver.h"
-#include "connectiontcpserver.h"
 #include "mutexguard.h"
 #include "util.h"
 
@@ -30,10 +29,15 @@
   {
     if( m_tcpServer )
       delete m_tcpServer;
+    m_tcpServer = 0;
 
+    m_mutex.lock();
     ConnectionMap::const_iterator it = m_connections.begin();
     for( ; it != m_connections.end(); ++it )
       delete (*it).first;
+    m_connections.clear();
+    util::clearList( m_oldConnections );
+    m_mutex.unlock();
   }
 
   ConnectionError SOCKS5BytestreamServer::listen()
@@ -53,15 +57,26 @@
     if( ce != ConnNoError )
       return ce;
 
-    ConnectionMap::const_iterator it = m_connections.begin();
-    ConnectionMap::const_iterator it2;
-    while( it != m_connections.end() )
+    // First take a snapshot of our connections, and then iterate the snapshot
+    // (so that the live map can be modified by an erase while we
+    // iterate the snapshot of the map)
+    ConnectionMap connectionsSnapshot;
+
+    m_mutex.lock();
+    connectionsSnapshot.insert( m_connections.begin(), m_connections.end() );
+    m_mutex.unlock();
+
+    ConnectionMap::const_iterator it = connectionsSnapshot.begin();
+    for( ; it != connectionsSnapshot.end(); ++it )
     {
-      it2 = it++;
-      (*it2).first->recv( timeout );
+      (*it).first->recv( timeout );
     }
+    connectionsSnapshot.clear();
 
+    m_mutex.lock();
     util::clearList( m_oldConnections );
+    m_mutex.unlock();
+
     return ConnNoError;
   }
 
@@ -126,15 +141,23 @@
     connection->registerConnectionDataHandler( this );
     ConnectionInfo ci;
     ci.state = StateUnnegotiated;
+
+    m_mutex.lock();
     m_connections[connection] = ci;
+    m_mutex.unlock();
   }
 
   void SOCKS5BytestreamServer::handleReceivedData( const ConnectionBase* connection,
                                                    const std::string& data )
   {
+    m_mutex.lock();
     ConnectionMap::iterator it = m_connections.find( const_cast<ConnectionBase*>( connection ) );
     if( it == m_connections.end() )
+    {
+      m_mutex.unlock();
       return;
+    }
+    m_mutex.unlock();
 
     switch( (*it).second.state )
     {
@@ -184,6 +207,7 @@
         {
           const std::string hash = data.substr( 5, 40 );
 
+          m_mutex.lock();
           HashMap::const_iterator ith = m_hashes.begin();
           for( ; ith != m_hashes.end() && (*ith) != hash; ++ith )
             ;
@@ -194,6 +218,7 @@
             (*it).second.hash = hash;
             (*it).second.state = StateDestinationAccepted;
           }
+          m_mutex.unlock();
         }
         (*it).first->send( reply );
         break;
@@ -213,6 +238,7 @@
   void SOCKS5BytestreamServer::handleDisconnect( const ConnectionBase* connection,
                                                        ConnectionError /*reason*/ )
   {
+    util::MutexGuard mg( m_mutex );
     m_connections.erase( const_cast<ConnectionBase*>( connection ) );
     m_oldConnections.push_back( connection );
   }

=== modified file 'src/socks5bytestreamserver.h'
--- src/socks5bytestreamserver.h	2010-01-17 13:05:04 +0000
+++ src/socks5bytestreamserver.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -16,14 +16,13 @@
 
 #include "macros.h"
 #include "connectionhandler.h"
+#include "connectiontcpserver.h"
 #include "logsink.h"
 #include "mutex.h"
 
 namespace gloox
 {
 
-  class ConnectionTCPServer;
-
   /**
    * @brief A server listening for SOCKS5 bytestreams.
    *
@@ -87,6 +86,12 @@
        */
       const std::string localInterface() const;
 
+      /**
+       * Exposes the local socket.
+       * @return The local socket.
+       */
+      int serverSocket() const { return m_tcpServer->socket(); }
+
       // reimplemented from ConnectionHandler
       virtual void handleIncomingConnection( ConnectionBase* server, ConnectionBase* connection );
 

=== modified file 'src/softwareversion.cpp'
--- src/softwareversion.cpp	2010-01-17 13:05:04 +0000
+++ src/softwareversion.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/softwareversion.h'
--- src/softwareversion.h	2010-01-17 13:05:04 +0000
+++ src/softwareversion.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2008-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
   class Tag;
 
   /**
-   * @brief This is an implementation of XEP-0092 as a StanzaExtension.
+   * @brief This is an implementation of @xep{0092} as a StanzaExtension.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 1.0

=== modified file 'src/stanza.cpp'
--- src/stanza.cpp	2010-01-17 13:05:04 +0000
+++ src/stanza.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -24,12 +24,12 @@
 {
 
   Stanza::Stanza( const JID& to )
-    : m_xmllang( "default" ), m_to( to )
+    : m_xmllang( "default" ), m_to( to ), m_hasEmbeddedStanza( false )
   {
   }
 
   Stanza::Stanza( Tag* tag )
-    : m_xmllang( "default" )
+    : m_xmllang( "default" ), m_hasEmbeddedStanza( false )
   {
     if( !tag )
       return;
@@ -66,6 +66,20 @@
     util::clearList( m_extensionList );
   }
 
+  Stanza* Stanza::embeddedStanza() const
+  {
+    StanzaExtensionList::const_iterator it = m_extensionList.begin();
+    for( ; it != m_extensionList.end() && !(*it)->embeddedStanza(); ++it ) ;
+    return it != m_extensionList.end() ? (*it)->embeddedStanza() : 0;
+  }
+  
+  Tag* Stanza::embeddedTag() const
+  {
+    StanzaExtensionList::const_iterator it = m_extensionList.begin();
+    for( ; it != m_extensionList.end() && !(*it)->embeddedTag(); ++it ) ;
+    return it != m_extensionList.end() ? (*it)->embeddedTag() : 0;
+  }
+  
   void Stanza::setLang( StringMap** map,
                         std::string& defaultLang,
                         const Tag* tag )

=== modified file 'src/stanza.h'
--- src/stanza.h	2010-01-17 13:05:04 +0000
+++ src/stanza.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -118,10 +118,49 @@
       void removeExtensions();
 
       /**
+       * This function is used by StanzaExtensionFactory to signal ClientBase
+       * that this Stanza instance contains an embedded Stanza that needs to be
+       * checked for further StanzaExtensions.
+       * You should not need to use this function directly.
+       */
+      void setEmbeddedStanza() { m_hasEmbeddedStanza = true; }
+
+      /**
+       * This function indicates whether this Stanza instance contains an embedded
+       * Stanza that needs to be checked for further StanzaExtensions.
+       * You should not need to use this function directly.
+       * @return Whether this Stanza instance contains an embedded
+       * Stanza.
+       */
+      bool hasEmbeddedStanza() const { return m_hasEmbeddedStanza; }
+      
+      /**
+       * This function returns the embedded Stanza. It is only needed by
+       * ClientBase/StanzaExtensionFactory.
+       * If hasEmbeddedStanza() is true, this function checks every
+       * embedded StanzaExtension for an embedded Stanza and returns the first it finds.
+       * You should not need to use this function directly.
+       * @return The embedded Stanza. May be 0.
+       */
+      Stanza* embeddedStanza() const;
+      
+      /**
+       * This function returns the embedded Tag that the embedded Stanza is based on.
+       * It is only needed by ClientBase/StanzaExtensionFactory.
+       * If hasEmbeddedStanza() is true, this function checks every
+       * embedded StanzaExtension for an embedded Tag and returns the first it finds.
+       * You should not need to use this function directly.
+       *
+       * @return The embedded Tag. May be 0.
+       */
+      Tag* embeddedTag() const;
+
+      /**
        * Creates a Tag representation of the Stanza. The Tag is completely
        * independent of the Stanza and will not be updated when the Stanza
        * is modified.
        * @return A pointer to a Tag representation. It is the job of the
+       *
        * caller to delete the Tag.
        */
       virtual Tag* tag() const = 0;
@@ -166,6 +205,8 @@
 
     private:
       Stanza( const Stanza& );
+      
+      bool m_hasEmbeddedStanza;
 
   };
 

=== modified file 'src/stanzaextension.h'
--- src/stanzaextension.h	2010-01-17 13:05:04 +0000
+++ src/stanzaextension.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -22,6 +22,7 @@
 {
 
   class Tag;
+  class Stanza;
 
   /**
    * Supported Stanza extension types.
@@ -30,62 +31,64 @@
   {
     ExtNone,                        /**< Invalid StanzaExtension. */
     ExtVCardUpdate,                 /**< Extension in the vcard-temp:x:update namespace,
-                                     * advertising a user avatar's SHA1 hash (XEP-0153). */
+                                     * advertising a user avatar's SHA1 hash (@xep{0153}). */
     ExtOOB,                         /**< An extension in the jabber:iq:oob or jabber:x:oob
-                                     * namespaces (XEP-0066). */
+                                     * namespaces (@xep{0066}). */
     ExtGPGSigned,                   /**< An extension containing a GPG/PGP signature
-                                     * (XEP-0027). */
+                                     * (@xep{0027}). */
     ExtGPGEncrypted,                /**< An extension containing a GPG/PGP encrypted message
-                                     * (XEP-0027). */
+                                     * (@xep{0027}). */
     ExtReceipt,                     /**< An extension containing a Message Receipt/Request
-                                     * (XEP-0184). */
+                                     * (@xep{0184}). */
     ExtDelay,                       /**< An extension containing notice of delayed delivery
-                                     * (XEP-0203 & XEP-0091). */
+                                     * (@xep{0203} & @xep{0091}). */
     ExtAMP,                         /**< An extension containing advanced message processing
-                                     * rules (XEP-0079). */
+                                     * rules (@xep{0079}). */
     ExtError,                       /**< An extension containing an error. */
     ExtCaps,                        /**< An extension containing Entity Capabilities
-                                     * (XEP-0115). */
-    ExtChatState,                   /**< An extension containing a chat state (XEP-0085). */
-    ExtMessageEvent,                /**< An extension containing a message event (XEP-0022). */
-    ExtDataForm,                    /**< An extension containing a Data Form (XEP-0004). */
-    ExtNickname,                    /**< An extension containing a User Nickname (XEP-0172). */
+                                     * (@xep{0115}). */
+    ExtChatState,                   /**< An extension containing a chat state (@xep{0085}). */
+    ExtMessageEvent,                /**< An extension containing a message event (@xep{0022}). */
+    ExtDataForm,                    /**< An extension containing a Data Form (@xep{0004}). */
+    ExtNickname,                    /**< An extension containing a User Nickname (@xep{0172}). */
     ExtResourceBind,                /**< A resource bind SE (RFC3921). */
     ExtSessionCreation,             /**< A session establishing SE (RFC3921). */
     ExtVersion,                     /**< An extension containing a Version request/reply
-                                     * (XEP-0092). */
+                                     * (@xep{0092}). */
     ExtXHtmlIM,                     /**< An extension containing an XHTML message
-                                     * representation (XEP-0071) */
-    ExtDiscoInfo,                   /**< An extension containing a disco#info element (XEP-0030). */
-    ExtDiscoItems,                  /**< An extension containing a disco#items element (XEP-0030). */
-    ExtAdhocCommand,                /**< An extension containing a Adhoc Command (XEP-0050). */
-    ExtPrivateXML,                  /**< An extension used for Private XML Storage (XEP-0048). */
+                                     * representation (@xep{0071}) */
+    ExtDiscoInfo,                   /**< An extension containing a disco#info element (@xep{0030}). */
+    ExtDiscoItems,                  /**< An extension containing a disco#items element (@xep{0030}). */
+    ExtAdhocCommand,                /**< An extension containing a Adhoc Command (@xep{0050}). */
+    ExtPrivateXML,                  /**< An extension used for Private XML Storage (@xep{0048}). */
     ExtRoster,                      /**< An extension dealing with the user's roster (RFC-3921). */
     ExtFeatureNeg,                  /**< An extension abstracting a Feature Negotiation element
-                                     * (XEP-0020). */
-    ExtIBB,                         /**< An extension dealing with IBBs (XEP-0047). */
-    ExtNonSaslAuth,                 /**< An extension for doing Non-SASL Authentication (XEP-0078). */
-    ExtMUC,                         /**< An extension dealing with the muc namespace of XEP-0045. */
-    ExtMUCOwner,                    /**< An extension dealing with the muc#owner namespace of XEP-0045. */
-    ExtMUCAdmin,                    /**< An extension dealing with the muc#admin namespace of XEP-0045. */
-    ExtMUCUser,                     /**< An extension dealing with the muc#user namespace of XEP-0045. */
-    ExtMUCUnique,                   /**< An extension dealing with the muc#unique namespace of XEP-0045. */
-    ExtPing,                        /**< An XMPP Ping (XEP-0199). */
-    ExtSearch,                      /**< A XEP-0055 (Jabber Search) wrapper. */
-    ExtRegistration,                /**< A XEP-0077 (In-Band Registration) wrapper. */
-    ExtJingle,                      /**< An extension dealing with Jingle (XEP-0166) */
-    ExtVCard,                       /**< An extension dealing with vcard-temp (XEP-0054) */
-    ExtPrivacy,                     /**< An extension dealing with Privacy Lists (XEP-0016) */
-    ExtLastActivity,                /**< An extension dealing with Last Activity (XEP-0012).  */
-    ExtFlexOffline,                 /**< An extension dealing with Flexible Offline Messages (XEP-0013). */
-    ExtSI,                          /**< An extension dealing with Stream Initiation (XEP-0095). */
-    ExtS5BQuery,                    /**< An extension dealing with stream host offers (XEP-0065) */
-    ExtPubSub,                      /**< An extension dealing with PubSub requests (XEP-0060). */
-    ExtPubSubOwner,                 /**< An extension dealing with PubSub owner requests (XEP-0060). */
+                                     * (@xep{0020}). */
+    ExtIBB,                         /**< An extension dealing with IBBs (@xep{0047}). */
+    ExtNonSaslAuth,                 /**< An extension for doing Non-SASL Authentication (@xep{0078}). */
+    ExtMUC,                         /**< An extension dealing with the muc namespace of @xep{0045}. */
+    ExtMUCOwner,                    /**< An extension dealing with the muc#owner namespace of @xep{0045}. */
+    ExtMUCAdmin,                    /**< An extension dealing with the muc#admin namespace of @xep{0045}. */
+    ExtMUCUser,                     /**< An extension dealing with the muc#user namespace of @xep{0045}. */
+    ExtMUCUnique,                   /**< An extension dealing with the muc#unique namespace of @xep{0045}. */
+    ExtPing,                        /**< An XMPP Ping (@xep{0199}). */
+    ExtSearch,                      /**< A @xep{0055} (Jabber Search) wrapper. */
+    ExtRegistration,                /**< A @xep{0077} (In-Band Registration) wrapper. */
+    ExtJingle,                      /**< An extension dealing with Jingle (@xep{0166}) */
+    ExtVCard,                       /**< An extension dealing with vcard-temp (@xep{0054}) */
+    ExtPrivacy,                     /**< An extension dealing with Privacy Lists (@xep{0016}) */
+    ExtLastActivity,                /**< An extension dealing with Last Activity (@xep{0012}).  */
+    ExtFlexOffline,                 /**< An extension dealing with Flexible Offline Messages (@xep{0013}). */
+    ExtSI,                          /**< An extension dealing with Stream Initiation (@xep{0095}). */
+    ExtS5BQuery,                    /**< An extension dealing with stream host offers (@xep{0065}) */
+    ExtPubSub,                      /**< An extension dealing with PubSub requests (@xep{0060}). */
+    ExtPubSubOwner,                 /**< An extension dealing with PubSub owner requests (@xep{0060}). */
     ExtPubSubEvent,                 /**< An extension for PubSub event notifications
-                                     * (XEP-0060) */
-    ExtSHIM,                        /**< An extension dealing with Stanza Headers and Internet Metadata (XEP-0131). */
-    ExtAttention,                   /**< An extension dealing with Attention (XEP-0224). */
+                                     * (@xep{0060}) */
+    ExtSHIM,                        /**< An extension dealing with Stanza Headers and Internet Metadata (@xep{0131}). */
+    ExtAttention,                   /**< An extension dealing with Attention (@xep{0224}). */
+    ExtForward,                     /**< An extension dealing with Stanza Forwarding (@xep{0297}). */
+    ExtCarbons,                     /**< An extension dealing with Message Carbons (@xep{0280}). */
     ExtUser                         /**< User-supplied extensions must use IDs above this. Do
                                      * not hard-code ExtUser's value anywhere, it is subject
                                      * to change. */
@@ -190,6 +193,22 @@
       virtual ~StanzaExtension() {}
 
       /**
+       * This function returns the embedded Stanza, if any.
+       * You only have to reimplement it if your protocol flow contains embedded Stanzas.
+       *
+       * @return The embedded Stanza. May be 0.
+       */
+      virtual Stanza* embeddedStanza() const { return 0; }
+
+      /**
+       * This function returns the embedded Tag that the embedded Stanza is based on, if any.
+       * You only have to reimplement it if your protocol flow contains embedded Stanzas.
+       *
+       * @return The embedded Tag. May be 0.
+       */
+      virtual Tag* embeddedTag() const { return 0; }
+
+      /**
        * Returns an XPath expression that describes a path to child elements of a
        * stanza that an extension handles.
        *

=== modified file 'src/stanzaextensionfactory.cpp'
--- src/stanzaextensionfactory.cpp	2010-01-17 13:05:04 +0000
+++ src/stanzaextensionfactory.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -14,6 +14,7 @@
 #include "stanzaextensionfactory.h"
 
 #include "gloox.h"
+#include "mutexguard.h"
 #include "util.h"
 #include "stanza.h"
 #include "stanzaextension.h"
@@ -28,7 +29,9 @@
 
   StanzaExtensionFactory::~StanzaExtensionFactory()
   {
+    m_extensionsMutex.lock();
     util::clearList( m_extensions );
+    m_extensionsMutex.unlock();
   }
 
   void StanzaExtensionFactory::registerExtension( StanzaExtension* ext )
@@ -36,6 +39,7 @@
     if( !ext )
       return;
 
+    util::MutexGuard m( m_extensionsMutex );
     SEList::iterator it = m_extensions.begin();
     SEList::iterator it2;
     while( it != m_extensions.end() )
@@ -52,6 +56,7 @@
 
   bool StanzaExtensionFactory::removeExtension( int ext )
   {
+    util::MutexGuard m( m_extensionsMutex );
     SEList::iterator it = m_extensions.begin();
     for( ; it != m_extensions.end(); ++it )
     {
@@ -68,6 +73,8 @@
   void StanzaExtensionFactory::addExtensions( Stanza& stanza, Tag* tag )
   {
     ConstTagList::const_iterator it;
+
+    util::MutexGuard m( m_extensionsMutex );
     SEList::const_iterator ite = m_extensions.begin();
     for( ; ite != m_extensions.end(); ++ite )
     {
@@ -77,7 +84,11 @@
       {
         StanzaExtension* se = (*ite)->newInstance( (*it) );
         if( se )
+        {
           stanza.addExtension( se );
+          if( se->embeddedStanza() )
+            stanza.setEmbeddedStanza();
+        }
       }
     }
   }

=== modified file 'src/stanzaextensionfactory.h'
--- src/stanzaextensionfactory.h	2010-01-17 13:05:04 +0000
+++ src/stanzaextensionfactory.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -14,6 +14,8 @@
 #ifndef STANZAEXTENSIONFACTORY_H__
 #define STANZAEXTENSIONFACTORY_H__
 
+#include "mutex.h"
+
 #include <list>
 
 namespace gloox
@@ -82,6 +84,7 @@
     private:
       typedef std::list<StanzaExtension*> SEList;
       SEList m_extensions;
+      util::Mutex m_extensionsMutex;
 
   };
 

=== modified file 'src/statisticshandler.h'
--- src/statisticshandler.h	2010-01-17 13:05:04 +0000
+++ src/statisticshandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/subscription.cpp'
--- src/subscription.cpp	2010-01-17 13:05:04 +0000
+++ src/subscription.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/subscription.h'
--- src/subscription.h	2010-01-17 13:05:04 +0000
+++ src/subscription.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -40,7 +40,7 @@
        */
       enum S10nType
       {
-        Subscribe,                  /**> A subscription request. */
+        Subscribe,                  /**< A subscription request. */
         Subscribed,                 /**< A subscription notification. */
         Unsubscribe,                /**< An unsubscription request. */
         Unsubscribed,               /**< An unsubscription notification. */

=== modified file 'src/subscriptionhandler.h'
--- src/subscriptionhandler.h	2010-01-17 13:05:04 +0000
+++ src/subscriptionhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tag.cpp'
--- src/tag.cpp	2010-01-17 13:05:04 +0000
+++ src/tag.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -127,7 +127,7 @@
     }
     xml += m_name;
     xml += "='";
-    xml += util::escape( m_value );
+    util::appendEscaped( xml, m_value );
     xml += '\'';
 
     return xml;
@@ -333,7 +333,7 @@
             xml += (*it_n)->tag->xml();
             break;
           case TypeString:
-            xml += util::escape( *((*it_n)->str) );
+            util::appendEscaped( xml, *((*it_n)->str) );
             break;
         }
       }

=== modified file 'src/tag.h'
--- src/tag.h	2010-01-17 13:05:04 +0000
+++ src/tag.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/taghandler.h'
--- src/taghandler.h	2010-01-17 13:05:04 +0000
+++ src/taghandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tests/Makefile.am'
--- src/tests/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/Makefile.am	2014-01-16 10:42:06 +0000
@@ -3,14 +3,14 @@
 ##
 
 SUBDIRS = adhoc adhoccommand adhoccommandnote amprule amp base64 \
-          capabilities chatstatefilter client clientbase connectionbosh \
+          capabilities carbons chatstatefilter client clientbase connectionbosh \
           dataform dataformfield \
           dataformreported dataformitem delayeddelivery discoinfo discoitems disco \
           error \
-          featureneg flexoffline flexofflineoffline \
+          featureneg flexoffline flexofflineoffline forward \
           gpgencrypted gpgsigned \
           inbandbytestreamibb inbandbytestream iq \
-          jid \
+          jid jinglecontent jingleiceudp jinglesession jinglesessionjingle jinglesessionmanager \
           lastactivity lastactivityquery \
           md5 message messageeventfilter \
           mucroommuc mucroommucadmin mucroommucowner mucroommucuser \

=== modified file 'src/tests/Makefile.in'
--- src/tests/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -15,6 +15,23 @@
 
 @SET_MAKE@
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -53,6 +70,11 @@
 	install-pdf-recursive install-ps-recursive install-recursive \
 	installcheck-recursive installdirs-recursive pdf-recursive \
 	ps-recursive uninstall-recursive
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 RECURSIVE_CLEAN_TARGETS = mostlyclean-recursive clean-recursive	\
   distclean-recursive maintainer-clean-recursive
 AM_RECURSIVE_TARGETS = $(RECURSIVE_TARGETS:-recursive=) \
@@ -106,6 +128,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -115,6 +138,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -130,7 +154,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -160,6 +186,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -194,7 +221,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -211,14 +237,14 @@
 top_builddir = @top_builddir@
 top_srcdir = @top_srcdir@
 SUBDIRS = adhoc adhoccommand adhoccommandnote amprule amp base64 \
-          capabilities chatstatefilter client clientbase connectionbosh \
+          capabilities carbons chatstatefilter client clientbase connectionbosh \
           dataform dataformfield \
           dataformreported dataformitem delayeddelivery discoinfo discoitems disco \
           error \
-          featureneg flexoffline flexofflineoffline \
+          featureneg flexoffline flexofflineoffline forward \
           gpgencrypted gpgsigned \
           inbandbytestreamibb inbandbytestream iq \
-          jid \
+          jid jinglecontent jingleiceudp jinglesession jinglesessionjingle jinglesessionmanager \
           lastactivity lastactivityquery \
           md5 message messageeventfilter \
           mucroommuc mucroommucadmin mucroommucowner mucroommucuser \
@@ -286,7 +312,7 @@
 #     (which will cause the Makefiles to be regenerated when you run `make');
 # (2) otherwise, pass the desired values on the `make' command line.
 $(RECURSIVE_TARGETS):
-	@failcom='exit 1'; \
+	@fail= failcom='exit 1'; \
 	for f in x $$MAKEFLAGS; do \
 	  case $$f in \
 	    *=* | --[!k]*);; \
@@ -311,7 +337,7 @@
 	fi; test -z "$$fail"
 
 $(RECURSIVE_CLEAN_TARGETS):
-	@failcom='exit 1'; \
+	@fail= failcom='exit 1'; \
 	for f in x $$MAKEFLAGS; do \
 	  case $$f in \
 	    *=* | --[!k]*);; \
@@ -446,13 +472,10 @@
 	done
 	@list='$(DIST_SUBDIRS)'; for subdir in $$list; do \
 	  if test "$$subdir" = .; then :; else \
-	    test -d "$(distdir)/$$subdir" \
-	    || $(MKDIR_P) "$(distdir)/$$subdir" \
-	    || exit 1; \
-	  fi; \
-	done
-	@list='$(DIST_SUBDIRS)'; for subdir in $$list; do \
-	  if test "$$subdir" = .; then :; else \
+	    $(am__make_dryrun) \
+	      || test -d "$(distdir)/$$subdir" \
+	      || $(MKDIR_P) "$(distdir)/$$subdir" \
+	      || exit 1; \
 	    dir1=$$subdir; dir2="$(distdir)/$$subdir"; \
 	    $(am__relativize); \
 	    new_distdir=$$reldir; \
@@ -487,10 +510,15 @@
 
 installcheck: installcheck-recursive
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/adhoc/Makefile.am'
--- src/tests/adhoc/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/adhoc/Makefile.am	2014-01-16 10:42:06 +0000
@@ -11,5 +11,5 @@
 			../../error.o ../../jid.o ../../prep.o \
 			../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
 			../../dataformitem.o ../../dataformfield.o \
-			../../softwareversion.o
+			../../softwareversion.o ../../mutex.o
 adhoc_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/adhoc/Makefile.in'
--- src/tests/adhoc/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/adhoc/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -53,7 +70,7 @@
 	../../iq.o ../../util.o ../../error.o ../../jid.o ../../prep.o \
 	../../dataform.o ../../dataformfieldcontainer.o \
 	../../dataformreported.o ../../dataformitem.o \
-	../../dataformfield.o ../../softwareversion.o
+	../../dataformfield.o ../../softwareversion.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -69,6 +86,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(adhoc_test_SOURCES)
 DIST_SOURCES = $(adhoc_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -91,6 +113,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -100,6 +123,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -115,7 +139,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -145,6 +171,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -179,7 +206,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -201,7 +227,7 @@
 			../../error.o ../../jid.o ../../prep.o \
 			../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
 			../../dataformitem.o ../../dataformfield.o \
-			../../softwareversion.o
+			../../softwareversion.o ../../mutex.o
 
 adhoc_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -247,7 +273,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-adhoc_test$(EXEEXT): $(adhoc_test_OBJECTS) $(adhoc_test_DEPENDENCIES) 
+adhoc_test$(EXEEXT): $(adhoc_test_OBJECTS) $(adhoc_test_DEPENDENCIES) $(EXTRA_adhoc_test_DEPENDENCIES) 
 	@rm -f adhoc_test$(EXEEXT)
 	$(CXXLINK) $(adhoc_test_OBJECTS) $(adhoc_test_LDADD) $(LIBS)
 
@@ -382,10 +408,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/adhoc/adhoc_test.cpp'
--- src/tests/adhoc/adhoc_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/adhoc/adhoc_test.cpp	2014-01-16 10:42:06 +0000
@@ -2,6 +2,8 @@
 #include "../../iq.h"
 #include "../../iqhandler.h"
 #include "../../jid.h"
+#include "../../mutex.h"
+#include "../../mutexguard.h"
 
 #include <stdio.h>
 #include <locale.h>
@@ -70,19 +72,19 @@
       if( m_test == 5 && command.node() == "foocmd" )
         m_result = true;
     }
-    virtual void handleAdhocSupport( const JID& /*remote*/, bool support )
+    virtual void handleAdhocSupport( const JID& /*remote*/, bool support, int /*context*/ )
     {
       if( m_test == 1 || m_test == 2 )
         m_result = support;
     }
-    virtual void handleAdhocCommands( const JID& /*remote*/, const StringMap& commands )
+    virtual void handleAdhocCommands( const JID& /*remote*/, const StringMap& commands, int /*context*/ )
     {
       if( m_test == 3 && commands.find( "node" ) != commands.end()
           && (*(commands.find( "node" ))).second == "name" )
         m_result = true;
     }
-    virtual void handleAdhocError( const JID& /*remote*/, const Error* /*error*/ ) {}
-    virtual void handleAdhocExecutionResult( const JID& /*remote*/, const Adhoc::Command& /*command*/ )
+    virtual void handleAdhocError( const JID& /*remote*/, const Error* /*error*/, int /*context*/ ) {}
+    virtual void handleAdhocExecutionResult( const JID& /*remote*/, const Adhoc::Command& /*command*/, int /*context*/ )
     {
       if( m_test == 4 )
         m_result = true;
@@ -152,7 +154,7 @@
   if( !at->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -162,7 +164,7 @@
   if( at->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -172,7 +174,7 @@
   if( !at->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -183,7 +185,7 @@
   if( !at->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   ah->registerAdhocCommandProvider( at, "foocmd", "fooname" );
@@ -199,7 +201,7 @@
     if( !at->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -215,7 +217,7 @@
   }
   else
   {
-    printf( "Adhoc: %d test(s) failed\n", fail );
+    fprintf( stderr, "Adhoc: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/adhoccommand/Makefile.am'
--- src/tests/adhoccommand/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/adhoccommand/Makefile.am	2014-01-16 10:42:06 +0000
@@ -17,5 +17,6 @@
 			../../iq.o ../../presence.o ../../message.o ../../subscription.o ../../util.o \
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o \
 			../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
-			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o
+			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o \
+			../../atomicrefcount.o
 adhoccommand_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/adhoccommand/Makefile.in'
--- src/tests/adhoccommand/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/adhoccommand/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -64,7 +81,8 @@
 	../../clientbase.o ../../jid.o ../../dataform.o \
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o \
-	../../eventdispatcher.o ../../softwareversion.o
+	../../eventdispatcher.o ../../softwareversion.o \
+	../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -80,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(adhoccommand_test_SOURCES)
 DIST_SOURCES = $(adhoccommand_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -102,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -111,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -126,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -156,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -190,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -218,7 +245,8 @@
 			../../iq.o ../../presence.o ../../message.o ../../subscription.o ../../util.o \
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o \
 			../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
-			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o
+			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o \
+			../../atomicrefcount.o
 
 adhoccommand_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -264,7 +292,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-adhoccommand_test$(EXEEXT): $(adhoccommand_test_OBJECTS) $(adhoccommand_test_DEPENDENCIES) 
+adhoccommand_test$(EXEEXT): $(adhoccommand_test_OBJECTS) $(adhoccommand_test_DEPENDENCIES) $(EXTRA_adhoccommand_test_DEPENDENCIES) 
 	@rm -f adhoccommand_test$(EXEEXT)
 	$(CXXLINK) $(adhoccommand_test_OBJECTS) $(adhoccommand_test_LDADD) $(LIBS)
 
@@ -399,10 +427,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/adhoccommand/adhoccommand_test.cpp'
--- src/tests/adhoccommand/adhoccommand_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/adhoccommand/adhoccommand_test.cpp	2014-01-16 10:42:06 +0000
@@ -26,7 +26,7 @@
         || ac.node() != "somecmd" || ac.action() != Adhoc::Command::Execute )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -42,7 +42,7 @@
         || ac.action() != Adhoc::Command::Execute )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -63,7 +63,7 @@
         || ac.action() != Adhoc::Command::Execute || ac.form() == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -81,7 +81,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -93,7 +93,7 @@
   }
   else
   {
-    printf( "Adhoc::Command: %d test(s) failed\n", fail );
+    fprintf( stderr, "Adhoc::Command: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/adhoccommandnote/Makefile.am'
--- src/tests/adhoccommandnote/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/adhoccommandnote/Makefile.am	2014-01-16 10:42:06 +0000
@@ -17,5 +17,6 @@
 			../../iq.o ../../presence.o ../../message.o ../../subscription.o ../../util.o \
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o \
 			../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
-			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o
+			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o \
+			../../atomicrefcount.o
 adhoccommandnote_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/adhoccommandnote/Makefile.in'
--- src/tests/adhoccommandnote/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/adhoccommandnote/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -64,7 +81,8 @@
 	../../clientbase.o ../../jid.o ../../dataform.o \
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o \
-	../../eventdispatcher.o ../../softwareversion.o
+	../../eventdispatcher.o ../../softwareversion.o \
+	../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -80,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(adhoccommandnote_test_SOURCES)
 DIST_SOURCES = $(adhoccommandnote_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -102,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -111,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -126,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -156,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -190,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -218,7 +245,8 @@
 			../../iq.o ../../presence.o ../../message.o ../../subscription.o ../../util.o \
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o \
 			../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
-			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o
+			../../dataformitem.o ../../dataformfield.o ../../eventdispatcher.o ../../softwareversion.o \
+			../../atomicrefcount.o
 
 adhoccommandnote_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -264,7 +292,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-adhoccommandnote_test$(EXEEXT): $(adhoccommandnote_test_OBJECTS) $(adhoccommandnote_test_DEPENDENCIES) 
+adhoccommandnote_test$(EXEEXT): $(adhoccommandnote_test_OBJECTS) $(adhoccommandnote_test_DEPENDENCIES) $(EXTRA_adhoccommandnote_test_DEPENDENCIES) 
 	@rm -f adhoccommandnote_test$(EXEEXT)
 	$(CXXLINK) $(adhoccommandnote_test_OBJECTS) $(adhoccommandnote_test_LDADD) $(LIBS)
 
@@ -399,10 +427,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/adhoccommandnote/adhoccommandnote_test.cpp'
--- src/tests/adhoccommandnote/adhoccommandnote_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/adhoccommandnote/adhoccommandnote_test.cpp	2014-01-16 10:42:06 +0000
@@ -26,7 +26,7 @@
         || t->xml() != "<note type='info'>content</note>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -41,37 +41,37 @@
         || t->xml() != "<note type='warn'>content</note>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
-    }
-    delete t;
-    t = 0;
-  }
-
-  // -------
-  {
-    name = "error note";
-    Adhoc::Command::Note n( Adhoc::Command::Note::Error, "content" );
-    t = n.tag();
-    if( n.severity() != Adhoc::Command::Note::Error || n.content() != "content"
-        || t->xml() != "<note type='error'>content</note>" )
-    {
-      ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
-    }
-    delete t;
-    t = 0;
-  }
-
-  // -------
-  {
-    name = "error note";
-    Adhoc::Command::Note n( Adhoc::Command::Note::Error, "content" );
-    t = n.tag();
-    if( n.severity() != Adhoc::Command::Note::Error || n.content() != "content"
-        || t->xml() != "<note type='error'>content</note>" )
-    {
-      ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
+    }
+    delete t;
+    t = 0;
+  }
+
+  // -------
+  {
+    name = "error note";
+    Adhoc::Command::Note n( Adhoc::Command::Note::Error, "content" );
+    t = n.tag();
+    if( n.severity() != Adhoc::Command::Note::Error || n.content() != "content"
+        || t->xml() != "<note type='error'>content</note>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
+    }
+    delete t;
+    t = 0;
+  }
+
+  // -------
+  {
+    name = "error note";
+    Adhoc::Command::Note n( Adhoc::Command::Note::Error, "content" );
+    t = n.tag();
+    if( n.severity() != Adhoc::Command::Note::Error || n.content() != "content"
+        || t->xml() != "<note type='error'>content</note>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -88,7 +88,7 @@
     if( *t != *b )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -106,7 +106,7 @@
     if( *t != *b )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -123,7 +123,7 @@
   }
   else
   {
-    printf( "Adhoc::Command::Note: %d test(s) failed\n", fail );
+    fprintf( stderr, "Adhoc::Command::Note: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/amp/Makefile.am'
--- src/tests/amp/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/amp/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,5 +9,5 @@
 amp_test_SOURCES = amp_test.cpp
 amp_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../amp.o
+			../../amp.o ../../mutex.o
 amp_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/amp/Makefile.in'
--- src/tests/amp/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/amp/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -51,7 +68,8 @@
 amp_test_OBJECTS = $(am_amp_test_OBJECTS)
 amp_test_DEPENDENCIES = ../../tag.o ../../stanza.o ../../prep.o \
 	../../stanzaextensionfactory.o ../../gloox.o ../../message.o \
-	../../util.o ../../error.o ../../jid.o ../../amp.o
+	../../util.o ../../error.o ../../jid.o ../../amp.o \
+	../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -67,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(amp_test_SOURCES)
 DIST_SOURCES = $(amp_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -197,7 +224,7 @@
 amp_test_SOURCES = amp_test.cpp
 amp_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../amp.o
+			../../amp.o ../../mutex.o
 
 amp_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -243,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-amp_test$(EXEEXT): $(amp_test_OBJECTS) $(amp_test_DEPENDENCIES) 
+amp_test$(EXEEXT): $(amp_test_OBJECTS) $(amp_test_DEPENDENCIES) $(EXTRA_amp_test_DEPENDENCIES) 
 	@rm -f amp_test$(EXEEXT)
 	$(CXXLINK) $(amp_test_OBJECTS) $(amp_test_LDADD) $(LIBS)
 
@@ -378,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/amp/amp_test.cpp'
--- src/tests/amp/amp_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/amp/amp_test.cpp	2014-01-16 10:42:06 +0000
@@ -25,7 +25,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -39,7 +39,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -56,7 +56,7 @@
                           "</amp>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     t = 0;
@@ -73,7 +73,7 @@
          "</amp>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     t = 0;
@@ -92,7 +92,7 @@
          "</amp>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     t = 0;
@@ -107,7 +107,7 @@
     if( a.rules().size() != 2 )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
   }
 
@@ -129,7 +129,7 @@
     if( *t != *q )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     t = 0;
@@ -149,7 +149,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -161,7 +161,7 @@
   }
   else
   {
-    printf( "AMP: %d test(s) failed\n", fail );
+    fprintf( stderr, "AMP: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/amprule/Makefile.am'
--- src/tests/amprule/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/amprule/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,5 +9,5 @@
 amprule_test_SOURCES = amprule_test.cpp
 amprule_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../amp.o
+			../../amp.o ../../mutex.o
 amprule_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/amprule/Makefile.in'
--- src/tests/amprule/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/amprule/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -51,7 +68,8 @@
 amprule_test_OBJECTS = $(am_amprule_test_OBJECTS)
 amprule_test_DEPENDENCIES = ../../tag.o ../../stanza.o ../../prep.o \
 	../../stanzaextensionfactory.o ../../gloox.o ../../message.o \
-	../../util.o ../../error.o ../../jid.o ../../amp.o
+	../../util.o ../../error.o ../../jid.o ../../amp.o \
+	../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -67,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(amprule_test_SOURCES)
 DIST_SOURCES = $(amprule_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -197,7 +224,7 @@
 amprule_test_SOURCES = amprule_test.cpp
 amprule_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../amp.o
+			../../amp.o ../../mutex.o
 
 amprule_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -243,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-amprule_test$(EXEEXT): $(amprule_test_OBJECTS) $(amprule_test_DEPENDENCIES) 
+amprule_test$(EXEEXT): $(amprule_test_OBJECTS) $(amprule_test_DEPENDENCIES) $(EXTRA_amprule_test_DEPENDENCIES) 
 	@rm -f amprule_test$(EXEEXT)
 	$(CXXLINK) $(amprule_test_OBJECTS) $(amprule_test_LDADD) $(LIBS)
 
@@ -378,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/amprule/amprule_test.cpp'
--- src/tests/amprule/amprule_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/amprule/amprule_test.cpp	2014-01-16 10:42:06 +0000
@@ -23,7 +23,7 @@
     if( !t || t->xml() != "<rule condition='deliver' action='notify' value='direct'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -37,7 +37,7 @@
     if( !t || t->xml() != "<rule condition='deliver' action='error' value='gateway'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -51,7 +51,7 @@
     if( !t || t->xml() != "<rule condition='deliver' action='drop' value='stored'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -65,7 +65,7 @@
     if( !t || t->xml() != "<rule condition='expire-at' action='notify' value='foodate'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -79,7 +79,7 @@
     if( !t || t->xml() != "<rule condition='match-resource' action='alert' value='exact'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -93,7 +93,7 @@
     if( !t || t->xml() != "<rule condition='deliver' action='drop' value='direct'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -107,7 +107,7 @@
     if( !t || t->xml() != "<rule condition='expire-at' action='notify' value='foodate'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -121,7 +121,7 @@
     if( !t || t->xml() != "<rule condition='match-resource' action='alert' value='other'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -137,7 +137,7 @@
   }
   else
   {
-    printf( "AMP::Rule: %d test(s) failed\n", fail );
+    fprintf( stderr, "AMP::Rule: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/base64/Makefile.in'
--- src/tests/base64/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/base64/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -17,6 +17,23 @@
 
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(base64_test_SOURCES)
 DIST_SOURCES = $(base64_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 HEADERS = $(noinst_HEADERS)
 ETAGS = etags
 CTAGS = ctags
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-base64_test$(EXEEXT): $(base64_test_OBJECTS) $(base64_test_DEPENDENCIES) 
+base64_test$(EXEEXT): $(base64_test_OBJECTS) $(base64_test_DEPENDENCIES) $(EXTRA_base64_test_DEPENDENCIES) 
 	@rm -f base64_test$(EXEEXT)
 	$(CXXLINK) $(base64_test_OBJECTS) $(base64_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/base64/base64_test.cpp'
--- src/tests/base64/base64_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/base64/base64_test.cpp	2014-01-16 10:42:06 +0000
@@ -22,7 +22,7 @@
   if( sample != Base64::decode64( b ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   b = "";
   sample = "";
@@ -34,7 +34,7 @@
   if( sample != Base64::decode64( b ) )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), b.c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), b.c_str() );
   }
   b = "";
   sample = "";
@@ -49,7 +49,7 @@
   }
   else
   {
-    printf( "Base64: %d test(s) failed\n", fail );
+    fprintf( stderr, "Base64: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/capabilities/Makefile.am'
--- src/tests/capabilities/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/capabilities/Makefile.am	2014-01-16 10:42:06 +0000
@@ -11,5 +11,5 @@
 			../../gloox.o ../../base64.o ../../util.o ../../sha.o \
                         ../../jid.o ../../iq.o ../../error.o ../../softwareversion.o \
                         ../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
-                        ../../dataformitem.o ../../dataformfield.o
+                        ../../dataformitem.o ../../dataformfield.o ../../mutex.o
 capabilities_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/capabilities/Makefile.in'
--- src/tests/capabilities/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/capabilities/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,7 @@
 	../../base64.o ../../util.o ../../sha.o ../../jid.o ../../iq.o \
 	../../error.o ../../softwareversion.o ../../dataform.o \
 	../../dataformfieldcontainer.o ../../dataformreported.o \
-	../../dataformitem.o ../../dataformfield.o
+	../../dataformitem.o ../../dataformfield.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(capabilities_test_SOURCES)
 DIST_SOURCES = $(capabilities_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -202,7 +228,7 @@
 			../../gloox.o ../../base64.o ../../util.o ../../sha.o \
                         ../../jid.o ../../iq.o ../../error.o ../../softwareversion.o \
                         ../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
-                        ../../dataformitem.o ../../dataformfield.o
+                        ../../dataformitem.o ../../dataformfield.o ../../mutex.o
 
 capabilities_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -248,7 +274,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-capabilities_test$(EXEEXT): $(capabilities_test_OBJECTS) $(capabilities_test_DEPENDENCIES) 
+capabilities_test$(EXEEXT): $(capabilities_test_OBJECTS) $(capabilities_test_DEPENDENCIES) $(EXTRA_capabilities_test_DEPENDENCIES) 
 	@rm -f capabilities_test$(EXEEXT)
 	$(CXXLINK) $(capabilities_test_OBJECTS) $(capabilities_test_LDADD) $(LIBS)
 
@@ -383,10 +409,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/capabilities/capabilities_test.cpp'
--- src/tests/capabilities/capabilities_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/capabilities/capabilities_test.cpp	2014-01-16 10:42:06 +0000
@@ -68,7 +68,7 @@
   if( c.ver() != "QgayPKawpkPSDYmwT/WM94uAlu0=" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -82,7 +82,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== added directory 'src/tests/carbons'
=== added file 'src/tests/carbons/Makefile.am'
--- src/tests/carbons/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/tests/carbons/Makefile.am	2014-01-16 10:42:06 +0000
@@ -0,0 +1,30 @@
+##
+## Process this file with automake to produce Makefile.in
+##
+
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+
+noinst_PROGRAMS = carbons_test
+
+carbons_test_SOURCES = carbons_test.cpp
+carbons_test_LDADD = ../../jid.o ../../tag.o \
+                        ../../logsink.o ../../prep.o ../../util.o \
+                        ../../gloox.o ../../iq.o ../../stanza.o \
+                        ../../error.o ../../message.o \
+                        ../../forward.o ../../delayeddelivery.o \
+                        ../../clientbase.o ../../client.o \
+                        ../../connectiontcpbase.o ../../connectiontcpclient.o \
+                        ../../disco.o ../../parser.o ../../base64.o \
+                        ../../md5.o ../../tlsgnutlsclient.o ../../tlsopensslclient.o ../../tlsopensslbase.o ../../tlsopensslserver.o ../../tlsschannel.o \
+                        ../../messagesession.o ../../compressionzlib.o \
+                        ../../dns.o ../../stanzaextensionfactory.o \
+                        ../../rostermanager.o ../../nonsaslauth.o ../../sha.o ../../dataform.o \
+                        ../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
+                        ../../dataformfield.o \
+                        ../../rosteritem.o ../../privatexml.o ../../tlsgnutlsbase.o \
+                        ../../tlsdefault.o ../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
+                        ../../mutex.o ../../presence.o ../../subscription.o \
+                        ../../capabilities.o ../../eventdispatcher.o \
+                        ../../softwareversion.o \
+                        ../../atomicrefcount.o ../../attention.o ../../carbons.o
+carbons_test_CFLAGS = $(CPPFLAGS)

=== added file 'src/tests/carbons/Makefile.in'
--- src/tests/carbons/Makefile.in	1970-01-01 00:00:00 +0000
+++ src/tests/carbons/Makefile.in	2014-01-16 10:42:06 +0000
@@ -0,0 +1,550 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+noinst_PROGRAMS = carbons_test$(EXEEXT)
+subdir = src/tests/carbons
+DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+mkinstalldirs = $(install_sh) -d
+CONFIG_HEADER = $(top_builddir)/config.h.unix
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+PROGRAMS = $(noinst_PROGRAMS)
+am_carbons_test_OBJECTS = carbons_test.$(OBJEXT)
+carbons_test_OBJECTS = $(am_carbons_test_OBJECTS)
+carbons_test_DEPENDENCIES = ../../jid.o ../../tag.o ../../logsink.o \
+	../../prep.o ../../util.o ../../gloox.o ../../iq.o \
+	../../stanza.o ../../error.o ../../message.o ../../forward.o \
+	../../delayeddelivery.o ../../clientbase.o ../../client.o \
+	../../connectiontcpbase.o ../../connectiontcpclient.o \
+	../../disco.o ../../parser.o ../../base64.o ../../md5.o \
+	../../tlsgnutlsclient.o ../../tlsopensslclient.o \
+	../../tlsopensslbase.o ../../tlsopensslserver.o \
+	../../tlsschannel.o ../../messagesession.o \
+	../../compressionzlib.o ../../dns.o \
+	../../stanzaextensionfactory.o ../../rostermanager.o \
+	../../nonsaslauth.o ../../sha.o ../../dataform.o \
+	../../dataformfieldcontainer.o ../../dataformreported.o \
+	../../dataformitem.o ../../dataformfield.o ../../rosteritem.o \
+	../../privatexml.o ../../tlsgnutlsbase.o ../../tlsdefault.o \
+	../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
+	../../mutex.o ../../presence.o ../../subscription.o \
+	../../capabilities.o ../../eventdispatcher.o \
+	../../softwareversion.o ../../atomicrefcount.o \
+	../../attention.o ../../carbons.o
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp = $(SHELL) $(top_srcdir)/depcomp
+am__depfiles_maybe = depfiles
+am__mv = mv -f
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+LTCXXCOMPILE = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
+SOURCES = $(carbons_test_SOURCES)
+DIST_SOURCES = $(carbons_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
+ACLOCAL = @ACLOCAL@
+AMTAR = @AMTAR@
+AR = @AR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+CC = @CC@
+CCDEPMODE = @CCDEPMODE@
+CFLAGS = @CFLAGS@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXDEPMODE = @CXXDEPMODE@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+DEFS = @DEFS@
+DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+EXEEXT = @EXEEXT@
+FGREP = @FGREP@
+GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+ISODATE = @ISODATE@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBOBJS = @LTLIBOBJS@
+MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
+MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
+MAYBE_TESTS = @MAYBE_TESTS@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PTHREAD_CC = @PTHREAD_CC@
+PTHREAD_CFLAGS = @PTHREAD_CFLAGS@
+PTHREAD_LIBS = @PTHREAD_LIBS@
+RANLIB = @RANLIB@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+VERSION = @VERSION@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+acx_pthread_config = @acx_pthread_config@
+am__include = @am__include@
+am__leading_dot = @am__leading_dot@
+am__quote = @am__quote@
+am__tar = @am__tar@
+am__untar = @am__untar@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+exec_prefix = @exec_prefix@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+localedir = @localedir@
+localstatedir = @localstatedir@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+carbons_test_SOURCES = carbons_test.cpp
+carbons_test_LDADD = ../../jid.o ../../tag.o \
+                        ../../logsink.o ../../prep.o ../../util.o \
+                        ../../gloox.o ../../iq.o ../../stanza.o \
+                        ../../error.o ../../message.o \
+                        ../../forward.o ../../delayeddelivery.o \
+                        ../../clientbase.o ../../client.o \
+                        ../../connectiontcpbase.o ../../connectiontcpclient.o \
+                        ../../disco.o ../../parser.o ../../base64.o \
+                        ../../md5.o ../../tlsgnutlsclient.o ../../tlsopensslclient.o ../../tlsopensslbase.o ../../tlsopensslserver.o ../../tlsschannel.o \
+                        ../../messagesession.o ../../compressionzlib.o \
+                        ../../dns.o ../../stanzaextensionfactory.o \
+                        ../../rostermanager.o ../../nonsaslauth.o ../../sha.o ../../dataform.o \
+                        ../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
+                        ../../dataformfield.o \
+                        ../../rosteritem.o ../../privatexml.o ../../tlsgnutlsbase.o \
+                        ../../tlsdefault.o ../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
+                        ../../mutex.o ../../presence.o ../../subscription.o \
+                        ../../capabilities.o ../../eventdispatcher.o \
+                        ../../softwareversion.o \
+                        ../../atomicrefcount.o ../../attention.o ../../carbons.o
+
+carbons_test_CFLAGS = $(CPPFLAGS)
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cpp .lo .o .obj
+$(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --gnu src/tests/carbons/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --gnu src/tests/carbons/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure:  $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4):  $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+
+clean-noinstPROGRAMS:
+	@list='$(noinst_PROGRAMS)'; test -n "$$list" || exit 0; \
+	echo " rm -f" $$list; \
+	rm -f $$list || exit $$?; \
+	test -n "$(EXEEXT)" || exit 0; \
+	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
+	echo " rm -f" $$list; \
+	rm -f $$list
+carbons_test$(EXEEXT): $(carbons_test_OBJECTS) $(carbons_test_DEPENDENCIES) $(EXTRA_carbons_test_DEPENDENCIES) 
+	@rm -f carbons_test$(EXEEXT)
+	$(CXXLINK) $(carbons_test_OBJECTS) $(carbons_test_LDADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/carbons_test.Po@am__quote@
+
+.cpp.o:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ $<
+
+.cpp.obj:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cpp.lo:
+@am__fastdepCXX_TRUE@	$(LTCXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+
+distdir: $(DISTFILES)
+	@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	list='$(DISTFILES)'; \
+	  dist_files=`for file in $$list; do echo $$file; done | \
+	  sed -e "s|^$$srcdirstrip/||;t" \
+	      -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+	case $$dist_files in \
+	  */*) $(MKDIR_P) `echo "$$dist_files" | \
+			   sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+			   sort -u` ;; \
+	esac; \
+	for file in $$dist_files; do \
+	  if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
+	  if test -d $$d/$$file; then \
+	    dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+	    if test -d "$(distdir)/$$file"; then \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
+	      cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
+	  else \
+	    test -f "$(distdir)/$$file" \
+	    || cp -p $$d/$$file "$(distdir)/$$file" \
+	    || exit 1; \
+	  fi; \
+	done
+check-am: all-am
+check: check-am
+all-am: Makefile $(PROGRAMS)
+installdirs:
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-noinstPROGRAMS \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am:
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am:
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-noinstPROGRAMS ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags distdir dvi dvi-am html html-am info info-am \
+	install install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip installcheck installcheck-am installdirs \
+	maintainer-clean maintainer-clean-generic mostlyclean \
+	mostlyclean-compile mostlyclean-generic mostlyclean-libtool \
+	pdf pdf-am ps ps-am tags uninstall uninstall-am
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:

=== added file 'src/tests/carbons/carbons_test.cpp'
--- src/tests/carbons/carbons_test.cpp	1970-01-01 00:00:00 +0000
+++ src/tests/carbons/carbons_test.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,159 @@
+#include "../../gloox.h"
+#include "../../jid.h"
+#include "../../delayeddelivery.h"
+#include "../../forward.h"
+#include "../../message.h"
+#include "../../messagehandler.h"
+#include "../../client.h"
+#include "../../attention.h"
+#include "../../carbons.h"
+
+#include <locale.h>
+#include <string>
+#include <cstdio> // [s]print[f]
+
+using namespace gloox;
+
+
+  class CarbonsTest : public MessageHandler
+  {
+    public:
+      CarbonsTest() : cb( "foo" )
+      {
+        cb.registerMessageHandler( this );
+        cb.registerStanzaExtension( new Forward() );
+        cb.registerStanzaExtension( new Carbons() );
+        cb.registerStanzaExtension( new Attention() );
+      }
+      ~CarbonsTest() {}
+      void testTag( Tag* tag ) { cb.handleTag( tag ); }
+      virtual void handleMessage( const Message& msg, MessageSession* )
+      {
+        Tag* m = msg.tag();
+        m_xml = m->xml();
+//         printf( "msg: %s\n", m->xml().c_str() );
+        delete m;
+      }
+      const std::string& getXml() { return m_xml; }
+    private:
+      Client cb;
+      std::string m_xml;
+  };
+
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  int fail = 0;
+  std::string name;
+
+  Tag* tag = new Tag( "message", XMLNS, XMLNS_CLIENT );
+  tag->addAttribute( "to", "foo@myserver/4444" );
+  tag->addAttribute( "from", "foo@myserver" );
+  tag->addAttribute( "id", "someid" );
+  tag->addAttribute( "type", "chat" );
+  Tag* c = new Tag( tag, "received", XMLNS, XMLNS_MESSAGE_CARBONS );
+  Tag* f = new Tag( c, "forwarded",  XMLNS, XMLNS_STANZA_FORWARDING );
+  Tag* m = new Tag( f, "message", XMLNS, XMLNS_CLIENT );
+  m->addAttribute( "to", "foo@myserver/0123" );
+  m->addAttribute( "from", "bar@theirserver/home" );
+  m->addAttribute( "id", "someotherid" );
+  m->addAttribute( "type", "chat" );
+  new Tag( m, "body", "a sample message body" );
+  new Tag( m, "attention", XMLNS, XMLNS_ATTENTION );
+
+  CarbonsTest t;
+  t.testTag( tag );
+
+  // -------
+  name = "parse Carbons";
+  if( tag->xml() != t.getXml() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed:\n%s\n---\n%s\n", name.c_str(), tag->xml().c_str(), t.getXml().c_str() );
+  }
+
+
+  Carbons* cm = 0;
+  Tag* temp = 0;
+
+  // -------
+  name = "create Carbons::Received";
+  cm = new Carbons( Carbons::Received );
+  temp = cm->tag();
+  if( cm->type() != Carbons::Received || temp->xml() != "<received xmlns='" + XMLNS_MESSAGE_CARBONS + "'/>" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: type: %d, tag: %s\n", name.c_str(), cm->type(), temp ? temp->xml().c_str() : "'0'" );
+  }
+  delete temp;
+  delete cm;
+
+  // -------
+  name = "create Carbons::Sent";
+  cm = new Carbons( Carbons::Sent );
+  temp = cm->tag();
+  if( cm->type() != Carbons::Sent  || temp->xml() != "<sent xmlns='" + XMLNS_MESSAGE_CARBONS + "'/>" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: type: %d, tag: %s\n", name.c_str(), cm->type(), temp ? temp->xml().c_str() : "'0'" );
+  }
+  delete temp;
+  delete cm;
+
+  // -------
+  name = "create Carbons::Enable";
+  cm = new Carbons( Carbons::Enable );
+  temp = cm->tag();
+  if( cm->type() != Carbons::Enable || temp->xml() != "<enable xmlns='" + XMLNS_MESSAGE_CARBONS + "'/>" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: type: %d, tag: %s\n", name.c_str(), cm->type(), temp ? temp->xml().c_str() : "'0'" );
+  }
+  delete temp;
+  delete cm;
+
+  // -------
+  name = "create Carbons::Disable";
+  cm = new Carbons( Carbons::Disable );
+  temp = cm->tag();
+  if( cm->type() != Carbons::Disable || temp->xml() != "<disable xmlns='" + XMLNS_MESSAGE_CARBONS + "'/>" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: type: %d, tag: %s\n", name.c_str(), cm->type(), temp ? temp->xml().c_str() : "'0'" );
+  }
+  delete temp;
+  delete cm;
+
+  // -------
+  name = "create Carbons::Private";
+  cm = new Carbons( Carbons::Private );
+  temp = cm->tag();
+  if( cm->type() != Carbons::Private || temp->xml() != "<private xmlns='" + XMLNS_MESSAGE_CARBONS + "'/>" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: type: %d, tag: %s\n", name.c_str(), cm->type(), temp ? temp->xml().c_str() : "'0'" );
+  }
+  delete temp;
+  delete cm;
+
+
+
+
+
+
+
+
+
+
+  if( fail == 0 )
+  {
+    printf( "Carbons: OK\n" );
+    return 0;
+  }
+  else
+  {
+    fprintf( stderr, "Carbons: %d test(s) failed\n", fail );
+    return 1;
+  }
+
+}

=== modified file 'src/tests/chatstatefilter/Makefile.am'
--- src/tests/chatstatefilter/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/chatstatefilter/Makefile.am	2014-01-16 10:42:06 +0000
@@ -10,5 +10,5 @@
 chatstatefilter_test_LDADD = ../../tag.o ../../stanza.o ../../stanzaextensionfactory.o \
  				../../jid.o ../../prep.o \
 				../../message.o ../../util.o \
-				../../gloox.o ../../chatstate.o
+				../../gloox.o ../../chatstate.o ../../mutex.o
 chatstatefilter_test_CPPFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/chatstatefilter/Makefile.in'
--- src/tests/chatstatefilter/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/chatstatefilter/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -52,7 +69,8 @@
 chatstatefilter_test_OBJECTS = $(am_chatstatefilter_test_OBJECTS)
 chatstatefilter_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
 	../../stanzaextensionfactory.o ../../jid.o ../../prep.o \
-	../../message.o ../../util.o ../../gloox.o ../../chatstate.o
+	../../message.o ../../util.o ../../gloox.o ../../chatstate.o \
+	../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -68,6 +86,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(chatstatefilter_test_SOURCES)
 DIST_SOURCES = $(chatstatefilter_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +113,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +123,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +139,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +171,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +206,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -199,7 +226,7 @@
 chatstatefilter_test_LDADD = ../../tag.o ../../stanza.o ../../stanzaextensionfactory.o \
  				../../jid.o ../../prep.o \
 				../../message.o ../../util.o \
-				../../gloox.o ../../chatstate.o
+				../../gloox.o ../../chatstate.o ../../mutex.o
 
 chatstatefilter_test_CPPFLAGS = $(CPPFLAGS)
 all: all-am
@@ -245,7 +272,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-chatstatefilter_test$(EXEEXT): $(chatstatefilter_test_OBJECTS) $(chatstatefilter_test_DEPENDENCIES) 
+chatstatefilter_test$(EXEEXT): $(chatstatefilter_test_OBJECTS) $(chatstatefilter_test_DEPENDENCIES) $(EXTRA_chatstatefilter_test_DEPENDENCIES) 
 	@rm -f chatstatefilter_test$(EXEEXT)
 	$(CXXLINK) $(chatstatefilter_test_OBJECTS) $(chatstatefilter_test_LDADD) $(LIBS)
 
@@ -394,10 +421,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/chatstatefilter/chatstatefilter_test.cpp'
--- src/tests/chatstatefilter/chatstatefilter_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/chatstatefilter/chatstatefilter_test.cpp	2014-01-16 10:42:06 +0000
@@ -140,7 +140,7 @@
            != gloox::ChatStateActive )
     {
       ++fail;
-      printf( "test '%s' failed:s %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:s %s\n", name.c_str(), t->xml().c_str() );
     }
     delete f;
     f = 0;
@@ -159,7 +159,7 @@
     if( !ms->ok() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -173,7 +173,7 @@
     if( !ms->ok() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -187,7 +187,7 @@
     if( !ms->ok() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -201,7 +201,7 @@
     if( !ms->ok() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -215,7 +215,7 @@
     if( !ms->ok() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -226,7 +226,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -236,7 +236,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -246,7 +246,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -256,7 +256,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -266,7 +266,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   delete f;
@@ -291,7 +291,7 @@
   }
   else
   {
-    printf( "ChatStateFilter: %d test(s) failed\n", fail );
+    fprintf( stderr, "ChatStateFilter: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/client/Makefile.am'
--- src/tests/client/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/client/Makefile.am	2014-01-16 10:42:06 +0000
@@ -7,7 +7,7 @@
 noinst_PROGRAMS = client_test
 
 client_test_SOURCES = client_test.cpp
-client_test_LDADD = ../../client.o ../../clientbase.o ../../connectiontcpbase.o ../../connectiontcpclient.o \
+client_test_LDADD = ../../client.o ../../connectiontcpbase.o ../../connectiontcpclient.o \
 			../../disco.o ../../parser.o ../../tag.o ../../stanza.o ../../base64.o ../../jid.o \
 			../../md5.o ../../tlsgnutlsclient.o ../../tlsopensslclient.o ../../tlsopensslbase.o ../../tlsopensslserver.o ../../tlsschannel.o \
 			../../logsink.o ../../messagesession.o ../../prep.o ../../compressionzlib.o \
@@ -19,5 +19,6 @@
 			../../tlsdefault.o ../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
 			../../mutex.o ../../iq.o ../../presence.o ../../message.o ../../subscription.o \
 			../../util.o ../../error.o ../../capabilities.o ../../eventdispatcher.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 client_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/client/Makefile.in'
--- src/tests/client/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/client/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -49,24 +66,24 @@
 PROGRAMS = $(noinst_PROGRAMS)
 am_client_test_OBJECTS = client_test.$(OBJEXT)
 client_test_OBJECTS = $(am_client_test_OBJECTS)
-client_test_DEPENDENCIES = ../../client.o ../../clientbase.o \
-	../../connectiontcpbase.o ../../connectiontcpclient.o \
-	../../disco.o ../../parser.o ../../tag.o ../../stanza.o \
-	../../base64.o ../../jid.o ../../md5.o ../../tlsgnutlsclient.o \
-	../../tlsopensslclient.o ../../tlsopensslbase.o \
-	../../tlsopensslserver.o ../../tlsschannel.o ../../logsink.o \
-	../../messagesession.o ../../prep.o ../../compressionzlib.o \
-	../../dns.o ../../stanzaextensionfactory.o \
-	../../rostermanager.o ../../nonsaslauth.o ../../sha.o \
-	../../dataform.o ../../dataformfieldcontainer.o \
-	../../dataformreported.o ../../dataformitem.o \
-	../../dataformfield.o ../../rosteritem.o ../../privatexml.o \
-	../../gloox.o ../../tlsgnutlsbase.o ../../tlsdefault.o \
-	../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
-	../../mutex.o ../../iq.o ../../presence.o ../../message.o \
-	../../subscription.o ../../util.o ../../error.o \
-	../../capabilities.o ../../eventdispatcher.o \
-	../../softwareversion.o
+client_test_DEPENDENCIES = ../../client.o ../../connectiontcpbase.o \
+	../../connectiontcpclient.o ../../disco.o ../../parser.o \
+	../../tag.o ../../stanza.o ../../base64.o ../../jid.o \
+	../../md5.o ../../tlsgnutlsclient.o ../../tlsopensslclient.o \
+	../../tlsopensslbase.o ../../tlsopensslserver.o \
+	../../tlsschannel.o ../../logsink.o ../../messagesession.o \
+	../../prep.o ../../compressionzlib.o ../../dns.o \
+	../../stanzaextensionfactory.o ../../rostermanager.o \
+	../../nonsaslauth.o ../../sha.o ../../dataform.o \
+	../../dataformfieldcontainer.o ../../dataformreported.o \
+	../../dataformitem.o ../../dataformfield.o ../../rosteritem.o \
+	../../privatexml.o ../../gloox.o ../../tlsgnutlsbase.o \
+	../../tlsdefault.o ../../tlsgnutlsclientanon.o \
+	../../tlsgnutlsserveranon.o ../../mutex.o ../../iq.o \
+	../../presence.o ../../message.o ../../subscription.o \
+	../../util.o ../../error.o ../../capabilities.o \
+	../../eventdispatcher.o ../../softwareversion.o \
+	../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -82,6 +99,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(client_test_SOURCES)
 DIST_SOURCES = $(client_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -104,6 +126,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -113,6 +136,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -128,7 +152,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -158,6 +184,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -192,7 +219,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -210,7 +236,7 @@
 top_srcdir = @top_srcdir@
 AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual 
 client_test_SOURCES = client_test.cpp
-client_test_LDADD = ../../client.o ../../clientbase.o ../../connectiontcpbase.o ../../connectiontcpclient.o \
+client_test_LDADD = ../../client.o ../../connectiontcpbase.o ../../connectiontcpclient.o \
 			../../disco.o ../../parser.o ../../tag.o ../../stanza.o ../../base64.o ../../jid.o \
 			../../md5.o ../../tlsgnutlsclient.o ../../tlsopensslclient.o ../../tlsopensslbase.o ../../tlsopensslserver.o ../../tlsschannel.o \
 			../../logsink.o ../../messagesession.o ../../prep.o ../../compressionzlib.o \
@@ -222,7 +248,8 @@
 			../../tlsdefault.o ../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
 			../../mutex.o ../../iq.o ../../presence.o ../../message.o ../../subscription.o \
 			../../util.o ../../error.o ../../capabilities.o ../../eventdispatcher.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 client_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -268,7 +295,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-client_test$(EXEEXT): $(client_test_OBJECTS) $(client_test_DEPENDENCIES) 
+client_test$(EXEEXT): $(client_test_OBJECTS) $(client_test_DEPENDENCIES) $(EXTRA_client_test_DEPENDENCIES) 
 	@rm -f client_test$(EXEEXT)
 	$(CXXLINK) $(client_test_OBJECTS) $(client_test_LDADD) $(LIBS)
 
@@ -403,10 +430,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/client/client_test.cpp'
--- src/tests/client/client_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/client/client_test.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,6 @@
 #define CLIENTBASE_TEST
 #include "../../client.h"
+#include "../../clientbase.cpp"
 #include "../../jid.h"
 #include "../../connectionbase.h"
 // #include "../../logsink.h"
@@ -13,21 +14,30 @@
 #include <string>
 #include <cstdio> // [s]print[f]
 
-class ClientTest : public Client, /*LogHandler,*/ ConnectionListener
+class ClientTest : public Client, LogHandler, ConnectionListener
 {
   public:
     ClientTest( const JID& jid, const std::string& password, int port = -1 )
-      : Client( jid, password, port ), m_idCount( 0 ), m_connected( 0 ), m_disconnected( 0 )
+      : Client( jid, password, port ), m_connected( 0 ), m_disconnected( 0 ), m_log( false )
     {
-//       logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this );
+      logInstance().registerLogHandler( LogLevelDebug, LogAreaAll, this );
       registerConnectionListener( this );
+      jidCopy = jid.full();
     }
     virtual ~ClientTest() {}
-//     virtual void handleLog( LogLevel level, LogArea area, const std::string& message )
-//     {
-//       printf("log: level: %d, area: %d, %s\n", level, area, message.c_str() );
-//     }
-    virtual void onConnect() { ++m_connected; disconnect(); }
+    virtual void handleLog( LogLevel level, LogArea area, const std::string& message )
+    {
+      if( m_log )
+        printf("log: level: %d, area: %d, %s\n", level, area, message.c_str() );
+    }
+    virtual void onConnect()
+    {
+      ++m_connected;
+      
+      // magic jid
+      if( jidCopy == "a@b/c" )
+        disconnect();
+    }
     virtual void onDisconnect( ConnectionError e )
     {
       ++m_disconnected;
@@ -44,8 +54,7 @@
     int disconnected() const { return m_disconnected; }
     ConnectionError disconnectReason() const { return m_disconnect; }
     StreamError streamErrorReason() const { return m_streamerror; }
-
-    int m_idCount;
+    void setLog( bool log ) { m_log = log; }
 
   protected:
 
@@ -54,6 +63,8 @@
     int m_disconnected;
     ConnectionError m_disconnect;
     StreamError m_streamerror;
+    bool m_log;
+    std::string jidCopy;
 };
 
 class ConnectionImpl : public ConnectionBase
@@ -103,11 +114,11 @@
     int m_test;
     int m_pos;
     bool m_run;
-    static const char* m_msgs[4][9];
+    static const char* m_msgs[6][12];
 
 };
 
-const char* ConnectionImpl::m_msgs[4][9] =
+const char* ConnectionImpl::m_msgs[6][12] =
   {
     { // connection/auth goes ok.
       "<stream:stream from='jabber.cc' id='6kpid3u736sqjwd65n25wm57mzz10wz7hopvsj2w' version='1.0' "
@@ -186,7 +197,72 @@
       "</stream:features>",
       "<stream:error><xml-not-well-formed xmlns='urn:ietf:params:xml:ns:xmpp-streams'/></stream:error>",
       0,
-    }
+    },
+    { // connection/auth goes ok. basic xep-0198 (stream management) ack'ing
+      "<stream:stream from='jabber.cc' id='6kpid3u736sqjwd65n25wm57mzz10wz7hopvsj2w' version='1.0' "
+      "xmlns='jabber:client' xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<stream:features xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<mechanisms xmlns='urn:ietf:params:xml:ns:xmpp-sasl'>"
+      "<mechanism>PLAIN</mechanism>"
+      "<mechanism>DIGEST-MD5</mechanism>"
+      "</mechanisms>"
+      "</stream:features>",
+      "<challenge xmlns='urn:ietf:params:xml:ns:xmpp-sasl'>"
+      "bm9uY2U9ImhvS1I2VkZDSGFibUVYY01weFhlL0QrcVZjWEdyMUdFNzQ0MVFzM2MxY2M9IixyZWFsbT0iamFiYmV"
+      "yLmNjIixxb3A9ImF1dGgsYXV0aC1pbnQsYXV0aC1jb25mIixjaXBoZXI9InJjNC00MCxyYzQtNTYscmM0LGRlcyw"
+      "zZGVzIixtYXhidWY9MTAyNCxjaGFyc2V0PXV0Zi04LGFsZ29yaXRobT1tZDUtc2Vzcw=="
+      "</challenge>",
+      "<challenge xmlns='urn:ietf:params:xml:ns:xmpp-sasl'>"
+      "cnNwYXV0aD1mNGFhZTM0YWY0N2I1MmM0MmQ2NWQzY2NjMGNjN2YyNA=="
+      "</challenge>",
+      "<success xmlns='urn:ietf:params:xml:ns:xmpp-sasl'/>",
+      "<stream:stream from='jabber.cc' id='1o4p1gz2h0m1wvqutohs24d439nbv9zxx4nykm11' version='1.0' "
+      "xmlns='jabber:client' xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<stream:features xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<bind xmlns='urn:ietf:params:xml:ns:xmpp-bind'/>"
+      "<session xmlns='urn:ietf:params:xml:ns:xmpp-session'/>"
+      "<sm xmlns='urn:xmpp:sm:3'/>"
+      "</stream:features>",
+      "<iq id='uid1' type='result' xmlns='jabber:client'>"
+      "<bind xmlns='urn:ietf:params:xml:ns:xmpp-bind'>"
+      "<jid>hurkhurk@jabber.cc/gloox</jid></bind></iq>",
+      "<enabled xmlns='urn:xmpp:sm:3' resume='true' id='some-long-id'/>",
+      "<iq id='uid2' type='result' xmlns='jabber:client'/>",
+      "<iq id='uid3' type='result' xmlns='jabber:client'><query xmlns='jabber:iq:private'>"
+      "<roster xmlns='roster:delimiter'>::</roster></query></iq>"
+      "<iq id='uid4' type='result' xmlns='jabber:client'><query xmlns='jabber:iq:roster'/></iq>",
+      0
+    },
+    { // connection/auth goes ok.
+      "<stream:stream from='jabber.cc' id='6kpid3u736sqjwd65n25wm57mzz10wz7hopvsj2w' version='1.0' "
+      "xmlns='jabber:client' xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<stream:features xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<mechanisms xmlns='urn:ietf:params:xml:ns:xmpp-sasl'>"
+      "<mechanism>PLAIN</mechanism>"
+      "<mechanism>DIGEST-MD5</mechanism>"
+      "</mechanisms>"
+      "</stream:features>",
+      "<challenge xmlns='urn:ietf:params:xml:ns:xmpp-sasl'>"
+      "bm9uY2U9ImhvS1I2VkZDSGFibUVYY01weFhlL0QrcVZjWEdyMUdFNzQ0MVFzM2MxY2M9IixyZWFsbT0iamFiYmV"
+      "yLmNjIixxb3A9ImF1dGgsYXV0aC1pbnQsYXV0aC1jb25mIixjaXBoZXI9InJjNC00MCxyYzQtNTYscmM0LGRlcyw"
+      "zZGVzIixtYXhidWY9MTAyNCxjaGFyc2V0PXV0Zi04LGFsZ29yaXRobT1tZDUtc2Vzcw=="
+      "</challenge>",
+      "<challenge xmlns='urn:ietf:params:xml:ns:xmpp-sasl'>"
+      "cnNwYXV0aD1mNGFhZTM0YWY0N2I1MmM0MmQ2NWQzY2NjMGNjN2YyNA=="
+      "</challenge>",
+      "<success xmlns='urn:ietf:params:xml:ns:xmpp-sasl'/>",
+      "<stream:stream from='jabber.cc' id='1o4p1gz2h0m1wvqutohs24d439nbv9zxx4nykm11' version='1.0' "
+      "xmlns='jabber:client' xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<stream:features xmlns:stream='http://etherx.jabber.org/streams'>"
+      "<bind xmlns='urn:ietf:params:xml:ns:xmpp-bind'/>"
+      "<session xmlns='urn:ietf:params:xml:ns:xmpp-session'/>"
+      "<sm xmlns='urn:xmpp:sm:3'/>"
+      "</stream:features>",
+      "<resumed xmlns='urn:xmpp:sm:3' h='3' previd='some-long-id' />",
+      "<r xmlns='urn:xmpp:sm:3'/>",
+      "<message from='someone' to='someother'><body>something</body></message>",
+      0
+    },
   };
 
 int main( int /*argc*/, char** /*argv*/ )
@@ -206,11 +282,13 @@
   c->setConnectionImpl( conn );
   c->setTls( TLSDisabled );
   c->setCompression( false );
+  //   c->setLog( true );
   c->connect();
+//   printf( "connected: %d, disconnected: %d, reason: %d\n", c->connected(), c->disconnected(), c->disconnectReason() );
   if( c->connected() != 1 || c->disconnected() != 1 || c->disconnectReason() != ConnUserDisconnected )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -223,11 +301,12 @@
   c->setConnectionImpl( conn );
   c->setTls( TLSDisabled );
   c->setCompression( false );
+  //   c->setLog( true );
   c->connect();
   if( c->connected() != 0 || c->disconnected() != 1 || c->disconnectReason() != ConnAuthenticationFailed )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -240,11 +319,12 @@
   c->setConnectionImpl( conn );
   c->setTls( TLSDisabled );
   c->setCompression( false );
+  //   c->setLog( true );
   c->connect();
   if( c->connected() != 0 || c->disconnected() != 1 || c->disconnectReason() != ConnIoError )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -257,12 +337,13 @@
   c->setConnectionImpl( conn );
   c->setTls( TLSDisabled );
   c->setCompression( false );
+  //   c->setLog( true );
   c->connect();
   if( c->connected() != 0 || c->disconnected() != 1 || c->disconnectReason() != ConnStreamError
       || c->streamErrorReason() != StreamErrorXmlNotWellFormed )
   {
     ++fail;
-    printf( "test '%s' failed: %d, %d\n", name.c_str(), c->disconnectReason(), c->streamErrorReason() );
+    fprintf( stderr, "test '%s' failed: %d, %d\n", name.c_str(), c->disconnectReason(), c->streamErrorReason() );
   }
   delete c;
   c = 0;
@@ -274,13 +355,14 @@
   c->setConnectionImpl( conn );
   c->setTls( TLSDisabled );
   c->setCompression( false );
+  //   c->setLog( true );
   for( int i = 1; i <= 100; ++i )
   {
     c->connect();
     if( c->connected() != 0 || c->disconnected() != i || c->disconnectReason() != ConnIoError )
     {
       ++fail;
-      printf( "test '%s' failed, %d, %d, %d\n", name.c_str(),
+      fprintf( stderr, "test '%s' failed, %d, %d, %d\n", name.c_str(),
               c->connected(), c->disconnected(),
               c->disconnectReason() );
       break;
@@ -296,26 +378,83 @@
   c->setConnectionImpl( conn );
   c->setTls( TLSDisabled );
   c->setCompression( false );
+  //   c->setLog( true );
   for( int i = 1; i <= 100; ++i )
   {
     c->connect();
     if( c->connected() != i || c->disconnected() != i || c->disconnectReason() != ConnUserDisconnected )
     {
       ++fail;
-      printf( "test '%s' failed, %d, %d, %d\n", name.c_str(),
+      fprintf( stderr, "test '%s' failed, %d, %d, %d\n", name.c_str(),
               c->connected(), c->disconnected(),
               c->disconnectReason() );
       break;
     }
-    c->m_idCount = 0; // FIXME re-using this variable in subsequent connection attempts
-                      // causes inconsistencies with the hard-coded replies.
-  }
-  delete c;
-  c = 0;
-
-
-
-
+  }
+  delete c;
+  c = 0;
+
+
+
+  // -------
+  name = "stream management test 1: basic ack";
+  c = new ClientTest( j, "b" );
+  conn = new ConnectionImpl( c, 4 );
+  c->setConnectionImpl( conn );
+  c->setTls( TLSDisabled );
+  c->setCompression( false );
+  c->setStreamManagement( true, false );
+//   c->setLog( true );
+  c->connect();
+  //   printf( "connected: %d, disconnected: %d, reason: %d\n", c->connected(), c->disconnected(), c->disconnectReason() );
+  if( c->connected() != 1 || c->disconnected() != 1 || c->disconnectReason() != ConnUserDisconnected )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed, %d, %d, %d\n", name.c_str(),
+            c->connected(), c->disconnected(),
+            c->disconnectReason() );
+  }
+  delete c;
+  c = 0;
+  
+  
+  j.setServer( "d" );
+  // -------
+  name = "stream management test 2: resume";
+  c = new ClientTest( j, "b" );
+  conn = new ConnectionImpl( c, 4 );
+  c->setConnectionImpl( conn );
+  c->setTls( TLSDisabled );
+  c->setCompression( false );
+  c->setStreamManagement( true, true );
+//   c->setLog( true );
+  c->connect();
+  //   printf( "connected: %d, disconnected: %d, reason: %d\n", c->connected(), c->disconnected(), c->disconnectReason() );
+  if( c->connected() != 1 || c->disconnected() != 1 || c->disconnectReason() != ConnIoError )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' part 1 failed, %d, %d, %d\n", name.c_str(),
+            c->connected(), c->disconnected(),
+            c->disconnectReason() );
+  }
+  else
+  {
+    conn = new ConnectionImpl( c, 5 );
+    c->setConnectionImpl( conn );
+    c->connect();
+    //   printf( "connected: %d, disconnected: %d, reason: %d\n", c->connected(), c->disconnected(), c->disconnectReason() );
+    if( c->connected() != 2 || c->disconnected() != 2 || c->disconnectReason() != ConnIoError )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' part 2 failed, %d, %d, %d\n", name.c_str(),
+              c->connected(), c->disconnected(),
+              c->disconnectReason() );
+    }
+  }
+  delete c;
+  c = 0;
+  
+  
 
 
 
@@ -337,7 +476,7 @@
   }
   else
   {
-    printf( "Client: %d test(s) failed\n", fail );
+    fprintf( stderr, "Client: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/clientbase/Makefile.am'
--- src/tests/clientbase/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/clientbase/Makefile.am	2014-01-16 10:42:06 +0000
@@ -17,5 +17,6 @@
 			../../dataformfield.o \
 			../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o ../../mutex.o \
 			../../iq.o ../../presence.o ../../message.o ../../subscription.o ../../util.o \
-			../../sha.o ../../error.o ../../eventdispatcher.o ../../softwareversion.o
+			../../sha.o ../../error.o ../../eventdispatcher.o ../../softwareversion.o \
+			../../atomicrefcount.o
 clientbase_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/clientbase/Makefile.in'
--- src/tests/clientbase/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/clientbase/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -63,7 +80,8 @@
 	../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
 	../../mutex.o ../../iq.o ../../presence.o ../../message.o \
 	../../subscription.o ../../util.o ../../sha.o ../../error.o \
-	../../eventdispatcher.o ../../softwareversion.o
+	../../eventdispatcher.o ../../softwareversion.o \
+	../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -79,6 +97,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(clientbase_test_SOURCES)
 DIST_SOURCES = $(clientbase_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -101,6 +124,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -110,6 +134,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -125,7 +150,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -155,6 +182,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -189,7 +217,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -217,7 +244,8 @@
 			../../dataformfield.o \
 			../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o ../../mutex.o \
 			../../iq.o ../../presence.o ../../message.o ../../subscription.o ../../util.o \
-			../../sha.o ../../error.o ../../eventdispatcher.o ../../softwareversion.o
+			../../sha.o ../../error.o ../../eventdispatcher.o ../../softwareversion.o \
+			../../atomicrefcount.o
 
 clientbase_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -263,7 +291,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-clientbase_test$(EXEEXT): $(clientbase_test_OBJECTS) $(clientbase_test_DEPENDENCIES) 
+clientbase_test$(EXEEXT): $(clientbase_test_OBJECTS) $(clientbase_test_DEPENDENCIES) $(EXTRA_clientbase_test_DEPENDENCIES) 
 	@rm -f clientbase_test$(EXEEXT)
 	$(CXXLINK) $(clientbase_test_OBJECTS) $(clientbase_test_LDADD) $(LIBS)
 
@@ -398,10 +426,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/clientbase/clientbase_test.cpp'
--- src/tests/clientbase/clientbase_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/clientbase/clientbase_test.cpp	2014-01-16 10:42:06 +0000
@@ -25,7 +25,7 @@
       registerConnectionListener( this );
     }
     virtual ~ClientBaseTest() {}
-    virtual void handleStartNode() { m_handleStartNodeCalled = true; }
+    virtual void handleStartNode( const Tag* /*tag*/ ) { m_handleStartNodeCalled = true; }
     virtual bool handleNormalNode(gloox::Tag*) { return true; }
     virtual void rosterFilled() {}
 /*    virtual void handleLog( LogLevel level, LogArea area, const std::string& message )
@@ -60,8 +60,8 @@
       : ConnectionBase( cdh ), m_pos( 0 ) {}
     virtual ~ConnectionImpl() {}
     virtual ConnectionError connect() { m_state = StateConnected; return ConnNoError; }
-    virtual ConnectionError recv( int timeout = -1 ) { return ConnNoError; }
-    virtual bool send( const std::string& data ) { return true; }
+    virtual ConnectionError recv( int /*timeout = -1*/ ) { return ConnNoError; }
+    virtual bool send( const std::string& /*data*/ ) { return true; }
     virtual ConnectionError receive()
     {
       ConnectionError ce = ConnNoError;
@@ -90,7 +90,7 @@
   if( c->recv() != ConnNotConnected )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -106,7 +106,7 @@
   if( !c->handleStartNodeCalled() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   delete t;
@@ -123,7 +123,7 @@
   if( !c->versionOK() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   delete t;
@@ -140,7 +140,7 @@
   if( c->versionOK() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   delete t;
@@ -155,7 +155,7 @@
   if( c->versionOK() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   delete t;
@@ -173,7 +173,7 @@
   if( !c->sidOK() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   delete t;
@@ -197,7 +197,7 @@
   }
   else
   {
-    printf( "ClientBase: %d test(s) failed\n", fail );
+    fprintf( stderr, "ClientBase: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/connectionbosh/Makefile.in'
--- src/tests/connectionbosh/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/connectionbosh/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(connectionbosh_test_SOURCES)
 DIST_SOURCES = $(connectionbosh_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-connectionbosh_test$(EXEEXT): $(connectionbosh_test_OBJECTS) $(connectionbosh_test_DEPENDENCIES) 
+connectionbosh_test$(EXEEXT): $(connectionbosh_test_OBJECTS) $(connectionbosh_test_DEPENDENCIES) $(EXTRA_connectionbosh_test_DEPENDENCIES) 
 	@rm -f connectionbosh_test$(EXEEXT)
 	$(CXXLINK) $(connectionbosh_test_OBJECTS) $(connectionbosh_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/connectionbosh/connectionbosh_test.cpp'
--- src/tests/connectionbosh/connectionbosh_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/connectionbosh/connectionbosh_test.cpp	2014-01-16 10:42:06 +0000
@@ -30,7 +30,7 @@
 //         printf( "FakeConnection::newInstance(): %d\n", g_test );
         return new FakeConnection();
       }
-      virtual void getStatistics( long int &totalIn, long int &totalOut ) {}
+      virtual void getStatistics( long int& /*totalIn*/, long int& /*totalOut*/ ) {}
       void setTest( int test ) { g_test = test; }
   };
 
@@ -73,7 +73,7 @@
 
     return ConnNoError;
   }
-  bool FakeConnection::send( const std::string& data )
+  bool FakeConnection::send( const std::string& /*data*/ )
   {
 //     printf( "FakeConnection::send(): %d\n", g_test );
     return true;
@@ -96,7 +96,7 @@
       virtual void handleReceivedData( const ConnectionBase* connection, const std::string& data );
       virtual void handleConnect( const ConnectionBase* connection );
       virtual void handleDisconnect( const ConnectionBase* connection, ConnectionError reason );
-      virtual void handleLog( LogLevel level, LogArea area, const std::string& message )
+      virtual void handleLog( LogLevel /*level*/, LogArea area, const std::string& /*message*/ )
       {
 //         printf("%d: ", int( time( 0 ) ) );
         switch(area)
@@ -122,7 +122,7 @@
       bool m_stopLoop;
   };
 
-  void FakeClientBase::handleConnect( const ConnectionBase* connection )
+  void FakeClientBase::handleConnect( const ConnectionBase* /*connection*/ )
   {
 //     printf( "FakeClientBase::handleConnect(): %d\n", g_test );
     m_stopLoop = true;
@@ -133,7 +133,7 @@
       ++g_test;
     }
   }
-  void FakeClientBase::handleReceivedData( const ConnectionBase* connection, const std::string& data )
+  void FakeClientBase::handleReceivedData( const ConnectionBase* /*connection*/, const std::string& /*data*/ )
   {
 //     printf( "FakeClientBase::handleReceivedData(): %d\n", g_test );
     m_stopLoop = true;
@@ -150,7 +150,7 @@
 //     else
 //       printf( "RECEIVED UNHANDLED: %s\n", data.c_str() );
   }
-  void FakeClientBase::handleDisconnect( const ConnectionBase* connection, ConnectionError reason )
+  void FakeClientBase::handleDisconnect( const ConnectionBase* /*connection*/, ConnectionError /*reason*/ )
   {
 //     printf( "FakeClientBase::handleDisconnect(): %d\n", g_test );
     m_stopLoop = true;
@@ -185,7 +185,7 @@
   if( 1 )
   {
     ++fail;
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -200,7 +200,7 @@
   }
   else
   {
-    printf( "ConnectionBOSH: %d test(s) failed\n", fail );
+    fprintf( stderr, "ConnectionBOSH: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/dataform/Makefile.in'
--- src/tests/dataform/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/dataform/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(dataform_test_SOURCES)
 DIST_SOURCES = $(dataform_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -241,7 +267,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-dataform_test$(EXEEXT): $(dataform_test_OBJECTS) $(dataform_test_DEPENDENCIES) 
+dataform_test$(EXEEXT): $(dataform_test_OBJECTS) $(dataform_test_DEPENDENCIES) $(EXTRA_dataform_test_DEPENDENCIES) 
 	@rm -f dataform_test$(EXEEXT)
 	$(CXXLINK) $(dataform_test_OBJECTS) $(dataform_test_LDADD) $(LIBS)
 
@@ -376,10 +402,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/dataform/dataform_test.cpp'
--- src/tests/dataform/dataform_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/dataform/dataform_test.cpp	2014-01-16 10:42:06 +0000
@@ -27,17 +27,17 @@
   if( f->instructions() != instructions )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   if( f->title() != title )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   if( f->type() != TypeForm )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -52,7 +52,7 @@
   }
   else
   {
-    printf( "DataForm: %d test(s) failed\n", fail );
+    fprintf( stderr, "DataForm: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/dataformfield/Makefile.in'
--- src/tests/dataformfield/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/dataformfield/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -66,6 +83,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(dataformfield_test_SOURCES)
 DIST_SOURCES = $(dataformfield_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -88,6 +110,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -97,6 +120,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -112,7 +136,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -142,6 +168,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -176,7 +203,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -239,7 +265,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-dataformfield_test$(EXEEXT): $(dataformfield_test_OBJECTS) $(dataformfield_test_DEPENDENCIES) 
+dataformfield_test$(EXEEXT): $(dataformfield_test_OBJECTS) $(dataformfield_test_DEPENDENCIES) $(EXTRA_dataformfield_test_DEPENDENCIES) 
 	@rm -f dataformfield_test$(EXEEXT)
 	$(CXXLINK) $(dataformfield_test_OBJECTS) $(dataformfield_test_LDADD) $(LIBS)
 
@@ -374,10 +400,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/dataformfield/dataformfield_test.cpp'
--- src/tests/dataformfield/dataformfield_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/dataformfield/dataformfield_test.cpp	2014-01-16 10:42:06 +0000
@@ -19,7 +19,7 @@
   if( f->type() != DataFormField::TypeTextSingle )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -30,7 +30,7 @@
   if( f->type() != DataFormField::TypeBoolean )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -42,7 +42,7 @@
       f->value() != "fieldValue" || f->label() != "fieldLabel" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -53,7 +53,7 @@
   if( f->type() != DataFormField::TypeInvalid )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -66,7 +66,7 @@
   if( f->name() != name )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -79,7 +79,7 @@
   if( f->required() != req )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -91,7 +91,7 @@
   if( f->label() != name )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -103,7 +103,7 @@
   if( f->value() != name )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -119,7 +119,7 @@
   if( f->values() != val )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -135,7 +135,7 @@
   if( f->options() != opt )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   f = 0;
@@ -150,7 +150,7 @@
   if( *ft != *t )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -181,7 +181,7 @@
   if( r->name() != "field" || !r->hasAttribute( "type", "list-multi" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -190,7 +190,7 @@
   if( !r->hasAttribute( "label", "blabla label" ) || !r->hasAttribute( "var", "features" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -199,7 +199,7 @@
   if( !r->hasChild( "option" ) || !r->findChild( "option" )->hasAttribute( "label", "lock" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -208,7 +208,7 @@
   if( !r->hasChild( "option", "label", "stock" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -217,7 +217,7 @@
   if( !r->hasChild( "option", "label", "smoking barrel" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -226,7 +226,7 @@
   if( !r->findChild( "option" )->findChild( "value" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -235,7 +235,7 @@
   if( r->findChild( "option" )->findChild( "value" )->cdata() != "lock" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -250,7 +250,7 @@
           !(*it)->hasChildWithCData( "value", "smoking barrel" ) ) )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
       printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
       printf( "       t: %s\n", t->xml().c_str() );
     }
@@ -260,7 +260,7 @@
   if( !r->hasChildWithCData( "value", "lock" ) || !r->hasChildWithCData( "value", "stock" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     printf( "f->tag(): %s\n", f->tag()->xml().c_str() );
     printf( "       t: %s\n", t->xml().c_str() );
   }
@@ -282,7 +282,7 @@
                                                "label='label'><value>1</value></field>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
   delete f;
   delete t;
@@ -304,7 +304,7 @@
   }
   else
   {
-    printf( "DataFormField: %d test(s) failed\n", fail );
+    fprintf( stderr, "DataFormField: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/dataformitem/Makefile.in'
--- src/tests/dataformitem/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/dataformitem/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(dataformitem_test_SOURCES)
 DIST_SOURCES = $(dataformitem_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -243,7 +269,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-dataformitem_test$(EXEEXT): $(dataformitem_test_OBJECTS) $(dataformitem_test_DEPENDENCIES) 
+dataformitem_test$(EXEEXT): $(dataformitem_test_OBJECTS) $(dataformitem_test_DEPENDENCIES) $(EXTRA_dataformitem_test_DEPENDENCIES) 
 	@rm -f dataformitem_test$(EXEEXT)
 	$(CXXLINK) $(dataformitem_test_OBJECTS) $(dataformitem_test_LDADD) $(LIBS)
 
@@ -378,10 +404,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/dataformitem/dataformitem_test.cpp'
--- src/tests/dataformitem/dataformitem_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/dataformitem/dataformitem_test.cpp	2014-01-16 10:42:06 +0000
@@ -22,7 +22,7 @@
   if( t->xml() != "<item/>" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   delete t;
@@ -38,7 +38,7 @@
        "<value>value</value></field></item>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
   delete f;
   delete t;
@@ -77,7 +77,7 @@
        "</item>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
   delete f;
   delete t;
@@ -98,7 +98,7 @@
   }
   else
   {
-    printf( "DataFormItem: %d test(s) failed\n", fail );
+    fprintf( stderr, "DataFormItem: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/dataformreported/Makefile.in'
--- src/tests/dataformreported/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/dataformreported/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(dataformreported_test_SOURCES)
 DIST_SOURCES = $(dataformreported_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-dataformreported_test$(EXEEXT): $(dataformreported_test_OBJECTS) $(dataformreported_test_DEPENDENCIES) 
+dataformreported_test$(EXEEXT): $(dataformreported_test_OBJECTS) $(dataformreported_test_DEPENDENCIES) $(EXTRA_dataformreported_test_DEPENDENCIES) 
 	@rm -f dataformreported_test$(EXEEXT)
 	$(CXXLINK) $(dataformreported_test_OBJECTS) $(dataformreported_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/dataformreported/dataformreported_test.cpp'
--- src/tests/dataformreported/dataformreported_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/dataformreported/dataformreported_test.cpp	2014-01-16 10:42:06 +0000
@@ -22,7 +22,7 @@
   if( t->xml() != "<reported/>" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
   delete t;
@@ -38,7 +38,7 @@
        "<value>value</value></field></reported>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
   delete f;
   delete t;
@@ -77,7 +77,7 @@
        "</reported>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
   delete f;
   delete t;
@@ -98,7 +98,7 @@
   }
   else
   {
-    printf( "DataFormReported: %d test(s) failed\n", fail );
+    fprintf( stderr, "DataFormReported: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/delayeddelivery/Makefile.in'
--- src/tests/delayeddelivery/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/delayeddelivery/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(delayeddelivery_test_SOURCES)
 DIST_SOURCES = $(delayeddelivery_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-delayeddelivery_test$(EXEEXT): $(delayeddelivery_test_OBJECTS) $(delayeddelivery_test_DEPENDENCIES) 
+delayeddelivery_test$(EXEEXT): $(delayeddelivery_test_OBJECTS) $(delayeddelivery_test_DEPENDENCIES) $(EXTRA_delayeddelivery_test_DEPENDENCIES) 
 	@rm -f delayeddelivery_test$(EXEEXT)
 	$(CXXLINK) $(delayeddelivery_test_OBJECTS) $(delayeddelivery_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/delayeddelivery/delayeddelivery_test.cpp'
--- src/tests/delayeddelivery/delayeddelivery_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/delayeddelivery/delayeddelivery_test.cpp	2014-01-16 10:42:06 +0000
@@ -25,7 +25,7 @@
   if( d->tag() != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -36,7 +36,7 @@
   if( d->reason() != "reason" || d->stamp() != "invalidstamp" || d->from() != j )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -51,7 +51,7 @@
        || t->cdata() != "reason" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -64,7 +64,7 @@
   if( d->reason() != "reason" || d->stamp() != "invalidstamp" || d->from() != j )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -80,7 +80,7 @@
        || t->cdata() != "reason" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -101,7 +101,7 @@
   }
   else
   {
-    printf( "DelayedDelivery: %d test(s) failed\n", fail );
+    fprintf( stderr, "DelayedDelivery: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/disco/Makefile.in'
--- src/tests/disco/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/disco/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -69,6 +86,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(disco_test_SOURCES)
 DIST_SOURCES = $(disco_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -91,6 +113,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -100,6 +123,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -115,7 +139,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -145,6 +171,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -179,7 +206,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -249,7 +275,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-disco_test$(EXEEXT): $(disco_test_OBJECTS) $(disco_test_DEPENDENCIES) 
+disco_test$(EXEEXT): $(disco_test_OBJECTS) $(disco_test_DEPENDENCIES) $(EXTRA_disco_test_DEPENDENCIES) 
 	@rm -f disco_test$(EXEEXT)
 	$(CXXLINK) $(disco_test_OBJECTS) $(disco_test_LDADD) $(LIBS)
 
@@ -384,10 +410,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/disco/disco_test.cpp'
--- src/tests/disco/disco_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/disco/disco_test.cpp	2014-01-16 10:42:06 +0000
@@ -238,7 +238,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -254,7 +254,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -268,7 +268,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -282,7 +282,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -296,7 +296,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -311,7 +311,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -325,7 +325,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -337,7 +337,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -349,7 +349,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -361,7 +361,7 @@
     if( !dt->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -376,7 +376,7 @@
     if( dt->checkResult() ) // should fail, as there's no handler for foonode anymore
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -395,7 +395,7 @@
   }
   else
   {
-    printf( "Disco: %d test(s) failed\n", fail );
+    fprintf( stderr, "Disco: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/discoinfo/Makefile.am'
--- src/tests/discoinfo/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/discoinfo/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,5 +18,6 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../eventdispatcher.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 discoinfo_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/discoinfo/Makefile.in'
--- src/tests/discoinfo/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/discoinfo/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -64,7 +81,8 @@
 	../../clientbase.o ../../jid.o ../../dataform.o \
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o \
-	../../eventdispatcher.o ../../softwareversion.o
+	../../eventdispatcher.o ../../softwareversion.o \
+	../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -80,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(discoinfo_test_SOURCES)
 DIST_SOURCES = $(discoinfo_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -102,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -111,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -126,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -156,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -190,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -219,7 +246,8 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../eventdispatcher.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 discoinfo_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -265,7 +293,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-discoinfo_test$(EXEEXT): $(discoinfo_test_OBJECTS) $(discoinfo_test_DEPENDENCIES) 
+discoinfo_test$(EXEEXT): $(discoinfo_test_OBJECTS) $(discoinfo_test_DEPENDENCIES) $(EXTRA_discoinfo_test_DEPENDENCIES) 
 	@rm -f discoinfo_test$(EXEEXT)
 	$(CXXLINK) $(discoinfo_test_OBJECTS) $(discoinfo_test_LDADD) $(LIBS)
 
@@ -400,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/discoinfo/discoinfo_test.cpp'
--- src/tests/discoinfo/discoinfo_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/discoinfo/discoinfo_test.cpp	2014-01-16 10:42:06 +0000
@@ -25,7 +25,7 @@
         || !di.node().empty() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -43,7 +43,7 @@
         || !di.node().empty() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -61,7 +61,7 @@
         || di.node() != "somenode" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -76,7 +76,7 @@
         || di.node() != "somenode" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -90,7 +90,7 @@
     if( di.node() != "othernode" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -117,7 +117,7 @@
         || !di.hasFeature( "foo1" ) || !di.hasFeature( "foo2" ) || !di.hasFeature( "foo3" ) )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -135,7 +135,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -147,7 +147,7 @@
   }
   else
   {
-    printf( "Disco::Info: %d test(s) failed\n", fail );
+    fprintf( stderr, "Disco::Info: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/discoitems/Makefile.am'
--- src/tests/discoitems/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/discoitems/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,5 +18,6 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../eventdispatcher.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 discoitems_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/discoitems/Makefile.in'
--- src/tests/discoitems/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/discoitems/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -64,7 +81,8 @@
 	../../clientbase.o ../../jid.o ../../dataform.o \
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o \
-	../../eventdispatcher.o ../../softwareversion.o
+	../../eventdispatcher.o ../../softwareversion.o \
+	../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -80,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(discoitems_test_SOURCES)
 DIST_SOURCES = $(discoitems_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -102,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -111,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -126,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -156,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -190,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -219,7 +246,8 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../eventdispatcher.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 discoitems_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -265,7 +293,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-discoitems_test$(EXEEXT): $(discoitems_test_OBJECTS) $(discoitems_test_DEPENDENCIES) 
+discoitems_test$(EXEEXT): $(discoitems_test_OBJECTS) $(discoitems_test_DEPENDENCIES) $(EXTRA_discoitems_test_DEPENDENCIES) 
 	@rm -f discoitems_test$(EXEEXT)
 	$(CXXLINK) $(discoitems_test_OBJECTS) $(discoitems_test_LDADD) $(LIBS)
 
@@ -400,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/discoitems/discoitems_test.cpp'
--- src/tests/discoitems/discoitems_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/discoitems/discoitems_test.cpp	2014-01-16 10:42:06 +0000
@@ -25,7 +25,7 @@
         || !di.node().empty() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -40,7 +40,7 @@
         || di.node() != "somenode" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -67,7 +67,7 @@
         || item->name() != "name1" || item->node() != "node1" || item->jid() != "jid1" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -85,7 +85,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -97,7 +97,7 @@
   }
   else
   {
-    printf( "Disco::Items: %d test(s) failed\n", fail );
+    fprintf( stderr, "Disco::Items: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/error/Makefile.in'
--- src/tests/error/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/error/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -66,6 +83,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(error_test_SOURCES)
 DIST_SOURCES = $(error_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -88,6 +110,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -97,6 +120,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -112,7 +136,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -142,6 +168,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -176,7 +203,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -239,7 +265,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-error_test$(EXEEXT): $(error_test_OBJECTS) $(error_test_DEPENDENCIES) 
+error_test$(EXEEXT): $(error_test_OBJECTS) $(error_test_DEPENDENCIES) $(EXTRA_error_test_DEPENDENCIES) 
 	@rm -f error_test$(EXEEXT)
 	$(CXXLINK) $(error_test_OBJECTS) $(error_test_LDADD) $(LIBS)
 
@@ -374,10 +400,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/error/error_test.cpp'
--- src/tests/error/error_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/error/error_test.cpp	2014-01-16 10:42:06 +0000
@@ -27,7 +27,7 @@
     || e->appError()->xml() != "<unsupported xmlns='errorNS' feature='f'/>"
     || e->text() != "shit happens" )
   {
-    printf( "failed: '%s' test\n", name.c_str() );
+    fprintf( stderr, "failed: '%s' test\n", name.c_str() );
     printf( "type == %d, should be %d\n", e->type(), StanzaErrorTypeAuth );
     printf( "err == %d, should be %d\n", e->error(), StanzaErrorFeatureNotImplemented );
     printf( "xml: %s\n", e->appError()->xml().c_str() );
@@ -47,7 +47,7 @@
   }
   else
   {
-    printf( "Error: %d test(s) failed\n", fail );
+    fprintf( stderr, "Error: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/featureneg/Makefile.am'
--- src/tests/featureneg/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/featureneg/Makefile.am	2014-01-16 10:42:06 +0000
@@ -10,5 +10,5 @@
 featureneg_test_LDADD = ../../tag.o ../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
                         ../../dataformitem.o ../../dataformfield.o ../../gloox.o ../../util.o \
                         ../../featureneg.o ../../stanzaextensionfactory.o ../../iq.o ../../message.o \
-                        ../../stanza.o ../../jid.o ../../prep.o
+                        ../../stanza.o ../../jid.o ../../prep.o ../../mutex.o
 featureneg_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/featureneg/Makefile.in'
--- src/tests/featureneg/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/featureneg/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,7 @@
 	../../dataformitem.o ../../dataformfield.o ../../gloox.o \
 	../../util.o ../../featureneg.o ../../stanzaextensionfactory.o \
 	../../iq.o ../../message.o ../../stanza.o ../../jid.o \
-	../../prep.o
+	../../prep.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(featureneg_test_SOURCES)
 DIST_SOURCES = $(featureneg_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -201,7 +227,7 @@
 featureneg_test_LDADD = ../../tag.o ../../dataform.o ../../dataformfieldcontainer.o ../../dataformreported.o \
                         ../../dataformitem.o ../../dataformfield.o ../../gloox.o ../../util.o \
                         ../../featureneg.o ../../stanzaextensionfactory.o ../../iq.o ../../message.o \
-                        ../../stanza.o ../../jid.o ../../prep.o
+                        ../../stanza.o ../../jid.o ../../prep.o ../../mutex.o
 
 featureneg_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -247,7 +273,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-featureneg_test$(EXEEXT): $(featureneg_test_OBJECTS) $(featureneg_test_DEPENDENCIES) 
+featureneg_test$(EXEEXT): $(featureneg_test_OBJECTS) $(featureneg_test_DEPENDENCIES) $(EXTRA_featureneg_test_DEPENDENCIES) 
 	@rm -f featureneg_test$(EXEEXT)
 	$(CXXLINK) $(featureneg_test_OBJECTS) $(featureneg_test_LDADD) $(LIBS)
 
@@ -382,10 +408,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/featureneg/featureneg_test.cpp'
--- src/tests/featureneg/featureneg_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/featureneg/featureneg_test.cpp	2014-01-16 10:42:06 +0000
@@ -25,7 +25,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -41,7 +41,7 @@
                           "</feature>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     // t re-used in next test
   }
@@ -54,7 +54,7 @@
     if( !t2 || *t2 != *t )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t2;
     delete t;
@@ -73,7 +73,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -87,7 +87,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -98,7 +98,7 @@
   }
   else
   {
-    printf( "FeatureNeg: %d test(s) failed\n", fail );
+    fprintf( stderr, "FeatureNeg: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/flexoffline/Makefile.in'
--- src/tests/flexoffline/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/flexoffline/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(flexoffline_test_SOURCES)
 DIST_SOURCES = $(flexoffline_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -250,7 +276,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-flexoffline_test$(EXEEXT): $(flexoffline_test_OBJECTS) $(flexoffline_test_DEPENDENCIES) 
+flexoffline_test$(EXEEXT): $(flexoffline_test_OBJECTS) $(flexoffline_test_DEPENDENCIES) $(EXTRA_flexoffline_test_DEPENDENCIES) 
 	@rm -f flexoffline_test$(EXEEXT)
 	$(CXXLINK) $(flexoffline_test_OBJECTS) $(flexoffline_test_LDADD) $(LIBS)
 
@@ -385,10 +411,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/flexoffline/flexoffline_test.cpp'
--- src/tests/flexoffline/flexoffline_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/flexoffline/flexoffline_test.cpp	2014-01-16 10:42:06 +0000
@@ -47,11 +47,11 @@
       void removeIqHandler( IqHandler* ih, const int ext );
       void removeIDHandler( IqHandler* ) {}
       void registerStanzaExtension( StanzaExtension* se );
-      void removeStanzaExtension( int ext ) {}
-      virtual void handleFlexibleOfflineSupport( bool support ) {}
-      virtual void handleFlexibleOfflineMsgNum( int num ) {}
-      virtual void handleFlexibleOfflineMessageHeaders( const Disco::ItemList& headers ) {}
-      virtual void handleFlexibleOfflineResult( FlexibleOfflineResult foResult ) {}
+      void removeStanzaExtension( int /*ext*/ ) {}
+      virtual void handleFlexibleOfflineSupport( bool /*support*/ ) {}
+      virtual void handleFlexibleOfflineMsgNum( int /*num*/ ) {}
+      virtual void handleFlexibleOfflineMessageHeaders( const Disco::ItemList& /*headers*/ ) {}
+      virtual void handleFlexibleOfflineResult( FlexibleOfflineResult /*foResult*/ ) {}
       const JID& jid() const { return g_jid; }
       void setTest( int test );
       bool ok();
@@ -106,7 +106,7 @@
   if( false )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -128,7 +128,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/flexofflineoffline/Makefile.am'
--- src/tests/flexofflineoffline/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/flexofflineoffline/Makefile.am	2014-01-16 10:42:06 +0000
@@ -12,5 +12,5 @@
                         ../../iq.o ../../base64.o ../../dataformfieldcontainer.o \
                         ../../dataform.o ../../dataformfield.o \
                         ../../dataformitem.o ../../softwareversion.o \
-                        ../../dataformreported.o
+                        ../../dataformreported.o ../../mutex.o
 flexofflineoffline_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/flexofflineoffline/Makefile.in'
--- src/tests/flexofflineoffline/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/flexofflineoffline/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -56,7 +73,7 @@
 	../../message.o ../../util.o ../../error.o ../../jid.o \
 	../../iq.o ../../base64.o ../../dataformfieldcontainer.o \
 	../../dataform.o ../../dataformfield.o ../../dataformitem.o \
-	../../softwareversion.o ../../dataformreported.o
+	../../softwareversion.o ../../dataformreported.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -72,6 +89,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(flexofflineoffline_test_SOURCES)
 DIST_SOURCES = $(flexofflineoffline_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -94,6 +116,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -103,6 +126,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -118,7 +142,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -148,6 +174,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -182,7 +209,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -205,7 +231,7 @@
                         ../../iq.o ../../base64.o ../../dataformfieldcontainer.o \
                         ../../dataform.o ../../dataformfield.o \
                         ../../dataformitem.o ../../softwareversion.o \
-                        ../../dataformreported.o
+                        ../../dataformreported.o ../../mutex.o
 
 flexofflineoffline_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -251,7 +277,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-flexofflineoffline_test$(EXEEXT): $(flexofflineoffline_test_OBJECTS) $(flexofflineoffline_test_DEPENDENCIES) 
+flexofflineoffline_test$(EXEEXT): $(flexofflineoffline_test_OBJECTS) $(flexofflineoffline_test_DEPENDENCIES) $(EXTRA_flexofflineoffline_test_DEPENDENCIES) 
 	@rm -f flexofflineoffline_test$(EXEEXT)
 	$(CXXLINK) $(flexofflineoffline_test_OBJECTS) $(flexofflineoffline_test_LDADD) $(LIBS)
 
@@ -386,10 +412,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/flexofflineoffline/flexofflineoffline_test.cpp'
--- src/tests/flexofflineoffline/flexofflineoffline_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/flexofflineoffline/flexofflineoffline_test.cpp	2014-01-16 10:42:06 +0000
@@ -65,7 +65,7 @@
     if( false )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -83,7 +83,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -97,7 +97,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== added directory 'src/tests/forward'
=== added file 'src/tests/forward/Makefile.am'
--- src/tests/forward/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/tests/forward/Makefile.am	2014-01-16 10:42:06 +0000
@@ -0,0 +1,30 @@
+##
+## Process this file with automake to produce Makefile.in
+##
+
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual 
+
+noinst_PROGRAMS = forward_test
+
+forward_test_SOURCES = forward_test.cpp
+forward_test_LDADD = ../../jid.o ../../tag.o \
+                        ../../logsink.o ../../prep.o ../../util.o \
+                        ../../gloox.o ../../iq.o ../../stanza.o \
+                        ../../error.o ../../message.o \
+                        ../../forward.o ../../delayeddelivery.o \
+                        ../../clientbase.o ../../client.o \
+                        ../../connectiontcpbase.o ../../connectiontcpclient.o \
+                        ../../disco.o ../../parser.o ../../base64.o \
+                        ../../md5.o ../../tlsgnutlsclient.o ../../tlsopensslclient.o ../../tlsopensslbase.o ../../tlsopensslserver.o ../../tlsschannel.o \
+                        ../../messagesession.o ../../compressionzlib.o \
+                        ../../dns.o ../../stanzaextensionfactory.o \
+                        ../../rostermanager.o ../../nonsaslauth.o ../../sha.o ../../dataform.o \
+                        ../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
+                        ../../dataformfield.o \
+                        ../../rosteritem.o ../../privatexml.o ../../tlsgnutlsbase.o \
+                        ../../tlsdefault.o ../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
+                        ../../mutex.o ../../presence.o ../../subscription.o \
+                        ../../capabilities.o ../../eventdispatcher.o \
+                        ../../softwareversion.o \
+                        ../../atomicrefcount.o ../../attention.o
+forward_test_CFLAGS = $(CPPFLAGS)

=== added file 'src/tests/forward/Makefile.in'
--- src/tests/forward/Makefile.in	1970-01-01 00:00:00 +0000
+++ src/tests/forward/Makefile.in	2014-01-16 10:42:06 +0000
@@ -0,0 +1,550 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+noinst_PROGRAMS = forward_test$(EXEEXT)
+subdir = src/tests/forward
+DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+mkinstalldirs = $(install_sh) -d
+CONFIG_HEADER = $(top_builddir)/config.h.unix
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+PROGRAMS = $(noinst_PROGRAMS)
+am_forward_test_OBJECTS = forward_test.$(OBJEXT)
+forward_test_OBJECTS = $(am_forward_test_OBJECTS)
+forward_test_DEPENDENCIES = ../../jid.o ../../tag.o ../../logsink.o \
+	../../prep.o ../../util.o ../../gloox.o ../../iq.o \
+	../../stanza.o ../../error.o ../../message.o ../../forward.o \
+	../../delayeddelivery.o ../../clientbase.o ../../client.o \
+	../../connectiontcpbase.o ../../connectiontcpclient.o \
+	../../disco.o ../../parser.o ../../base64.o ../../md5.o \
+	../../tlsgnutlsclient.o ../../tlsopensslclient.o \
+	../../tlsopensslbase.o ../../tlsopensslserver.o \
+	../../tlsschannel.o ../../messagesession.o \
+	../../compressionzlib.o ../../dns.o \
+	../../stanzaextensionfactory.o ../../rostermanager.o \
+	../../nonsaslauth.o ../../sha.o ../../dataform.o \
+	../../dataformfieldcontainer.o ../../dataformreported.o \
+	../../dataformitem.o ../../dataformfield.o ../../rosteritem.o \
+	../../privatexml.o ../../tlsgnutlsbase.o ../../tlsdefault.o \
+	../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
+	../../mutex.o ../../presence.o ../../subscription.o \
+	../../capabilities.o ../../eventdispatcher.o \
+	../../softwareversion.o ../../atomicrefcount.o \
+	../../attention.o
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp = $(SHELL) $(top_srcdir)/depcomp
+am__depfiles_maybe = depfiles
+am__mv = mv -f
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+LTCXXCOMPILE = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
+SOURCES = $(forward_test_SOURCES)
+DIST_SOURCES = $(forward_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
+ACLOCAL = @ACLOCAL@
+AMTAR = @AMTAR@
+AR = @AR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+CC = @CC@
+CCDEPMODE = @CCDEPMODE@
+CFLAGS = @CFLAGS@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXDEPMODE = @CXXDEPMODE@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+DEFS = @DEFS@
+DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+EXEEXT = @EXEEXT@
+FGREP = @FGREP@
+GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+ISODATE = @ISODATE@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBOBJS = @LTLIBOBJS@
+MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
+MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
+MAYBE_TESTS = @MAYBE_TESTS@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PTHREAD_CC = @PTHREAD_CC@
+PTHREAD_CFLAGS = @PTHREAD_CFLAGS@
+PTHREAD_LIBS = @PTHREAD_LIBS@
+RANLIB = @RANLIB@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+VERSION = @VERSION@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+acx_pthread_config = @acx_pthread_config@
+am__include = @am__include@
+am__leading_dot = @am__leading_dot@
+am__quote = @am__quote@
+am__tar = @am__tar@
+am__untar = @am__untar@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+exec_prefix = @exec_prefix@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+localedir = @localedir@
+localstatedir = @localstatedir@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual 
+forward_test_SOURCES = forward_test.cpp
+forward_test_LDADD = ../../jid.o ../../tag.o \
+                        ../../logsink.o ../../prep.o ../../util.o \
+                        ../../gloox.o ../../iq.o ../../stanza.o \
+                        ../../error.o ../../message.o \
+                        ../../forward.o ../../delayeddelivery.o \
+                        ../../clientbase.o ../../client.o \
+                        ../../connectiontcpbase.o ../../connectiontcpclient.o \
+                        ../../disco.o ../../parser.o ../../base64.o \
+                        ../../md5.o ../../tlsgnutlsclient.o ../../tlsopensslclient.o ../../tlsopensslbase.o ../../tlsopensslserver.o ../../tlsschannel.o \
+                        ../../messagesession.o ../../compressionzlib.o \
+                        ../../dns.o ../../stanzaextensionfactory.o \
+                        ../../rostermanager.o ../../nonsaslauth.o ../../sha.o ../../dataform.o \
+                        ../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
+                        ../../dataformfield.o \
+                        ../../rosteritem.o ../../privatexml.o ../../tlsgnutlsbase.o \
+                        ../../tlsdefault.o ../../tlsgnutlsclientanon.o ../../tlsgnutlsserveranon.o \
+                        ../../mutex.o ../../presence.o ../../subscription.o \
+                        ../../capabilities.o ../../eventdispatcher.o \
+                        ../../softwareversion.o \
+                        ../../atomicrefcount.o ../../attention.o
+
+forward_test_CFLAGS = $(CPPFLAGS)
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cpp .lo .o .obj
+$(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --gnu src/tests/forward/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --gnu src/tests/forward/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure:  $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4):  $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+
+clean-noinstPROGRAMS:
+	@list='$(noinst_PROGRAMS)'; test -n "$$list" || exit 0; \
+	echo " rm -f" $$list; \
+	rm -f $$list || exit $$?; \
+	test -n "$(EXEEXT)" || exit 0; \
+	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
+	echo " rm -f" $$list; \
+	rm -f $$list
+forward_test$(EXEEXT): $(forward_test_OBJECTS) $(forward_test_DEPENDENCIES) $(EXTRA_forward_test_DEPENDENCIES) 
+	@rm -f forward_test$(EXEEXT)
+	$(CXXLINK) $(forward_test_OBJECTS) $(forward_test_LDADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/forward_test.Po@am__quote@
+
+.cpp.o:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ $<
+
+.cpp.obj:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cpp.lo:
+@am__fastdepCXX_TRUE@	$(LTCXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+
+distdir: $(DISTFILES)
+	@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	list='$(DISTFILES)'; \
+	  dist_files=`for file in $$list; do echo $$file; done | \
+	  sed -e "s|^$$srcdirstrip/||;t" \
+	      -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+	case $$dist_files in \
+	  */*) $(MKDIR_P) `echo "$$dist_files" | \
+			   sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+			   sort -u` ;; \
+	esac; \
+	for file in $$dist_files; do \
+	  if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
+	  if test -d $$d/$$file; then \
+	    dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+	    if test -d "$(distdir)/$$file"; then \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
+	      cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
+	  else \
+	    test -f "$(distdir)/$$file" \
+	    || cp -p $$d/$$file "$(distdir)/$$file" \
+	    || exit 1; \
+	  fi; \
+	done
+check-am: all-am
+check: check-am
+all-am: Makefile $(PROGRAMS)
+installdirs:
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-noinstPROGRAMS \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am:
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am:
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-noinstPROGRAMS ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags distdir dvi dvi-am html html-am info info-am \
+	install install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip installcheck installcheck-am installdirs \
+	maintainer-clean maintainer-clean-generic mostlyclean \
+	mostlyclean-compile mostlyclean-generic mostlyclean-libtool \
+	pdf pdf-am ps ps-am tags uninstall uninstall-am
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:

=== added file 'src/tests/forward/forward_test.cpp'
--- src/tests/forward/forward_test.cpp	1970-01-01 00:00:00 +0000
+++ src/tests/forward/forward_test.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,89 @@
+#include "../../gloox.h"
+#include "../../jid.h"
+#include "../../delayeddelivery.h"
+#include "../../forward.h"
+#include "../../message.h"
+#include "../../messagehandler.h"
+#include "../../client.h"
+#include "../../attention.h"
+
+#include <locale.h>
+#include <string>
+#include <cstdio> // [s]print[f]
+
+using namespace gloox;
+
+
+  class ForwardTest : public MessageHandler
+  {
+    public:
+      ForwardTest() : cb( "foo" )
+      {
+        cb.registerMessageHandler( this );
+        cb.registerStanzaExtension( new Forward() );
+        cb.registerStanzaExtension( new Attention() );
+      }
+      ~ForwardTest() {}
+      void testTag( Tag* tag ) { cb.handleTag( tag ); }
+      virtual void handleMessage( const Message& msg, MessageSession* )
+      {
+        Tag* m = msg.tag();
+        m_xml = m->xml();
+//         printf( "msg: %s\n", m->xml().c_str() );
+        delete m;
+      }
+      const std::string& getXml() { return m_xml; }
+    private:
+      Client cb;
+      std::string m_xml;
+  };
+
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  int fail = 0;
+  std::string name;
+
+  Message m( Message::Chat, JID( "a@b/c" ), "body test", "subject" );
+  Message* fm = new Message( Message::Headline, JID( "d@e/f" ), "headline test", "headline subject" );
+  fm->addExtension( new Attention() );
+  DelayedDelivery* d = new DelayedDelivery( JID( "from@me/res" ), "thestamp" );
+  Forward* f = new Forward( fm, d );
+  m.addExtension( f );
+  
+  Tag* tag = m.tag();
+  ForwardTest t;
+  t.testTag( tag );
+  
+  
+  
+
+  // -------
+  name = "create Forward 1";
+  if( tag->xml() != t.getXml() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed:\n%s\n---\n%s\n", name.c_str(), tag->xml().c_str(), t.getXml().c_str() );
+  }
+
+
+
+
+
+
+
+
+
+  printf( "Forward: " );
+  if( fail == 0 )
+  {
+    printf( "OK\n" );
+    return 0;
+  }
+  else
+  {
+    fprintf( stderr, "%d test(s) failed\n", fail );
+    return 1;
+  }
+
+}

=== modified file 'src/tests/gpgencrypted/Makefile.in'
--- src/tests/gpgencrypted/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/gpgencrypted/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -66,6 +83,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(gpgencrypted_test_SOURCES)
 DIST_SOURCES = $(gpgencrypted_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -88,6 +110,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -97,6 +120,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -112,7 +136,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -142,6 +168,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -176,7 +203,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -239,7 +265,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-gpgencrypted_test$(EXEEXT): $(gpgencrypted_test_OBJECTS) $(gpgencrypted_test_DEPENDENCIES) 
+gpgencrypted_test$(EXEEXT): $(gpgencrypted_test_OBJECTS) $(gpgencrypted_test_DEPENDENCIES) $(EXTRA_gpgencrypted_test_DEPENDENCIES) 
 	@rm -f gpgencrypted_test$(EXEEXT)
 	$(CXXLINK) $(gpgencrypted_test_OBJECTS) $(gpgencrypted_test_LDADD) $(LIBS)
 
@@ -374,10 +400,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/gpgencrypted/gpgencrypted_test.cpp'
--- src/tests/gpgencrypted/gpgencrypted_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/gpgencrypted/gpgencrypted_test.cpp	2014-01-16 10:42:06 +0000
@@ -22,7 +22,7 @@
   if( d->tag() != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -33,7 +33,7 @@
   if( d->encrypted() != "invalidencrypted" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -46,7 +46,7 @@
        || t->cdata() != "invalidencrypted" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -59,7 +59,7 @@
   if( d->encrypted() != "invalidencrypted" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -73,7 +73,7 @@
        || t->cdata() != "invalidencrypted" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -94,7 +94,7 @@
   }
   else
   {
-    printf( "GPGEncrypted: %d test(s) failed\n", fail );
+    fprintf( stderr, "GPGEncrypted: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/gpgsigned/Makefile.in'
--- src/tests/gpgsigned/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/gpgsigned/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -66,6 +83,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(gpgsigned_test_SOURCES)
 DIST_SOURCES = $(gpgsigned_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -88,6 +110,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -97,6 +120,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -112,7 +136,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -142,6 +168,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -176,7 +203,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -239,7 +265,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-gpgsigned_test$(EXEEXT): $(gpgsigned_test_OBJECTS) $(gpgsigned_test_DEPENDENCIES) 
+gpgsigned_test$(EXEEXT): $(gpgsigned_test_OBJECTS) $(gpgsigned_test_DEPENDENCIES) $(EXTRA_gpgsigned_test_DEPENDENCIES) 
 	@rm -f gpgsigned_test$(EXEEXT)
 	$(CXXLINK) $(gpgsigned_test_OBJECTS) $(gpgsigned_test_LDADD) $(LIBS)
 
@@ -374,10 +400,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/gpgsigned/gpgsigned_test.cpp'
--- src/tests/gpgsigned/gpgsigned_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/gpgsigned/gpgsigned_test.cpp	2014-01-16 10:42:06 +0000
@@ -22,7 +22,7 @@
   if( d->tag() != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -33,7 +33,7 @@
   if( d->signature() != "invalidsignature" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -47,7 +47,7 @@
        || t->cdata() != "invalidsignature" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -60,7 +60,7 @@
   if( d->signature() != "invalidsignature" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -74,7 +74,7 @@
        || t->cdata() != "invalidsignature" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -95,7 +95,7 @@
   }
   else
   {
-    printf( "GPGSigned: %d test(s) failed\n", fail );
+    fprintf( stderr, "GPGSigned: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/inbandbytestream/Makefile.am'
--- src/tests/inbandbytestream/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/inbandbytestream/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,5 +9,5 @@
 inbandbytestream_test_SOURCES = inbandbytestream_test.cpp
 inbandbytestream_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../iq.o ../../base64.o ../../logsink.o
+			../../iq.o ../../base64.o ../../logsink.o ../../mutex.o
 inbandbytestream_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/inbandbytestream/Makefile.in'
--- src/tests/inbandbytestream/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/inbandbytestream/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -52,7 +69,7 @@
 inbandbytestream_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
 	../../prep.o ../../stanzaextensionfactory.o ../../gloox.o \
 	../../message.o ../../util.o ../../error.o ../../jid.o \
-	../../iq.o ../../base64.o ../../logsink.o
+	../../iq.o ../../base64.o ../../logsink.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(inbandbytestream_test_SOURCES)
 DIST_SOURCES = $(inbandbytestream_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -198,7 +224,7 @@
 inbandbytestream_test_SOURCES = inbandbytestream_test.cpp
 inbandbytestream_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../iq.o ../../base64.o ../../logsink.o
+			../../iq.o ../../base64.o ../../logsink.o ../../mutex.o
 
 inbandbytestream_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-inbandbytestream_test$(EXEEXT): $(inbandbytestream_test_OBJECTS) $(inbandbytestream_test_DEPENDENCIES) 
+inbandbytestream_test$(EXEEXT): $(inbandbytestream_test_OBJECTS) $(inbandbytestream_test_DEPENDENCIES) $(EXTRA_inbandbytestream_test_DEPENDENCIES) 
 	@rm -f inbandbytestream_test$(EXEEXT)
 	$(CXXLINK) $(inbandbytestream_test_OBJECTS) $(inbandbytestream_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/inbandbytestream/inbandbytestream_test.cpp'
--- src/tests/inbandbytestream/inbandbytestream_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/inbandbytestream/inbandbytestream_test.cpp	2014-01-16 10:42:06 +0000
@@ -129,7 +129,7 @@
     if( it->checkResult() != 2 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -141,7 +141,7 @@
     if( !it->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -153,7 +153,7 @@
     if( !it->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -167,7 +167,7 @@
     if( it->checkResult() != 2 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -181,7 +181,7 @@
     if( it->checkResult() != 2 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -195,7 +195,7 @@
     if( !it->checkResult() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -209,7 +209,7 @@
   }
   else
   {
-    printf( "InBandBytestream: %d test(s) failed\n", fail );
+    fprintf( stderr, "InBandBytestream: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/inbandbytestreamibb/Makefile.am'
--- src/tests/inbandbytestreamibb/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/inbandbytestreamibb/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,5 +9,5 @@
 inbandbytestreamibb_test_SOURCES = inbandbytestreamibb_test.cpp
 inbandbytestreamibb_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../iq.o ../../base64.o
+			../../iq.o ../../base64.o ../../mutex.o
 inbandbytestreamibb_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/inbandbytestreamibb/Makefile.in'
--- src/tests/inbandbytestreamibb/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/inbandbytestreamibb/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,7 @@
 inbandbytestreamibb_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
 	../../prep.o ../../stanzaextensionfactory.o ../../gloox.o \
 	../../message.o ../../util.o ../../error.o ../../jid.o \
-	../../iq.o ../../base64.o
+	../../iq.o ../../base64.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(inbandbytestreamibb_test_SOURCES)
 DIST_SOURCES = $(inbandbytestreamibb_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -200,7 +226,7 @@
 inbandbytestreamibb_test_SOURCES = inbandbytestreamibb_test.cpp
 inbandbytestreamibb_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../iq.o ../../base64.o
+			../../iq.o ../../base64.o ../../mutex.o
 
 inbandbytestreamibb_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -246,7 +272,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-inbandbytestreamibb_test$(EXEEXT): $(inbandbytestreamibb_test_OBJECTS) $(inbandbytestreamibb_test_DEPENDENCIES) 
+inbandbytestreamibb_test$(EXEEXT): $(inbandbytestreamibb_test_OBJECTS) $(inbandbytestreamibb_test_DEPENDENCIES) $(EXTRA_inbandbytestreamibb_test_DEPENDENCIES) 
 	@rm -f inbandbytestreamibb_test$(EXEEXT)
 	$(CXXLINK) $(inbandbytestreamibb_test_OBJECTS) $(inbandbytestreamibb_test_LDADD) $(LIBS)
 
@@ -381,10 +407,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/inbandbytestreamibb/inbandbytestreamibb_test.cpp'
--- src/tests/inbandbytestreamibb/inbandbytestreamibb_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/inbandbytestreamibb/inbandbytestreamibb_test.cpp	2014-01-16 10:42:06 +0000
@@ -64,7 +64,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -80,7 +80,7 @@
          || ibb.type() != InBandBytestream::IBBOpen)
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -98,7 +98,7 @@
          || ibb.type() != InBandBytestream::IBBData )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -114,7 +114,7 @@
          || ibb.type() != InBandBytestream::IBBClose )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -133,7 +133,7 @@
         || !ibb.data().empty() || ibb.type() != InBandBytestream::IBBOpen )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -154,7 +154,7 @@
         || ibb.blocksize() != 0 || ibb.type() != InBandBytestream::IBBData )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -174,7 +174,7 @@
          || ibb.type() != InBandBytestream::IBBClose )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -194,7 +194,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -210,7 +210,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -226,7 +226,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -238,7 +238,7 @@
   }
   else
   {
-    printf( "InBandBytestream::IBB: %d test(s) failed\n", fail );
+    fprintf( stderr, "InBandBytestream::IBB: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/iq/Makefile.in'
--- src/tests/iq/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/iq/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(iq_test_SOURCES)
 DIST_SOURCES = $(iq_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-iq_test$(EXEEXT): $(iq_test_OBJECTS) $(iq_test_DEPENDENCIES) 
+iq_test$(EXEEXT): $(iq_test_OBJECTS) $(iq_test_DEPENDENCIES) $(EXTRA_iq_test_DEPENDENCIES) 
 	@rm -f iq_test$(EXEEXT)
 	$(CXXLINK) $(iq_test_OBJECTS) $(iq_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/iq/iq_test.cpp'
--- src/tests/iq/iq_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/iq/iq_test.cpp	2014-01-16 10:42:06 +0000
@@ -28,7 +28,7 @@
         || i->to().full() != "you@example.net/gloox" || i->id() != "id1" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -41,7 +41,7 @@
         || i->to().full() != "you@example.net/gloox" || i->id() != "id1" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -54,7 +54,7 @@
         || i->to().full() != "you@example.net/gloox" || i->id() != "id1" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -67,7 +67,7 @@
         || i->to().full() != "you@example.net/gloox" || i->id() != "id1" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -81,7 +81,7 @@
         || !i->hasAttribute( "to", "xyz@example.org/blah" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -95,7 +95,7 @@
         || !i->hasAttribute( "to", "xyz@example.org/blah" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -109,7 +109,7 @@
         || !i->hasAttribute( "to", "xyz@example.org/blah" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -123,7 +123,7 @@
         || !i->hasAttribute( "to", "xyz@example.org/blah" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -138,7 +138,7 @@
 //         || !i->hasAttribute( "to", "xyz@example.org/blah" ) || !i->hasChild( "query", "xmlns", "mynamespace" ) )
 //     {
 //       ++fail;
-//       printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+//       fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
 //     }
 //     delete i;
 //   }
@@ -153,7 +153,7 @@
 //         || !i->hasChild( "testtag", "xmlns", "mynamespace" ) )
 //     {
 //       ++fail;
-//       printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+//       fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
 //     }
 //     delete i;
 //   }
@@ -169,7 +169,7 @@
 //         || !i->hasAttribute( "from", "blah@example.net/foo" ) )
 //     {
 //       ++fail;
-//       printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+//       fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
 //     }
 //     delete i;
 //   }
@@ -184,7 +184,7 @@
 //        || iq->children().size() != 0 )
 //   {
 //     ++fail;
-//     printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+//     fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
 //   }
 //   delete i;
 //   i = 0;
@@ -205,7 +205,7 @@
   }
   else
   {
-    printf( "IQ: %d test(s) failed\n", fail );
+    fprintf( stderr, "IQ: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/jid/Makefile.in'
--- src/tests/jid/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/jid/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(jid_perf_SOURCES) $(jid_test_SOURCES)
 DIST_SOURCES = $(jid_perf_SOURCES) $(jid_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -246,10 +272,10 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-jid_perf$(EXEEXT): $(jid_perf_OBJECTS) $(jid_perf_DEPENDENCIES) 
+jid_perf$(EXEEXT): $(jid_perf_OBJECTS) $(jid_perf_DEPENDENCIES) $(EXTRA_jid_perf_DEPENDENCIES) 
 	@rm -f jid_perf$(EXEEXT)
 	$(CXXLINK) $(jid_perf_OBJECTS) $(jid_perf_LDADD) $(LIBS)
-jid_test$(EXEEXT): $(jid_test_OBJECTS) $(jid_test_DEPENDENCIES) 
+jid_test$(EXEEXT): $(jid_test_OBJECTS) $(jid_test_DEPENDENCIES) $(EXTRA_jid_test_DEPENDENCIES) 
 	@rm -f jid_test$(EXEEXT)
 	$(CXXLINK) $(jid_test_OBJECTS) $(jid_test_LDADD) $(LIBS)
 
@@ -385,10 +411,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/jid/jid_perf.cpp'
--- src/tests/jid/jid_perf.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/jid/jid_perf.cpp	2014-01-16 10:42:06 +0000
@@ -14,8 +14,6 @@
 static int num = 10000;
 static double t;
 
-static JID * jid;
-
 static void printTime ( const char * testName, struct timeval tv1, struct timeval tv2 )
 {
   t = tv2.tv_sec - tv1.tv_sec;

=== modified file 'src/tests/jid/jid_test.cpp'
--- src/tests/jid/jid_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/jid/jid_test.cpp	2014-01-16 10:42:06 +0000
@@ -18,7 +18,7 @@
   if( j.bare() != "abc@server.dom" || j.username() != "abc" || j.server() != "server.dom" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -28,7 +28,7 @@
       || j.resource() != "res" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -37,7 +37,7 @@
   if( j.full() != "server.dom/res" || j.server() != "server.dom" || j.resource() != "res" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -46,7 +46,7 @@
   if( j.full() != "server.dom" || j.server() != "server.dom" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -55,7 +55,7 @@
   if( j.bare() != "abc@server.dom" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -64,7 +64,7 @@
   if( j.bare() != "abc@server.dom" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -73,7 +73,7 @@
   if( j.resource() != "rEsOurCe" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -82,7 +82,7 @@
   if( j.username() != "abc" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -91,7 +91,7 @@
   if( j.server() != "server.dom" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -101,7 +101,7 @@
   if( j.bareJID() != t1.bareJID() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -116,7 +116,7 @@
         || !j.full().empty() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -125,7 +125,7 @@
   if( !jid1 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -134,7 +134,7 @@
   if( jid2 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -143,7 +143,7 @@
   if( e != "1\\202\\223\\264\\275\\2f6\\3a7\\3c8\\3e9\\4010\\5c" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -152,7 +152,7 @@
   if( f != "1 2\"3&4'5/6:7<8>9@10\\" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -171,7 +171,7 @@
   }
   else
   {
-    printf( "JID: %d test(s) failed\n", fail );
+    fprintf( stderr, "JID: %d test(s) failed\n", fail );
     return 1;
   }
 

=== added directory 'src/tests/jinglecontent'
=== added file 'src/tests/jinglecontent/Makefile.am'
--- src/tests/jinglecontent/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/tests/jinglecontent/Makefile.am	2014-01-16 10:42:06 +0000
@@ -0,0 +1,16 @@
+
+##
+## Process this file with automake to produce Makefile.in
+##
+
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+
+noinst_PROGRAMS = jinglecontent_test
+
+jinglecontent_test_SOURCES = jinglecontent_test.cpp
+jinglecontent_test_LDADD = ../../stanza.o ../../jid.o ../../tag.o ../../prep.o \
+                ../../gloox.o \
+                ../../iq.o ../../util.o ../../sha.o ../../base64.o \
+                ../../jinglecontent.o ../../error.o ../../mutex.o \
+                ../../jinglepluginfactory.o
+jinglecontent_test_CFLAGS = $(CPPFLAGS)

=== added file 'src/tests/jinglecontent/Makefile.in'
--- src/tests/jinglecontent/Makefile.in	1970-01-01 00:00:00 +0000
+++ src/tests/jinglecontent/Makefile.in	2014-01-16 10:42:06 +0000
@@ -0,0 +1,519 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+noinst_PROGRAMS = jinglecontent_test$(EXEEXT)
+subdir = src/tests/jinglecontent
+DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+mkinstalldirs = $(install_sh) -d
+CONFIG_HEADER = $(top_builddir)/config.h.unix
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+PROGRAMS = $(noinst_PROGRAMS)
+am_jinglecontent_test_OBJECTS = jinglecontent_test.$(OBJEXT)
+jinglecontent_test_OBJECTS = $(am_jinglecontent_test_OBJECTS)
+jinglecontent_test_DEPENDENCIES = ../../stanza.o ../../jid.o \
+	../../tag.o ../../prep.o ../../gloox.o ../../iq.o ../../util.o \
+	../../sha.o ../../base64.o ../../jinglecontent.o ../../error.o \
+	../../mutex.o ../../jinglepluginfactory.o
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp = $(SHELL) $(top_srcdir)/depcomp
+am__depfiles_maybe = depfiles
+am__mv = mv -f
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+LTCXXCOMPILE = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
+SOURCES = $(jinglecontent_test_SOURCES)
+DIST_SOURCES = $(jinglecontent_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
+ACLOCAL = @ACLOCAL@
+AMTAR = @AMTAR@
+AR = @AR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+CC = @CC@
+CCDEPMODE = @CCDEPMODE@
+CFLAGS = @CFLAGS@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXDEPMODE = @CXXDEPMODE@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+DEFS = @DEFS@
+DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+EXEEXT = @EXEEXT@
+FGREP = @FGREP@
+GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+ISODATE = @ISODATE@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBOBJS = @LTLIBOBJS@
+MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
+MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
+MAYBE_TESTS = @MAYBE_TESTS@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PTHREAD_CC = @PTHREAD_CC@
+PTHREAD_CFLAGS = @PTHREAD_CFLAGS@
+PTHREAD_LIBS = @PTHREAD_LIBS@
+RANLIB = @RANLIB@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+VERSION = @VERSION@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+acx_pthread_config = @acx_pthread_config@
+am__include = @am__include@
+am__leading_dot = @am__leading_dot@
+am__quote = @am__quote@
+am__tar = @am__tar@
+am__untar = @am__untar@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+exec_prefix = @exec_prefix@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+localedir = @localedir@
+localstatedir = @localstatedir@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+jinglecontent_test_SOURCES = jinglecontent_test.cpp
+jinglecontent_test_LDADD = ../../stanza.o ../../jid.o ../../tag.o ../../prep.o \
+                ../../gloox.o \
+                ../../iq.o ../../util.o ../../sha.o ../../base64.o \
+                ../../jinglecontent.o ../../error.o ../../mutex.o \
+                ../../jinglepluginfactory.o
+
+jinglecontent_test_CFLAGS = $(CPPFLAGS)
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cpp .lo .o .obj
+$(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --gnu src/tests/jinglecontent/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --gnu src/tests/jinglecontent/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure:  $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4):  $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+
+clean-noinstPROGRAMS:
+	@list='$(noinst_PROGRAMS)'; test -n "$$list" || exit 0; \
+	echo " rm -f" $$list; \
+	rm -f $$list || exit $$?; \
+	test -n "$(EXEEXT)" || exit 0; \
+	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
+	echo " rm -f" $$list; \
+	rm -f $$list
+jinglecontent_test$(EXEEXT): $(jinglecontent_test_OBJECTS) $(jinglecontent_test_DEPENDENCIES) $(EXTRA_jinglecontent_test_DEPENDENCIES) 
+	@rm -f jinglecontent_test$(EXEEXT)
+	$(CXXLINK) $(jinglecontent_test_OBJECTS) $(jinglecontent_test_LDADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglecontent_test.Po@am__quote@
+
+.cpp.o:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ $<
+
+.cpp.obj:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cpp.lo:
+@am__fastdepCXX_TRUE@	$(LTCXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+
+distdir: $(DISTFILES)
+	@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	list='$(DISTFILES)'; \
+	  dist_files=`for file in $$list; do echo $$file; done | \
+	  sed -e "s|^$$srcdirstrip/||;t" \
+	      -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+	case $$dist_files in \
+	  */*) $(MKDIR_P) `echo "$$dist_files" | \
+			   sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+			   sort -u` ;; \
+	esac; \
+	for file in $$dist_files; do \
+	  if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
+	  if test -d $$d/$$file; then \
+	    dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+	    if test -d "$(distdir)/$$file"; then \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
+	      cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
+	  else \
+	    test -f "$(distdir)/$$file" \
+	    || cp -p $$d/$$file "$(distdir)/$$file" \
+	    || exit 1; \
+	  fi; \
+	done
+check-am: all-am
+check: check-am
+all-am: Makefile $(PROGRAMS)
+installdirs:
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-noinstPROGRAMS \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am:
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am:
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-noinstPROGRAMS ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags distdir dvi dvi-am html html-am info info-am \
+	install install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip installcheck installcheck-am installdirs \
+	maintainer-clean maintainer-clean-generic mostlyclean \
+	mostlyclean-compile mostlyclean-generic mostlyclean-libtool \
+	pdf pdf-am ps ps-am tags uninstall uninstall-am
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:

=== added file 'src/tests/jinglecontent/jinglecontent_test.cpp'
--- src/tests/jinglecontent/jinglecontent_test.cpp	1970-01-01 00:00:00 +0000
+++ src/tests/jinglecontent/jinglecontent_test.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,66 @@
+#define JINGLECONTENT_TEST
+#include "../../gloox.h"
+#include "../../jid.h"
+#include "../../tag.h"
+#include "../../jinglecontent.h"
+using namespace gloox;
+
+#include <stdio.h>
+#include <locale.h>
+#include <string>
+#include <cstdio> // [s]print[f]
+
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  int fail = 0;
+  std::string name;
+  JID jid( "foo@bar/barfoo" );
+
+  // -------
+  {
+    name = "invalid Jingle 1";
+    Jingle::Content jc;
+    Tag* t = jc.tag();
+    if( t )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
+    }
+    delete t;
+  }
+
+
+
+
+
+  // -------
+//   name = "Jingle::Session::Jingle/SEFactory test";
+//   StanzaExtensionFactory sef;
+//   sef.registerExtension( new Jingle::Session::Jingle() );
+//   Tag* f = new Tag( "iq" );
+//   new Tag( f, "jingle", "xmlns", XMLNS_JINGLE );
+//   IQ iq( IQ::Get, JID() );
+//   sef.addExtensions( iq, f );
+//   const Jingle::Session::Jingle* se = iq.findExtension<Jingle::Session::Jingle>( ExtJingle );
+//   if( se == 0 )
+//   {
+//     ++fail;
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
+//   }
+//   delete f;
+
+
+
+  if( fail == 0 )
+  {
+    printf( "Jingle::Content: OK\n" );
+    return 0;
+  }
+  else
+  {
+    fprintf( stderr, "Jingle::Content: %d test(s) failed\n", fail );
+    return 1;
+  }
+
+}

=== added directory 'src/tests/jingleiceudp'
=== added file 'src/tests/jingleiceudp/Makefile.am'
--- src/tests/jingleiceudp/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/tests/jingleiceudp/Makefile.am	2014-01-16 10:42:06 +0000
@@ -0,0 +1,15 @@
+
+##
+## Process this file with automake to produce Makefile.in
+##
+
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+
+noinst_PROGRAMS = jingleiceudp_test
+
+jingleiceudp_test_SOURCES = jingleiceudp_test.cpp
+jingleiceudp_test_LDADD = ../../stanza.o ../../jid.o ../../tag.o ../../prep.o \
+                ../../gloox.o \
+                ../../iq.o ../../util.o ../../sha.o ../../base64.o \
+                ../../jingleiceudp.o ../../error.o ../../mutex.o
+jingleiceudp_test_CFLAGS = $(CPPFLAGS)

=== added file 'src/tests/jingleiceudp/Makefile.in'
--- src/tests/jingleiceudp/Makefile.in	1970-01-01 00:00:00 +0000
+++ src/tests/jingleiceudp/Makefile.in	2014-01-16 10:42:06 +0000
@@ -0,0 +1,518 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+noinst_PROGRAMS = jingleiceudp_test$(EXEEXT)
+subdir = src/tests/jingleiceudp
+DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+mkinstalldirs = $(install_sh) -d
+CONFIG_HEADER = $(top_builddir)/config.h.unix
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+PROGRAMS = $(noinst_PROGRAMS)
+am_jingleiceudp_test_OBJECTS = jingleiceudp_test.$(OBJEXT)
+jingleiceudp_test_OBJECTS = $(am_jingleiceudp_test_OBJECTS)
+jingleiceudp_test_DEPENDENCIES = ../../stanza.o ../../jid.o \
+	../../tag.o ../../prep.o ../../gloox.o ../../iq.o ../../util.o \
+	../../sha.o ../../base64.o ../../jingleiceudp.o ../../error.o \
+	../../mutex.o
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp = $(SHELL) $(top_srcdir)/depcomp
+am__depfiles_maybe = depfiles
+am__mv = mv -f
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+LTCXXCOMPILE = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
+SOURCES = $(jingleiceudp_test_SOURCES)
+DIST_SOURCES = $(jingleiceudp_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
+ACLOCAL = @ACLOCAL@
+AMTAR = @AMTAR@
+AR = @AR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+CC = @CC@
+CCDEPMODE = @CCDEPMODE@
+CFLAGS = @CFLAGS@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXDEPMODE = @CXXDEPMODE@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+DEFS = @DEFS@
+DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+EXEEXT = @EXEEXT@
+FGREP = @FGREP@
+GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+ISODATE = @ISODATE@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBOBJS = @LTLIBOBJS@
+MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
+MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
+MAYBE_TESTS = @MAYBE_TESTS@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PTHREAD_CC = @PTHREAD_CC@
+PTHREAD_CFLAGS = @PTHREAD_CFLAGS@
+PTHREAD_LIBS = @PTHREAD_LIBS@
+RANLIB = @RANLIB@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+VERSION = @VERSION@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+acx_pthread_config = @acx_pthread_config@
+am__include = @am__include@
+am__leading_dot = @am__leading_dot@
+am__quote = @am__quote@
+am__tar = @am__tar@
+am__untar = @am__untar@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+exec_prefix = @exec_prefix@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+localedir = @localedir@
+localstatedir = @localstatedir@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+jingleiceudp_test_SOURCES = jingleiceudp_test.cpp
+jingleiceudp_test_LDADD = ../../stanza.o ../../jid.o ../../tag.o ../../prep.o \
+                ../../gloox.o \
+                ../../iq.o ../../util.o ../../sha.o ../../base64.o \
+                ../../jingleiceudp.o ../../error.o ../../mutex.o
+
+jingleiceudp_test_CFLAGS = $(CPPFLAGS)
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cpp .lo .o .obj
+$(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --gnu src/tests/jingleiceudp/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --gnu src/tests/jingleiceudp/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure:  $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4):  $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+
+clean-noinstPROGRAMS:
+	@list='$(noinst_PROGRAMS)'; test -n "$$list" || exit 0; \
+	echo " rm -f" $$list; \
+	rm -f $$list || exit $$?; \
+	test -n "$(EXEEXT)" || exit 0; \
+	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
+	echo " rm -f" $$list; \
+	rm -f $$list
+jingleiceudp_test$(EXEEXT): $(jingleiceudp_test_OBJECTS) $(jingleiceudp_test_DEPENDENCIES) $(EXTRA_jingleiceudp_test_DEPENDENCIES) 
+	@rm -f jingleiceudp_test$(EXEEXT)
+	$(CXXLINK) $(jingleiceudp_test_OBJECTS) $(jingleiceudp_test_LDADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jingleiceudp_test.Po@am__quote@
+
+.cpp.o:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ $<
+
+.cpp.obj:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cpp.lo:
+@am__fastdepCXX_TRUE@	$(LTCXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+
+distdir: $(DISTFILES)
+	@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	list='$(DISTFILES)'; \
+	  dist_files=`for file in $$list; do echo $$file; done | \
+	  sed -e "s|^$$srcdirstrip/||;t" \
+	      -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+	case $$dist_files in \
+	  */*) $(MKDIR_P) `echo "$$dist_files" | \
+			   sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+			   sort -u` ;; \
+	esac; \
+	for file in $$dist_files; do \
+	  if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
+	  if test -d $$d/$$file; then \
+	    dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+	    if test -d "$(distdir)/$$file"; then \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
+	      cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
+	  else \
+	    test -f "$(distdir)/$$file" \
+	    || cp -p $$d/$$file "$(distdir)/$$file" \
+	    || exit 1; \
+	  fi; \
+	done
+check-am: all-am
+check: check-am
+all-am: Makefile $(PROGRAMS)
+installdirs:
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-noinstPROGRAMS \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am:
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am:
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-noinstPROGRAMS ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags distdir dvi dvi-am html html-am info info-am \
+	install install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip installcheck installcheck-am installdirs \
+	maintainer-clean maintainer-clean-generic mostlyclean \
+	mostlyclean-compile mostlyclean-generic mostlyclean-libtool \
+	pdf pdf-am ps ps-am tags uninstall uninstall-am
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:

=== added file 'src/tests/jingleiceudp/jingleiceudp_test.cpp'
--- src/tests/jingleiceudp/jingleiceudp_test.cpp	1970-01-01 00:00:00 +0000
+++ src/tests/jingleiceudp/jingleiceudp_test.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,66 @@
+#define JINGLEICEUDP_TEST
+#include "../../gloox.h"
+#include "../../jid.h"
+#include "../../tag.h"
+#include "../../jingleiceudp.h"
+using namespace gloox;
+
+#include <stdio.h>
+#include <locale.h>
+#include <string>
+#include <cstdio> // [s]print[f]
+
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  int fail = 0;
+  std::string name;
+  JID jid( "foo@bar/barfoo" );
+
+  // -------
+  {
+    name = "invalid Jingle 1";
+    Jingle::ICEUDP jc;
+    Tag* t = jc.tag();
+    if( !t || t->xml() != "<transport xmlns='" + XMLNS_JINGLE_ICE_UDP + "'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+
+
+
+
+  // -------
+//   name = "Jingle::Session::Jingle/SEFactory test";
+//   StanzaExtensionFactory sef;
+//   sef.registerExtension( new Jingle::Session::Jingle() );
+//   Tag* f = new Tag( "iq" );
+//   new Tag( f, "jingle", "xmlns", XMLNS_JINGLE );
+//   IQ iq( IQ::Get, JID() );
+//   sef.addExtensions( iq, f );
+//   const Jingle::Session::Jingle* se = iq.findExtension<Jingle::Session::Jingle>( ExtJingle );
+//   if( se == 0 )
+//   {
+//     ++fail;
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
+//   }
+//   delete f;
+
+
+
+  if( fail == 0 )
+  {
+    printf( "Jingle::ICEUDP: OK\n" );
+    return 0;
+  }
+  else
+  {
+    fprintf( stderr, "Jingle::ICEUDP: %d test(s) failed\n", fail );
+    return 1;
+  }
+
+}

=== added directory 'src/tests/jinglesession'
=== added file 'src/tests/jinglesession/Makefile.am'
--- src/tests/jinglesession/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesession/Makefile.am	2014-01-16 10:42:06 +0000
@@ -0,0 +1,15 @@
+##
+## Process this file with automake to produce Makefile.in
+##
+
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+
+noinst_PROGRAMS = jinglesession_test
+
+jinglesession_test_SOURCES = jinglesession_test.cpp
+jinglesession_test_LDADD = ../../tag.o ../../stanza.o ../../base64.o \
+			../../prep.o ../../gloox.o \
+			../../iq.o ../../util.o \
+			../../sha.o ../../error.o ../../jid.o \
+			../../jinglecontent.o ../../jinglepluginfactory.o
+jinglesession_test_CFLAGS = $(CPPFLAGS) -g3

=== added file 'src/tests/jinglesession/Makefile.in'
--- src/tests/jinglesession/Makefile.in	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesession/Makefile.in	2014-01-16 10:42:06 +0000
@@ -0,0 +1,519 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+noinst_PROGRAMS = jinglesession_test$(EXEEXT)
+subdir = src/tests/jinglesession
+DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+mkinstalldirs = $(install_sh) -d
+CONFIG_HEADER = $(top_builddir)/config.h.unix
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+PROGRAMS = $(noinst_PROGRAMS)
+am_jinglesession_test_OBJECTS = jinglesession_test.$(OBJEXT)
+jinglesession_test_OBJECTS = $(am_jinglesession_test_OBJECTS)
+jinglesession_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
+	../../base64.o ../../prep.o ../../gloox.o ../../iq.o \
+	../../util.o ../../sha.o ../../error.o ../../jid.o \
+	../../jinglecontent.o ../../jinglepluginfactory.o
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp = $(SHELL) $(top_srcdir)/depcomp
+am__depfiles_maybe = depfiles
+am__mv = mv -f
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+LTCXXCOMPILE = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
+SOURCES = $(jinglesession_test_SOURCES)
+DIST_SOURCES = $(jinglesession_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
+ACLOCAL = @ACLOCAL@
+AMTAR = @AMTAR@
+AR = @AR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+CC = @CC@
+CCDEPMODE = @CCDEPMODE@
+CFLAGS = @CFLAGS@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXDEPMODE = @CXXDEPMODE@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+DEFS = @DEFS@
+DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+EXEEXT = @EXEEXT@
+FGREP = @FGREP@
+GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+ISODATE = @ISODATE@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBOBJS = @LTLIBOBJS@
+MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
+MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
+MAYBE_TESTS = @MAYBE_TESTS@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PTHREAD_CC = @PTHREAD_CC@
+PTHREAD_CFLAGS = @PTHREAD_CFLAGS@
+PTHREAD_LIBS = @PTHREAD_LIBS@
+RANLIB = @RANLIB@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+VERSION = @VERSION@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+acx_pthread_config = @acx_pthread_config@
+am__include = @am__include@
+am__leading_dot = @am__leading_dot@
+am__quote = @am__quote@
+am__tar = @am__tar@
+am__untar = @am__untar@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+exec_prefix = @exec_prefix@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+localedir = @localedir@
+localstatedir = @localstatedir@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+jinglesession_test_SOURCES = jinglesession_test.cpp
+jinglesession_test_LDADD = ../../tag.o ../../stanza.o ../../base64.o \
+			../../prep.o ../../gloox.o \
+			../../iq.o ../../util.o \
+			../../sha.o ../../error.o ../../jid.o \
+			../../jinglecontent.o ../../jinglepluginfactory.o
+
+jinglesession_test_CFLAGS = $(CPPFLAGS) -g3
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cpp .lo .o .obj
+$(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --gnu src/tests/jinglesession/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --gnu src/tests/jinglesession/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure:  $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4):  $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+
+clean-noinstPROGRAMS:
+	@list='$(noinst_PROGRAMS)'; test -n "$$list" || exit 0; \
+	echo " rm -f" $$list; \
+	rm -f $$list || exit $$?; \
+	test -n "$(EXEEXT)" || exit 0; \
+	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
+	echo " rm -f" $$list; \
+	rm -f $$list
+jinglesession_test$(EXEEXT): $(jinglesession_test_OBJECTS) $(jinglesession_test_DEPENDENCIES) $(EXTRA_jinglesession_test_DEPENDENCIES) 
+	@rm -f jinglesession_test$(EXEEXT)
+	$(CXXLINK) $(jinglesession_test_OBJECTS) $(jinglesession_test_LDADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglesession_test.Po@am__quote@
+
+.cpp.o:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ $<
+
+.cpp.obj:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cpp.lo:
+@am__fastdepCXX_TRUE@	$(LTCXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+
+distdir: $(DISTFILES)
+	@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	list='$(DISTFILES)'; \
+	  dist_files=`for file in $$list; do echo $$file; done | \
+	  sed -e "s|^$$srcdirstrip/||;t" \
+	      -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+	case $$dist_files in \
+	  */*) $(MKDIR_P) `echo "$$dist_files" | \
+			   sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+			   sort -u` ;; \
+	esac; \
+	for file in $$dist_files; do \
+	  if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
+	  if test -d $$d/$$file; then \
+	    dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+	    if test -d "$(distdir)/$$file"; then \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
+	      cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
+	  else \
+	    test -f "$(distdir)/$$file" \
+	    || cp -p $$d/$$file "$(distdir)/$$file" \
+	    || exit 1; \
+	  fi; \
+	done
+check-am: all-am
+check: check-am
+all-am: Makefile $(PROGRAMS)
+installdirs:
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-noinstPROGRAMS \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am:
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am:
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-noinstPROGRAMS ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags distdir dvi dvi-am html html-am info info-am \
+	install install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip installcheck installcheck-am installdirs \
+	maintainer-clean maintainer-clean-generic mostlyclean \
+	mostlyclean-compile mostlyclean-generic mostlyclean-libtool \
+	pdf pdf-am ps ps-am tags uninstall uninstall-am
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:

=== added file 'src/tests/jinglesession/jinglesession_test.cpp'
--- src/tests/jinglesession/jinglesession_test.cpp	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesession/jinglesession_test.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,353 @@
+#define CLIENTBASE_H__
+#define DISCO_H__
+#define GLOOX_TESTS
+#define JINGLE_TEST
+#include "../../iq.h"
+#include "../../iqhandler.h"
+#include "../../jid.h"
+#include "../../stanzaextension.h"
+
+#include <stdio.h>
+#include <locale.h>
+#include <string>
+#include <cstdio> // [s]print[f]
+
+gloox::JID remote_jid( "foo@bar" );
+
+namespace gloox
+{
+  class Disco
+  {
+  public:
+    Disco() {}
+    void addFeature( const std::string& ) {}
+  };
+
+  class ClientBase
+  {
+    public:
+      ClientBase() : m_jid( "self" ) {}
+      virtual ~ClientBase() {}
+      const JID& jid() const { return m_jid; }
+      const std::string getID();
+      virtual void send( const IQ& ) = 0;
+      virtual void send( IQ&, IqHandler*, int ) = 0;
+      void removeIqHandler( IqHandler* ih, int exttype );
+      void removeIDHandler( IqHandler* ih );
+      void registerIqHandler( IqHandler* ih, int exttype );
+      void registerStanzaExtension( StanzaExtension* ext );
+      void removeStanzaExtension( int ext );
+      Disco* disco() { return &m_disco; }
+    private:
+      JID m_jid;
+      Disco m_disco;
+  };
+  void ClientBase::removeIqHandler( IqHandler*, int ) {}
+  void ClientBase::removeIDHandler( IqHandler* ) {}
+  void ClientBase::registerIqHandler( IqHandler*, int ) {}
+  void ClientBase::registerStanzaExtension( StanzaExtension* se ) { delete se; }
+  void ClientBase::removeStanzaExtension( int ) {}
+  const std::string ClientBase::getID() { return "id"; }
+}
+using namespace gloox;
+
+#define JINGLESESSION_TEST
+#include "../../jinglesession.h"
+#include "../../jinglesession.cpp"
+#include "../../jinglesessionhandler.h"
+#include "../../jinglesessionmanager.h"
+#include "../../jinglesessionmanager.cpp"
+#include "../../jinglecontent.h"
+class TestInitiator : public ClientBase, public Jingle::SessionHandler
+{
+  public:
+    TestInitiator() : m_js( new Jingle::Session( this, remote_jid, this ) ), m_result( false ), m_result2( false )
+    {}
+    virtual ~TestInitiator() { delete m_js; }
+    void setTest( int test ) { m_test = test; }
+    virtual void send( const IQ& iq );
+    virtual void send( IQ& iq, IqHandler*, int );
+    virtual void trackID( IqHandler *ih, const std::string& id, int context );
+    bool checkResult() { bool t = m_result; m_result = false; return t; }
+    bool checkResult2() { bool t = m_result2; m_result2 = false; return t; }
+    Jingle::Session* js() { return m_js; }
+    virtual void handleSessionAction( Jingle::Action action, const Jingle::Session* session, const Jingle::Session::Jingle* jingle );
+    virtual void handleSessionActionError( Jingle::Action action, const Jingle::Session* /*session*/, const Error* /*e*/ ) {}
+    virtual void handleIncomingSession( Jingle::Session* session ) {}
+private:
+    Jingle::Session* m_js;
+    int m_test;
+    bool m_result;
+    bool m_result2;
+};
+
+class TestResponder : public ClientBase, public Jingle::SessionHandler
+{
+public:
+  TestResponder() : m_js( 0 ), m_result( false ), m_result2( false ),
+    m_manager( 0 )
+    {}
+  virtual ~TestResponder() { delete m_js; delete m_manager; }
+  void setTest( int test ) { if( !m_manager ) m_manager = new Jingle::SessionManager( this, this ); m_test = test; }
+  virtual void send( const IQ& iq );
+  virtual void send( IQ& iq, IqHandler*, int );
+  virtual void trackID( IqHandler *ih, const std::string& id, int context );
+  bool checkResult() { bool t = m_result; m_result = false; return t; }
+  bool checkResult2() { bool t = m_result2; m_result2 = false; return t; }
+  Jingle::Session* js() { return m_js; }
+  Jingle::SessionManager* sm() { return m_manager; }
+  virtual void handleSessionAction( Jingle::Action action, const Jingle::Session* session, const Jingle::Session::Jingle* jingle );
+  virtual void handleSessionActionError( Jingle::Action action, const Jingle::Session* /*session*/, const Error* /*e*/ ) {}
+
+  virtual void handleIncomingSession( Jingle::Session* session ) { m_js = session; }
+private:
+  Jingle::Session* m_js;
+  int m_test;
+  bool m_result;
+  bool m_result2;
+  Jingle::SessionManager* m_manager;
+};
+
+TestInitiator* ini;
+TestResponder* res;
+
+
+void TestInitiator::handleSessionAction( Jingle::Action action, const Jingle::Session* session, const Jingle::Session::Jingle* jingle )
+{
+//   m_result2 = false;
+
+//   if( m_test == 1 && session->state() == Jingle::Session::Pending )
+//     m_result2 = true;
+}
+
+void TestInitiator::send( const IQ& iq )
+{
+//   printf( "TestInitiator::senD(IQ): %s\n", iq.tag()->xml().c_str() );
+  m_result2 = false;
+
+  switch( m_test )
+  {
+    case 2:
+    case 3:
+      if( iq.subtype() == IQ::Result && iq.to().full() == "foo@bar" )
+        m_result2 = true;
+      break;
+  }
+}
+
+void TestInitiator::send( IQ& iq, IqHandler*, int ctx )
+{
+  m_result = false;
+  iq.setFrom( JID( "self" ) );
+  Tag* t = iq.tag();
+  std::string expected;
+
+//   printf( "TestInitiator: test %d: %s\n", m_test, t->xml().c_str() );
+
+  switch( m_test )
+  {
+    case 1:
+    {
+      expected = "<iq to='foo@bar' from='self' id='id' type='set'><jingle xmlns='" + XMLNS_JINGLE + "' action='session-initiate' initiator='self' sid='somesid'/></iq>";
+      if( t->xml() == expected )
+        m_result = true;
+      else
+        fprintf( stderr, "Jingle::Session test %d\nHave:     %s\nExpected: %s\n", m_test, t->xml().c_str(), expected.c_str() );
+      res->sm()->handleIq( iq );
+      break;
+    }
+  }
+
+  delete t;
+}
+
+void TestInitiator::trackID( IqHandler*, const std::string&, int ) {}
+
+// ------------------------------------------------------------------------------------------------------------
+
+void TestResponder::handleSessionAction( Jingle::Action action, const Jingle::Session* session, const Jingle::Session::Jingle* jingle )
+{
+  m_result2 = false;
+
+  if( m_test == 1 && session->state() == Jingle::Session::Pending )
+    m_result2 = true;
+}
+
+void TestResponder::send( const IQ& iq )
+{
+  m_result2 = false;
+//   printf( "TestResponder::senD(IQ): %s\n", iq.tag()->xml().c_str() );
+
+  switch( m_test )
+  {
+    case 1:
+      if( iq.subtype() == IQ::Result && iq.to().full() == "self" )
+      {
+//         printf( "m_result2 = true;\n" );
+        m_result2 = true;
+      }
+      break;
+  }
+}
+
+void TestResponder::send( IQ& iq, IqHandler*, int ctx )
+{
+  m_result = false;
+  iq.setFrom( remote_jid );
+  Tag* t = iq.tag();
+  std::string expected;
+
+//   printf( "TestResponder: test %d: %s\n", m_test, t->xml().c_str() );
+  switch( m_test )
+  {
+    case 1:
+      break;
+    case 2:
+      expected = "<iq to='self' from='foo@bar' id='id' type='set'><jingle xmlns='" + XMLNS_JINGLE + "' action='session-accept' sid='somesid'/></iq>";
+      if( t->xml() == expected )
+        m_result = true;
+      else
+        fprintf( stderr, "Jingle::Session test %d\nHave:     %s\nExpected: %s\n", m_test, t->xml().c_str(), expected.c_str() );
+      ini->js()->handleIq( iq );
+      break;
+    case 3:
+      expected = "<iq to='self' from='foo@bar' id='id' type='set'><jingle xmlns='" + XMLNS_JINGLE + "' action='session-terminate' sid='somesid'><reason><success/></reason></jingle></iq>";
+      if( t->xml() == expected )
+        m_result = true;
+      else
+        fprintf( stderr, "Jingle::Session test %d\nHave:     %s\nExpected: %s\n", m_test, t->xml().c_str(), expected.c_str() );
+      ini->js()->handleIq( iq );
+      break;
+    case 4:
+    case 5:
+    {
+      break;
+    }
+  }
+
+  delete t;
+}
+
+void TestResponder::trackID( IqHandler*, const std::string&, int ) {}
+
+// ------------------------------------------------------------------------------------------------------------
+
+// ------------------------------------------------------------------------------------------------------------
+
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  int fail = 0;
+  std::string name;
+  ini = new TestInitiator();
+  ini->js()->setSID( "somesid" );
+
+  res = new TestResponder();
+
+  // -------
+  name = "Initiator: ended (initial) state";
+  if( ini->js()->state() != Jingle::Session::Ended )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Initiator: session initiate";
+  ini->setTest( 1 );
+  res->setTest( 1 );
+  Jingle::PluginList pl;
+  pl.push_back( new Jingle::Content() );
+  if( !ini->js()->sessionInitiate( pl ) || !ini->checkResult() || !res->checkResult2() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Initiator: pending state";
+  if( ini->js()->state() != Jingle::Session::Pending )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Responder: pending state";
+  if( res->js()->state() != Jingle::Session::Pending )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Responder: session accept";
+  ini->setTest( 2 );
+  res->setTest( 2 );
+  if( !res->js()->sessionAccept( new Jingle::Content() ) || !res->checkResult() || !ini->checkResult2() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Initiator: active state";
+  if( ini->js()->state() != Jingle::Session::Active )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Responder: active state";
+  if( res->js()->state() != Jingle::Session::Active )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Responder: session terminate";
+  ini->setTest( 3 );
+  res->setTest( 3 );
+  if( !res->js()->sessionTerminate( new Jingle::Session::Reason( Jingle::Session::Reason::Success ) ) || !res->checkResult() || !ini->checkResult2() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Initiator: ended state";
+  if( ini->js()->state() != Jingle::Session::Ended )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "Responder: ended state";
+  if( res->js()->state() != Jingle::Session::Ended )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+
+
+
+
+  delete ini;
+  delete res;
+
+  if( fail == 0 )
+  {
+    printf( "Jingle::Session: OK\n" );
+    return 0;
+  }
+  else
+  {
+    fprintf( stderr, "Jingle::Session: %d test(s) failed\n", fail );
+    return 1;
+  }
+
+}

=== added directory 'src/tests/jinglesessionjingle'
=== added file 'src/tests/jinglesessionjingle/Makefile.am'
--- src/tests/jinglesessionjingle/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesessionjingle/Makefile.am	2014-01-16 10:42:06 +0000
@@ -0,0 +1,16 @@
+
+##
+## Process this file with automake to produce Makefile.in
+##
+
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+
+noinst_PROGRAMS = jinglesessionjingle_test
+
+jinglesessionjingle_test_SOURCES = jinglesessionjingle_test.cpp
+jinglesessionjingle_test_LDADD = ../../stanza.o ../../jid.o ../../tag.o ../../prep.o \
+ 		../../gloox.o ../../stanzaextensionfactory.o \
+		../../iq.o ../../util.o ../../sha.o ../../base64.o \
+		../../jinglecontent.o ../../error.o ../../mutex.o \
+		../../jinglepluginfactory.o
+jinglesessionjingle_test_CFLAGS = $(CPPFLAGS)

=== added file 'src/tests/jinglesessionjingle/Makefile.in'
--- src/tests/jinglesessionjingle/Makefile.in	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesessionjingle/Makefile.in	2014-01-16 10:42:06 +0000
@@ -0,0 +1,522 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+noinst_PROGRAMS = jinglesessionjingle_test$(EXEEXT)
+subdir = src/tests/jinglesessionjingle
+DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+mkinstalldirs = $(install_sh) -d
+CONFIG_HEADER = $(top_builddir)/config.h.unix
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+PROGRAMS = $(noinst_PROGRAMS)
+am_jinglesessionjingle_test_OBJECTS =  \
+	jinglesessionjingle_test.$(OBJEXT)
+jinglesessionjingle_test_OBJECTS =  \
+	$(am_jinglesessionjingle_test_OBJECTS)
+jinglesessionjingle_test_DEPENDENCIES = ../../stanza.o ../../jid.o \
+	../../tag.o ../../prep.o ../../gloox.o \
+	../../stanzaextensionfactory.o ../../iq.o ../../util.o \
+	../../sha.o ../../base64.o ../../jinglecontent.o ../../error.o \
+	../../mutex.o ../../jinglepluginfactory.o
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp = $(SHELL) $(top_srcdir)/depcomp
+am__depfiles_maybe = depfiles
+am__mv = mv -f
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+LTCXXCOMPILE = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
+SOURCES = $(jinglesessionjingle_test_SOURCES)
+DIST_SOURCES = $(jinglesessionjingle_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
+ACLOCAL = @ACLOCAL@
+AMTAR = @AMTAR@
+AR = @AR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+CC = @CC@
+CCDEPMODE = @CCDEPMODE@
+CFLAGS = @CFLAGS@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXDEPMODE = @CXXDEPMODE@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+DEFS = @DEFS@
+DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+EXEEXT = @EXEEXT@
+FGREP = @FGREP@
+GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+ISODATE = @ISODATE@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBOBJS = @LTLIBOBJS@
+MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
+MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
+MAYBE_TESTS = @MAYBE_TESTS@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PTHREAD_CC = @PTHREAD_CC@
+PTHREAD_CFLAGS = @PTHREAD_CFLAGS@
+PTHREAD_LIBS = @PTHREAD_LIBS@
+RANLIB = @RANLIB@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+VERSION = @VERSION@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+acx_pthread_config = @acx_pthread_config@
+am__include = @am__include@
+am__leading_dot = @am__leading_dot@
+am__quote = @am__quote@
+am__tar = @am__tar@
+am__untar = @am__untar@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+exec_prefix = @exec_prefix@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+localedir = @localedir@
+localstatedir = @localstatedir@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+jinglesessionjingle_test_SOURCES = jinglesessionjingle_test.cpp
+jinglesessionjingle_test_LDADD = ../../stanza.o ../../jid.o ../../tag.o ../../prep.o \
+ 		../../gloox.o ../../stanzaextensionfactory.o \
+		../../iq.o ../../util.o ../../sha.o ../../base64.o \
+		../../jinglecontent.o ../../error.o ../../mutex.o \
+		../../jinglepluginfactory.o
+
+jinglesessionjingle_test_CFLAGS = $(CPPFLAGS)
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cpp .lo .o .obj
+$(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --gnu src/tests/jinglesessionjingle/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --gnu src/tests/jinglesessionjingle/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure:  $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4):  $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+
+clean-noinstPROGRAMS:
+	@list='$(noinst_PROGRAMS)'; test -n "$$list" || exit 0; \
+	echo " rm -f" $$list; \
+	rm -f $$list || exit $$?; \
+	test -n "$(EXEEXT)" || exit 0; \
+	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
+	echo " rm -f" $$list; \
+	rm -f $$list
+jinglesessionjingle_test$(EXEEXT): $(jinglesessionjingle_test_OBJECTS) $(jinglesessionjingle_test_DEPENDENCIES) $(EXTRA_jinglesessionjingle_test_DEPENDENCIES) 
+	@rm -f jinglesessionjingle_test$(EXEEXT)
+	$(CXXLINK) $(jinglesessionjingle_test_OBJECTS) $(jinglesessionjingle_test_LDADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglesessionjingle_test.Po@am__quote@
+
+.cpp.o:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ $<
+
+.cpp.obj:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cpp.lo:
+@am__fastdepCXX_TRUE@	$(LTCXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+
+distdir: $(DISTFILES)
+	@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	list='$(DISTFILES)'; \
+	  dist_files=`for file in $$list; do echo $$file; done | \
+	  sed -e "s|^$$srcdirstrip/||;t" \
+	      -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+	case $$dist_files in \
+	  */*) $(MKDIR_P) `echo "$$dist_files" | \
+			   sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+			   sort -u` ;; \
+	esac; \
+	for file in $$dist_files; do \
+	  if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
+	  if test -d $$d/$$file; then \
+	    dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+	    if test -d "$(distdir)/$$file"; then \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
+	      cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
+	  else \
+	    test -f "$(distdir)/$$file" \
+	    || cp -p $$d/$$file "$(distdir)/$$file" \
+	    || exit 1; \
+	  fi; \
+	done
+check-am: all-am
+check: check-am
+all-am: Makefile $(PROGRAMS)
+installdirs:
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-noinstPROGRAMS \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am:
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am:
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-noinstPROGRAMS ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags distdir dvi dvi-am html html-am info info-am \
+	install install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip installcheck installcheck-am installdirs \
+	maintainer-clean maintainer-clean-generic mostlyclean \
+	mostlyclean-compile mostlyclean-generic mostlyclean-libtool \
+	pdf pdf-am ps ps-am tags uninstall uninstall-am
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:

=== added file 'src/tests/jinglesessionjingle/jinglesessionjingle_test.cpp'
--- src/tests/jinglesessionjingle/jinglesessionjingle_test.cpp	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesessionjingle/jinglesessionjingle_test.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,328 @@
+#define JINGLE_TEST
+#include "../../gloox.h"
+#include "../../jid.h"
+#include "../../tag.h"
+#include "../../iq.h"
+#include "../../iqhandler.h"
+#include "../../stanzaextension.h"
+#include "../../stanzaextensionfactory.h"
+using namespace gloox;
+
+#include <stdio.h>
+#include <locale.h>
+#include <string>
+#include <cstdio> // [s]print[f]
+
+namespace gloox
+{
+
+  class Disco;
+  class Capabilities : public StanzaExtension
+  {
+    public:
+      Capabilities() : StanzaExtension( ExtUser + 1 ) {}
+      const std::string& ver() const { return EmptyString; }
+      const std::string& node() const { return EmptyString; }
+  };
+
+  class ClientBase
+  {
+    public:
+      ClientBase() : m_jid( "fooqbar/foobar" ) {}
+      virtual ~ClientBase() {}
+      const std::string getID() { return "id"; }
+      virtual void send( IQ& iq, IqHandler*, int ) = 0;
+      virtual void send( IQ& iq ) = 0;
+      virtual void trackID( IqHandler *ih, const std::string& id, int context ) = 0;
+      void removeIDHandler( IqHandler* ) {}
+      void registerIqHandler( IqHandler*, int ) {}
+      void removeIqHandler( IqHandler*, int ) {}
+      void registerStanzaExtension( StanzaExtension* ext ) { delete ext; }
+      void removeStanzaExtension( int ) {}
+      ConnectionState state() const { return StateConnected; }
+      bool authed() { return false; }
+      const JID& jid() const { return m_jid; }
+    private:
+      JID m_jid;
+  };
+}
+
+#define CLIENTBASE_H__
+#include "../../jinglesession.h"
+#include "../../jinglesession.cpp"
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  int fail = 0;
+  std::string name;
+  JID jid( "foo@bar/barfoo" );
+
+  // -------
+  {
+    name = "invalid Jingle 1";
+    Jingle::Session::Jingle js;
+    Tag* t = js.tag();
+    if( t )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "invalid Jingle 2";
+    Jingle::Session::Jingle js( Jingle::SessionAccept, JID(), 0, "" );
+    Tag* t = js.tag();
+    if( t )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, content-accept";
+    Jingle::Session::Jingle js( Jingle::ContentAccept, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='content-accept' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, content-add";
+    Jingle::Session::Jingle js( Jingle::ContentAdd, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='content-add' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, content-modify";
+    Jingle::Session::Jingle js( Jingle::ContentModify, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='content-modify' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, content-reject";
+    Jingle::Session::Jingle js( Jingle::ContentReject, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='content-reject' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, content-remove";
+    Jingle::Session::Jingle js( Jingle::ContentRemove, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='content-remove' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, description-info";
+    Jingle::Session::Jingle js( Jingle::DescriptionInfo, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='description-info' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, session-accept";
+    Jingle::Session::Jingle js( Jingle::SessionAccept, jid, 0, "somesid" );
+    js.setResponder( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='session-accept' responder='foo@bar/barfoo' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, session-info";
+    Jingle::Session::Jingle js( Jingle::SessionInfo, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='session-info' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, session-initiate";
+    Jingle::Session::Jingle js( Jingle::SessionInitiate, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='session-initiate' initiator='foo@bar/barfoo' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, session-terminate";
+    Jingle::Session::Jingle js( Jingle::SessionTerminate, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='session-terminate' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, transport-accept";
+    Jingle::Session::Jingle js( Jingle::TransportAccept, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='transport-accept' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, transport-info";
+    Jingle::Session::Jingle js( Jingle::TransportInfo, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='transport-info' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, transport-reject";
+    Jingle::Session::Jingle js( Jingle::TransportReject, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='transport-reject' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+  // -------
+  {
+    name = "empty Jingle, transport-replace";
+    Jingle::Session::Jingle js( Jingle::TransportReplace, jid, 0, "somesid" );
+    js.setInitiator( jid );
+    Tag* t = js.tag();
+    if( !t || t->xml() != "<jingle xmlns='" + XMLNS_JINGLE + "' "
+      "action='transport-replace' sid='somesid'/>" )
+    {
+      ++fail;
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    }
+    delete t;
+  }
+
+
+
+
+  // -------
+  name = "Jingle::Session::Jingle/SEFactory test";
+  StanzaExtensionFactory sef;
+  sef.registerExtension( new Jingle::Session::Jingle() );
+  Tag* f = new Tag( "iq" );
+  new Tag( f, "jingle", "xmlns", XMLNS_JINGLE );
+  IQ iq( IQ::Get, JID() );
+  sef.addExtensions( iq, f );
+  const Jingle::Session::Jingle* se = iq.findExtension<Jingle::Session::Jingle>( ExtJingle );
+  if( se == 0 )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+  delete f;
+
+
+
+  if( fail == 0 )
+  {
+    printf( "Jingle::Session::Jingle: OK\n" );
+    return 0;
+  }
+  else
+  {
+    fprintf( stderr, "Jingle::Session::Jingle: %d test(s) failed\n", fail );
+    return 1;
+  }
+
+}

=== added directory 'src/tests/jinglesessionmanager'
=== added file 'src/tests/jinglesessionmanager/Makefile.am'
--- src/tests/jinglesessionmanager/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesessionmanager/Makefile.am	2014-01-16 10:42:06 +0000
@@ -0,0 +1,16 @@
+##
+## Process this file with automake to produce Makefile.in
+##
+
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+
+noinst_PROGRAMS = jinglesessionmanager_test
+
+jinglesessionmanager_test_SOURCES = jinglesessionmanager_test.cpp
+jinglesessionmanager_test_LDADD = ../../tag.o ../../stanza.o ../../base64.o \
+			../../prep.o ../../gloox.o \
+			../../iq.o ../../util.o ../../mutex.o \
+			../../sha.o ../../error.o ../../jid.o \
+			../../jinglecontent.o ../../jinglepluginfactory.o \
+			../../stanzaextensionfactory.o ../../jingleiceudp.o ../../jinglefiletransfer.o
+jinglesessionmanager_test_CFLAGS = $(CPPFLAGS) -g3

=== added file 'src/tests/jinglesessionmanager/Makefile.in'
--- src/tests/jinglesessionmanager/Makefile.in	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesessionmanager/Makefile.in	2014-01-16 10:42:06 +0000
@@ -0,0 +1,524 @@
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
+# @configure_input@
+
+# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
+# This Makefile.in is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY, to the extent permitted by law; without
+# even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+# PARTICULAR PURPOSE.
+
+@SET_MAKE@
+
+VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
+pkgdatadir = $(datadir)/@PACKAGE@
+pkgincludedir = $(includedir)/@PACKAGE@
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
+am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
+install_sh_DATA = $(install_sh) -c -m 644
+install_sh_PROGRAM = $(install_sh) -c
+install_sh_SCRIPT = $(install_sh) -c
+INSTALL_HEADER = $(INSTALL_DATA)
+transform = $(program_transform_name)
+NORMAL_INSTALL = :
+PRE_INSTALL = :
+POST_INSTALL = :
+NORMAL_UNINSTALL = :
+PRE_UNINSTALL = :
+POST_UNINSTALL = :
+build_triplet = @build@
+host_triplet = @host@
+noinst_PROGRAMS = jinglesessionmanager_test$(EXEEXT)
+subdir = src/tests/jinglesessionmanager
+DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in
+ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
+am__aclocal_m4_deps = $(top_srcdir)/acinclude.m4 \
+	$(top_srcdir)/configure.ac
+am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
+	$(ACLOCAL_M4)
+mkinstalldirs = $(install_sh) -d
+CONFIG_HEADER = $(top_builddir)/config.h.unix
+CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
+PROGRAMS = $(noinst_PROGRAMS)
+am_jinglesessionmanager_test_OBJECTS =  \
+	jinglesessionmanager_test.$(OBJEXT)
+jinglesessionmanager_test_OBJECTS =  \
+	$(am_jinglesessionmanager_test_OBJECTS)
+jinglesessionmanager_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
+	../../base64.o ../../prep.o ../../gloox.o ../../iq.o \
+	../../util.o ../../mutex.o ../../sha.o ../../error.o \
+	../../jid.o ../../jinglecontent.o ../../jinglepluginfactory.o \
+	../../stanzaextensionfactory.o ../../jingleiceudp.o \
+	../../jinglefiletransfer.o
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
+depcomp = $(SHELL) $(top_srcdir)/depcomp
+am__depfiles_maybe = depfiles
+am__mv = mv -f
+CXXCOMPILE = $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+LTCXXCOMPILE = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=compile $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) \
+	$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS)
+CXXLD = $(CXX)
+CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
+	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
+SOURCES = $(jinglesessionmanager_test_SOURCES)
+DIST_SOURCES = $(jinglesessionmanager_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
+ETAGS = etags
+CTAGS = ctags
+DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
+ACLOCAL = @ACLOCAL@
+AMTAR = @AMTAR@
+AR = @AR@
+AUTOCONF = @AUTOCONF@
+AUTOHEADER = @AUTOHEADER@
+AUTOMAKE = @AUTOMAKE@
+AWK = @AWK@
+CC = @CC@
+CCDEPMODE = @CCDEPMODE@
+CFLAGS = @CFLAGS@
+CPP = @CPP@
+CPPFLAGS = @CPPFLAGS@
+CXX = @CXX@
+CXXCPP = @CXXCPP@
+CXXDEPMODE = @CXXDEPMODE@
+CXXFLAGS = @CXXFLAGS@
+CYGPATH_W = @CYGPATH_W@
+DEFS = @DEFS@
+DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
+DSYMUTIL = @DSYMUTIL@
+DUMPBIN = @DUMPBIN@
+ECHO_C = @ECHO_C@
+ECHO_N = @ECHO_N@
+ECHO_T = @ECHO_T@
+EGREP = @EGREP@
+EXEEXT = @EXEEXT@
+FGREP = @FGREP@
+GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
+INSTALL = @INSTALL@
+INSTALL_DATA = @INSTALL_DATA@
+INSTALL_PROGRAM = @INSTALL_PROGRAM@
+INSTALL_SCRIPT = @INSTALL_SCRIPT@
+INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+ISODATE = @ISODATE@
+LD = @LD@
+LDFLAGS = @LDFLAGS@
+LIBOBJS = @LIBOBJS@
+LIBS = @LIBS@
+LIBTOOL = @LIBTOOL@
+LIPO = @LIPO@
+LN_S = @LN_S@
+LTLIBOBJS = @LTLIBOBJS@
+MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
+MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
+MAYBE_TESTS = @MAYBE_TESTS@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
+NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
+OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
+PACKAGE = @PACKAGE@
+PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
+PACKAGE_NAME = @PACKAGE_NAME@
+PACKAGE_STRING = @PACKAGE_STRING@
+PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
+PACKAGE_VERSION = @PACKAGE_VERSION@
+PATH_SEPARATOR = @PATH_SEPARATOR@
+PTHREAD_CC = @PTHREAD_CC@
+PTHREAD_CFLAGS = @PTHREAD_CFLAGS@
+PTHREAD_LIBS = @PTHREAD_LIBS@
+RANLIB = @RANLIB@
+SED = @SED@
+SET_MAKE = @SET_MAKE@
+SHELL = @SHELL@
+STRIP = @STRIP@
+VERSION = @VERSION@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
+ac_ct_CC = @ac_ct_CC@
+ac_ct_CXX = @ac_ct_CXX@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
+acx_pthread_config = @acx_pthread_config@
+am__include = @am__include@
+am__leading_dot = @am__leading_dot@
+am__quote = @am__quote@
+am__tar = @am__tar@
+am__untar = @am__untar@
+bindir = @bindir@
+build = @build@
+build_alias = @build_alias@
+build_cpu = @build_cpu@
+build_os = @build_os@
+build_vendor = @build_vendor@
+builddir = @builddir@
+datadir = @datadir@
+datarootdir = @datarootdir@
+docdir = @docdir@
+dvidir = @dvidir@
+exec_prefix = @exec_prefix@
+host = @host@
+host_alias = @host_alias@
+host_cpu = @host_cpu@
+host_os = @host_os@
+host_vendor = @host_vendor@
+htmldir = @htmldir@
+includedir = @includedir@
+infodir = @infodir@
+install_sh = @install_sh@
+libdir = @libdir@
+libexecdir = @libexecdir@
+localedir = @localedir@
+localstatedir = @localstatedir@
+mandir = @mandir@
+mkdir_p = @mkdir_p@
+oldincludedir = @oldincludedir@
+pdfdir = @pdfdir@
+prefix = @prefix@
+program_transform_name = @program_transform_name@
+psdir = @psdir@
+sbindir = @sbindir@
+sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
+sysconfdir = @sysconfdir@
+target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
+AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual
+jinglesessionmanager_test_SOURCES = jinglesessionmanager_test.cpp
+jinglesessionmanager_test_LDADD = ../../tag.o ../../stanza.o ../../base64.o \
+			../../prep.o ../../gloox.o \
+			../../iq.o ../../util.o ../../mutex.o \
+			../../sha.o ../../error.o ../../jid.o \
+			../../jinglecontent.o ../../jinglepluginfactory.o \
+			../../stanzaextensionfactory.o ../../jingleiceudp.o ../../jinglefiletransfer.o
+
+jinglesessionmanager_test_CFLAGS = $(CPPFLAGS) -g3
+all: all-am
+
+.SUFFIXES:
+.SUFFIXES: .cpp .lo .o .obj
+$(srcdir)/Makefile.in:  $(srcdir)/Makefile.am  $(am__configure_deps)
+	@for dep in $?; do \
+	  case '$(am__configure_deps)' in \
+	    *$$dep*) \
+	      ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+	        && { if test -f $@; then exit 0; else break; fi; }; \
+	      exit 1;; \
+	  esac; \
+	done; \
+	echo ' cd $(top_srcdir) && $(AUTOMAKE) --gnu src/tests/jinglesessionmanager/Makefile'; \
+	$(am__cd) $(top_srcdir) && \
+	  $(AUTOMAKE) --gnu src/tests/jinglesessionmanager/Makefile
+.PRECIOUS: Makefile
+Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
+	@case '$?' in \
+	  *config.status*) \
+	    cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh;; \
+	  *) \
+	    echo ' cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe)'; \
+	    cd $(top_builddir) && $(SHELL) ./config.status $(subdir)/$@ $(am__depfiles_maybe);; \
+	esac;
+
+$(top_builddir)/config.status: $(top_srcdir)/configure $(CONFIG_STATUS_DEPENDENCIES)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+
+$(top_srcdir)/configure:  $(am__configure_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(ACLOCAL_M4):  $(am__aclocal_m4_deps)
+	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
+
+clean-noinstPROGRAMS:
+	@list='$(noinst_PROGRAMS)'; test -n "$$list" || exit 0; \
+	echo " rm -f" $$list; \
+	rm -f $$list || exit $$?; \
+	test -n "$(EXEEXT)" || exit 0; \
+	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
+	echo " rm -f" $$list; \
+	rm -f $$list
+jinglesessionmanager_test$(EXEEXT): $(jinglesessionmanager_test_OBJECTS) $(jinglesessionmanager_test_DEPENDENCIES) $(EXTRA_jinglesessionmanager_test_DEPENDENCIES) 
+	@rm -f jinglesessionmanager_test$(EXEEXT)
+	$(CXXLINK) $(jinglesessionmanager_test_OBJECTS) $(jinglesessionmanager_test_LDADD) $(LIBS)
+
+mostlyclean-compile:
+	-rm -f *.$(OBJEXT)
+
+distclean-compile:
+	-rm -f *.tab.c
+
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/jinglesessionmanager_test.Po@am__quote@
+
+.cpp.o:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ $<
+
+.cpp.obj:
+@am__fastdepCXX_TRUE@	$(CXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXXCOMPILE) -c -o $@ `$(CYGPATH_W) '$<'`
+
+.cpp.lo:
+@am__fastdepCXX_TRUE@	$(LTCXXCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCXX_TRUE@	$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(LTCXXCOMPILE) -c -o $@ $<
+
+mostlyclean-libtool:
+	-rm -f *.lo
+
+clean-libtool:
+	-rm -rf .libs _libs
+
+ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
+	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	mkid -fID $$unique
+tags: TAGS
+
+TAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	set x; \
+	here=`pwd`; \
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	shift; \
+	if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
+	  test -n "$$unique" || unique=$$empty_fix; \
+	  if test $$# -gt 0; then \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      "$$@" $$unique; \
+	  else \
+	    $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+	      $$unique; \
+	  fi; \
+	fi
+ctags: CTAGS
+CTAGS:  $(HEADERS) $(SOURCES)  $(TAGS_DEPENDENCIES) \
+		$(TAGS_FILES) $(LISP)
+	list='$(SOURCES) $(HEADERS)  $(LISP) $(TAGS_FILES)'; \
+	unique=`for i in $$list; do \
+	    if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
+	  done | \
+	  $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+	      END { if (nonempty) { for (i in files) print i; }; }'`; \
+	test -z "$(CTAGS_ARGS)$$unique" \
+	  || $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
+	     $$unique
+
+GTAGS:
+	here=`$(am__cd) $(top_builddir) && pwd` \
+	  && $(am__cd) $(top_srcdir) \
+	  && gtags -i $(GTAGS_ARGS) "$$here"
+
+distclean-tags:
+	-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
+
+distdir: $(DISTFILES)
+	@srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+	list='$(DISTFILES)'; \
+	  dist_files=`for file in $$list; do echo $$file; done | \
+	  sed -e "s|^$$srcdirstrip/||;t" \
+	      -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+	case $$dist_files in \
+	  */*) $(MKDIR_P) `echo "$$dist_files" | \
+			   sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+			   sort -u` ;; \
+	esac; \
+	for file in $$dist_files; do \
+	  if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
+	  if test -d $$d/$$file; then \
+	    dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+	    if test -d "$(distdir)/$$file"; then \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
+	      cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+	      find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+	    fi; \
+	    cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
+	  else \
+	    test -f "$(distdir)/$$file" \
+	    || cp -p $$d/$$file "$(distdir)/$$file" \
+	    || exit 1; \
+	  fi; \
+	done
+check-am: all-am
+check: check-am
+all-am: Makefile $(PROGRAMS)
+installdirs:
+install: install-am
+install-exec: install-exec-am
+install-data: install-data-am
+uninstall: uninstall-am
+
+install-am: all-am
+	@$(MAKE) $(AM_MAKEFLAGS) install-exec-am install-data-am
+
+installcheck: installcheck-am
+install-strip:
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
+mostlyclean-generic:
+
+clean-generic:
+
+distclean-generic:
+	-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+	-test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
+
+maintainer-clean-generic:
+	@echo "This command is intended for maintainers to use"
+	@echo "it deletes files that may require special tools to rebuild."
+clean: clean-am
+
+clean-am: clean-generic clean-libtool clean-noinstPROGRAMS \
+	mostlyclean-am
+
+distclean: distclean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+distclean-am: clean-am distclean-compile distclean-generic \
+	distclean-tags
+
+dvi: dvi-am
+
+dvi-am:
+
+html: html-am
+
+html-am:
+
+info: info-am
+
+info-am:
+
+install-data-am:
+
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
+install-exec-am:
+
+install-html: install-html-am
+
+install-html-am:
+
+install-info: install-info-am
+
+install-info-am:
+
+install-man:
+
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
+installcheck-am:
+
+maintainer-clean: maintainer-clean-am
+	-rm -rf ./$(DEPDIR)
+	-rm -f Makefile
+maintainer-clean-am: distclean-am maintainer-clean-generic
+
+mostlyclean: mostlyclean-am
+
+mostlyclean-am: mostlyclean-compile mostlyclean-generic \
+	mostlyclean-libtool
+
+pdf: pdf-am
+
+pdf-am:
+
+ps: ps-am
+
+ps-am:
+
+uninstall-am:
+
+.MAKE: install-am install-strip
+
+.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
+	clean-libtool clean-noinstPROGRAMS ctags distclean \
+	distclean-compile distclean-generic distclean-libtool \
+	distclean-tags distdir dvi dvi-am html html-am info info-am \
+	install install-am install-data install-data-am install-dvi \
+	install-dvi-am install-exec install-exec-am install-html \
+	install-html-am install-info install-info-am install-man \
+	install-pdf install-pdf-am install-ps install-ps-am \
+	install-strip installcheck installcheck-am installdirs \
+	maintainer-clean maintainer-clean-generic mostlyclean \
+	mostlyclean-compile mostlyclean-generic mostlyclean-libtool \
+	pdf pdf-am ps ps-am tags uninstall uninstall-am
+
+
+# Tell versions [3.59,3.63) of GNU make to not export all variables.
+# Otherwise a system limit (for SysV at least) may be exceeded.
+.NOEXPORT:

=== added file 'src/tests/jinglesessionmanager/jinglesessionmanager_test.cpp'
--- src/tests/jinglesessionmanager/jinglesessionmanager_test.cpp	1970-01-01 00:00:00 +0000
+++ src/tests/jinglesessionmanager/jinglesessionmanager_test.cpp	2014-01-16 10:42:06 +0000
@@ -0,0 +1,227 @@
+#define CLIENTBASE_H__
+#define DISCO_H__
+#define GLOOX_TESTS
+#define JINGLE_TEST
+#define IQ_TEST
+#include "../../iq.h"
+#include "../../iqhandler.h"
+#include "../../jid.h"
+#include "../../stanzaextension.h"
+#include "../../stanzaextensionfactory.h"
+
+#include <stdio.h>
+#include <locale.h>
+#include <string>
+#include <cstdio> // [s]print[f]
+
+namespace gloox
+{
+  class Disco
+  {
+  public:
+    Disco() {}
+    void addFeature( const std::string& ) {}
+  };
+
+  class ClientBase
+  {
+    public:
+      ClientBase() : m_jid( "self" ) {}
+      virtual ~ClientBase() {}
+      const JID& jid() const { return m_jid; }
+      const std::string getID();
+      virtual void send( const IQ& ) = 0;
+      virtual void send( IQ&, IqHandler*, int ) = 0;
+      void removeIqHandler( IqHandler* ih, int exttype );
+      void removeIDHandler( IqHandler* ih );
+      void registerIqHandler( IqHandler* ih, int exttype );
+      void registerStanzaExtension( StanzaExtension* ext );
+      void removeStanzaExtension( int ext );
+      Disco* disco() { return &m_disco; }
+    protected:
+      JID m_jid;
+      Disco m_disco;
+      StanzaExtensionFactory m_sef;
+  };
+  void ClientBase::removeIqHandler( IqHandler*, int ) {}
+  void ClientBase::removeIDHandler( IqHandler* ) {}
+  void ClientBase::registerIqHandler( IqHandler*, int ) {}
+  void ClientBase::registerStanzaExtension( StanzaExtension* se ) { delete se; }
+  void ClientBase::removeStanzaExtension( int ) {}
+  const std::string ClientBase::getID() { return "id"; }
+}
+using namespace gloox;
+
+#define JINGLESESSION_TEST
+#include "../../jinglesession.h"
+#include "../../jinglesession.cpp"
+#include "../../jinglesessionhandler.h"
+#include "../../jinglesessionmanager.h"
+#include "../../jinglesessionmanager.cpp"
+#include "../../jinglecontent.h"
+#include "../../jingleiceudp.h"
+#include "../../jinglefiletransfer.h"
+class TestInitiator : public ClientBase, public Jingle::SessionHandler
+{
+  public:
+    TestInitiator() : m_sm( this, this ), m_result( false ), m_result2( false )
+    {
+      m_sef.registerExtension( new Jingle::Session::Jingle() );
+      m_sm.registerPlugin( new Jingle::Content() );
+      m_sm.registerPlugin( new Jingle::ICEUDP() );
+      m_sm.registerPlugin( new Jingle::FileTransfer() );
+    }
+    virtual ~TestInitiator() {}
+    void setTest( int test ) { m_test = test; }
+    virtual void send( const IQ&  ) {}
+    virtual void send( IQ& , IqHandler*, int ) {}
+    virtual void send( Tag* tag );
+    virtual void trackID( IqHandler *ih, const std::string& id, int context ) {}
+    bool checkResult() { bool t = m_result; m_result = false; return t; }
+    bool checkResult2() { bool t = m_result2; m_result2 = false; return t; }
+    virtual void handleSessionAction( Jingle::Action action, const Jingle::Session* session, const Jingle::Session::Jingle* jingle );
+    virtual void handleSessionActionError( Jingle::Action action, const Jingle::Session* /*session*/, const Error* /*e*/ ) {}
+    virtual void handleIncomingSession( Jingle::Session* session ) {}
+private:
+    Jingle::SessionManager m_sm;
+    int m_test;
+    bool m_result;
+    bool m_result2;
+};
+
+
+
+
+void TestInitiator::handleSessionAction( Jingle::Action action, const Jingle::Session* session, const Jingle::Session::Jingle* jingle )
+{
+  m_result = false;
+  switch( m_test )
+  {
+    case 1:
+      if( action != Jingle::InvalidAction || jingle->plugins().size() != 0 )
+      {
+        printf( "action: %d, plugins: %d\n", action, jingle->plugins().size() );
+      }
+      else
+        m_result = true;
+      break;
+    case 2:
+      if( action != Jingle::SessionInitiate || jingle->plugins().size() != 1 || static_cast<const Jingle::Content*>( jingle->plugins().front() )->name() != "stub" )
+      {
+        printf( "action: %d, plugins: %d\n", action, jingle->plugins().size() );
+      }
+      else
+        m_result = true;
+      break;
+    case 3:
+      if( action != Jingle::SessionInitiate || jingle->plugins().size() != 1 || static_cast<const Jingle::Content*>( jingle->plugins().front() )->name() != "iceudp"
+        || static_cast<const Jingle::Content*>( jingle->plugins().front() )->plugins().size() != 1
+        || static_cast<const Jingle::ICEUDP*>( static_cast<const Jingle::Content*>( jingle->plugins().front() )->plugins().front() )->pwd() != "pwd" )
+      {
+        printf( "action: %d, plugins: %d\n", action, jingle->plugins().size() );
+      }
+      else
+        m_result = true;
+      break;
+    case 4:
+      if( action != Jingle::SessionInitiate || jingle->plugins().size() != 1 || static_cast<const Jingle::Content*>( jingle->plugins().front() )->name() != "ft"
+        || static_cast<const Jingle::Content*>( jingle->plugins().front() )->plugins().size() != 2
+        || static_cast<const Jingle::ICEUDP*>( static_cast<const Jingle::Content*>( jingle->plugins().front() )->plugins().front() )->pwd() != "pwd"
+        || static_cast<const Jingle::FileTransfer*>( static_cast<const Jingle::Content*>( jingle->plugins().front() )->plugins().back() )->type() != Jingle::FileTransfer::Offer )
+      {
+        printf( "action: %d, plugins: %d\n", action, jingle->plugins().size() );
+      }
+      else
+        m_result = true;
+      break;
+  }
+
+}
+
+void TestInitiator::send( Tag* tag )
+{
+  IQ iq( tag );
+  m_sef.addExtensions( iq, tag );
+  m_sm.handleIq( iq );
+}
+
+
+// ------------------------------------------------------------------------------------------------------------
+
+
+
+// ------------------------------------------------------------------------------------------------------------
+
+
+int main( int /*argc*/, char** /*argv*/ )
+{
+  int fail = 0;
+  std::string name;
+  TestInitiator ini;
+  Tag* i = new Tag( "iq" ); i->addAttribute( "from", "me@there" ); i->addAttribute( "to", "you@here" ); i->addAttribute( "type", "set" ); i->addAttribute( "id", "someid" );
+  Tag* j = new Tag( i, "jingle", XMLNS, XMLNS_JINGLE );
+  Tag* c = 0;
+
+  // -------
+  name = "invalid jingle";
+  ini.setTest( 1 );
+  ini.send( i );
+  if( !ini.checkResult() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "jingle with empty content";
+  ini.setTest( 2 );
+  j->addAttribute( "action", "session-initiate" );
+  c = new Tag( j, "content" ); c->addAttribute( "creator", "initor" ); c->addAttribute( "name", "stub" );
+  ini.send( i );
+  if( !ini.checkResult() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "jingle with content and transport";
+  ini.setTest( 3 );
+  c->addAttribute( "name", "iceudp" );
+  Tag* t = new Tag( c, "transport", XMLNS, XMLNS_JINGLE_ICE_UDP ); t->addAttribute( "pwd", "pwd" ); t->addAttribute( "ufrag", "ufrag" );
+  ini.send( i );
+  if( !ini.checkResult() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+  // -------
+  name = "jingle with content and transport + description";
+  ini.setTest( 4 );
+  c->addAttribute( "name", "ft" );
+  Tag* d = new Tag( c, "description", XMLNS, XMLNS_JINGLE_FILE_TRANSFER ); new Tag( new Tag( d, "offer" ), "file" );
+  ini.send( i );
+  if( !ini.checkResult() )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
+  }
+
+
+
+  delete i;
+
+
+  if( fail == 0 )
+  {
+    printf( "Jingle::SessionManager: OK\n" );
+    return 0;
+  }
+  else
+  {
+    fprintf( stderr, "Jingle::SessionManager: %d test(s) failed\n", fail );
+    return 1;
+  }
+
+}

=== modified file 'src/tests/lastactivity/Makefile.in'
--- src/tests/lastactivity/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/lastactivity/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(lastactivity_test_SOURCES)
 DIST_SOURCES = $(lastactivity_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -250,7 +276,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-lastactivity_test$(EXEEXT): $(lastactivity_test_OBJECTS) $(lastactivity_test_DEPENDENCIES) 
+lastactivity_test$(EXEEXT): $(lastactivity_test_OBJECTS) $(lastactivity_test_DEPENDENCIES) $(EXTRA_lastactivity_test_DEPENDENCIES) 
 	@rm -f lastactivity_test$(EXEEXT)
 	$(CXXLINK) $(lastactivity_test_OBJECTS) $(lastactivity_test_LDADD) $(LIBS)
 
@@ -385,10 +411,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/lastactivity/lastactivity_test.cpp'
--- src/tests/lastactivity/lastactivity_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/lastactivity/lastactivity_test.cpp	2014-01-16 10:42:06 +0000
@@ -102,7 +102,7 @@
   if( false )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -124,7 +124,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/lastactivityquery/Makefile.am'
--- src/tests/lastactivityquery/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/lastactivityquery/Makefile.am	2014-01-16 10:42:06 +0000
@@ -12,5 +12,5 @@
                         ../../iq.o ../../base64.o ../../dataformfieldcontainer.o \
                         ../../dataform.o ../../dataformfield.o \
                         ../../dataformitem.o ../../softwareversion.o \
-                        ../../dataformreported.o
+                        ../../dataformreported.o ../../mutex.o
 lastactivityquery_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/lastactivityquery/Makefile.in'
--- src/tests/lastactivityquery/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/lastactivityquery/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,7 @@
 	../../message.o ../../util.o ../../error.o ../../jid.o \
 	../../iq.o ../../base64.o ../../dataformfieldcontainer.o \
 	../../dataform.o ../../dataformfield.o ../../dataformitem.o \
-	../../softwareversion.o ../../dataformreported.o
+	../../softwareversion.o ../../dataformreported.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(lastactivityquery_test_SOURCES)
 DIST_SOURCES = $(lastactivityquery_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -203,7 +229,7 @@
                         ../../iq.o ../../base64.o ../../dataformfieldcontainer.o \
                         ../../dataform.o ../../dataformfield.o \
                         ../../dataformitem.o ../../softwareversion.o \
-                        ../../dataformreported.o
+                        ../../dataformreported.o ../../mutex.o
 
 lastactivityquery_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -249,7 +275,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-lastactivityquery_test$(EXEEXT): $(lastactivityquery_test_OBJECTS) $(lastactivityquery_test_DEPENDENCIES) 
+lastactivityquery_test$(EXEEXT): $(lastactivityquery_test_OBJECTS) $(lastactivityquery_test_DEPENDENCIES) $(EXTRA_lastactivityquery_test_DEPENDENCIES) 
 	@rm -f lastactivityquery_test$(EXEEXT)
 	$(CXXLINK) $(lastactivityquery_test_OBJECTS) $(lastactivityquery_test_LDADD) $(LIBS)
 
@@ -384,10 +410,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/lastactivityquery/lastactivityquery_test.cpp'
--- src/tests/lastactivityquery/lastactivityquery_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/lastactivityquery/lastactivityquery_test.cpp	2014-01-16 10:42:06 +0000
@@ -65,7 +65,7 @@
     if( false )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -80,7 +80,7 @@
     if( laq.seconds() != 123 || laq.status() != "foo" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
 
   // -------
@@ -89,7 +89,7 @@
     if( *t != *s )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     delete s;
@@ -111,7 +111,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -125,7 +125,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/md5/Makefile.in'
--- src/tests/md5/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/md5/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,6 +82,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(md5_test_SOURCES)
 DIST_SOURCES = $(md5_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -87,6 +109,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -96,6 +119,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -111,7 +135,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -141,6 +167,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -175,7 +202,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -238,7 +264,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-md5_test$(EXEEXT): $(md5_test_OBJECTS) $(md5_test_DEPENDENCIES) 
+md5_test$(EXEEXT): $(md5_test_OBJECTS) $(md5_test_DEPENDENCIES) $(EXTRA_md5_test_DEPENDENCIES) 
 	@rm -f md5_test$(EXEEXT)
 	$(CXXLINK) $(md5_test_OBJECTS) $(md5_test_LDADD) $(LIBS)
 
@@ -373,10 +399,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/md5/md5_test.cpp'
--- src/tests/md5/md5_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/md5/md5_test.cpp	2014-01-16 10:42:06 +0000
@@ -22,7 +22,7 @@
   {
     printf( "expect: d41d8cd98f00b204e9800998ecf8427e\n" );
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
   }
   md5.reset();
 
@@ -34,7 +34,7 @@
   {
     printf( "expect: 9e107d9d372bb6826bd81d3542a419d6\n" );
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
   }
   md5.reset();
 
@@ -46,7 +46,7 @@
   {
     printf( "expect: 1055d3e698d289f2af8663725127bd4b\n" );
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
   }
   md5.reset();
 
@@ -59,7 +59,7 @@
   {
     printf( "expect: 9e107d9d372bb6826bd81d3542a419d6\n" );
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
   }
   md5.reset();
 
@@ -75,7 +75,7 @@
   {
     printf( "expect: 9e107d9d372bb6826bd81d3542a419d6\n" );
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), md5.hex().c_str() );
   }
   md5.reset();
 
@@ -88,7 +88,7 @@
   }
   else
   {
-    printf( "MD5: %d test(s) failed\n", fail );
+    fprintf( stderr, "MD5: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/message/Makefile.in'
--- src/tests/message/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/message/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(message_test_SOURCES)
 DIST_SOURCES = $(message_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-message_test$(EXEEXT): $(message_test_OBJECTS) $(message_test_DEPENDENCIES) 
+message_test$(EXEEXT): $(message_test_OBJECTS) $(message_test_DEPENDENCIES) $(EXTRA_message_test_DEPENDENCIES) 
 	@rm -f message_test$(EXEEXT)
 	$(CXXLINK) $(message_test_OBJECTS) $(message_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/message/message_test.cpp'
--- src/tests/message/message_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/message/message_test.cpp	2014-01-16 10:42:06 +0000
@@ -30,7 +30,7 @@
       || i->id() != "id1" || i->body() != "the body" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -44,7 +44,7 @@
       || i->id() != "id1" || i->body() != "the body" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -58,7 +58,7 @@
       || i->id() != "id1" || i->body() != "the body" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -72,7 +72,7 @@
       || i->id() != "id1" || i->body() != "the body" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -86,7 +86,7 @@
       || i->id() != "id1" || i->body() != "the body" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -105,7 +105,7 @@
         || !i->hasChild( "subject", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -126,7 +126,7 @@
         || m.from() != "foo@bar.com" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -145,7 +145,7 @@
         || !i->hasChild( "subject", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -165,7 +165,7 @@
         || !i->hasChild( "subject", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
     i = 0;
@@ -197,7 +197,7 @@
    || i->subject( "fr" ) != "sujet" )
   {
     ++fail;
-    printf( "test '%s' failed: %s, %s, %s, %s, %s, %s, %s, %s\n", name.c_str(),
+    fprintf( stderr, "test '%s' failed: %s, %s, %s, %s, %s, %s, %s, %s\n", name.c_str(),
             i->body().c_str(),  i->body( "default" ).c_str(),
             i->body( "xyz" ).c_str(),  i->body( "fr" ).c_str(),
             i->subject().c_str(),  i->subject( "default" ).c_str(),
@@ -232,7 +232,7 @@
   }
   else
   {
-    printf( "Message: %d test(s) failed\n", fail );
+    fprintf( stderr, "Message: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/messageeventfilter/Makefile.in'
--- src/tests/messageeventfilter/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/messageeventfilter/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -69,6 +86,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(messageeventfilter_test_SOURCES)
 DIST_SOURCES = $(messageeventfilter_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -91,6 +113,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -100,6 +123,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -115,7 +139,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -145,6 +171,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -179,7 +206,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -246,7 +272,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-messageeventfilter_test$(EXEEXT): $(messageeventfilter_test_OBJECTS) $(messageeventfilter_test_DEPENDENCIES) 
+messageeventfilter_test$(EXEEXT): $(messageeventfilter_test_OBJECTS) $(messageeventfilter_test_DEPENDENCIES) $(EXTRA_messageeventfilter_test_DEPENDENCIES) 
 	@rm -f messageeventfilter_test$(EXEEXT)
 	$(CXXLINK) $(messageeventfilter_test_OBJECTS) $(messageeventfilter_test_LDADD) $(LIBS)
 
@@ -395,10 +421,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/messageeventfilter/messageeventfilter_test.cpp'
--- src/tests/messageeventfilter/messageeventfilter_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/messageeventfilter/messageeventfilter_test.cpp	2014-01-16 10:42:06 +0000
@@ -106,7 +106,7 @@
                          | gloox::MessageEventDisplayed | gloox::MessageEventComposing ) )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
     f = 0;
@@ -129,7 +129,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise offline event 2";
@@ -138,7 +138,7 @@
   if( ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise delivered event 1";
@@ -147,7 +147,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise delivered event 2";
@@ -156,7 +156,7 @@
   if( ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise displayed event 1";
@@ -165,7 +165,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise displayed event 2";
@@ -174,7 +174,7 @@
   if( ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise composing event 1";
@@ -183,7 +183,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise composing event 2";
@@ -192,7 +192,7 @@
   if( ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise cancel event 1";
@@ -201,7 +201,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "raise cancel event 2";
@@ -210,7 +210,7 @@
   if( !ms->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   delete f;
@@ -233,7 +233,7 @@
   }
   else
   {
-    printf( "MessageEventFilter: %d test(s) failed\n", fail );
+    fprintf( stderr, "MessageEventFilter: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/mucroommuc/Makefile.am'
--- src/tests/mucroommuc/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommuc/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,5 +18,6 @@
                         ../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
                         ../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
                         ../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-                        ../../softwareversion.o
+                        ../../softwareversion.o \
+                        ../../atomicrefcount.o
 mucroommuc_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/mucroommuc/Makefile.in'
--- src/tests/mucroommuc/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommuc/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,7 +82,7 @@
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o ../../mucroom.o \
 	../../delayeddelivery.o ../../mucmessagesession.o \
-	../../softwareversion.o
+	../../softwareversion.o ../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -81,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(mucroommuc_test_SOURCES)
 DIST_SOURCES = $(mucroommuc_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -103,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -112,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -127,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -157,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -191,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -220,7 +246,8 @@
                         ../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
                         ../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
                         ../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-                        ../../softwareversion.o
+                        ../../softwareversion.o \
+                        ../../atomicrefcount.o
 
 mucroommuc_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -266,7 +293,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-mucroommuc_test$(EXEEXT): $(mucroommuc_test_OBJECTS) $(mucroommuc_test_DEPENDENCIES) 
+mucroommuc_test$(EXEEXT): $(mucroommuc_test_OBJECTS) $(mucroommuc_test_DEPENDENCIES) $(EXTRA_mucroommuc_test_DEPENDENCIES) 
 	@rm -f mucroommuc_test$(EXEEXT)
 	$(CXXLINK) $(mucroommuc_test_OBJECTS) $(mucroommuc_test_LDADD) $(LIBS)
 
@@ -401,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/mucroommuc/mucroommuc_test.cpp'
--- src/tests/mucroommuc/mucroommuc_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommuc/mucroommuc_test.cpp	2014-01-16 10:42:06 +0000
@@ -27,7 +27,7 @@
     if( !t || t->xml() != "<x xmlns='" + XMLNS_MUC + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -42,7 +42,7 @@
                           "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -57,7 +57,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -72,7 +72,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -87,7 +87,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -103,7 +103,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -121,7 +121,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -131,7 +131,7 @@
   if( !fail )
     printf( "OK\n" );
   else
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
 
   return fail;
 }

=== modified file 'src/tests/mucroommucadmin/Makefile.am'
--- src/tests/mucroommucadmin/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucadmin/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,5 +18,6 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 mucroommucadmin_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/mucroommucadmin/Makefile.in'
--- src/tests/mucroommucadmin/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucadmin/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,7 +82,7 @@
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o ../../mucroom.o \
 	../../delayeddelivery.o ../../mucmessagesession.o \
-	../../softwareversion.o
+	../../softwareversion.o ../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -81,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(mucroommucadmin_test_SOURCES)
 DIST_SOURCES = $(mucroommucadmin_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -103,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -112,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -127,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -157,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -191,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -220,7 +246,8 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 mucroommucadmin_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -266,7 +293,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-mucroommucadmin_test$(EXEEXT): $(mucroommucadmin_test_OBJECTS) $(mucroommucadmin_test_DEPENDENCIES) 
+mucroommucadmin_test$(EXEEXT): $(mucroommucadmin_test_OBJECTS) $(mucroommucadmin_test_DEPENDENCIES) $(EXTRA_mucroommucadmin_test_DEPENDENCIES) 
 	@rm -f mucroommucadmin_test$(EXEEXT)
 	$(CXXLINK) $(mucroommucadmin_test_OBJECTS) $(mucroommucadmin_test_LDADD) $(LIBS)
 
@@ -401,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/mucroommucadmin/mucroommucadmin_test.cpp'
--- src/tests/mucroommucadmin/mucroommucadmin_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucadmin/mucroommucadmin_test.cpp	2014-01-16 10:42:06 +0000
@@ -29,7 +29,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -45,7 +45,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -61,7 +61,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -77,7 +77,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -93,7 +93,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -109,7 +109,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -125,7 +125,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -141,7 +141,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -157,7 +157,7 @@
          "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -172,7 +172,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -187,7 +187,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -202,7 +202,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -217,7 +217,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -236,7 +236,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -255,7 +255,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -274,7 +274,7 @@
     if( !t || q != *t )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -291,7 +291,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -300,7 +300,7 @@
   if( !fail )
     printf( "OK\n" );
   else
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
 
   return fail;
 }

=== modified file 'src/tests/mucroommucowner/Makefile.am'
--- src/tests/mucroommucowner/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucowner/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,5 +18,6 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 mucroommucowner_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/mucroommucowner/Makefile.in'
--- src/tests/mucroommucowner/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucowner/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,7 +82,7 @@
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o ../../mucroom.o \
 	../../delayeddelivery.o ../../mucmessagesession.o \
-	../../softwareversion.o
+	../../softwareversion.o ../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -81,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(mucroommucowner_test_SOURCES)
 DIST_SOURCES = $(mucroommucowner_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -103,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -112,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -127,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -157,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -191,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -220,7 +246,8 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 mucroommucowner_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -266,7 +293,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-mucroommucowner_test$(EXEEXT): $(mucroommucowner_test_OBJECTS) $(mucroommucowner_test_DEPENDENCIES) 
+mucroommucowner_test$(EXEEXT): $(mucroommucowner_test_OBJECTS) $(mucroommucowner_test_DEPENDENCIES) $(EXTRA_mucroommucowner_test_DEPENDENCIES) 
 	@rm -f mucroommucowner_test$(EXEEXT)
 	$(CXXLINK) $(mucroommucowner_test_OBJECTS) $(mucroommucowner_test_LDADD) $(LIBS)
 
@@ -401,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/mucroommucowner/mucroommucowner_test.cpp'
--- src/tests/mucroommucowner/mucroommucowner_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucowner/mucroommucowner_test.cpp	2014-01-16 10:42:06 +0000
@@ -26,7 +26,7 @@
     if( !t || t->xml() != "<query xmlns='" + XMLNS_MUC_OWNER + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -41,7 +41,7 @@
                           "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -56,7 +56,7 @@
                           "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -71,7 +71,7 @@
                           "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -88,7 +88,7 @@
                             "</destroy></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -102,7 +102,7 @@
          "<destroy/></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -117,7 +117,7 @@
     if( !t || *t != *d )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     delete d;
@@ -137,7 +137,7 @@
     if( !t || *t != *d )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     delete d;
@@ -155,7 +155,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -164,7 +164,7 @@
   if( !fail )
     printf( "OK\n" );
   else
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
 
   return fail;
 }

=== modified file 'src/tests/mucroommucuser/Makefile.am'
--- src/tests/mucroommucuser/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucuser/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,5 +18,6 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 mucroommucuser_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/mucroommucuser/Makefile.in'
--- src/tests/mucroommucuser/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucuser/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,7 +82,7 @@
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o ../../mucroom.o \
 	../../delayeddelivery.o ../../mucmessagesession.o \
-	../../softwareversion.o
+	../../softwareversion.o ../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -81,6 +98,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(mucroommucuser_test_SOURCES)
 DIST_SOURCES = $(mucroommucuser_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -103,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -112,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -127,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -157,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -191,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -220,7 +246,8 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 mucroommucuser_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -266,7 +293,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-mucroommucuser_test$(EXEEXT): $(mucroommucuser_test_OBJECTS) $(mucroommucuser_test_DEPENDENCIES) 
+mucroommucuser_test$(EXEEXT): $(mucroommucuser_test_OBJECTS) $(mucroommucuser_test_DEPENDENCIES) $(EXTRA_mucroommucuser_test_DEPENDENCIES) 
 	@rm -f mucroommucuser_test$(EXEEXT)
 	$(CXXLINK) $(mucroommucuser_test_OBJECTS) $(mucroommucuser_test_LDADD) $(LIBS)
 
@@ -401,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/mucroommucuser/mucroommucuser_test.cpp'
--- src/tests/mucroommucuser/mucroommucuser_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/mucroommucuser/mucroommucuser_test.cpp	2014-01-16 10:42:06 +0000
@@ -34,7 +34,7 @@
                           "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     delete x;
@@ -68,7 +68,7 @@
     if( !t || *t != *x )
     {
       ++fail;
-      printf( "test '%s' failed:\n%s\n%s\n", name.c_str(), x->xml().c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:\n%s\n%s\n", name.c_str(), x->xml().c_str(), t->xml().c_str() );
     }
     delete t;
     delete x;
@@ -87,7 +87,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -105,7 +105,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -131,7 +131,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     delete x;
@@ -149,7 +149,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -166,7 +166,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
   }
@@ -188,7 +188,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     delete x;
@@ -213,7 +213,7 @@
          "</x>" )
     {
       ++fail;
-      printf( "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s \n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     delete x;
@@ -232,7 +232,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -250,7 +250,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -260,7 +260,7 @@
   if( !fail )
     printf( "OK\n" );
   else
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
 
   return fail;
 }

=== modified file 'src/tests/nickname/Makefile.in'
--- src/tests/nickname/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/nickname/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -66,6 +83,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(nickname_test_SOURCES)
 DIST_SOURCES = $(nickname_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -88,6 +110,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -97,6 +120,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -112,7 +136,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -142,6 +168,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -176,7 +203,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -239,7 +265,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-nickname_test$(EXEEXT): $(nickname_test_OBJECTS) $(nickname_test_DEPENDENCIES) 
+nickname_test$(EXEEXT): $(nickname_test_OBJECTS) $(nickname_test_DEPENDENCIES) $(EXTRA_nickname_test_DEPENDENCIES) 
 	@rm -f nickname_test$(EXEEXT)
 	$(CXXLINK) $(nickname_test_OBJECTS) $(nickname_test_LDADD) $(LIBS)
 
@@ -374,10 +400,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/nickname/nickname_test.cpp'
--- src/tests/nickname/nickname_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/nickname/nickname_test.cpp	2014-01-16 10:42:06 +0000
@@ -20,7 +20,7 @@
     if( !n.nick().empty() || n.tag() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -32,7 +32,7 @@
     if( n.nick() != "foo" || !t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -45,7 +45,7 @@
     if( t->xml() != "<nick xmlns='http://jabber.org/protocol/nick'>foo</nick>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -59,7 +59,7 @@
   }
   else
   {
-    printf( "Nickname: %d test(s) failed\n", fail );
+    fprintf( stderr, "Nickname: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/nonsaslauth/Makefile.in'
--- src/tests/nonsaslauth/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/nonsaslauth/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(nonsaslauth_test_SOURCES)
 DIST_SOURCES = $(nonsaslauth_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-nonsaslauth_test$(EXEEXT): $(nonsaslauth_test_OBJECTS) $(nonsaslauth_test_DEPENDENCIES) 
+nonsaslauth_test$(EXEEXT): $(nonsaslauth_test_OBJECTS) $(nonsaslauth_test_DEPENDENCIES) $(EXTRA_nonsaslauth_test_DEPENDENCIES) 
 	@rm -f nonsaslauth_test$(EXEEXT)
 	$(CXXLINK) $(nonsaslauth_test_OBJECTS) $(nonsaslauth_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/nonsaslauth/nonsaslauth_test.cpp'
--- src/tests/nonsaslauth/nonsaslauth_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/nonsaslauth/nonsaslauth_test.cpp	2014-01-16 10:42:06 +0000
@@ -176,7 +176,7 @@
     if( nsat->checkResult() != 4 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -188,7 +188,7 @@
     if( nsat->checkResult() != 5 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -204,7 +204,7 @@
   }
   else
   {
-    printf( "NonSaslAuth: %d test(s) failed\n", fail );
+    fprintf( stderr, "NonSaslAuth: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/nonsaslauthquery/Makefile.am'
--- src/tests/nonsaslauthquery/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/nonsaslauthquery/Makefile.am	2014-01-16 10:42:06 +0000
@@ -10,5 +10,5 @@
 nonsaslauthquery_test_SOURCES = nonsaslauthquery_test.cpp
 nonsaslauthquery_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../iq.o ../../base64.o ../../sha.o ../../stanzaextensionfactory.o
+			../../iq.o ../../base64.o ../../sha.o ../../stanzaextensionfactory.o ../../mutex.o
 nonsaslauthquery_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/nonsaslauthquery/Makefile.in'
--- src/tests/nonsaslauthquery/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/nonsaslauthquery/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -52,7 +69,7 @@
 nonsaslauthquery_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
 	../../prep.o ../../gloox.o ../../message.o ../../util.o \
 	../../error.o ../../jid.o ../../iq.o ../../base64.o \
-	../../sha.o ../../stanzaextensionfactory.o
+	../../sha.o ../../stanzaextensionfactory.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(nonsaslauthquery_test_SOURCES)
 DIST_SOURCES = $(nonsaslauthquery_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -198,7 +224,7 @@
 nonsaslauthquery_test_SOURCES = nonsaslauthquery_test.cpp
 nonsaslauthquery_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o \
 			../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-			../../iq.o ../../base64.o ../../sha.o ../../stanzaextensionfactory.o
+			../../iq.o ../../base64.o ../../sha.o ../../stanzaextensionfactory.o ../../mutex.o
 
 nonsaslauthquery_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-nonsaslauthquery_test$(EXEEXT): $(nonsaslauthquery_test_OBJECTS) $(nonsaslauthquery_test_DEPENDENCIES) 
+nonsaslauthquery_test$(EXEEXT): $(nonsaslauthquery_test_OBJECTS) $(nonsaslauthquery_test_DEPENDENCIES) $(EXTRA_nonsaslauthquery_test_DEPENDENCIES) 
 	@rm -f nonsaslauthquery_test$(EXEEXT)
 	$(CXXLINK) $(nonsaslauthquery_test_OBJECTS) $(nonsaslauthquery_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/nonsaslauthquery/nonsaslauthquery_test.cpp'
--- src/tests/nonsaslauthquery/nonsaslauthquery_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/nonsaslauthquery/nonsaslauthquery_test.cpp	2014-01-16 10:42:06 +0000
@@ -89,7 +89,7 @@
                           "<username>user</username></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -113,7 +113,7 @@
                           "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete nq;
     delete q;
@@ -143,7 +143,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete nq;
     delete q;
@@ -164,7 +164,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -177,7 +177,7 @@
   }
   else
   {
-    printf( "NonSaslAuth::Query: %d test(s) failed\n", fail );
+    fprintf( stderr, "NonSaslAuth::Query: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/oob/Makefile.am'
--- src/tests/oob/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/oob/Makefile.am	2014-01-16 10:42:06 +0000
@@ -8,5 +8,5 @@
 
 oob_test_SOURCES = oob_test.cpp
 oob_test_LDADD = ../../oob.o ../../tag.o ../../gloox.o ../../iq.o ../../stanzaextensionfactory.o \
-                 ../../stanza.o ../../util.o ../../jid.o ../../prep.o
+                 ../../stanza.o ../../util.o ../../jid.o ../../prep.o ../../mutex.o
 oob_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/oob/Makefile.in'
--- src/tests/oob/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/oob/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -51,7 +68,7 @@
 oob_test_OBJECTS = $(am_oob_test_OBJECTS)
 oob_test_DEPENDENCIES = ../../oob.o ../../tag.o ../../gloox.o \
 	../../iq.o ../../stanzaextensionfactory.o ../../stanza.o \
-	../../util.o ../../jid.o ../../prep.o
+	../../util.o ../../jid.o ../../prep.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(oob_test_SOURCES)
 DIST_SOURCES = $(oob_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -196,7 +222,7 @@
 AM_CPPFLAGS = -pedantic -Wall -pipe -W -Wfloat-equal -Wcast-align -Wsign-compare -Wpointer-arith -Wswitch -Wunknown-pragmas -Wconversion -Wundef -Wcast-qual 
 oob_test_SOURCES = oob_test.cpp
 oob_test_LDADD = ../../oob.o ../../tag.o ../../gloox.o ../../iq.o ../../stanzaextensionfactory.o \
-                 ../../stanza.o ../../util.o ../../jid.o ../../prep.o
+                 ../../stanza.o ../../util.o ../../jid.o ../../prep.o ../../mutex.o
 
 oob_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-oob_test$(EXEEXT): $(oob_test_OBJECTS) $(oob_test_DEPENDENCIES) 
+oob_test$(EXEEXT): $(oob_test_OBJECTS) $(oob_test_DEPENDENCIES) $(EXTRA_oob_test_DEPENDENCIES) 
 	@rm -f oob_test$(EXEEXT)
 	$(CXXLINK) $(oob_test_OBJECTS) $(oob_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/oob/oob_test.cpp'
--- src/tests/oob/oob_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/oob/oob_test.cpp	2014-01-16 10:42:06 +0000
@@ -22,7 +22,7 @@
   if( d->tag() != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -42,7 +42,7 @@
   if( d->url() != "invalidurl" || d->desc() != "description" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -56,7 +56,7 @@
        || !t->hasChild( "desc" ) || t->findChild( "desc" )->cdata() != "description")
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -69,7 +69,7 @@
   if( d->url() != "invalidurl" || d->desc() != "description" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -83,7 +83,7 @@
        || !t->hasChild( "desc" ) || t->findChild( "desc" )->cdata() != "description")
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -109,7 +109,7 @@
   if( d->url() != "invalidurl" || d->desc() != "description" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -123,7 +123,7 @@
        || !t->hasChild( "desc" ) || t->findChild( "desc" )->cdata() != "description")
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -136,7 +136,7 @@
   if( d->url() != "invalidurl" || d->desc() != "description" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -150,7 +150,7 @@
        || !t->hasChild( "desc" ) || t->findChild( "desc" )->cdata() != "description")
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -178,7 +178,7 @@
   if( se == 0 || se->url() != "url" || se->desc() != "desc" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -190,7 +190,7 @@
   }
   else
   {
-    printf( "OOB: %d test(s) failed\n", fail );
+    fprintf( stderr, "OOB: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/parser/Makefile.in'
--- src/tests/parser/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/parser/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -66,6 +83,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(parser_test_SOURCES)
 DIST_SOURCES = $(parser_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -88,6 +110,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -97,6 +120,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -112,7 +136,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -142,6 +168,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -176,7 +203,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -239,7 +265,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-parser_test$(EXEEXT): $(parser_test_OBJECTS) $(parser_test_DEPENDENCIES) 
+parser_test$(EXEEXT): $(parser_test_OBJECTS) $(parser_test_DEPENDENCIES) $(EXTRA_parser_test_DEPENDENCIES) 
 	@rm -f parser_test$(EXEEXT)
 	$(CXXLINK) $(parser_test_OBJECTS) $(parser_test_LDADD) $(LIBS)
 
@@ -374,10 +400,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/parser/parser_test.cpp'
--- src/tests/parser/parser_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/parser/parser_test.cpp	2014-01-16 10:42:06 +0000
@@ -43,7 +43,7 @@
       if( m_tag == 0 || m_tag->name() != "tag" )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -55,7 +55,7 @@
       if( m_tag == 0 || m_tag->name() != "tag1" || !m_tag->hasChild( "child" ) )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -70,7 +70,7 @@
             !m_tag->hasChild( "child" ) )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -96,7 +96,7 @@
       if( tfail )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
         tfail = false;
       }
       delete m_tag;
@@ -111,7 +111,7 @@
             m_tag->cdata() != "cdata" )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -124,7 +124,7 @@
             m_tag->name() != "tag4" )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -137,7 +137,7 @@
             m_tag->name() != "tag4" )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -150,7 +150,7 @@
             m_tag->name() != "tag4" )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -164,7 +164,7 @@
             !m_tag->hasChild( "child" ) )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -184,7 +184,7 @@
             !m_tag->hasAttribute( "xmlns", "jabber:client" ) )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
     //   printf( "stanza: %s\n", m_tag->xml().c_str() );
       delete m_tag;
@@ -200,7 +200,7 @@
             !m_tag->hasAttribute( "version", "1.0" )*/ )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
     //   printf( "stanza: %s\n", m_tag->xml().c_str() );
       delete m_tag;
@@ -215,7 +215,7 @@
             !m_tag->hasAttribute( "version", "1.0" )*/ )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
     //   printf( "stanza: %s\n", m_tag->xml().c_str() );
       delete m_tag;
@@ -227,7 +227,7 @@
       if( p->feed( data ) != 0 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
     //   printf( "stanza: %s\n", m_tag->xml().c_str() );
       delete m_tag;
@@ -268,7 +268,7 @@
       if( tfail )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
         printf( "got: %s\n", m_tag->xml().c_str() );
         tfail = false;
       }
@@ -282,7 +282,7 @@
       if( m_tag == 0 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -294,7 +294,7 @@
       if( m_tag == 0 || m_tag->xml() != data )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -306,7 +306,79 @@
       if( m_tag == 0 || m_tag->xml() != data )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+      }
+      delete m_tag;
+      m_tag = 0;
+
+      // -------
+      name = "mixed content 4";
+      data = "<tag1><tag2>foo</tag2>&apos;<tag3>bar</tag3></tag1>";
+      p->feed( data );
+      if( m_tag == 0 || m_tag->xml() != data )
+      {
+        ++fail;
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+      }
+      delete m_tag;
+      m_tag = 0;
+
+      // -------
+      name = "mixed content 5";
+      data = "<tag1><tag2>foo</tag2>  <tag3>bar</tag3></tag1>";
+      p->feed( data );
+      if( m_tag == 0 || m_tag->xml() != data )
+      {
+        ++fail;
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+      }
+      delete m_tag;
+      m_tag = 0;
+
+      // -------
+      name = "mixed content 6";
+      data = "<tag1><tag2>foo</tag2>something<tag3>bar</tag3></tag1>";
+      p->feed( data );
+      if( m_tag == 0 || m_tag->xml() != data )
+      {
+        ++fail;
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+      }
+      delete m_tag;
+      m_tag = 0;
+
+      // -------
+      name = "mixed content 7";
+      data = "<tag1><tag2>foo</tag2>something<tag3>bar</tag3>somethingelse<tag4>bar</tag4></tag1>";
+      p->feed( data );
+      if( m_tag == 0 || m_tag->xml() != data )
+      {
+        ++fail;
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+      }
+      delete m_tag;
+      m_tag = 0;
+
+      // -------
+      name = "mixed content 8";
+      data = "<tag1><tag2>foo</tag2>some&apos;thing<tag3>bar</tag3>something&amp;else<tag4>bar</tag4></tag1>";
+      p->feed( data );
+      if( m_tag == 0 || m_tag->xml() != data )
+      {
+        ++fail;
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
+      }
+      delete m_tag;
+      m_tag = 0;
+
+      // -------
+      name = "mixed content 9";
+      data = "<tag1><tag2>foo</tag2>&apos;thing<tag3>bar</tag3>something&amp;else<tag4>bar</tag4>&quot;<tag5>bar</tag5></tag1>";
+      p->feed( data );
+      if( m_tag == 0 || m_tag->xml() != data )
+      {
+        ++fail;
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -318,7 +390,7 @@
       if( m_tag == 0 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -329,7 +401,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
 
       // -------
@@ -338,7 +410,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
 
       // -------
@@ -347,7 +419,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
 
       // -------
@@ -356,7 +428,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
 
       // -------
@@ -366,7 +438,7 @@
       if( !m_tag )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -378,7 +450,7 @@
       if( !m_tag )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -389,7 +461,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
 
       // -------
@@ -399,7 +471,7 @@
       if( !m_tag )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -411,7 +483,7 @@
       if( !m_tag )
       {
         ++fail;
-        printf( "test '%s: %s' failed\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s: %s' failed\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -424,7 +496,7 @@
       if( ( i = p->feed( data ) ) >= 0 || m_tags.size() != 3 )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       m_multiple = false;
 //       util::clearList( m_tags );
@@ -448,7 +520,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "abcdefg" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -461,7 +533,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "123abcdefg456" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -473,7 +545,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "abc&amp;&&lt;]]defg" )
       {
         ++fail;
-        printf( "test '%s' failed: %s\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -485,13 +557,13 @@
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "TA[abc&amp;&&lt;]]defg]]></tag1>";
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "abc&amp;&&lt;]]defg" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -503,20 +575,20 @@
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "DA";
       i = -1;
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "TA[abc&amp;&&lt;]]defg]]></tag1>";
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "abc&amp;&&lt;]]defg" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -528,20 +600,20 @@
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "TA[abc&amp;&&lt;]]defg]";
       i = -1;
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "]></tag1>";
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "abc&amp;&&lt;]]defg" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -553,13 +625,13 @@
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "p;</tag1>";
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "&" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -571,20 +643,20 @@
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "m";
       i = -1;
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "p;</tag1>";
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "&" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -596,20 +668,20 @@
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = "5";
       i = -1;
       if( ( i = p->feed( data ) ) >= 0 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       data = ";</tag1>";
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "A" )
       {
         ++fail;
-        printf( "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
+        fprintf( stderr, "test '%s' failed at pos %d: %s\n", name.c_str(), i, data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -620,7 +692,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -631,7 +703,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s\n", name.c_str(), data.c_str() );
+        fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), data.c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -642,7 +714,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -653,7 +725,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -664,7 +736,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -675,7 +747,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -686,7 +758,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -697,7 +769,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -708,7 +780,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -719,7 +791,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -730,7 +802,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -741,7 +813,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -752,7 +824,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -763,7 +835,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -774,7 +846,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -785,7 +857,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -796,7 +868,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -807,7 +879,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -818,7 +890,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -829,7 +901,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -840,7 +912,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -851,7 +923,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -862,7 +934,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -873,7 +945,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -884,7 +956,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -895,7 +967,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -906,7 +978,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -917,7 +989,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -928,7 +1000,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -939,7 +1011,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -950,7 +1022,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -961,7 +1033,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -972,7 +1044,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -983,7 +1055,7 @@
       if( p->feed( data ) == -1 )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -994,7 +1066,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "<" )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1005,7 +1077,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != ">" )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1016,7 +1088,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "'" )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1027,7 +1099,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "&" )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1038,7 +1110,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "\"" )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1049,7 +1121,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "ሴ><'&\"" )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1060,7 +1132,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "ሴC\"+" )
       {
         ++fail;
-        printf( "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: %s -- %s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1072,7 +1144,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->cdata() != "&<>'\"  <>'\"  <><>'\"  <><>'\"" )
       {
         ++fail;
-        printf( "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1084,7 +1156,7 @@
             || m_tag->attributes().front()->xmlns() != "foobar" )
       {
         ++fail;
-        printf( "test '%s' failed: \n%s\n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str(),
+        fprintf( stderr, "test '%s' failed: \n%s\n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str(),
                 m_tag->attributes().front()->xmlns().c_str() );
       }
       delete m_tag;
@@ -1096,7 +1168,7 @@
       if( ( i = p->feed( data ) ) == -1 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1108,7 +1180,7 @@
             || m_tag->xmlns() != "foobar" )
       {
         ++fail;
-        printf( "test '%s' failed (%d): \n%s\n", name.c_str(), i, data.c_str()/*, m_tag->xml().c_str()*/ );
+        fprintf( stderr, "test '%s' failed (%d): \n%s\n", name.c_str(), i, data.c_str()/*, m_tag->xml().c_str()*/ );
       }
       delete m_tag;
       m_tag = 0;
@@ -1119,7 +1191,7 @@
       if( ( i = p->feed( data ) ) == -1 || m_tag )
       {
         ++fail;
-        printf( "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1130,7 +1202,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->xmlns() != "foobar" )
       {
         ++fail;
-        printf( "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1141,7 +1213,7 @@
       if( ( i = p->feed( data ) ) >= 0 || !m_tag || m_tag->xmlns( "foo" ) != "bar" )
       {
         ++fail;
-        printf( "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed: \n%s\n%s\n", name.c_str(), data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1158,7 +1230,7 @@
             || m_tag->xml() != data )
       {
         ++fail;
-        printf( "test '%s' failed (%d): \n%s\n%s\n", name.c_str(), i, data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed (%d): \n%s\n%s\n", name.c_str(), i, data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1178,7 +1250,7 @@
             || m_tag->children().front()->children().front()->xmlns() != "ggg" )
       {
         ++fail;
-        printf( "test '%s' failed (%d): \n%s\n%s\n", name.c_str(), i, data.c_str(), m_tag->xml().c_str() );
+        fprintf( stderr, "test '%s' failed (%d): \n%s\n%s\n", name.c_str(), i, data.c_str(), m_tag->xml().c_str() );
       }
       delete m_tag;
       m_tag = 0;
@@ -1194,7 +1266,7 @@
       if( ( i = p->feed( data ) ) < 0 )
       {
         ++fail;
-        printf( "test '%s' failed (%d)", name.c_str(), i );
+        fprintf( stderr, "test '%s' failed (%d)", name.c_str(), i );
       }
       delete m_tag;
       m_tag = 0;
@@ -1231,7 +1303,7 @@
       }
       else
       {
-        printf( "Parser: %d test(s) failed\n", fail );
+        fprintf( stderr, "Parser: %d test(s) failed\n", fail );
         return 1;
       }
 

=== modified file 'src/tests/prep/Makefile.in'
--- src/tests/prep/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/prep/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,6 +82,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(prep_test_SOURCES)
 DIST_SOURCES = $(prep_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -87,6 +109,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -96,6 +119,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -111,7 +135,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -141,6 +167,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -175,7 +202,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -238,7 +264,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-prep_test$(EXEEXT): $(prep_test_OBJECTS) $(prep_test_DEPENDENCIES) 
+prep_test$(EXEEXT): $(prep_test_OBJECTS) $(prep_test_DEPENDENCIES) $(EXTRA_prep_test_DEPENDENCIES) 
 	@rm -f prep_test$(EXEEXT)
 	$(CXXLINK) $(prep_test_OBJECTS) $(prep_test_LDADD) $(LIBS)
 
@@ -373,10 +399,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/prep/prep_test.cpp'
--- src/tests/prep/prep_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/prep/prep_test.cpp	2014-01-16 10:42:06 +0000
@@ -18,7 +18,7 @@
   if( prep::nodeprep( t, result ) || !result.empty() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -27,7 +27,7 @@
   if( prep::resourceprep( t, result ) || !result.empty() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -36,7 +36,7 @@
   if( prep::nameprep( t, result ) || !result.empty() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -45,7 +45,7 @@
   if( prep::idna( t, result ) || !result.empty() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -55,7 +55,7 @@
   if( !( prep::nodeprep( t1, result ) && result == t1 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -64,7 +64,7 @@
   if( !( prep::resourceprep( t1, result ) && result == t1 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -73,7 +73,7 @@
   if( !( prep::nameprep( t1, result ) && result == t1 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -82,7 +82,7 @@
   if( !( prep::idna( t1, result ) && result == t1 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -93,7 +93,7 @@
   if( !( prep::nodeprep( t2, result ) && result == t3 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -102,7 +102,7 @@
   if( !( prep::resourceprep( t2, result ) && result == t2 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -111,7 +111,7 @@
   if( !( prep::nameprep( t2, result ) && result == t3 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -120,7 +120,7 @@
   if( !( prep::idna( "www.dömäin.de", result ) && result == "www.xn--dmin-moa0i.de" ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   result = "";
 
@@ -142,7 +142,7 @@
   }
   else
   {
-    printf( "Prep: %d test(s) failed\n", fail );
+    fprintf( stderr, "Prep: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/presence/Makefile.in'
--- src/tests/presence/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/presence/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(presence_test_SOURCES)
 DIST_SOURCES = $(presence_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-presence_test$(EXEEXT): $(presence_test_OBJECTS) $(presence_test_DEPENDENCIES) 
+presence_test$(EXEEXT): $(presence_test_OBJECTS) $(presence_test_DEPENDENCIES) $(EXTRA_presence_test_DEPENDENCIES) 
 	@rm -f presence_test$(EXEEXT)
 	$(CXXLINK) $(presence_test_OBJECTS) $(presence_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/presence/presence_test.cpp'
--- src/tests/presence/presence_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/presence/presence_test.cpp	2014-01-16 10:42:06 +0000
@@ -31,7 +31,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -45,7 +45,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -59,7 +59,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -73,7 +73,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -87,7 +87,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -103,7 +103,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -118,7 +118,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -133,7 +133,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -148,7 +148,7 @@
       || i->status() != "the status" || i->priority() != 10 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -167,7 +167,7 @@
         || i->hasAttribute( "type" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -185,7 +185,7 @@
         || !i->hasChild( "status", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -204,7 +204,7 @@
         || !i->hasChildWithCData( "show", "chat" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -223,7 +223,7 @@
         || !i->hasChildWithCData( "show", "away" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -242,7 +242,7 @@
         || !i->hasChildWithCData( "show", "dnd" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -261,7 +261,7 @@
         || !i->hasChildWithCData( "show", "xa" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -280,7 +280,7 @@
         || !i->hasChildWithCData( "priority", "10" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -299,7 +299,7 @@
         || !i->hasChildWithCData( "priority", "10" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -316,7 +316,7 @@
   }
   else
   {
-    printf( "Presence: %d test(s) failed\n", fail );
+    fprintf( stderr, "Presence: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/privacymanager/Makefile.in'
--- src/tests/privacymanager/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/privacymanager/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(privacymanager_test_SOURCES)
 DIST_SOURCES = $(privacymanager_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-privacymanager_test$(EXEEXT): $(privacymanager_test_OBJECTS) $(privacymanager_test_DEPENDENCIES) 
+privacymanager_test$(EXEEXT): $(privacymanager_test_OBJECTS) $(privacymanager_test_DEPENDENCIES) $(EXTRA_privacymanager_test_DEPENDENCIES) 
 	@rm -f privacymanager_test$(EXEEXT)
 	$(CXXLINK) $(privacymanager_test_OBJECTS) $(privacymanager_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/privacymanager/privacymanager_test.cpp'
--- src/tests/privacymanager/privacymanager_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/privacymanager/privacymanager_test.cpp	2014-01-16 10:42:06 +0000
@@ -50,11 +50,11 @@
       void setTest( int test );
       bool ok();
 
-      virtual void handlePrivacyListNames( const std::string& active, const std::string& def,
-                                           const StringList& lists ) {}
-      virtual void handlePrivacyList( const std::string& name, const PrivacyList& items ) {}
-      virtual void handlePrivacyListChanged( const std::string& name ) {}
-      virtual void handlePrivacyListResult( const std::string& id, PrivacyListResult plResult ) {}
+      virtual void handlePrivacyListNames( const std::string& /*active*/, const std::string& /*def*/,
+                                           const StringList& /*lists*/ ) {}
+      virtual void handlePrivacyList( const std::string& /*name*/, const PrivacyList& /*items*/ ) {}
+      virtual void handlePrivacyListChanged( const std::string& /*name*/ ) {}
+      virtual void handlePrivacyListResult( const std::string& /*id*/, PrivacyListResult /*plResult*/ ) {}
 
     private:
       Disco* m_disco;
@@ -108,7 +108,7 @@
   if( 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -126,7 +126,7 @@
   }
   else
   {
-    printf( "PrivacyManager: %d test(s) failed\n", fail );
+    fprintf( stderr, "PrivacyManager: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/privacymanagerquery/Makefile.am'
--- src/tests/privacymanagerquery/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/privacymanagerquery/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,5 +9,5 @@
 privacymanagerquery_test_SOURCES = privacymanagerquery_test.cpp
 privacymanagerquery_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
                         ../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-                        ../../iq.o ../../base64.o
+                        ../../iq.o ../../base64.o ../../mutex.o
 privacymanagerquery_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/privacymanagerquery/Makefile.in'
--- src/tests/privacymanagerquery/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/privacymanagerquery/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,7 @@
 privacymanagerquery_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
 	../../prep.o ../../stanzaextensionfactory.o ../../gloox.o \
 	../../message.o ../../util.o ../../error.o ../../jid.o \
-	../../iq.o ../../base64.o
+	../../iq.o ../../base64.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(privacymanagerquery_test_SOURCES)
 DIST_SOURCES = $(privacymanagerquery_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -200,7 +226,7 @@
 privacymanagerquery_test_SOURCES = privacymanagerquery_test.cpp
 privacymanagerquery_test_LDADD = ../../tag.o ../../stanza.o ../../prep.o ../../stanzaextensionfactory.o \
                         ../../gloox.o ../../message.o ../../util.o ../../error.o ../../jid.o \
-                        ../../iq.o ../../base64.o
+                        ../../iq.o ../../base64.o ../../mutex.o
 
 privacymanagerquery_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -246,7 +272,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-privacymanagerquery_test$(EXEEXT): $(privacymanagerquery_test_OBJECTS) $(privacymanagerquery_test_DEPENDENCIES) 
+privacymanagerquery_test$(EXEEXT): $(privacymanagerquery_test_OBJECTS) $(privacymanagerquery_test_DEPENDENCIES) $(EXTRA_privacymanagerquery_test_DEPENDENCIES) 
 	@rm -f privacymanagerquery_test$(EXEEXT)
 	$(CXXLINK) $(privacymanagerquery_test_OBJECTS) $(privacymanagerquery_test_LDADD) $(LIBS)
 
@@ -381,10 +407,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/privacymanagerquery/privacymanagerquery_test.cpp'
--- src/tests/privacymanagerquery/privacymanagerquery_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/privacymanagerquery/privacymanagerquery_test.cpp	2014-01-16 10:42:06 +0000
@@ -64,7 +64,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -80,7 +80,7 @@
          || ibb.type() != InBandBytestream::IBBOpen)
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -98,7 +98,7 @@
          || ibb.type() != InBandBytestream::IBBData )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -114,7 +114,7 @@
          || ibb.type() != InBandBytestream::IBBClose )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -133,7 +133,7 @@
         || !ibb.data().empty() || ibb.type() != InBandBytestream::IBBOpen )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -154,7 +154,7 @@
         || ibb.blocksize() != 0 || ibb.type() != InBandBytestream::IBBData )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -174,7 +174,7 @@
          || ibb.type() != InBandBytestream::IBBClose )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -194,7 +194,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -210,7 +210,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -226,7 +226,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -238,7 +238,7 @@
   }
   else
   {
-    printf( "InBandBytestream::IBB: %d test(s) failed\n", fail );
+    fprintf( stderr, "InBandBytestream::IBB: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/privatexml/Makefile.am'
--- src/tests/privatexml/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/privatexml/Makefile.am	2014-01-16 10:42:06 +0000
@@ -10,6 +10,6 @@
 privatexml_test_LDADD = ../../gloox.o ../../tag.o \
                   ../../util.o ../../stanza.o ../../message.o \
                   ../../jid.o ../../prep.o \
-                  ../../stanzaextensionfactory.o ../../iq.o
+                  ../../stanzaextensionfactory.o ../../iq.o ../../mutex.o
 
 privatexml_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/privatexml/Makefile.in'
--- src/tests/privatexml/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/privatexml/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -51,7 +68,7 @@
 privatexml_test_OBJECTS = $(am_privatexml_test_OBJECTS)
 privatexml_test_DEPENDENCIES = ../../gloox.o ../../tag.o ../../util.o \
 	../../stanza.o ../../message.o ../../jid.o ../../prep.o \
-	../../stanzaextensionfactory.o ../../iq.o
+	../../stanzaextensionfactory.o ../../iq.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(privatexml_test_SOURCES)
 DIST_SOURCES = $(privatexml_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -198,7 +224,7 @@
 privatexml_test_LDADD = ../../gloox.o ../../tag.o \
                   ../../util.o ../../stanza.o ../../message.o \
                   ../../jid.o ../../prep.o \
-                  ../../stanzaextensionfactory.o ../../iq.o
+                  ../../stanzaextensionfactory.o ../../iq.o ../../mutex.o
 
 privatexml_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-privatexml_test$(EXEEXT): $(privatexml_test_OBJECTS) $(privatexml_test_DEPENDENCIES) 
+privatexml_test$(EXEEXT): $(privatexml_test_OBJECTS) $(privatexml_test_DEPENDENCIES) $(EXTRA_privatexml_test_DEPENDENCIES) 
 	@rm -f privatexml_test$(EXEEXT)
 	$(CXXLINK) $(privatexml_test_OBJECTS) $(privatexml_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/privatexml/privatexml_test.cpp'
--- src/tests/privatexml/privatexml_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/privatexml/privatexml_test.cpp	2014-01-16 10:42:06 +0000
@@ -126,7 +126,7 @@
         break;
     }
   }
-  void ClientBase::handlePrivateXMLResult( const std::string& uid, PrivateXMLResult pxResult )
+  void ClientBase::handlePrivateXMLResult( const std::string& /*uid*/, PrivateXMLResult pxResult )
   {
     switch( m_test )
     {
@@ -149,7 +149,6 @@
   t1 = new Tag( "foo" );
   t1->setXmlns( "test" );
   new Tag( t1, "foobar" );
-  Tag *t;
   ClientBase* cb = new ClientBase();
   PrivateXML px( cb );
 
@@ -161,7 +160,7 @@
     if( !cb->ok() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -173,7 +172,7 @@
     if( !cb->ok() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -190,7 +189,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -206,7 +205,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/pubsubevent/Makefile.in'
--- src/tests/pubsubevent/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/pubsubevent/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -69,6 +86,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(pubsubevent_test_SOURCES)
 DIST_SOURCES = $(pubsubevent_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -91,6 +113,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -100,6 +123,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -115,7 +139,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -145,6 +171,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -179,7 +206,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -247,7 +273,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-pubsubevent_test$(EXEEXT): $(pubsubevent_test_OBJECTS) $(pubsubevent_test_DEPENDENCIES) 
+pubsubevent_test$(EXEEXT): $(pubsubevent_test_OBJECTS) $(pubsubevent_test_DEPENDENCIES) $(EXTRA_pubsubevent_test_DEPENDENCIES) 
 	@rm -f pubsubevent_test$(EXEEXT)
 	$(CXXLINK) $(pubsubevent_test_OBJECTS) $(pubsubevent_test_LDADD) $(LIBS)
 
@@ -382,10 +408,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/pubsubevent/pubsubevent_test.cpp'
--- src/tests/pubsubevent/pubsubevent_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/pubsubevent/pubsubevent_test.cpp	2014-01-16 10:42:06 +0000
@@ -17,7 +17,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "items test failed\n" );
+    fprintf( stderr, "items test failed\n" );
   }
   delete tag;
   delete t;
@@ -40,7 +40,7 @@
     if( t )
       printf ( "%s\n", t->xml().c_str() );
       printf ( "%s\n", tag->xml().c_str() );
-    printf( "items from collection test failed\n" );
+    fprintf( stderr, "items from collection test failed\n" );
   }
   delete tag;
   delete t;
@@ -67,7 +67,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "items w/ payload test failed\n" );
+    fprintf( stderr, "items w/ payload test failed\n" );
   }
   delete tag;
   delete t;
@@ -89,7 +89,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "items w/ subscription id test failed\n" );
+    fprintf( stderr, "items w/ subscription id test failed\n" );
   }
   delete tag;
   delete t;
@@ -107,7 +107,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag || pse->type() != PubSub::EventItemsRetract )
   {
     ++failed;
-    printf( "retract test failed\n" );
+    fprintf( stderr, "retract test failed\n" );
   }
   delete pse;
   delete t;
@@ -124,7 +124,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "retract w/ subscription id test failed\n" );
+    fprintf( stderr, "retract w/ subscription id test failed\n" );
   }
   delete pse;
   delete t;
@@ -146,7 +146,7 @@
     ++failed;
     printf("t: %s\n", t->xml().c_str() );
     printf("tag: %s\n", tag->xml().c_str() );
-    printf( "'subscription successful' test failed\n" );
+    fprintf( stderr, "'subscription successful' test failed\n" );
   }
   delete pse;
   delete t;
@@ -164,7 +164,7 @@
       || pse->node() != "princely_musings" || pse->jid().full() != "foo@bar.com" || pse->subscription())
   {
     ++failed;
-    printf( "'subscription failed' test failed\n" );
+    fprintf( stderr, "'subscription failed' test failed\n" );
   }
   delete pse;
   delete t;
@@ -183,7 +183,7 @@
     if( tmp )
       printf( "t1: %s\n", tmp->xml().c_str() );
     printf( "t2: %s\n", tag->xml().c_str() );
-    printf( "configuration w/o payload failed\n" );
+    fprintf( stderr, "configuration w/o payload failed\n" );
   }
   delete tmp;
   delete pse;
@@ -205,7 +205,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "configuration w/ payload failed\n" );
+    fprintf( stderr, "configuration w/ payload failed\n" );
   }
   delete t;
   delete pse;
@@ -222,7 +222,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "delete node test failed\n" );
+    fprintf( stderr, "delete node test failed\n" );
   }
   delete pse;
   delete tag;
@@ -239,7 +239,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "purge node id test failed\n" );
+    fprintf( stderr, "purge node id test failed\n" );
   }
   delete pse;
   delete tag;
@@ -260,7 +260,7 @@
     if( tmp )
       printf( "t1: %s\n", tmp->xml().c_str() );
     printf( "t2: %s\n", tag->xml().c_str() );
-    printf( "collection test failed\n" );
+    fprintf( stderr, "collection test failed\n" );
   }
   delete tmp;
   delete pse;
@@ -281,7 +281,7 @@
   if( !pse || !(t = pse->tag()) || *t != *tag )
   {
     ++failed;
-    printf( "collection w/ payload failed\n" );
+    fprintf( stderr, "collection w/ payload failed\n" );
   }
   delete t;
   delete pse;
@@ -304,7 +304,7 @@
 
   if( failed )
   {
-    printf( "PubSub::Event: %d test(s) failed\n", failed );
+    fprintf( stderr, "PubSub::Event: %d test(s) failed\n", failed );
     return 1;
   }
   else

=== modified file 'src/tests/pubsubmanager/Makefile.in'
--- src/tests/pubsubmanager/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/pubsubmanager/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(pubsubmanager_test_SOURCES)
 DIST_SOURCES = $(pubsubmanager_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -254,7 +280,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-pubsubmanager_test$(EXEEXT): $(pubsubmanager_test_OBJECTS) $(pubsubmanager_test_DEPENDENCIES) 
+pubsubmanager_test$(EXEEXT): $(pubsubmanager_test_OBJECTS) $(pubsubmanager_test_DEPENDENCIES) $(EXTRA_pubsubmanager_test_DEPENDENCIES) 
 	@rm -f pubsubmanager_test$(EXEEXT)
 	$(CXXLINK) $(pubsubmanager_test_OBJECTS) $(pubsubmanager_test_LDADD) $(LIBS)
 
@@ -389,10 +415,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/pubsubmanager/pubsubmanager_test.cpp'
--- src/tests/pubsubmanager/pubsubmanager_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/pubsubmanager/pubsubmanager_test.cpp	2014-01-16 10:42:06 +0000
@@ -32,10 +32,12 @@
                                     const JID&, const JID&,
                                                 const std::string&,
                                                 const DataForm*,
+                                                const std::string&,
                                                 const Error*) {}
     void handleSubscriptionOptionsResult( const std::string&,
                                           const JID&, const JID&,
                                                       const std::string&,
+                                                      const std::string&,
                                                       const Error* ) {}
     void handleSubscribers( const std::string&,
                             const JID&, const std::string&,
@@ -260,7 +262,7 @@
       tag = iq.tag();
       if( !tag || tag->xml() != testValues[m_context][1] )
       {
-        printf( "test failed: %s\n", testValues[m_context][0].c_str() );
+        fprintf( stderr, "test failed: %s\n", testValues[m_context][0].c_str() );
         printf( "- %s\n", testValues[m_context][1].c_str() );
         if( tag )
           printf( "- %s\n", tag->xml().c_str() );
@@ -353,7 +355,7 @@
 
 
   if( cb->failed )
-    printf( "PubSub::Manager: %d test(s) failed\n", cb->failed );
+    fprintf( stderr, "PubSub::Manager: %d test(s) failed\n", cb->failed );
   else
     printf( "PubSub::Manager: OK\n" );
 

=== modified file 'src/tests/pubsubmanagerpubsub/Makefile.am'
--- src/tests/pubsubmanagerpubsub/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/pubsubmanagerpubsub/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,6 +18,7 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../delayeddelivery.o ../../pubsubitem.o ../../shim.o \
-			../../softwareversion.o 
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 pubsubmanagerpubsub_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/pubsubmanagerpubsub/Makefile.in'
--- src/tests/pubsubmanagerpubsub/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/pubsubmanagerpubsub/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,7 +84,7 @@
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o \
 	../../delayeddelivery.o ../../pubsubitem.o ../../shim.o \
-	../../softwareversion.o
+	../../softwareversion.o ../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -83,6 +100,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(pubsubmanagerpubsub_test_SOURCES)
 DIST_SOURCES = $(pubsubmanagerpubsub_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -105,6 +127,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -114,6 +137,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -129,7 +153,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -159,6 +185,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -193,7 +220,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -222,7 +248,8 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../delayeddelivery.o ../../pubsubitem.o ../../shim.o \
-			../../softwareversion.o 
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 pubsubmanagerpubsub_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -268,7 +295,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-pubsubmanagerpubsub_test$(EXEEXT): $(pubsubmanagerpubsub_test_OBJECTS) $(pubsubmanagerpubsub_test_DEPENDENCIES) 
+pubsubmanagerpubsub_test$(EXEEXT): $(pubsubmanagerpubsub_test_OBJECTS) $(pubsubmanagerpubsub_test_DEPENDENCIES) $(EXTRA_pubsubmanagerpubsub_test_DEPENDENCIES) 
 	@rm -f pubsubmanagerpubsub_test$(EXEEXT)
 	$(CXXLINK) $(pubsubmanagerpubsub_test_OBJECTS) $(pubsubmanagerpubsub_test_LDADD) $(LIBS)
 
@@ -403,10 +430,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/pubsubmanagerpubsub/pubsubmanagerpubsub_test.cpp'
--- src/tests/pubsubmanagerpubsub/pubsubmanagerpubsub_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/pubsubmanagerpubsub/pubsubmanagerpubsub_test.cpp	2014-01-16 10:42:06 +0000
@@ -9,8 +9,6 @@
 static const JID jid( "aaa@bbb.ccc" );
 static const std::string node( "node" );
 
-static const Tag* tag;
-
 #define PUBSUBMANAGER_TEST
 #include "../../pubsubmanager.cpp"
 #include "../../pubsubmanager.h"
@@ -38,7 +36,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -49,7 +47,7 @@
 
   printf( "PubSub::Manager::PubSub: " );
   if( fail )
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
   else
     printf( "OK\n" );
 

=== modified file 'src/tests/receipt/Makefile.am'
--- src/tests/receipt/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/receipt/Makefile.am	2014-01-16 10:42:06 +0000
@@ -10,6 +10,6 @@
 receipt_test_LDADD = ../../receipt.o ../../gloox.o ../../tag.o \
                   ../../util.o ../../stanza.o ../../message.o \
                   ../../jid.o ../../prep.o \
-                  ../../stanzaextensionfactory.o
+                  ../../stanzaextensionfactory.o ../../mutex.o
 
 receipt_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/receipt/Makefile.in'
--- src/tests/receipt/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/receipt/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -51,7 +68,7 @@
 receipt_test_OBJECTS = $(am_receipt_test_OBJECTS)
 receipt_test_DEPENDENCIES = ../../receipt.o ../../gloox.o ../../tag.o \
 	../../util.o ../../stanza.o ../../message.o ../../jid.o \
-	../../prep.o ../../stanzaextensionfactory.o
+	../../prep.o ../../stanzaextensionfactory.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(receipt_test_SOURCES)
 DIST_SOURCES = $(receipt_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -198,7 +224,7 @@
 receipt_test_LDADD = ../../receipt.o ../../gloox.o ../../tag.o \
                   ../../util.o ../../stanza.o ../../message.o \
                   ../../jid.o ../../prep.o \
-                  ../../stanzaextensionfactory.o
+                  ../../stanzaextensionfactory.o ../../mutex.o
 
 receipt_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-receipt_test$(EXEEXT): $(receipt_test_OBJECTS) $(receipt_test_DEPENDENCIES) 
+receipt_test$(EXEEXT): $(receipt_test_OBJECTS) $(receipt_test_DEPENDENCIES) $(EXTRA_receipt_test_DEPENDENCIES) 
 	@rm -f receipt_test$(EXEEXT)
 	$(CXXLINK) $(receipt_test_OBJECTS) $(receipt_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/receipt/receipt_test.cpp'
--- src/tests/receipt/receipt_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/receipt/receipt_test.cpp	2014-01-16 10:42:06 +0000
@@ -23,7 +23,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -37,7 +37,7 @@
     if( t->xml() != "<request xmlns='"+ XMLNS_RECEIPTS + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     t = 0;
@@ -51,7 +51,7 @@
     if( t->xml() != "<received xmlns='"+ XMLNS_RECEIPTS + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     t = 0;
@@ -70,7 +70,7 @@
     if( se == 0 || se->rcpt() != Receipt::Request )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -86,7 +86,7 @@
     if( se == 0 || se->rcpt() != Receipt::Received )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -99,7 +99,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/registration/Makefile.am'
--- src/tests/registration/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/registration/Makefile.am	2014-01-16 10:42:06 +0000
@@ -11,5 +11,5 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o ../../oob.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o
+		../../error.o ../../mutex.o
 registration_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/registration/Makefile.in'
--- src/tests/registration/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/registration/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,8 @@
 	../../dataformreported.o ../../dataformitem.o \
 	../../dataformfield.o ../../tag.o ../../prep.o ../../gloox.o \
 	../../stanzaextensionfactory.o ../../oob.o ../../iq.o \
-	../../util.o ../../sha.o ../../base64.o ../../error.o
+	../../util.o ../../sha.o ../../base64.o ../../error.o \
+	../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +88,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(registration_test_SOURCES)
 DIST_SOURCES = $(registration_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +115,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +125,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +141,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +173,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +208,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -202,7 +229,7 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o ../../oob.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o
+		../../error.o ../../mutex.o
 
 registration_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -248,7 +275,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-registration_test$(EXEEXT): $(registration_test_OBJECTS) $(registration_test_DEPENDENCIES) 
+registration_test$(EXEEXT): $(registration_test_OBJECTS) $(registration_test_DEPENDENCIES) $(EXTRA_registration_test_DEPENDENCIES) 
 	@rm -f registration_test$(EXEEXT)
 	$(CXXLINK) $(registration_test_OBJECTS) $(registration_test_LDADD) $(LIBS)
 
@@ -383,10 +410,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/registration/registration_test.cpp'
--- src/tests/registration/registration_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/registration/registration_test.cpp	2014-01-16 10:42:06 +0000
@@ -60,7 +60,7 @@
   public:
     RegistrationTest();
     ~RegistrationTest();
-    virtual void handleRegistrationFields( const gloox::JID& from, int fields,
+    virtual void handleRegistrationFields( const gloox::JID& /*from*/, int fields,
                                            std::string instructions )
     {
       if( m_test == 2 && fields & ( gloox::Registration::FieldUsername | gloox::Registration::FieldPassword
@@ -80,7 +80,7 @@
       m_test = 0;
     }
 
-    virtual void handleRegistrationResult( const gloox::JID& from, gloox::RegistrationResult regResult )
+    virtual void handleRegistrationResult( const gloox::JID& /*from*/, gloox::RegistrationResult regResult )
     {
       if( ( m_test == 4 || m_test == 6 || m_test == 7 || m_test == 8 )
             && regResult == gloox::RegistrationSuccess )
@@ -89,7 +89,7 @@
       m_test = 0;
     }
 
-    virtual void handleDataForm( const gloox::JID& from, const gloox::DataForm& form )
+    virtual void handleDataForm( const gloox::JID& /*from*/, const gloox::DataForm& form )
     {
       if( m_test == 5 && form )
         m_result = true;
@@ -97,7 +97,7 @@
       m_test = 0;
     }
 
-    virtual void handleOOB( const gloox::JID& from, const gloox::OOB& oob )
+    virtual void handleOOB( const gloox::JID& /*from*/, const gloox::OOB& /*oob*/ )
     {
     }
 
@@ -218,7 +218,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -239,7 +239,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete q;
   }
@@ -261,7 +261,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete q;
   }
@@ -279,7 +279,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -291,7 +291,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -311,7 +311,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete q;
   }
@@ -325,7 +325,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -337,7 +337,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -349,7 +349,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -368,7 +368,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/registrationquery/Makefile.am'
--- src/tests/registrationquery/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/registrationquery/Makefile.am	2014-01-16 10:42:06 +0000
@@ -12,5 +12,5 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o ../../oob.o
+		../../error.o ../../oob.o ../../mutex.o
 registrationquery_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/registrationquery/Makefile.in'
--- src/tests/registrationquery/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/registrationquery/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,8 @@
 	../../dataformreported.o ../../dataformitem.o \
 	../../dataformfield.o ../../tag.o ../../prep.o ../../gloox.o \
 	../../stanzaextensionfactory.o ../../iq.o ../../util.o \
-	../../sha.o ../../base64.o ../../error.o ../../oob.o
+	../../sha.o ../../base64.o ../../error.o ../../oob.o \
+	../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +88,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(registrationquery_test_SOURCES)
 DIST_SOURCES = $(registrationquery_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +115,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +125,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +141,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +173,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +208,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -202,7 +229,7 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o ../../oob.o
+		../../error.o ../../oob.o ../../mutex.o
 
 registrationquery_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -248,7 +275,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-registrationquery_test$(EXEEXT): $(registrationquery_test_OBJECTS) $(registrationquery_test_DEPENDENCIES) 
+registrationquery_test$(EXEEXT): $(registrationquery_test_OBJECTS) $(registrationquery_test_DEPENDENCIES) $(EXTRA_registrationquery_test_DEPENDENCIES) 
 	@rm -f registrationquery_test$(EXEEXT)
 	$(CXXLINK) $(registrationquery_test_OBJECTS) $(registrationquery_test_LDADD) $(LIBS)
 
@@ -383,10 +410,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/registrationquery/registrationquery_test.cpp'
--- src/tests/registrationquery/registrationquery_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/registrationquery/registrationquery_test.cpp	2014-01-16 10:42:06 +0000
@@ -61,7 +61,7 @@
     if( !t || t->xml() != "<query xmlns='" + XMLNS_REGISTER + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -88,7 +88,7 @@
                              | Registration::FieldEmail ) )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     delete d;
@@ -111,7 +111,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -132,7 +132,7 @@
          || !sq.form() )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     delete d;
@@ -149,7 +149,7 @@
        "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -164,7 +164,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -183,7 +183,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -209,7 +209,7 @@
          || sq.oob()->url() != "http://camaya.net/gloox" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     delete d;
@@ -230,7 +230,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -244,7 +244,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/rostermanager/Makefile.in'
--- src/tests/rostermanager/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/rostermanager/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -71,6 +88,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(rostermanager_test_SOURCES)
 DIST_SOURCES = $(rostermanager_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -93,6 +115,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -102,6 +125,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -117,7 +141,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -147,6 +173,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -181,7 +208,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -251,7 +277,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-rostermanager_test$(EXEEXT): $(rostermanager_test_OBJECTS) $(rostermanager_test_DEPENDENCIES) 
+rostermanager_test$(EXEEXT): $(rostermanager_test_OBJECTS) $(rostermanager_test_DEPENDENCIES) $(EXTRA_rostermanager_test_DEPENDENCIES) 
 	@rm -f rostermanager_test$(EXEEXT)
 	$(CXXLINK) $(rostermanager_test_OBJECTS) $(rostermanager_test_LDADD) $(LIBS)
 
@@ -386,10 +412,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/rostermanager/rostermanager_test.cpp'
--- src/tests/rostermanager/rostermanager_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/rostermanager/rostermanager_test.cpp	2014-01-16 10:42:06 +0000
@@ -109,6 +109,8 @@
     {
       if( m_test == 1 && roster.size() == 3 )
         m_result2 = true;
+      else
+        printf("rostersize: %d\n", roster.size() );
     }
     virtual void handleRosterPresence( const RosterItem& /*item*/, const std::string& /*resource*/,
                                        Presence::PresenceType /*presence*/, const std::string& /*msg*/ ) {}
@@ -160,9 +162,9 @@
       Tag* r = new Tag( "iq" );
       Tag* q = new Tag( r, "query" );
       q->setXmlns( XMLNS_ROSTER );
-      Tag* i = new Tag( q, "item", "jid", "jid1" );
-      i = new Tag( q, "item", "jid", "jid2" );
-      i = new Tag( q, "item", "jid", "jid3" );
+      Tag* i = new Tag( q, "item", "jid", "foo@bar" ); i->addAttribute( "subscription", "both" );
+      i = new Tag( q, "item", "jid", "bar@foo" ); i->addAttribute( "subscription", "both" );
+      i = new Tag( q, "item", "jid", "foobar" ); i->addAttribute( "subscription", "both" );
       re.addExtension( new RosterManager::Query( q ) );
       delete r;
       m_rm->handleIqID( re, ctx );
@@ -251,7 +253,7 @@
   if( !rmt->checkResult() || !rmt->checkResult2() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -263,7 +265,7 @@
   if( !rmt->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -272,7 +274,7 @@
   if( !ri || ri->name() != "fooname" || ri->groups().size() != 1 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -289,7 +291,7 @@
   if( !ri || ri->name() != "foof" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -300,7 +302,7 @@
   if( !rmt->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -309,7 +311,7 @@
   if( !ri || ri->name() != "foof" || ri->groups().size() != 3 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -319,7 +321,7 @@
   if( !rmt->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -328,7 +330,7 @@
   if( ri )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), ri->jid().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), ri->jidJID().full().c_str() );
   }
 
   // -------
@@ -338,7 +340,7 @@
   if( !rmt->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -347,7 +349,7 @@
   if( !ri || ri->name() != "" || ri->groups().size() != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -357,7 +359,7 @@
   if( !rmt->checkResult() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -366,7 +368,7 @@
   if( ri )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), ri->jid().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), ri->jidJID().full().c_str() );
   }
 
   // -------
@@ -379,7 +381,7 @@
     if( !rmt->checkResult() || !rmt->checkResult2() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -393,7 +395,7 @@
     if( !rmt->checkResult() || !rmt->checkResult2() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -407,7 +409,7 @@
     if( !rmt->checkResult() || !rmt->checkResult2() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -429,7 +431,7 @@
   }
   else
   {
-    printf( "RosterManager: %d test(s) failed\n", fail );
+    fprintf( stderr, "RosterManager: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/rostermanagerquery/Makefile.am'
--- src/tests/rostermanagerquery/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/rostermanagerquery/Makefile.am	2014-01-16 10:42:06 +0000
@@ -20,5 +20,6 @@
 			../../capabilities.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../eventdispatcher.o\
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 rostermanagerquery_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/rostermanagerquery/Makefile.in'
--- src/tests/rostermanagerquery/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/rostermanagerquery/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,7 +84,8 @@
 	../../capabilities.o ../../dataform.o \
 	../../dataformfieldcontainer.o ../../dataformreported.o \
 	../../dataformitem.o ../../dataformfield.o \
-	../../eventdispatcher.o ../../softwareversion.o
+	../../eventdispatcher.o ../../softwareversion.o \
+	../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -83,6 +101,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(rostermanagerquery_test_SOURCES)
 DIST_SOURCES = $(rostermanagerquery_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -105,6 +128,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -114,6 +138,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -129,7 +154,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -159,6 +186,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -193,7 +221,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -223,7 +250,8 @@
 			../../capabilities.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../eventdispatcher.o\
-			../../softwareversion.o
+			../../softwareversion.o \
+			../../atomicrefcount.o
 
 rostermanagerquery_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -269,7 +297,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-rostermanagerquery_test$(EXEEXT): $(rostermanagerquery_test_OBJECTS) $(rostermanagerquery_test_DEPENDENCIES) 
+rostermanagerquery_test$(EXEEXT): $(rostermanagerquery_test_OBJECTS) $(rostermanagerquery_test_DEPENDENCIES) $(EXTRA_rostermanagerquery_test_DEPENDENCIES) 
 	@rm -f rostermanagerquery_test$(EXEEXT)
 	$(CXXLINK) $(rostermanagerquery_test_OBJECTS) $(rostermanagerquery_test_LDADD) $(LIBS)
 
@@ -404,10 +432,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/rostermanagerquery/rostermanagerquery_test.cpp'
--- src/tests/rostermanagerquery/rostermanagerquery_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/rostermanagerquery/rostermanagerquery_test.cpp	2014-01-16 10:42:06 +0000
@@ -25,7 +25,7 @@
     if( t->xml() != "<query xmlns='" + XMLNS_ROSTER + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -46,7 +46,7 @@
                     "</item></query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -62,7 +62,7 @@
         "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -84,7 +84,7 @@
     if( *t != *q || rq.roster().size() != 2 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -106,7 +106,7 @@
     if( *t != *q )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
       printf( "     got: %s\n", t->xml().c_str() );
       printf( "expected: %s\n", q->xml().c_str() );
     }
@@ -128,7 +128,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -140,7 +140,7 @@
   }
   else
   {
-    printf( "RosterManager::Query: %d test(s) failed\n", fail );
+    fprintf( stderr, "RosterManager::Query: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/search/Makefile.am'
--- src/tests/search/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/search/Makefile.am	2014-01-16 10:42:06 +0000
@@ -11,5 +11,5 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o
+		../../error.o ../../mutex.o
 search_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/search/Makefile.in'
--- src/tests/search/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/search/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,7 @@
 	../../dataformitem.o ../../dataformfield.o ../../tag.o \
 	../../prep.o ../../gloox.o ../../stanzaextensionfactory.o \
 	../../iq.o ../../util.o ../../sha.o ../../base64.o \
-	../../error.o
+	../../error.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(search_test_SOURCES)
 DIST_SOURCES = $(search_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -202,7 +228,7 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o
+		../../error.o ../../mutex.o
 
 search_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -248,7 +274,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-search_test$(EXEEXT): $(search_test_OBJECTS) $(search_test_DEPENDENCIES) 
+search_test$(EXEEXT): $(search_test_OBJECTS) $(search_test_DEPENDENCIES) $(EXTRA_search_test_DEPENDENCIES) 
 	@rm -f search_test$(EXEEXT)
 	$(CXXLINK) $(search_test_OBJECTS) $(search_test_LDADD) $(LIBS)
 
@@ -383,10 +409,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/search/search_test.cpp'
--- src/tests/search/search_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/search/search_test.cpp	2014-01-16 10:42:06 +0000
@@ -175,7 +175,7 @@
   if( !t.result() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -193,7 +193,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -205,7 +205,7 @@
   if( !t.result() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -233,7 +233,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete q;
   }
@@ -247,7 +247,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -262,7 +262,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -273,7 +273,7 @@
   if( !t.result() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -287,7 +287,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
   }
 
@@ -299,7 +299,7 @@
   if( !t.result() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -313,7 +313,7 @@
     if( !t.result() )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     }
 
@@ -330,7 +330,7 @@
   }
   else
   {
-    printf( "Search: %d test(s) failed\n", fail );
+    fprintf( stderr, "Search: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/searchquery/Makefile.am'
--- src/tests/searchquery/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/searchquery/Makefile.am	2014-01-16 10:42:06 +0000
@@ -11,5 +11,5 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o
+		../../error.o ../../mutex.o
 searchquery_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/searchquery/Makefile.in'
--- src/tests/searchquery/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/searchquery/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -54,7 +71,7 @@
 	../../dataformreported.o ../../dataformitem.o \
 	../../dataformfield.o ../../tag.o ../../prep.o ../../gloox.o \
 	../../stanzaextensionfactory.o ../../iq.o ../../util.o \
-	../../sha.o ../../base64.o ../../error.o
+	../../sha.o ../../base64.o ../../error.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -70,6 +87,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(searchquery_test_SOURCES)
 DIST_SOURCES = $(searchquery_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -92,6 +114,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -101,6 +124,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -116,7 +140,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -146,6 +172,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -180,7 +207,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -202,7 +228,7 @@
  		../../dataformreported.o ../../dataformitem.o ../../dataformfield.o ../../tag.o ../../prep.o \
  		../../gloox.o ../../stanzaextensionfactory.o \
 		../../iq.o ../../util.o ../../sha.o ../../base64.o \
-		../../error.o
+		../../error.o ../../mutex.o
 
 searchquery_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -248,7 +274,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-searchquery_test$(EXEEXT): $(searchquery_test_OBJECTS) $(searchquery_test_DEPENDENCIES) 
+searchquery_test$(EXEEXT): $(searchquery_test_OBJECTS) $(searchquery_test_DEPENDENCIES) $(EXTRA_searchquery_test_DEPENDENCIES) 
 	@rm -f searchquery_test$(EXEEXT)
 	$(CXXLINK) $(searchquery_test_OBJECTS) $(searchquery_test_LDADD) $(LIBS)
 
@@ -383,10 +409,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/searchquery/searchquery_test.cpp'
--- src/tests/searchquery/searchquery_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/searchquery/searchquery_test.cpp	2014-01-16 10:42:06 +0000
@@ -58,7 +58,7 @@
     if( !t || t->xml() != "<query xmlns='" + XMLNS_SEARCH + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -86,7 +86,7 @@
          || sq.fields() != ( SearchFieldFirst | SearchFieldLast | SearchFieldNick | SearchFieldEmail ) )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     delete d;
@@ -108,7 +108,7 @@
          || !sq.form() )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     delete d;
@@ -125,7 +125,7 @@
        "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -144,7 +144,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -164,7 +164,7 @@
          "</query>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     delete d;
@@ -205,7 +205,7 @@
        || srl.size() != 2 )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     delete d;
@@ -226,7 +226,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -240,7 +240,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/sha/Makefile.in'
--- src/tests/sha/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/sha/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,6 +82,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(sha_test_SOURCES)
 DIST_SOURCES = $(sha_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -87,6 +109,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -96,6 +119,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -111,7 +135,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -141,6 +167,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -175,7 +202,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -238,7 +264,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-sha_test$(EXEEXT): $(sha_test_OBJECTS) $(sha_test_DEPENDENCIES) 
+sha_test$(EXEEXT): $(sha_test_OBJECTS) $(sha_test_DEPENDENCIES) $(EXTRA_sha_test_DEPENDENCIES) 
 	@rm -f sha_test$(EXEEXT)
 	$(CXXLINK) $(sha_test_OBJECTS) $(sha_test_LDADD) $(LIBS)
 
@@ -373,10 +399,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/sha/sha_test.cpp'
--- src/tests/sha/sha_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/sha/sha_test.cpp	2014-01-16 10:42:06 +0000
@@ -21,7 +21,7 @@
   if( sha.hex() != "da39a3ee5e6b4b0d3255bfef95601890afd80709" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   sha.reset();
 
@@ -32,7 +32,7 @@
   if( sha.hex() != "2fd4e1c67a2d28fced849ee1bb76e7391b93eb12" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
   }
   sha.reset();
 
@@ -43,7 +43,7 @@
   if( sha.hex() != "de9f2c7fd25e1b3afad3e85a0bd17d9b100db4b3" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
   }
   sha.reset();
 
@@ -55,7 +55,51 @@
   if( sha.hex() != "2fd4e1c67a2d28fced849ee1bb76e7391b93eb12" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+  }
+  sha.reset();
+
+  // -------
+  name = "54byte string";
+  sha.feed( std::string( 54, 'x' ) );
+  sha.finalize();
+  if( sha.hex() != "31045e7bb077ff8d188a776b196b980388735dbb" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+  }
+  sha.reset();
+
+  // -------
+  name = "55byte string";
+  sha.feed( std::string( 55, 'x' ) );
+  sha.finalize();
+  if( sha.hex() != "cef734ba81a024479e09eb5a75b6ddae62e6abf1" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+  }
+  sha.reset();
+
+  // -------
+  name = "56byte string";
+  sha.feed( std::string( 56, 'x' ) );
+  sha.finalize();
+  if( sha.hex() != "901305367c259952f4e7af8323f480d59f81335b" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+  }
+  sha.reset();
+
+  // -------
+  name = "57byte string";
+  sha.feed( std::string( 57, 'x' ) );
+  sha.finalize();
+  if( sha.hex() != "025ecbd5d70f8fb3c5457cd96bab13fda305dc59" )
+  {
+    ++fail;
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
   }
   sha.reset();
 
@@ -70,7 +114,7 @@
   if( sha.hex() != "2fd4e1c67a2d28fced849ee1bb76e7391b93eb12" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), sha.hex().c_str() );
   }
   sha.reset();
 
@@ -83,7 +127,7 @@
   }
   else
   {
-    printf( "SHA: %d test(s) failed\n", fail );
+    fprintf( stderr, "SHA: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/shim/Makefile.am'
--- src/tests/shim/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/shim/Makefile.am	2014-01-16 10:42:06 +0000
@@ -10,6 +10,6 @@
 shim_test_LDADD = ../../shim.o ../../gloox.o ../../tag.o \
                   ../../util.o ../../stanza.o ../../message.o \
                   ../../jid.o ../../prep.o \
-                  ../../stanzaextensionfactory.o
+                  ../../stanzaextensionfactory.o ../../mutex.o
 
 shim_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/shim/Makefile.in'
--- src/tests/shim/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/shim/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -51,7 +68,7 @@
 shim_test_OBJECTS = $(am_shim_test_OBJECTS)
 shim_test_DEPENDENCIES = ../../shim.o ../../gloox.o ../../tag.o \
 	../../util.o ../../stanza.o ../../message.o ../../jid.o \
-	../../prep.o ../../stanzaextensionfactory.o
+	../../prep.o ../../stanzaextensionfactory.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(shim_test_SOURCES)
 DIST_SOURCES = $(shim_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -198,7 +224,7 @@
 shim_test_LDADD = ../../shim.o ../../gloox.o ../../tag.o \
                   ../../util.o ../../stanza.o ../../message.o \
                   ../../jid.o ../../prep.o \
-                  ../../stanzaextensionfactory.o
+                  ../../stanzaextensionfactory.o ../../mutex.o
 
 shim_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-shim_test$(EXEEXT): $(shim_test_OBJECTS) $(shim_test_DEPENDENCIES) 
+shim_test$(EXEEXT): $(shim_test_OBJECTS) $(shim_test_DEPENDENCIES) $(EXTRA_shim_test_DEPENDENCIES) 
 	@rm -f shim_test$(EXEEXT)
 	$(CXXLINK) $(shim_test_OBJECTS) $(shim_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/shim/shim_test.cpp'
--- src/tests/shim/shim_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/shim/shim_test.cpp	2014-01-16 10:42:06 +0000
@@ -23,7 +23,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -40,7 +40,7 @@
     if( t->xml() != "<headers xmlns='"+ XMLNS_SHIM + "'><header name='created'>yesterday</header><header name='name'>foo</header></headers>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
 
     name = "headers to tag to headers, part 2/2";
@@ -48,7 +48,7 @@
     if( s.headers() != hl )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -67,7 +67,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -81,7 +81,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/simanager/Makefile.in'
--- src/tests/simanager/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/simanager/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(simanager_test_SOURCES)
 DIST_SOURCES = $(simanager_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -244,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-simanager_test$(EXEEXT): $(simanager_test_OBJECTS) $(simanager_test_DEPENDENCIES) 
+simanager_test$(EXEEXT): $(simanager_test_OBJECTS) $(simanager_test_DEPENDENCIES) $(EXTRA_simanager_test_DEPENDENCIES) 
 	@rm -f simanager_test$(EXEEXT)
 	$(CXXLINK) $(simanager_test_OBJECTS) $(simanager_test_LDADD) $(LIBS)
 
@@ -379,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/simanager/simanager_test.cpp'
--- src/tests/simanager/simanager_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/simanager/simanager_test.cpp	2014-01-16 10:42:06 +0000
@@ -123,7 +123,7 @@
   if( !cb->ok() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -146,7 +146,7 @@
   }
   else
   {
-    printf( "SIManager: %d test(s) failed\n", fail );
+    fprintf( stderr, "SIManager: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/simanagersi/Makefile.am'
--- src/tests/simanagersi/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/simanagersi/Makefile.am	2014-01-16 10:42:06 +0000
@@ -10,5 +10,5 @@
 simanagersi_test_LDADD = ../../jid.o ../../tag.o \
                         ../../logsink.o ../../prep.o ../../util.o \
                         ../../gloox.o ../../iq.o ../../stanza.o \
-                        ../../error.o ../../stanzaextensionfactory.o
+                        ../../error.o ../../stanzaextensionfactory.o ../../mutex.o
 simanagersi_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/simanagersi/Makefile.in'
--- src/tests/simanagersi/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/simanagersi/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -52,7 +69,7 @@
 simanagersi_test_DEPENDENCIES = ../../jid.o ../../tag.o \
 	../../logsink.o ../../prep.o ../../util.o ../../gloox.o \
 	../../iq.o ../../stanza.o ../../error.o \
-	../../stanzaextensionfactory.o
+	../../stanzaextensionfactory.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(simanagersi_test_SOURCES)
 DIST_SOURCES = $(simanagersi_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -199,7 +225,7 @@
 simanagersi_test_LDADD = ../../jid.o ../../tag.o \
                         ../../logsink.o ../../prep.o ../../util.o \
                         ../../gloox.o ../../iq.o ../../stanza.o \
-                        ../../error.o ../../stanzaextensionfactory.o
+                        ../../error.o ../../stanzaextensionfactory.o ../../mutex.o
 
 simanagersi_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -245,7 +271,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-simanagersi_test$(EXEEXT): $(simanagersi_test_OBJECTS) $(simanagersi_test_DEPENDENCIES) 
+simanagersi_test$(EXEEXT): $(simanagersi_test_OBJECTS) $(simanagersi_test_DEPENDENCIES) $(EXTRA_simanagersi_test_DEPENDENCIES) 
 	@rm -f simanagersi_test$(EXEEXT)
 	$(CXXLINK) $(simanagersi_test_OBJECTS) $(simanagersi_test_LDADD) $(LIBS)
 
@@ -380,10 +406,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/simanagersi/simanagersi_test.cpp'
--- src/tests/simanagersi/simanagersi_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/simanagersi/simanagersi_test.cpp	2014-01-16 10:42:06 +0000
@@ -76,7 +76,7 @@
     if( t )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -97,7 +97,7 @@
         || !t->hasChild( "bar" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
     }
     delete t;
     t = 0;
@@ -121,7 +121,7 @@
     if( !t || *t != *s )
     {
       ++fail;
-      printf( "test '%s' failed:\n%s\n%s\n", name.c_str(), t->xml().c_str(), s->xml().c_str() );
+      fprintf( stderr, "test '%s' failed:\n%s\n%s\n", name.c_str(), t->xml().c_str(), s->xml().c_str() );
     }
     delete s;
     delete t;
@@ -141,7 +141,7 @@
     if( se == 0 )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete f;
   }
@@ -155,7 +155,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/stanzaextensionfactory/Makefile.am'
--- src/tests/stanzaextensionfactory/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/stanzaextensionfactory/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,11 +9,11 @@
 stanzaextensionfactory_test_SOURCES = stanzaextensionfactory_test.cpp
 stanzaextensionfactory_test_LDADD = ../../tag.o ../../stanza.o ../../jid.o ../../prep.o \
                                     ../../stanzaextensionfactory.o ../../gloox.o ../../util.o ../../sha.o \
-                                    ../../base64.o ../../iq.o
+                                    ../../base64.o ../../iq.o ../../mutex.o
 stanzaextensionfactory_test_CFLAGS = $(CPPFLAGS)
 
 stanzaextensionfactory_perf_SOURCES = stanzaextensionfactory_perf.cpp
 stanzaextensionfactory_perf_LDADD = ../../tag.o ../../stanza.o ../../jid.o ../../prep.o \
                                     ../../stanzaextensionfactory.o ../../gloox.o ../../util.o ../../sha.o \
-                                    ../../base64.o ../../iq.o
+                                    ../../base64.o ../../iq.o ../../mutex.o
 stanzaextensionfactory_perf_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/stanzaextensionfactory/Makefile.in'
--- src/tests/stanzaextensionfactory/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/stanzaextensionfactory/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -55,7 +72,7 @@
 stanzaextensionfactory_perf_DEPENDENCIES = ../../tag.o ../../stanza.o \
 	../../jid.o ../../prep.o ../../stanzaextensionfactory.o \
 	../../gloox.o ../../util.o ../../sha.o ../../base64.o \
-	../../iq.o
+	../../iq.o ../../mutex.o
 am_stanzaextensionfactory_test_OBJECTS =  \
 	stanzaextensionfactory_test.$(OBJEXT)
 stanzaextensionfactory_test_OBJECTS =  \
@@ -63,7 +80,7 @@
 stanzaextensionfactory_test_DEPENDENCIES = ../../tag.o ../../stanza.o \
 	../../jid.o ../../prep.o ../../stanzaextensionfactory.o \
 	../../gloox.o ../../util.o ../../sha.o ../../base64.o \
-	../../iq.o
+	../../iq.o ../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -81,6 +98,11 @@
 	$(stanzaextensionfactory_test_SOURCES)
 DIST_SOURCES = $(stanzaextensionfactory_perf_SOURCES) \
 	$(stanzaextensionfactory_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -103,6 +125,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -112,6 +135,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -127,7 +151,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -157,6 +183,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -191,7 +218,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -211,13 +237,13 @@
 stanzaextensionfactory_test_SOURCES = stanzaextensionfactory_test.cpp
 stanzaextensionfactory_test_LDADD = ../../tag.o ../../stanza.o ../../jid.o ../../prep.o \
                                     ../../stanzaextensionfactory.o ../../gloox.o ../../util.o ../../sha.o \
-                                    ../../base64.o ../../iq.o
+                                    ../../base64.o ../../iq.o ../../mutex.o
 
 stanzaextensionfactory_test_CFLAGS = $(CPPFLAGS)
 stanzaextensionfactory_perf_SOURCES = stanzaextensionfactory_perf.cpp
 stanzaextensionfactory_perf_LDADD = ../../tag.o ../../stanza.o ../../jid.o ../../prep.o \
                                     ../../stanzaextensionfactory.o ../../gloox.o ../../util.o ../../sha.o \
-                                    ../../base64.o ../../iq.o
+                                    ../../base64.o ../../iq.o ../../mutex.o
 
 stanzaextensionfactory_perf_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -263,10 +289,10 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-stanzaextensionfactory_perf$(EXEEXT): $(stanzaextensionfactory_perf_OBJECTS) $(stanzaextensionfactory_perf_DEPENDENCIES) 
+stanzaextensionfactory_perf$(EXEEXT): $(stanzaextensionfactory_perf_OBJECTS) $(stanzaextensionfactory_perf_DEPENDENCIES) $(EXTRA_stanzaextensionfactory_perf_DEPENDENCIES) 
 	@rm -f stanzaextensionfactory_perf$(EXEEXT)
 	$(CXXLINK) $(stanzaextensionfactory_perf_OBJECTS) $(stanzaextensionfactory_perf_LDADD) $(LIBS)
-stanzaextensionfactory_test$(EXEEXT): $(stanzaextensionfactory_test_OBJECTS) $(stanzaextensionfactory_test_DEPENDENCIES) 
+stanzaextensionfactory_test$(EXEEXT): $(stanzaextensionfactory_test_OBJECTS) $(stanzaextensionfactory_test_DEPENDENCIES) $(EXTRA_stanzaextensionfactory_test_DEPENDENCIES) 
 	@rm -f stanzaextensionfactory_test$(EXEEXT)
 	$(CXXLINK) $(stanzaextensionfactory_test_OBJECTS) $(stanzaextensionfactory_test_LDADD) $(LIBS)
 
@@ -402,10 +428,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/stanzaextensionfactory/stanzaextensionfactory_perf.cpp'
--- src/tests/stanzaextensionfactory/stanzaextensionfactory_perf.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/stanzaextensionfactory/stanzaextensionfactory_perf.cpp	2014-01-16 10:42:06 +0000
@@ -53,7 +53,7 @@
   if( se == 0 || se == set || se->tag() != b )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -62,7 +62,7 @@
   if( !sef.removeExtension( ExtUser + 1 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -73,7 +73,7 @@
   }
   else
   {
-    printf( "StanzaExtensionFactory: %d test(s) failed\n", fail );
+    fprintf( stderr, "StanzaExtensionFactory: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/stanzaextensionfactory/stanzaextensionfactory_test.cpp'
--- src/tests/stanzaextensionfactory/stanzaextensionfactory_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/stanzaextensionfactory/stanzaextensionfactory_test.cpp	2014-01-16 10:42:06 +0000
@@ -53,7 +53,7 @@
   if( se == 0 || se == set || se->tag() != b )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -62,7 +62,7 @@
   if( !sef.removeExtension( ExtUser + 1 ) )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -73,7 +73,7 @@
   }
   else
   {
-    printf( "StanzaExtensionFactory: %d test(s) failed\n", fail );
+    fprintf( stderr, "StanzaExtensionFactory: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/subscription/Makefile.in'
--- src/tests/subscription/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/subscription/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(subscription_test_SOURCES)
 DIST_SOURCES = $(subscription_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -242,7 +268,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-subscription_test$(EXEEXT): $(subscription_test_OBJECTS) $(subscription_test_DEPENDENCIES) 
+subscription_test$(EXEEXT): $(subscription_test_OBJECTS) $(subscription_test_DEPENDENCIES) $(EXTRA_subscription_test_DEPENDENCIES) 
 	@rm -f subscription_test$(EXEEXT)
 	$(CXXLINK) $(subscription_test_OBJECTS) $(subscription_test_LDADD) $(LIBS)
 
@@ -377,10 +403,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/subscription/subscription_test.cpp'
--- src/tests/subscription/subscription_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/subscription/subscription_test.cpp	2014-01-16 10:42:06 +0000
@@ -30,7 +30,7 @@
       || i->status() != "the status" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -44,7 +44,7 @@
       || i->status() != "the status" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -58,7 +58,7 @@
       || i->status() != "the status" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -72,7 +72,7 @@
       || i->status() != "the status" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete i;
   i = 0;
@@ -90,7 +90,7 @@
         || !i->hasChild( "status", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -108,7 +108,7 @@
         || !i->hasChild( "status", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -126,7 +126,7 @@
         || !i->hasChild( "status", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
     }
@@ -144,7 +144,7 @@
         || !i->hasChild( "status", "xml:lang", "the xmllang" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), i->xml().c_str() );
     }
     delete i;
   }
@@ -177,7 +177,7 @@
   }
   else
   {
-    printf( "Subscription: %d test(s) failed\n", fail );
+    fprintf( stderr, "Subscription: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/tag/Makefile.in'
--- src/tests/tag/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/tag/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(tag_perf_SOURCES) $(tag_test_SOURCES)
 DIST_SOURCES = $(tag_perf_SOURCES) $(tag_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -244,10 +270,10 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-tag_perf$(EXEEXT): $(tag_perf_OBJECTS) $(tag_perf_DEPENDENCIES) 
+tag_perf$(EXEEXT): $(tag_perf_OBJECTS) $(tag_perf_DEPENDENCIES) $(EXTRA_tag_perf_DEPENDENCIES) 
 	@rm -f tag_perf$(EXEEXT)
 	$(CXXLINK) $(tag_perf_OBJECTS) $(tag_perf_LDADD) $(LIBS)
-tag_test$(EXEEXT): $(tag_test_OBJECTS) $(tag_test_DEPENDENCIES) 
+tag_test$(EXEEXT): $(tag_test_OBJECTS) $(tag_test_DEPENDENCIES) $(EXTRA_tag_test_DEPENDENCIES) 
 	@rm -f tag_test$(EXEEXT)
 	$(CXXLINK) $(tag_test_OBJECTS) $(tag_test_LDADD) $(LIBS)
 
@@ -383,10 +409,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/tag/tag_perf.cpp'
--- src/tests/tag/tag_perf.cpp	2014-01-16 01:11:18 +0000
+++ src/tests/tag/tag_perf.cpp	2014-01-16 10:42:06 +0000
@@ -57,7 +57,7 @@
 
 static void randomize( const int size )
 {
-  srand( time(NULL) );
+  srand( time( 0 ) );
   for (int i = 0; i < size-1; ++i)
   {
     values[i] = rand() % 96 + 32;

=== modified file 'src/tests/tag/tag_test.cpp'
--- src/tests/tag/tag_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/tag/tag_test.cpp	2014-01-16 10:42:06 +0000
@@ -27,7 +27,7 @@
   if( t->name() != "toe" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -36,7 +36,7 @@
   if( c->name() != "cod" || c->cdata() != "foobar" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -47,7 +47,7 @@
   if( *z != *c )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -58,7 +58,7 @@
   if( *t != *c )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -69,7 +69,7 @@
   if( *t == *c )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -82,7 +82,7 @@
   if( *t == *c )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -98,7 +98,7 @@
   if( *d == *c )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   delete d;
@@ -116,7 +116,7 @@
   if( *d != *c )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   delete d;
@@ -130,7 +130,7 @@
   if( l.size() != 2 || (*it) != v || *(++it) != v2 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete c;
   c = 0;
@@ -140,7 +140,7 @@
   if ( util::escape( "&<>'\"" ) != "&amp;&lt;&gt;&apos;&quot;" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   //-------
@@ -149,7 +149,7 @@
                     "</uni><vie v3='3v' v32='3v2'><xep x3='3x'/></vie><vie/></toe>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -159,7 +159,7 @@
                     "</uni><vie v3='3v' v32='3v2'><xep x3='3x'/></vie><vie/></toe>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -168,7 +168,7 @@
       || !u->hasChild( "yps" ) )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -177,7 +177,7 @@
       || !t->hasAttribute( "foo" ) || !t->hasAttribute( "foo", "bar" ) )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -185,7 +185,7 @@
   if( t->findAttribute( "test" ) != "bacd" || t->findAttribute( "foo" ) != "bar" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -194,7 +194,7 @@
   if( c != u )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -203,7 +203,7 @@
   if( c != u )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -212,7 +212,7 @@
   if( c != u )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -221,7 +221,7 @@
   if( c != u )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -230,7 +230,7 @@
   if( c != u )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t->xml().c_str() );
   }
 
   //-------
@@ -242,7 +242,7 @@
   if( *c != *d )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), d->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), d->xml().c_str() );
   }
   delete c;
   c = 0;
@@ -260,7 +260,7 @@
   if( c->xml() != "<abc>cdata1<fgh/>cdata2<xyz/>cdata3</abc>" )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), c->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), c->xml().c_str() );
   }
   delete c;
   c = 0;
@@ -271,7 +271,7 @@
   if( tag1 )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), tag1.xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), tag1.xml().c_str() );
   }
 
   //-------
@@ -280,7 +280,7 @@
   if( !tag2 )
   {
     ++fail;
-    printf( "test '%s' failed: %s\n", name.c_str(), d->xml().c_str() );
+    fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), d->xml().c_str() );
   }
 
   //-------
@@ -291,7 +291,7 @@
     if( t.xml() != "<abc xmlns='foo'/>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
   }
 
@@ -306,7 +306,7 @@
     if( t.xml() != "<abc xmlns='foo'><xyz:def xmlns:xyz='foobar'/></abc>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
   }
 
@@ -321,7 +321,7 @@
     if( t.xml() != "<abc xmlns:xyz='foo' xyz:foo='bar'/>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
   }
 
@@ -332,7 +332,7 @@
     if( t.xml() != "<foo abc='&amp;amp;'/>" )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
   }
 
@@ -348,7 +348,7 @@
     if( t.hasChild( "test" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
 
     name = "remove child 2";
@@ -356,7 +356,7 @@
     if( t.hasChild( "abc", "xmlns", "foobar" ) )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
 
     name = "remove attrib 1";
@@ -364,7 +364,7 @@
     if( t.hasAttribute( "attr1", "value1") )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
 
     name = "remove attrib 2";
@@ -372,7 +372,7 @@
     if( t.hasAttribute( "attr2", "value2") )
     {
       ++fail;
-      printf( "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed: %s\n", name.c_str(), t.xml().c_str() );
     }
   }
 
@@ -384,7 +384,7 @@
     if( check || t.hasAttribute( "nul" ) )
     {
       ++fail;
-      printf( "test '%s' failed:%s\n", name.c_str(), t.xml().c_str() );
+      fprintf( stderr, "test '%s' failed:%s\n", name.c_str(), t.xml().c_str() );
     }
   }
 
@@ -400,14 +400,14 @@
           || i == 0xc1 || i >= 0xf5 ) && a )
       {
         ++fail;
-        printf( "test '%s' (branch 1) failed (i == %02X)\n", name.c_str(), i );
+        fprintf( stderr, "test '%s' (branch 1) failed (i == %02X)\n", name.c_str(), i );
       }
       else if( ( i == 0x09 || i == 0x0a || i == 0x0d
                  || ( i >= 0x20 && i < 0xc0 )
                  || ( i > 0xc1 && i < 0xf5 ) ) && !a )
       {
         ++fail;
-        printf( "test '%s' (branch 2) failed (i == %02X)\n", name.c_str(), i );
+        fprintf( stderr, "test '%s' (branch 2) failed (i == %02X)\n", name.c_str(), i );
       }
 //       printf( "i: 0x%02X, a: %d, value: %s\n", i, (bool)a, std::string( 1, i ).c_str() );
     }
@@ -445,7 +445,7 @@
   }
   else
   {
-    printf( "Tag: %d test(s) failed\n", fail );
+    fprintf( stderr, "Tag: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/tlsgnutls/Makefile.in'
--- src/tests/tlsgnutls/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/tlsgnutls/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -67,6 +84,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(tlsgnutls_test_SOURCES)
 DIST_SOURCES = $(tlsgnutls_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +111,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +121,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +137,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +169,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +204,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -240,7 +266,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-tlsgnutls_test$(EXEEXT): $(tlsgnutls_test_OBJECTS) $(tlsgnutls_test_DEPENDENCIES) 
+tlsgnutls_test$(EXEEXT): $(tlsgnutls_test_OBJECTS) $(tlsgnutls_test_DEPENDENCIES) $(EXTRA_tlsgnutls_test_DEPENDENCIES) 
 	@rm -f tlsgnutls_test$(EXEEXT)
 	$(CXXLINK) $(tlsgnutls_test_OBJECTS) $(tlsgnutls_test_LDADD) $(LIBS)
 
@@ -375,10 +401,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/tlsgnutls/tlsgnutls_test.cpp'
--- src/tests/tlsgnutls/tlsgnutls_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/tlsgnutls/tlsgnutls_test.cpp	2014-01-16 10:42:06 +0000
@@ -188,7 +188,7 @@
   if( !t->handshake() )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -197,7 +197,7 @@
   if( t->send( text ) != text )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -206,7 +206,7 @@
   if( t->send( text ) != text )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -215,7 +215,7 @@
   if( t->send( text ) != text )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -224,7 +224,7 @@
   if( t->send( text ) != text )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -252,7 +252,7 @@
   }
   else
   {
-    printf( "TLSGnuTLS: %d test(s) failed\n", fail );
+    fprintf( stderr, "TLSGnuTLS: %d test(s) failed\n", fail );
     return 1;
   }
 }

=== modified file 'src/tests/uniquemucroomunique/Makefile.am'
--- src/tests/uniquemucroomunique/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/uniquemucroomunique/Makefile.am	2014-01-16 10:42:06 +0000
@@ -18,5 +18,6 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../instantmucroom.o ../../softwareversion.o
+			../../instantmucroom.o ../../softwareversion.o \
+			../../atomicrefcount.o
 uniquemucroomunique_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/uniquemucroomunique/Makefile.in'
--- src/tests/uniquemucroomunique/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/uniquemucroomunique/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,7 +85,7 @@
 	../../dataformreported.o ../../dataformitem.o \
 	../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o \
 	../../mucmessagesession.o ../../instantmucroom.o \
-	../../softwareversion.o
+	../../softwareversion.o ../../atomicrefcount.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -84,6 +101,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(uniquemucroomunique_test_SOURCES)
 DIST_SOURCES = $(uniquemucroomunique_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -106,6 +128,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -115,6 +138,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -130,7 +154,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -160,6 +186,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -194,7 +221,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -223,7 +249,8 @@
 			../../sha.o ../../error.o ../../clientbase.o ../../jid.o ../../dataform.o \
 			../../dataformfieldcontainer.o ../../dataformreported.o ../../dataformitem.o \
 			../../dataformfield.o ../../mucroom.o ../../delayeddelivery.o ../../mucmessagesession.o \
-			../../instantmucroom.o ../../softwareversion.o
+			../../instantmucroom.o ../../softwareversion.o \
+			../../atomicrefcount.o
 
 uniquemucroomunique_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -269,7 +296,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-uniquemucroomunique_test$(EXEEXT): $(uniquemucroomunique_test_OBJECTS) $(uniquemucroomunique_test_DEPENDENCIES) 
+uniquemucroomunique_test$(EXEEXT): $(uniquemucroomunique_test_OBJECTS) $(uniquemucroomunique_test_DEPENDENCIES) $(EXTRA_uniquemucroomunique_test_DEPENDENCIES) 
 	@rm -f uniquemucroomunique_test$(EXEEXT)
 	$(CXXLINK) $(uniquemucroomunique_test_OBJECTS) $(uniquemucroomunique_test_LDADD) $(LIBS)
 
@@ -404,10 +431,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/uniquemucroomunique/uniquemucroomunique_test.cpp'
--- src/tests/uniquemucroomunique/uniquemucroomunique_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/uniquemucroomunique/uniquemucroomunique_test.cpp	2014-01-16 10:42:06 +0000
@@ -24,7 +24,7 @@
     if( !t || t->xml() != "<unique xmlns='" + XMLNS_MUC_UNIQUE + "'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -42,7 +42,7 @@
        || uq.name() != "foo" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
   }
@@ -59,7 +59,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -68,7 +68,7 @@
   if( !fail )
     printf( "OK\n" );
   else
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
 
   return fail;
 }

=== modified file 'src/tests/util/Makefile.in'
--- src/tests/util/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/util/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,6 +82,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(util_test_SOURCES)
 DIST_SOURCES = $(util_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -87,6 +109,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -96,6 +119,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -111,7 +135,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -141,6 +167,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -175,7 +202,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -238,7 +264,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-util_test$(EXEEXT): $(util_test_OBJECTS) $(util_test_DEPENDENCIES) 
+util_test$(EXEEXT): $(util_test_OBJECTS) $(util_test_DEPENDENCIES) $(EXTRA_util_test_DEPENDENCIES) 
 	@rm -f util_test$(EXEEXT)
 	$(CXXLINK) $(util_test_OBJECTS) $(util_test_LDADD) $(LIBS)
 
@@ -373,10 +399,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/util/util_test.cpp'
--- src/tests/util/util_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/util/util_test.cpp	2014-01-16 10:42:06 +0000
@@ -17,7 +17,7 @@
   std::string name = "string lookup";
   if( util::lookup( "a", values ) != A )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -25,7 +25,7 @@
   name = "invalid string lookup";
   if( util::lookup( "", values ) != Inval )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -33,7 +33,7 @@
   name = "code lookup";
   if( util::lookup( A, values ) != "a" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -41,7 +41,7 @@
   name = "invalid code lookup";
   if( !util::lookup( Inval, values ).empty() )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -49,7 +49,7 @@
   name = "out-of-range code lookup";
   if( !util::lookup( 700, values ).empty() )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -57,7 +57,7 @@
   name = "string lookup (ORable)";
   if( util::lookup2( "d", values2 ) != D )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -65,7 +65,7 @@
   name = "invalid string lookup (ORable)";
   if( util::lookup2( "", values2 ) != Inval2 )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -73,7 +73,7 @@
   name = "code lookup (ORable)";
   if( util::lookup2( D, values2 ) != "d" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -81,7 +81,7 @@
   name = "invalid code lookup (ORable)";
   if( !util::lookup2( Inval2, values2 ).empty() )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -89,7 +89,7 @@
   name = "out-of-range code lookup (ORable)";
   if( !util::lookup2( 700, values2 ).empty() )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -97,7 +97,7 @@
   name = "string lookup w/ default";
   if( util::deflookup( "a", values, B ) != A )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -105,7 +105,7 @@
   name = "invalid string lookup w/ default";
   if( util::deflookup( "", values, B ) != B )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -113,7 +113,7 @@
   name = "code lookup w/ default";
   if( util::deflookup( A, values, "foo" ) != "a" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -121,7 +121,7 @@
   name = "invalid code lookup w/ default";
   if( util::deflookup( Inval, values, "foo" ) != "foo" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -129,7 +129,7 @@
   name = "out-of-range code lookup w/ default";
   if( util::deflookup( 700, values, "foo" ) != "foo" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -137,7 +137,7 @@
   name = "string lookup (ORable) w/ default";
   if( util::deflookup2( "d", values2, A ) != D )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -145,7 +145,7 @@
   name = "invalid string lookup (ORable) w/ default";
   if( util::deflookup2( "", values2, E ) != E )
   {
-    printf( "test '%s' failed: %d\n", name.c_str(), util::deflookup2( "", values2, E ) );
+    fprintf( stderr, "test '%s' failed: %d\n", name.c_str(), util::deflookup2( "", values2, E ) );
     ++fail;
   }
 
@@ -153,7 +153,7 @@
   name = "code lookup (ORable) w/ default";
   if( util::deflookup2( D, values2, "foo" ) != "d" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -161,7 +161,7 @@
   name = "invalid code lookup (ORable) w/ default";
   if( util::deflookup2( Inval2, values2, "foo" ) != "foo" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -169,7 +169,7 @@
   name = "out-of-range code lookup (ORable) w/ default";
   if( util::deflookup2( 700, values2, "foo" ) != "foo" )
   {
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
     ++fail;
   }
 
@@ -179,7 +179,7 @@
   std::string re = util::long2string( ex );
   if( "2147483647" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -189,7 +189,7 @@
   re = util::long2string( ex );
   if( "0" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -199,7 +199,7 @@
   re = util::long2string( ex );
   if( "-1" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -209,7 +209,7 @@
   re = util::long2string( ex );
   if( "1" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -219,7 +219,7 @@
   re = util::long2string( ex );
   if( "-2147483647" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -229,7 +229,7 @@
   re = util::long2string( ex );
   if( "-10" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -239,7 +239,7 @@
   re = util::long2string( ex );
   if( "11" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -249,7 +249,7 @@
   re = util::int2string( ex );
   if( "2147483647" != re )
   {
-    printf( "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
+    fprintf( stderr, "test '%s' failed, expected: %d, result: '%s'\n", name.c_str(), ex, re.c_str() );
     ++fail;
   }
 
@@ -263,7 +263,7 @@
   }
   else
   {
-    printf( "Util: %d test(s) failed\n", fail );
+    fprintf( stderr, "Util: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/vcard/Makefile.am'
--- src/tests/vcard/Makefile.am	2010-01-17 13:05:04 +0000
+++ src/tests/vcard/Makefile.am	2014-01-16 10:42:06 +0000
@@ -9,5 +9,5 @@
 vcard_test_SOURCES = vcard_test.cpp
 vcard_test_LDADD = ../../vcard.o ../../gloox.o ../../tag.o ../../util.o ../../iq.o \
                    ../../stanzaextensionfactory.o ../../base64.o ../../stanza.o \
-                   ../../jid.o ../../prep.o
+                   ../../jid.o ../../prep.o ../../mutex.o
 vcard_test_CFLAGS = $(CPPFLAGS)

=== modified file 'src/tests/vcard/Makefile.in'
--- src/tests/vcard/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/vcard/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -51,7 +68,8 @@
 vcard_test_OBJECTS = $(am_vcard_test_OBJECTS)
 vcard_test_DEPENDENCIES = ../../vcard.o ../../gloox.o ../../tag.o \
 	../../util.o ../../iq.o ../../stanzaextensionfactory.o \
-	../../base64.o ../../stanza.o ../../jid.o ../../prep.o
+	../../base64.o ../../stanza.o ../../jid.o ../../prep.o \
+	../../mutex.o
 DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
@@ -67,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(vcard_test_SOURCES)
 DIST_SOURCES = $(vcard_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -89,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -98,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -113,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -143,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -177,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -197,7 +224,7 @@
 vcard_test_SOURCES = vcard_test.cpp
 vcard_test_LDADD = ../../vcard.o ../../gloox.o ../../tag.o ../../util.o ../../iq.o \
                    ../../stanzaextensionfactory.o ../../base64.o ../../stanza.o \
-                   ../../jid.o ../../prep.o
+                   ../../jid.o ../../prep.o ../../mutex.o
 
 vcard_test_CFLAGS = $(CPPFLAGS)
 all: all-am
@@ -243,7 +270,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-vcard_test$(EXEEXT): $(vcard_test_OBJECTS) $(vcard_test_DEPENDENCIES) 
+vcard_test$(EXEEXT): $(vcard_test_OBJECTS) $(vcard_test_DEPENDENCIES) $(EXTRA_vcard_test_DEPENDENCIES) 
 	@rm -f vcard_test$(EXEEXT)
 	$(CXXLINK) $(vcard_test_OBJECTS) $(vcard_test_LDADD) $(LIBS)
 
@@ -378,10 +405,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/vcard/vcard_test.cpp'
--- src/tests/vcard/vcard_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/vcard/vcard_test.cpp	2014-01-16 10:42:06 +0000
@@ -24,7 +24,7 @@
     if( !t || t->xml() != "<vCard xmlns='" + XMLNS_VCARD_TEMP + "' version='3.0'/>" )
     {
       ++fail;
-      printf( "test '%s' failed\n", name.c_str() );
+      fprintf( stderr, "test '%s' failed\n", name.c_str() );
     }
     delete t;
     t = 0;
@@ -42,7 +42,7 @@
   if( se == 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete f;
 
@@ -55,7 +55,7 @@
   }
   else
   {
-    printf( "%d test(s) failed\n", fail );
+    fprintf( stderr, "%d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/vcardupdate/Makefile.in'
--- src/tests/vcardupdate/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/vcardupdate/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -66,6 +83,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(vcardupdate_test_SOURCES)
 DIST_SOURCES = $(vcardupdate_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -88,6 +110,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -97,6 +120,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -112,7 +136,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -142,6 +168,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -176,7 +203,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -239,7 +265,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-vcardupdate_test$(EXEEXT): $(vcardupdate_test_OBJECTS) $(vcardupdate_test_DEPENDENCIES) 
+vcardupdate_test$(EXEEXT): $(vcardupdate_test_OBJECTS) $(vcardupdate_test_DEPENDENCIES) $(EXTRA_vcardupdate_test_DEPENDENCIES) 
 	@rm -f vcardupdate_test$(EXEEXT)
 	$(CXXLINK) $(vcardupdate_test_OBJECTS) $(vcardupdate_test_LDADD) $(LIBS)
 
@@ -374,10 +400,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/vcardupdate/vcardupdate_test.cpp'
--- src/tests/vcardupdate/vcardupdate_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/vcardupdate/vcardupdate_test.cpp	2014-01-16 10:42:06 +0000
@@ -23,7 +23,7 @@
   if( d->tag() != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -34,7 +34,7 @@
   if( d->hash() != "invalidhash" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -47,7 +47,7 @@
        || !t->hasChild( "photo" ) || t->findChild( "photo" )->cdata() != "invalidhash" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -60,7 +60,7 @@
   if( d->hash() != "invalidhash" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   d = 0;
@@ -73,7 +73,7 @@
        || !t->hasChild( "photo" ) || t->findChild( "photo" )->cdata() != "invalidhash" )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
   delete d;
   delete t;
@@ -94,7 +94,7 @@
   }
   else
   {
-    printf( "VCardUpdate: %d test(s) failed\n", fail );
+    fprintf( stderr, "VCardUpdate: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/xpath/Makefile.in'
--- src/tests/xpath/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/xpath/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -65,6 +82,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(xpath_test_SOURCES)
 DIST_SOURCES = $(xpath_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -87,6 +109,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -96,6 +119,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -111,7 +135,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -141,6 +167,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -175,7 +202,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -238,7 +264,7 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-xpath_test$(EXEEXT): $(xpath_test_OBJECTS) $(xpath_test_DEPENDENCIES) 
+xpath_test$(EXEEXT): $(xpath_test_OBJECTS) $(xpath_test_DEPENDENCIES) $(EXTRA_xpath_test_DEPENDENCIES) 
 	@rm -f xpath_test$(EXEEXT)
 	$(CXXLINK) $(xpath_test_OBJECTS) $(xpath_test_LDADD) $(LIBS)
 
@@ -373,10 +399,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/xpath/xpath_test.cpp'
--- src/tests/xpath/xpath_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/xpath/xpath_test.cpp	2014-01-16 10:42:06 +0000
@@ -27,7 +27,7 @@
 //   if( !t || t->toString() != name )
 //   {
 //     ++fail;
-//     printf( "test 'lexer: %s' failed: %s\n", name.c_str(), t->toString().c_str() );
+//     fprintf( stderr, "test 'lexer: %s' failed: %s\n", name.c_str(), t->toString().c_str() );
 //   }
 //   printf( "str: %s\n", t->toString().c_str() );
 //   printf( "xml: %s\n", t->xml().c_str() );
@@ -77,7 +77,7 @@
 //   if( t != 0 )
 //   {
 //     ++fail;
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   delete t;
 
@@ -87,7 +87,7 @@
 //   if( t != 0 )
 //   {
 //     ++fail;
-//     printf( "test 'lexer: %s' failed\n", name.c_str() );
+//     fprintf( stderr, "test 'lexer: %s' failed\n", name.c_str() );
 //   }
 //   delete t;
 
@@ -177,7 +177,7 @@
   if( aaa->findTag( "/" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -185,7 +185,7 @@
   if( aaa->findTag( "//" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -193,7 +193,7 @@
   if( aaa->findTag( "aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -201,7 +201,7 @@
   if( aaa->findTag( "/aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -209,7 +209,7 @@
   if( aaa->findTag( "/aaa/bbb" ) != bbb )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -217,7 +217,7 @@
   if( aaa->findTag( "/aaa/ccc" ) != ccc )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -225,7 +225,7 @@
   if( aaa->findTag( "/aaa/ccc/ddd" ) != ddd )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -233,7 +233,7 @@
   if( aaa->findTag( "//aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -241,7 +241,7 @@
   if( aaa->findTag( "//eee" ) != eee )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -249,7 +249,7 @@
   if( aaa->findTag( "//bbb" ) != bbb )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -257,7 +257,7 @@
   if( bbb->findTag( "/aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -265,7 +265,7 @@
   if( aaa->findTag( "/abc" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -273,7 +273,7 @@
   if( aaa->findTag( "/bbb" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -281,7 +281,7 @@
   if( aaa->findTag( "aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -289,7 +289,7 @@
   if( bbb->findTag( "bbb" ) != bbb )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -300,7 +300,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -311,7 +311,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -324,7 +324,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -334,7 +334,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -345,7 +345,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -357,7 +357,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -367,7 +367,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -377,7 +377,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -387,7 +387,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -397,7 +397,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -408,7 +408,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -419,7 +419,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -430,7 +430,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -441,7 +441,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -452,7 +452,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -463,7 +463,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 //   printf( "--------------------------------------------------------------\n" );
@@ -476,7 +476,7 @@
 //   {
 //     ++fail;
 //     printResult( name, result );
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -488,7 +488,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -499,7 +499,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -510,7 +510,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -523,7 +523,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -534,7 +534,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -553,7 +553,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -565,7 +565,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -577,7 +577,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -589,7 +589,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -602,7 +602,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -614,7 +614,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -635,7 +635,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -647,7 +647,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -659,7 +659,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -671,7 +671,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -683,7 +683,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -695,7 +695,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -707,7 +707,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -719,7 +719,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -731,7 +731,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -743,7 +743,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -755,7 +755,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "deepsearch + predicate + literal 2: //bbb[@name='test@test2']";
@@ -766,7 +766,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -778,7 +778,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -790,7 +790,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -801,7 +801,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -813,7 +813,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -824,7 +824,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -836,7 +836,7 @@
 //   {
 //     ++fail;
 //     printResult( name, result );
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -848,7 +848,7 @@
 //   {
 //     ++fail;
 //     printResult( name, result );
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -863,7 +863,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -872,7 +872,7 @@
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -935,7 +935,7 @@
   }
   else
   {
-    printf( "XPath: %d test(s) failed\n", fail );
+    fprintf( stderr, "XPath: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tests/zlib/Makefile.in'
--- src/tests/zlib/Makefile.in	2010-01-17 13:05:04 +0000
+++ src/tests/zlib/Makefile.in	2014-01-16 10:42:06 +0000
@@ -1,9 +1,9 @@
-# Makefile.in generated by automake 1.11 from Makefile.am.
+# Makefile.in generated by automake 1.11.6 from Makefile.am.
 # @configure_input@
 
 # Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005, 2006, 2007, 2008, 2009  Free Software Foundation,
-# Inc.
+# 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
+# Foundation, Inc.
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.
@@ -16,6 +16,23 @@
 @SET_MAKE@
 
 VPATH = @srcdir@
+am__make_dryrun = \
+  { \
+    am__dry=no; \
+    case $$MAKEFLAGS in \
+      *\\[\ \	]*) \
+        echo 'am--echo: ; @echo "AM"  OK' | $(MAKE) -f - 2>/dev/null \
+          | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+      *) \
+        for am__flg in $$MAKEFLAGS; do \
+          case $$am__flg in \
+            *=*|--*) ;; \
+            *n*) am__dry=yes; break;; \
+          esac; \
+        done;; \
+    esac; \
+    test $$am__dry = yes; \
+  }
 pkgdatadir = $(datadir)/@PACKAGE@
 pkgincludedir = $(includedir)/@PACKAGE@
 pkglibdir = $(libdir)/@PACKAGE@
@@ -68,6 +85,11 @@
 	$(LDFLAGS) -o $@
 SOURCES = $(zlib_perf_SOURCES) $(zlib_test_SOURCES)
 DIST_SOURCES = $(zlib_perf_SOURCES) $(zlib_test_SOURCES)
+am__can_run_installinfo = \
+  case $$AM_UPDATE_INFO_DIR in \
+    n|no|NO) false;; \
+    *) (install-info --version) >/dev/null 2>&1;; \
+  esac
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -90,6 +112,7 @@
 CYGPATH_W = @CYGPATH_W@
 DEFS = @DEFS@
 DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
 DSYMUTIL = @DSYMUTIL@
 DUMPBIN = @DUMPBIN@
 ECHO_C = @ECHO_C@
@@ -99,6 +122,7 @@
 EXEEXT = @EXEEXT@
 FGREP = @FGREP@
 GREP = @GREP@
+HAVE_GCC_ATOMIC_BUILTINS = @HAVE_GCC_ATOMIC_BUILTINS@
 INSTALL = @INSTALL@
 INSTALL_DATA = @INSTALL_DATA@
 INSTALL_PROGRAM = @INSTALL_PROGRAM@
@@ -114,7 +138,9 @@
 LN_S = @LN_S@
 LTLIBOBJS = @LTLIBOBJS@
 MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
 MAYBE_EXAMPLES = @MAYBE_EXAMPLES@
+MAYBE_LIB_mdns = @MAYBE_LIB_mdns@
 MAYBE_TESTS = @MAYBE_TESTS@
 MKDIR_P = @MKDIR_P@
 NM = @NM@
@@ -144,6 +170,7 @@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CXX = @ac_ct_CXX@
 ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
@@ -178,7 +205,6 @@
 libexecdir = @libexecdir@
 localedir = @localedir@
 localstatedir = @localstatedir@
-lt_ECHO = @lt_ECHO@
 mandir = @mandir@
 mkdir_p = @mkdir_p@
 oldincludedir = @oldincludedir@
@@ -244,10 +270,10 @@
 	list=`for p in $$list; do echo "$$p"; done | sed 's/$(EXEEXT)$$//'`; \
 	echo " rm -f" $$list; \
 	rm -f $$list
-zlib_perf$(EXEEXT): $(zlib_perf_OBJECTS) $(zlib_perf_DEPENDENCIES) 
+zlib_perf$(EXEEXT): $(zlib_perf_OBJECTS) $(zlib_perf_DEPENDENCIES) $(EXTRA_zlib_perf_DEPENDENCIES) 
 	@rm -f zlib_perf$(EXEEXT)
 	$(CXXLINK) $(zlib_perf_OBJECTS) $(zlib_perf_LDADD) $(LIBS)
-zlib_test$(EXEEXT): $(zlib_test_OBJECTS) $(zlib_test_DEPENDENCIES) 
+zlib_test$(EXEEXT): $(zlib_test_OBJECTS) $(zlib_test_DEPENDENCIES) $(EXTRA_zlib_test_DEPENDENCIES) 
 	@rm -f zlib_test$(EXEEXT)
 	$(CXXLINK) $(zlib_test_OBJECTS) $(zlib_test_LDADD) $(LIBS)
 
@@ -383,10 +409,15 @@
 
 installcheck: installcheck-am
 install-strip:
-	$(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
-	  install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
-	  `test -z '$(STRIP)' || \
-	    echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+	if test -z '$(STRIP)'; then \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	      install; \
+	else \
+	  $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+	    install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+	    "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+	fi
 mostlyclean-generic:
 
 clean-generic:

=== modified file 'src/tests/zlib/zlib_test.cpp'
--- src/tests/zlib/zlib_test.cpp	2010-01-17 13:05:04 +0000
+++ src/tests/zlib/zlib_test.cpp	2014-01-16 10:42:06 +0000
@@ -53,7 +53,7 @@
   if( t.data() != a )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -63,7 +63,7 @@
   if( t.data() != b )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -73,7 +73,7 @@
   if( t.data() != c )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -83,7 +83,7 @@
   if( t.data() != d )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -95,7 +95,7 @@
   if( t.data() != a + b + c + d )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 
@@ -114,7 +114,7 @@
   }
   else
   {
-    printf( "CompressionZlib: %d test(s) failed\n", fail );
+    fprintf( stderr, "CompressionZlib: %d test(s) failed\n", fail );
     return 1;
   }
 

=== modified file 'src/tlsbase.h'
--- src/tlsbase.h	2010-01-17 13:05:04 +0000
+++ src/tlsbase.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -61,7 +61,7 @@
       /**
        * Enables/disables initialization of the underlying TLS library. By default,
        * initialization is performed. You may want to switch it off if the TLS library
-       * is used elsewhere in your applicationas well and you have no control over the
+       * is used elsewhere in your application as well and you have no control over the
        * initialization.
        * @param init Whether or not to intialize the underlying TLS library.
        */
@@ -105,6 +105,18 @@
       virtual bool isSecure() const { return m_secure; }
 
       /**
+       * This function indicates whether the underlying TLS implementation supports channel binding (used in e.g. SASL SCRAM-SHA-1-PLUS).
+       * @return @b True if channel binding is supported, @b false otherwise.
+       */
+      virtual bool hasChannelBinding() const { return false; }
+
+      /**
+       * Returns the channel binding data for the established connection.
+       * @return The channel binding data, if any, or the empty string.
+       */
+      virtual const std::string channelBinding() const { return EmptyString; }
+
+      /**
        * Use this function to set a number of trusted root CA certificates which shall be
        * used to verify a servers certificate.
        * @param cacerts A list of absolute paths to CA root certificate files in PEM format.

=== modified file 'src/tlsdefault.cpp'
--- src/tlsdefault.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsdefault.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license
@@ -126,6 +126,16 @@
     return m_impl ? m_impl->isSecure() : false;
   }
 
+  bool TLSDefault::hasChannelBinding() const
+  {
+    return m_impl ? m_impl->hasChannelBinding() : false;
+  }
+
+  const std::string TLSDefault::channelBinding() const
+  {
+    return m_impl ? m_impl->channelBinding() : EmptyString;
+  }
+
   void TLSDefault::setCACerts( const StringList& cacerts )
   {
     if( m_impl )

=== modified file 'src/tlsdefault.h'
--- src/tlsdefault.h	2010-01-17 13:05:04 +0000
+++ src/tlsdefault.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license
@@ -82,6 +82,12 @@
       virtual bool isSecure() const;
 
       // reimplemented from TLSBase
+      virtual bool hasChannelBinding() const;
+
+      // reimplemented from TLSBase
+      virtual const std::string channelBinding() const;
+
+      // reimplemented from TLSBase
       virtual void setCACerts( const StringList& cacerts );
 
       // reimplemented from TLSBase

=== modified file 'src/tlsgnutlsbase.cpp'
--- src/tlsgnutlsbase.cpp	2014-01-16 01:11:18 +0000
+++ src/tlsgnutlsbase.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -19,6 +19,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
+#include <cstdio>
 
 #include <cstdlib>
 #include <cstring>
@@ -100,12 +101,13 @@
     gnutls_bye( *m_session, GNUTLS_SHUT_RDWR );
     gnutls_db_remove_session( *m_session );
     gnutls_credentials_clear( *m_session );
-    if( m_secure )
+    if( m_session )
       gnutls_deinit( *m_session );
 
+    delete m_session;
+
     m_secure = false;
     m_valid = false;
-    delete m_session;
     m_session = 0;
     m_session = new gnutls_session_t;
     m_handler = handler;
@@ -142,6 +144,28 @@
     return true;
   }
 
+  bool GnuTLSBase::hasChannelBinding() const
+  {
+#ifdef HAVE_GNUTLS_SESSION_CHANNEL_BINDING
+    return true;
+#else
+    return false;
+#endif
+  }
+
+  const std::string GnuTLSBase::channelBinding() const
+  {
+#ifdef HAVE_GNUTLS_SESSION_CHANNEL_BINDING
+    gnutls_datum_t cb;
+    int rc;
+    rc = gnutls_session_channel_binding( *m_session, GNUTLS_CB_TLS_UNIQUE, &cb );
+    if( !rc )
+      return std::string( (char*)cb.data, cb.size );
+    else
+#endif
+      return EmptyString;
+  }
+
   ssize_t GnuTLSBase::pullFunc( void* data, size_t len )
   {
     ssize_t cpy = ( len > m_recvBuffer.length() ) ? ( m_recvBuffer.length() ) : ( len );

=== modified file 'src/tlsgnutlsbase.h'
--- src/tlsgnutlsbase.h	2010-01-17 13:05:04 +0000
+++ src/tlsgnutlsbase.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -63,6 +63,12 @@
       virtual bool handshake();
 
       // reimplemented from TLSBase
+      virtual bool hasChannelBinding() const;
+
+      // reimplemented from TLSBase
+      virtual const std::string channelBinding() const;
+
+      // reimplemented from TLSBase
       virtual void setCACerts( const StringList& /*cacerts*/ ) {}
 
       // reimplemented from TLSBase

=== modified file 'src/tlsgnutlsclient.cpp'
--- src/tlsgnutlsclient.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsgnutlsclient.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -18,6 +18,12 @@
 
 #include <errno.h>
 
+#ifdef HAVE_PTHREAD
+extern "C" {
+GCRY_THREAD_OPTION_PTHREAD_IMPL;
+}
+#endif
+
 namespace gloox
 {
 
@@ -33,13 +39,17 @@
   void GnuTLSClient::cleanup()
   {
     GnuTLSBase::cleanup();
+    if( m_credentials )
+      gnutls_certificate_free_credentials( m_credentials );
     init();
   }
 
-  bool GnuTLSClient::init( const std::string& clientKey,
-                           const std::string& clientCerts,
-                           const StringList& cacerts )
+  bool GnuTLSClient::init( const std::string& /*clientKey*/,
+                           const std::string& /*clientCerts*/,
+                           const StringList& /*cacerts*/ )
   {
+    gcry_control( GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread );
+
     const int protocolPriority[] = {
 #ifdef GNUTLS_TLS1_2
       GNUTLS_TLS1_2,
@@ -119,10 +129,12 @@
     if( status & GNUTLS_CERT_SIGNER_NOT_CA )
       m_certInfo.status |= CertSignerNotCa;
     const gnutls_datum_t* certList = 0;
-    unsigned int certListSize;
+    unsigned int certListSize = 0;
     if( !error && ( ( certList = gnutls_certificate_get_peers( *m_session, &certListSize ) ) == 0 ) )
       error = true;
 
+    unsigned int certListSizeFull = certListSize;
+
     gnutls_x509_crt_t* cert = new gnutls_x509_crt_t[certListSize+1];
     for( unsigned int i=0; !error && ( i<certListSize ); ++i )
     {
@@ -189,7 +201,7 @@
     if( !gnutls_x509_crt_check_hostname( cert[0], m_server.c_str() ) )
       m_certInfo.status |= CertWrongPeer;
 
-    for( unsigned int i = 0; i < certListSize; ++i )
+    for( unsigned int i = 0; i < certListSizeFull; ++i )
       gnutls_x509_crt_deinit( cert[i] );
 
     delete[] cert;

=== modified file 'src/tlsgnutlsclient.h'
--- src/tlsgnutlsclient.h	2010-01-17 13:05:04 +0000
+++ src/tlsgnutlsclient.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -23,6 +23,7 @@
 
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
+#include <gcrypt.h>
 
 namespace gloox
 {

=== modified file 'src/tlsgnutlsclientanon.cpp'
--- src/tlsgnutlsclientanon.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsgnutlsclientanon.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlsgnutlsclientanon.h'
--- src/tlsgnutlsclientanon.h	2010-01-17 13:05:04 +0000
+++ src/tlsgnutlsclientanon.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlsgnutlsserveranon.cpp'
--- src/tlsgnutlsserveranon.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsgnutlsserveranon.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlsgnutlsserveranon.h'
--- src/tlsgnutlsserveranon.h	2010-01-17 13:05:04 +0000
+++ src/tlsgnutlsserveranon.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlshandler.h'
--- src/tlshandler.h	2010-01-17 13:05:04 +0000
+++ src/tlshandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlsopensslbase.cpp'
--- src/tlsopensslbase.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsopensslbase.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlsopensslbase.h'
--- src/tlsopensslbase.h	2010-01-17 13:05:04 +0000
+++ src/tlsopensslbase.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlsopensslclient.cpp'
--- src/tlsopensslclient.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsopensslclient.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -37,6 +37,18 @@
     return true;
   }
 
+  bool OpenSSLClient::hasChannelBinding() const
+  {
+    return true;
+  }
+
+  const std::string OpenSSLClient::channelBinding() const
+  {
+    unsigned char* buf[128];
+    int res = SSL_get_finished( m_ssl, buf, 128 );
+    return std::string( (char*)buf, res );
+  }
+
   int OpenSSLClient::handshakeFunction()
   {
     return SSL_connect( m_ssl );

=== modified file 'src/tlsopensslclient.h'
--- src/tlsopensslclient.h	2010-01-17 13:05:04 +0000
+++ src/tlsopensslclient.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -47,7 +47,13 @@
        */
       virtual ~OpenSSLClient();
 
-    private:
+      // reimplemented from TLSBase
+      virtual bool hasChannelBinding() const;
+
+      // reimplemented from TLSBase
+      virtual const std::string channelBinding() const;
+
+  private:
       // reimplemented from OpenSSLBase
       virtual bool setType();
 

=== modified file 'src/tlsopensslserver.cpp'
--- src/tlsopensslserver.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsopensslserver.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -254,7 +254,6 @@
   {
     SSL_CTX_set_tmp_rsa_callback( m_ctx, tmp_rsa_callback );
     SSL_CTX_set_tmp_dh_callback( m_ctx, tmp_dh_callback );
-    SSL_CTX_set_tmp_ecdh( m_ctx, EC_KEY_new_by_curve_name( NID_sect163r2 ) );
     SSL_CTX_set_options( m_ctx, SSL_OP_CIPHER_SERVER_PREFERENCE );
     return true;
   }

=== modified file 'src/tlsopensslserver.h'
--- src/tlsopensslserver.h	2010-01-17 13:05:04 +0000
+++ src/tlsopensslserver.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2009-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/tlsschannel.cpp'
--- src/tlsschannel.cpp	2010-01-17 13:05:04 +0000
+++ src/tlsschannel.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license
@@ -465,6 +465,27 @@
     while( true );
   }
 
+  bool SChannel::hasChannelBinding() const
+  {
+#ifdef HAVE_WINTLS_CHANNEL_BINDING
+    return true;
+#else
+    return false;
+#endif
+  }
+
+  const std::string SChannel::channelBinding() const
+  {
+#ifdef HAVE_WINTLS_CHANNEL_BINDING // see ../config.h.win if the following doesn't compile
+    SecPkgContext_Bindings buf;
+    if( QueryContextAttributes( &m_context, SECPKG_ATTR_UNIQUE_BINDINGS, &buf ) == SEC_E_OK )
+    {
+      return std::string( buf->Bindings[buf->Bindings.dwApplicationDataOffset], buf->Bindings.cbApplicationDataLength );
+    }
+#endif
+    return EmptyString;
+  }
+
   void SChannel::setCACerts( const StringList& /*cacerts*/ ) {}
 
   void SChannel::setClientCert( const std::string& /*clientKey*/, const std::string& /*clientCerts*/ ) {}

=== modified file 'src/tlsschannel.h'
--- src/tlsschannel.h	2010-01-17 13:05:04 +0000
+++ src/tlsschannel.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license
@@ -69,6 +69,12 @@
       virtual bool handshake();
 
       // reimplemented from TLSBase
+      virtual bool hasChannelBinding() const;
+
+      // reimplemented from TLSBase
+      virtual const std::string channelBinding() const;
+
+      // reimplemented from TLSBase
       virtual void setCACerts( const StringList& cacerts );
 
       // reimplemented from TLSBase

=== modified file 'src/uniquemucroom.cpp'
--- src/uniquemucroom.cpp	2010-01-17 13:05:04 +0000
+++ src/uniquemucroom.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/uniquemucroom.h'
--- src/uniquemucroom.h	2010-01-17 13:05:04 +0000
+++ src/uniquemucroom.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/util.cpp'
--- src/util.cpp	2010-01-17 13:05:04 +0000
+++ src/util.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -13,6 +13,8 @@
 #include "util.h"
 #include "gloox.h"
 
+#include <cstdio>
+
 namespace gloox
 {
 
@@ -55,10 +57,21 @@
       return i < size ? std::string( values[i] ) : def;
     }
 
+    std::string hex( const std::string& input )
+    {
+      const char* H = input.c_str();
+      char* buf = new char[input.length() * 2 + 1];
+      for( unsigned int i = 0; i < input.length(); ++i )
+        sprintf( buf + i * 2, "%02x", (unsigned char)( H[i] ) );
+      return std::string( buf, 40 );
+    }
+
     static const char escape_chars[] = { '&', '<', '>', '\'', '"' };
 
     static const std::string escape_seqs[] = { "amp;", "lt;", "gt;", "apos;", "quot;" };
 
+    static const std::string escape_seqs_full[] = { "&amp;", "&lt;", "&gt;", "&apos;", "&quot;" };
+
     static const unsigned escape_size = 5;
 
     const std::string escape( std::string what )
@@ -79,23 +92,86 @@
       return what;
     }
 
+    void appendEscaped( std::string& target, const std::string& data )
+    {
+      size_t rangeStart = 0, rangeCount = 0;
+      size_t length = data.length();
+      const char* dataPtr = data.data();
+      for( size_t val, i = 0; i < length; ++i )
+      {
+        const char current = dataPtr[i];
+        for( val = 0; val < escape_size; ++val )
+        {
+          if( current == escape_chars[val] )
+          {
+            // We have a character that needs to be escaped.
+            if( rangeCount > 0 )
+            {
+              // We have a range of the data that needs to be appended
+              // before we escape the current character.
+              // NOTE: Use "data" (std::string) here not dataPtr (const char*).
+              //  Both have the same content, but there isn't
+              //  an append override that takes const char*, pos, n
+              //  (so a temporary std::string would be created)
+              target.append( data, rangeStart, rangeCount );
+            }
+            target.append( escape_seqs_full[val] );
+            rangeStart = i + 1;
+            rangeCount = 0;
+            break;
+          }
+        }
+
+        if( rangeStart <= i )
+        {
+          // current did not need to be escaped
+          ++rangeCount;
+        }
+      }
+
+      if( rangeCount > 0 )
+      {
+        // Append the remaining pending range of data that does
+        // not need to be escaped.
+        // NOTE: See previous comment on using data not dataPtr for append.
+        target.append( data, rangeStart, rangeCount );
+      }
+    }
+
     bool checkValidXMLChars( const std::string& data )
     {
       if( data.empty() )
         return true;
 
-      std::string::const_iterator it = data.begin();
-      for( ; it != data.end()
-             && ( (unsigned char)(*it) == 0x09
-                  || (unsigned char)(*it) == 0x0a
-                  || (unsigned char)(*it) == 0x0d
-                  || ( (unsigned char)(*it) >= 0x20
-                     && (unsigned char)(*it) != 0xc0
-                     && (unsigned char)(*it) != 0xc1
-                     && (unsigned char)(*it) < 0xf5 ) ); ++it )
-        ;
+      const char* dataPtr = data.data();
+      const char* end = dataPtr + data.length();
+      for( ; dataPtr != end; ++dataPtr )
+      {
+        unsigned char current = (unsigned char) *dataPtr;
+        if( current < 0x20 )
+        {
+          if( current == 0x09
+              || current == 0x0a
+              || current == 0x0d )
+            // Valid character
+            continue;
+          else
+            // Invalid character
+            break;
+        }
+        else if( current >= 0xf5 )
+          // Invalid character
+          break;
+        else if( current == 0xc0
+                 || current == 0xc1 )
+          // Invalid character
+          break;
+        else
+          // Valid character
+          continue;
+      }
 
-      return ( it == data.end() );
+      return ( dataPtr == end );
     }
 
     void replaceAll( std::string& target, const std::string& find, const std::string& replace )

=== modified file 'src/util.h'
--- src/util.h	2010-01-17 13:05:04 +0000
+++ src/util.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -20,6 +20,7 @@
 #include <string>
 #include <list>
 #include <map>
+#include <cstdlib>
 
 namespace gloox
 {
@@ -80,6 +81,13 @@
                                 unsigned size, const std::string& def = EmptyString );
 
     /**
+     * Returns the input string in hex notation.
+     * @param input The (binary) input string.
+     * @return The input string in hex notation.
+     */
+    std::string hex( const std::string& input );
+
+    /**
      * A convenience function that executes the given function on each object in a given list.
      * @param t The object to execute the function on.
      * @param f The function to execute.
@@ -190,12 +198,25 @@
 
     /**
      * Does some fancy escaping. (& --> &amp;amp;, etc).
+     * @note If you intend to append the result of escape
+     *  to another string, use the faster appendEscaped.
      * @param what A string to escape.
      * @return The escaped string.
      */
     GLOOX_API const std::string escape( std::string what );
 
     /**
+     * Append the data to the target, doing any necessary escaping
+     * along the way (& --> &amp;amp;, etc).
+     * This method is faster than calling "escape" and appending the
+     * return value, especially for source strings that don't need
+     * any escaping.
+     * @param target The string to append the data to.
+     * @param data The string to append that might need escaping.
+     */
+    GLOOX_API void appendEscaped( std::string& target, const std::string& data );
+
+    /**
      * Checks whether the given input is valid UTF-8.
      * @param data The data to check for validity.
      * @return @@b True if the input is valid UTF-8, @b false otherwise.
@@ -228,28 +249,25 @@
      */
     static inline const std::string long2string( long int value, const int base = 10 )
     {
-      int add = 0;
       if( base < 2 || base > 16 || value == 0 )
         return "0";
-      else if( value < 0 )
+
+      std::string output;
+      std::string sign;
+
+      if( value < 0 )
       {
-        ++add;
+        sign += "-";
         value = -value;
       }
-      int len = (int)( log( (double)( value ? value : 1 ) ) / log( (double)base ) ) + 1;
-      const char digits[] = "0123456789ABCDEF";
-      char* num = (char*)calloc( len + 1 + add, sizeof( char ) );
-      num[len--] = '\0';
-      if( add )
-        num[0] = '-';
-      while( value && len > -1 )
+
+      while( output.empty() || value > 0 )
       {
-        num[len-- + add] = digits[(int)( value % base )];
+        output.insert( 0, 1, static_cast<char>( value % base + '0' ) );
         value /= base;
       }
-      const std::string result( num );
-      free( num );
-      return result;
+
+      return sign + output;
     }
 
     /**

=== modified file 'src/vcard.cpp'
--- src/vcard.cpp	2010-01-17 13:05:04 +0000
+++ src/vcard.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -236,7 +236,7 @@
     m_N = true;
   }
 
-  void VCard::setPhoto( const std::string& extval )
+  void VCard::setPhotoUri( const std::string& extval )
   {
     if( !extval.empty() )
     {

=== modified file 'src/vcard.h'
--- src/vcard.h	2010-01-17 13:05:04 +0000
+++ src/vcard.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -39,7 +39,7 @@
        * @note @c AddrTypeDom and @c AddrTypeIntl are mutually exclusive. If both are present,
        * @c AddrTypeDom takes precendence.
        * @note Also note that not all adress types are applicable everywhere. For example,
-       * @c AddrTypeIsdn does not make sense for a postal address. Check XEP-0054
+       * @c AddrTypeIsdn does not make sense for a postal address. Check @xep{0054}
        * for details.
        */
       enum AddressType
@@ -428,7 +428,7 @@
        * Sets a URI to a photo.
        * @param extval The URI to the photo.
        */
-      void setPhoto( const std::string& extval );
+      void setPhotoUri( const std::string& extval );
 
       /**
        * Sets the photo directly.
@@ -475,7 +475,7 @@
        * Returns a list of email addresses.
        * @return A list of email addresses.
        */
-      EmailList& emailAddresses() { return m_emailList; }
+      const EmailList& emailAddresses() const { return m_emailList; }
 
       /**
        * Adds an address.
@@ -504,13 +504,13 @@
        * Returns a list of addresses.
        * @return A list of addresses.
        */
-      AddressList& addresses() { return m_addressList; }
+      const AddressList& addresses() const { return m_addressList; }
 
       /**
        * Returns a list of address labels.
        * @return A list of address labels.
        */
-      LabelList& labels() { return m_labelList; }
+      const LabelList& labels() const { return m_labelList; }
 
       /**
        * Adds a telephone number.
@@ -523,7 +523,7 @@
        * Returns a list of telephone numbers.
        * @return A list of telephone numbers.
        */
-      TelephoneList& telephone() { return m_telephoneList; }
+      const TelephoneList& telephone() const { return m_telephoneList; }
 
       /**
        * Sets "Geographical position. Values are the decimal degrees of
@@ -562,7 +562,7 @@
        * Returns information about classification.
        * @return Info about the classification.
        */
-      VCardClassification classification() const { return m_class; }
+      const VCardClassification& classification() const { return m_class; }
 
       // reimplemented from StanzaExtension
       virtual const std::string& filterString() const;

=== modified file 'src/vcardhandler.h'
--- src/vcardhandler.h	2010-01-17 13:05:04 +0000
+++ src/vcardhandler.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/vcardmanager.cpp'
--- src/vcardmanager.cpp	2010-01-17 13:05:04 +0000
+++ src/vcardmanager.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license

=== modified file 'src/vcardmanager.h'
--- src/vcardmanager.h	2010-01-17 13:05:04 +0000
+++ src/vcardmanager.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -72,7 +72,7 @@
    * @section sec_store Storing one's own VCard
    *
    * @note Some, if not many, servers do not implement support for all the fields specified
-   * in XEP-0054. Therefore it is possible that you cannot retrieve fields you stored previously.
+   * in @xep{0054}. Therefore it is possible that you cannot retrieve fields you stored previously.
    *
    * Similar to the above, you need a VCardManager and a VCardHandler. Then construct
    * your VCard and call storeVCard().

=== modified file 'src/vcardupdate.cpp'
--- src/vcardupdate.cpp	2010-01-17 13:05:04 +0000
+++ src/vcardupdate.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -19,24 +19,21 @@
 
   VCardUpdate::VCardUpdate()
     : StanzaExtension( ExtVCardUpdate ),
-      m_notReady( true ), m_noImage( true ), m_valid( true )
+      m_notReady( true ), m_noImage( true ), m_valid( true ), m_hasPhoto( false )
   {
   }
 
   VCardUpdate::VCardUpdate( const std::string& hash )
     : StanzaExtension( ExtVCardUpdate ),
-      m_hash( hash ), m_notReady( false ), m_noImage( false ), m_valid( true )
+      m_hash( hash ), m_notReady( false ), m_noImage( false ), m_valid( true ), m_hasPhoto( false )
   {
     if( m_hash.empty() )
-    {
       m_noImage = true;
-      m_valid = false;
-    }
   }
 
   VCardUpdate::VCardUpdate( const Tag* tag )
     : StanzaExtension( ExtVCardUpdate ),
-      m_notReady( true ), m_noImage( true ), m_valid( false )
+      m_notReady( true ), m_noImage( true ), m_valid( false ), m_hasPhoto( false )
   {
     if( tag && tag->name() == "x" && tag->hasAttribute( XMLNS, XMLNS_X_VCARD_UPDATE ) )
     {
@@ -44,6 +41,9 @@
       if( tag->hasChild( "photo" ) )
       {
         m_notReady = false;
+        if( tag->hasChild( "photo" ) )
+          m_hasPhoto = true;
+
         m_hash = tag->findChild( "photo" )->cdata();
         if( !m_hash.empty() )
           m_noImage = false;

=== modified file 'src/vcardupdate.h'
--- src/vcardupdate.h	2010-01-17 13:05:04 +0000
+++ src/vcardupdate.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -25,7 +25,7 @@
   class Tag;
 
   /**
-   * @brief This is an abstraction of a vcard-temp:x:update namespace element, as used in XEP-0153
+   * @brief This is an abstraction of a vcard-temp:x:update namespace element, as used in @xep{0153}
    * (vCard-Based Avatars).
    *
    * XEP version: 1.0
@@ -63,6 +63,16 @@
        * @return The avatar's SHA hash.
        */
       const std::string& hash() const { return m_hash; }
+      
+      /**
+       * Indicates whether the VCard update contained a @c photo tag
+       * (which might have been empty).
+       * This function is only useful for incoming VCardUpdate objects.
+       * @return @b True if the VCard update contained a @c photo
+       * tag (empty or non-empty), @b false otherwise.
+       * @since 1.0.3
+       */
+      bool hasPhoto() { return m_hasPhoto; }
 
       // reimplemented from StanzaExtension
       virtual const std::string& filterString() const;
@@ -87,6 +97,7 @@
       bool m_notReady;
       bool m_noImage;
       bool m_valid;
+      bool m_hasPhoto;
 
   };
 

=== modified file 'src/version.rc'
--- src/version.rc	2010-01-17 13:05:04 +0000
+++ src/version.rc	2014-01-16 10:42:06 +0000
@@ -2,8 +2,8 @@
 
 
 VS_VERSION_INFO VERSIONINFO
-  FILEVERSION    1,0,0,0
-  PRODUCTVERSION 1,0,0,0
+  FILEVERSION    1,0,9,0
+  PRODUCTVERSION 1,0,9,0
   FILEFLAGSMASK  VS_FFI_FILEFLAGSMASK
   FILEFLAGS      0
   FILEOS         VOS__WINDOWS32
@@ -14,13 +14,13 @@
         BLOCK "040904b0"
         BEGIN
             VALUE "FileDescription", "gloox Jabber/XMPP library\0"
-            VALUE "ProductVersion", "1.0\0"
-            VALUE "FileVersion", "1.0\0"
+            VALUE "ProductVersion", "1.0.9\0"
+            VALUE "FileVersion", "1.0.9\0"
             VALUE "InternalName", "gloox\0"
             VALUE "OriginalFilename", "gloox.dll\0"
             VALUE "CompanyName", "Jakob Schroeter\0"
-            VALUE "LegalCopyright", "Copyright (C) 2004-2009 Jakob Schroeter\0"
-            VALUE "Licence", "GPL\0"
+            VALUE "LegalCopyright", "Copyright (C) 2004-2013 Jakob Schroeter\0"
+            VALUE "Licence", "GPLv3\0"
             VALUE "Info", "http://camaya.net/gloox\0"
         END
     END

=== modified file 'src/xhtmlim.cpp'
--- src/xhtmlim.cpp	2010-01-17 13:05:04 +0000
+++ src/xhtmlim.cpp	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -50,7 +50,7 @@
   {
     XHtmlIM* x = new XHtmlIM();
     x->m_xhtml = m_xhtml ? m_xhtml->clone() : 0;
-    return 0;
+    return x;
   }
 
 }

=== modified file 'src/xhtmlim.h'
--- src/xhtmlim.h	2010-01-17 13:05:04 +0000
+++ src/xhtmlim.h	2014-01-16 10:42:06 +0000
@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2007-2013 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -26,7 +26,7 @@
   class Tag;
 
   /**
-   * @brief This is a wrapper of an XHTML-IM (XEP-0071) message body.
+   * @brief This is a wrapper of an XHTML-IM (@xep{0071}) message body.
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 1.0

